(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3069255,      95934]*)
(*NotebookOutlinePosition[   3069953,      95959]*)
(*  CellTagsIndexPosition[   3069909,      95955]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The n-Queens problem", "Title"],

Cell[TextData[{
  "Implementation of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programs of I. Vardi"
}], "Subtitle"],

Cell["\<\
Bernd Fiedler
Leipzig, September 2000\
\>", "Subtitle"],

Cell["\<\
Bernd Fiedler, Alfred-Rosch-Str. 13, D-04249 Leipzig, Germany\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["The problem", "Section"],

Cell[TextData[StyleBox["Problem 1:",
  FontWeight->"Bold"]], "Text"],

Cell["\<\
We search for all allowed posibilities to place n queens on an \
(n\[Times]n)-board.\
\>", "Text"],

Cell["Problem 2:", "Text",
  FontWeight->"Bold"],

Cell["\<\
We want to determine the number of all solutions of problem 1 for a given \
n.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell[TextData[{
  "[1] Vardi, I., Computational Recreations in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", Addison-Wesley, Redwood City, Menlo Park, Reading, 1991."
}], "Text"],

Cell["\<\
[2] Aigner, M., Diskrete Mathematik, Braunschweig, Wiesbaden, Vieweg, 1993.\
\>", "Text"],

Cell["\<\
[3] Littlewood, D.E., The Theory of Group Characters ans Matrix \
Representations of Groups (2. Ed.), Oxford, Clarendon Press, 1950.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The program QueensSolution", "Section"],

Cell["\<\
The procedure QueensSolution generates all queens solutions of an \
(n\[Times]n)-board in the following way: It generates all n! rook solutions \
and makes then a test for every such rook solutions whether it is a queens \
solution, too. 
QueensSolution is an implementation of a program from [1].\
\>", "Text"],

Cell["\<\
QueensSolution[n_] :=
With[{r = Range[n]},
    Select[Permutations[r],
          {Length[Union[# + r]], Length[Union[# - r]]} === {n,n}&
          ]
    ]\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["QueensPlot", "Section"],

Cell["\<\
QueensPlot allows to plot a graphic of a queens solution given by a \
permutation.\
\>", "Text"],

Cell["\<\
board[n_] :=
        {
         {
         GrayLevel[0],
         Table[Rectangle[{i,j},{i+1,j+1}],
              {i,1,n,2},
              {j,1,n,2}
              ]
         },
         {
         GrayLevel[0.9],
         Table[Rectangle[{i,j},{i+1,j+1}],
              {i,1,n,2},
              {j,2,n,2}
              ]
         },
         {
         GrayLevel[0],
         Table[Rectangle[{i,j},{i+1,j+1}],
              {i,2,n,2},
              {j,2,n,2}
              ]
         },
         {
         GrayLevel[0.9],
         Table[Rectangle[{i,j},{i+1,j+1}],
              {i,2,n,2},
              {j,1,n,2}
              ]
         }
        }\
\>", "Input"],

Cell["\<\
Queen1[i_,j_] := {GrayLevel[1], {Disk[{i + 0.5, j + 0.5}, 0.4]}}\
\>", "Input"],

Cell["Queen2[i_,j_] := {Circle[{i + 0.5, j + 0.5}, 0.4]}", "Input"],

Cell["\<\
Queen3[i_,j_] := {GrayLevel[0], {Disk[{i + 0.5, j + 0.5}, 0.1]}}\
\>", "Input"],

Cell["\<\
QueensPlot[perm_List]:=
          With[{n = Length[perm]},
              (* do *)
              Graphics[
                      {
                      board[n],
                      Table[Queen1[perm[[i]],i],
                           {i,1,n}
                           ],
                      Table[Queen2[perm[[i]],i],
                           {i,1,n}
                           ],
                      Table[Queen3[perm[[i]],i],
                           {i,1,n}
                           ]
                      },
                      AspectRatio -> 1
                      ]
              ] (* End With *)\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples of Queens Solutions", "Section"],

Cell["\<\
Before you carry out the following examples, you have to evaluate the \
definitions of the subsections \"The program QueensSolution\" and \
\"QueensPlot\".\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData["The (n \[Times] n)-board with n = 2, 3"], "Subsection"],

Cell[CellGroupData[{

Cell["QueensSolution[2]", "Input"],

Cell[OutputFormData["\<\
{}\
\>", "\<\
{}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QueensSolution[3]", "Input"],

Cell[OutputFormData["\<\
{}\
\>", "\<\
{}\
\>"], "Output"]
}, Open  ]],

Cell["These boards admit no queens solution.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["The (4 \[Times] 4)-board"], "Subsection"],

Cell[CellGroupData[{

Cell["qs = QueensSolution[4] //Timing", "Input"],

Cell[OutputFormData["\<\
{0.*Second, {{2, 4, 1, 3}, {3, 1, 4, 2}}}\
\>", "\<\
{0. Second, {{2, 4, 1, 3}, {3, 1, 4, 2}}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["t4 = qs[[1]]", "Input"],

Cell[OutputFormData["\<\
0.*Second\
\>", "\<\
0. Second\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsg = QueensPlot[#]& /@ qs[[2]]", "Input"],

Cell[OutputFormData["\<\
{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, {GrayLevel[0], {Disk[{2.5, \
4.5}, 0.1]}}}
}, AspectRatio -> 1]}\
\>", "\<\
{-Graphics-, -Graphics-}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[GraphicsArray[qsg]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -0.214286 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .2619 L
.2619 .2619 L
.2619 .02381 L
F
.02381 .5 m
.02381 .7381 L
.2619 .7381 L
.2619 .5 L
F
.5 .02381 m
.5 .2619 L
.7381 .2619 L
.7381 .02381 L
F
.5 .5 m
.5 .7381 L
.7381 .7381 L
.7381 .5 L
F
.9 g
.02381 .2619 m
.02381 .5 L
.2619 .5 L
.2619 .2619 L
F
.02381 .7381 m
.02381 .97619 L
.2619 .97619 L
.2619 .7381 L
F
.5 .2619 m
.5 .5 L
.7381 .5 L
.7381 .2619 L
F
.5 .7381 m
.5 .97619 L
.7381 .97619 L
.7381 .7381 L
F
0 g
.2619 .2619 m
.2619 .5 L
.5 .5 L
.5 .2619 L
F
.2619 .7381 m
.2619 .97619 L
.5 .97619 L
.5 .7381 L
F
.7381 .2619 m
.7381 .5 L
.97619 .5 L
.97619 .2619 L
F
.7381 .7381 m
.7381 .97619 L
.97619 .97619 L
.97619 .7381 L
F
.9 g
.2619 .02381 m
.2619 .2619 L
.5 .2619 L
.5 .02381 L
F
.2619 .5 m
.2619 .7381 L
.5 .7381 L
.5 .5 L
F
.7381 .02381 m
.7381 .2619 L
.97619 .2619 L
.97619 .02381 L
F
.7381 .5 m
.7381 .7381 L
.97619 .7381 L
.97619 .5 L
F
1 g
.38095 .14286 m
.38095 .14286 .09524 0 365.73 arc
F
.85714 .38095 m
.85714 .38095 .09524 0 365.73 arc
F
.14286 .61905 m
.14286 .61905 .09524 0 365.73 arc
F
.61905 .85714 m
.61905 .85714 .09524 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.38095 .14286 .09524 0 365.73 arc
s
newpath
.85714 .38095 .09524 0 365.73 arc
s
newpath
.14286 .61905 .09524 0 365.73 arc
s
newpath
.61905 .85714 .09524 0 365.73 arc
s
.38095 .14286 m
.38095 .14286 .02381 0 365.73 arc
F
.85714 .38095 m
.85714 .38095 .02381 0 365.73 arc
F
.14286 .61905 m
.14286 .61905 .02381 0 365.73 arc
F
.61905 .85714 m
.61905 .85714 .02381 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -0.214286 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .2619 L
.2619 .2619 L
.2619 .02381 L
F
.02381 .5 m
.02381 .7381 L
.2619 .7381 L
.2619 .5 L
F
.5 .02381 m
.5 .2619 L
.7381 .2619 L
.7381 .02381 L
F
.5 .5 m
.5 .7381 L
.7381 .7381 L
.7381 .5 L
F
.9 g
.02381 .2619 m
.02381 .5 L
.2619 .5 L
.2619 .2619 L
F
.02381 .7381 m
.02381 .97619 L
.2619 .97619 L
.2619 .7381 L
F
.5 .2619 m
.5 .5 L
.7381 .5 L
.7381 .2619 L
F
.5 .7381 m
.5 .97619 L
.7381 .97619 L
.7381 .7381 L
F
0 g
.2619 .2619 m
.2619 .5 L
.5 .5 L
.5 .2619 L
F
.2619 .7381 m
.2619 .97619 L
.5 .97619 L
.5 .7381 L
F
.7381 .2619 m
.7381 .5 L
.97619 .5 L
.97619 .2619 L
F
.7381 .7381 m
.7381 .97619 L
.97619 .97619 L
.97619 .7381 L
F
.9 g
.2619 .02381 m
.2619 .2619 L
.5 .2619 L
.5 .02381 L
F
.2619 .5 m
.2619 .7381 L
.5 .7381 L
.5 .5 L
F
.7381 .02381 m
.7381 .2619 L
.97619 .2619 L
.97619 .02381 L
F
.7381 .5 m
.7381 .7381 L
.97619 .7381 L
.97619 .5 L
F
1 g
.61905 .14286 m
.61905 .14286 .09524 0 365.73 arc
F
.14286 .38095 m
.14286 .38095 .09524 0 365.73 arc
F
.85714 .61905 m
.85714 .61905 .09524 0 365.73 arc
F
.38095 .85714 m
.38095 .85714 .09524 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.61905 .14286 .09524 0 365.73 arc
s
newpath
.14286 .38095 .09524 0 365.73 arc
s
newpath
.85714 .61905 .09524 0 365.73 arc
s
newpath
.38095 .85714 .09524 0 365.73 arc
s
.61905 .14286 m
.61905 .14286 .02381 0 365.73 arc
F
.14286 .38095 m
.14286 .38095 .02381 0 365.73 arc
F
.85714 .61905 m
.85714 .61905 .02381 0 365.73 arc
F
.38095 .85714 m
.38095 .85714 .02381 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 137.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000RA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000Yooal0000O
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/07`0001i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`DOolN00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk01l0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/037oo000:OolO000OLi`O000NLi`DOolN000OLi`O000O
Li`<Ool000Yooal0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`:00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/07`0001i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`DOolN00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk01l0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/037oo000:OolO0009Li`00`00Oomoo`08Ool20009Li`O
000NLi`DOolN000OLi`;0009Ool;000OLi`<Ool000Yooal00009Kg]cW6mkLia_Ng>LKg]cW00000eo
o`09001cW6mkLia_Ng>LKg]cW6mk01l0000NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L57oo7P0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0:000<Ool900007fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00aoo`002Woo
7`001g>L00<007ooOol03Goo00<007>LLi`01G>L7`007W>L57oo7P007g>L2@003goo1`007g>L37oo
000:OolO00001fmkLia_Ng>LKg]cW000015oo`800005Kg]cW6mkLia_N`0O00007VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Aooah0000OKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
20004Goo1P0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0<Ool000Yooal000EcW003001oogoo019oo`03001cW7>L009cW1l001icW1Ao
oah001mcW0L001=oo`D001mcW0aoo`002Woo7`0000I_Ng>LKg]cW6mk000DOol01@00Lia_Ng>LKg/0
7`0001i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`DOolN00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00L001Aoo`@0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/037oo000:OolO0004Li`00`00Oomoo`0COol00`00
LiacW002Li`O000NLi`DOolN000OLi`6000EOol4000OLi`<Ool000Yooal00005Kg]cW6mkLi`0000F
Ool01000Kg]cW6mk7`0001i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`DOolN00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00H001Ioo`<0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/037oo000:OolO0003Li`00`00
Oomoo`0EOol01000LiacW7>L7`007W>L57oo7P007g>L1@005goo0`007g>L37oo000:OolO000016mk
Lia_N`002Goo1@002Woo00<007>LKg/07`0001i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`DOolN00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00D000Uoo`@000Yoo`<0000OKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
37oo000:OolO0003Li`00`00Oomoo`07Ool5000:Ool00`00LiacW00O000NLi`DOolN000OLi`4000:
Ool50009Ool3000OLi`<Ool000Yooal00004Kg]cW6mk0008Ool6000:Ool00`00Lia_N`0O00007Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Ao
oah0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/010002Goo1P002Goo0`0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0<Ool000Yooal000=cW003001oogoo00Moo`D000Yo
o`03001cW7>L01l001icW1Aooah001mcW0@000Uoo`H000Uoo`<001mcW0aoo`002Woo7`0000A_Ng>L
Kg/000Uoo`@000Yoo`04001_Ng>LKg/O00007VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Aooah0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01@0027oo1@002Woo0`0001m_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0<
Ool000Yooal000=cW003001oogoo01Eoo`04001cW7>LLi`O000NLi`DOolN000OLi`5000GOol3000O
Li`<Ool000Yooal00005Kg]cW6mkLi`0000FOol01000Kg]cW6mk7`0001i_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`DOolN00007fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00D001Io
o`@0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/037oo000:OolO0004Li`00`00Oomoo`0DOol01000LiacW7>L7`007W>L57oo7P007g>L
1@005Woo10007g>L37oo000:OolO00001VmkLia_Ng>LKg/001Aoo`05001cW6mkLia_N`0O00007Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Ao
oah0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/01P0057oo1@0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0<Ool000Yooal000EcW003001oogoo015oo`03001cW7>L00=c
W1l001icW1Aooah001mcW0H001Aoo`D001mcW0aoo`002Woo7`0000I_Ng>LKg]cW6mk000BOol01`00
Lia_Ng>LKg]cW6mk01l0000NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L57oo7P0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`07000BOol600007fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00aoo`002Woo7`001W>L0P00
47oo00<007>LLi`017>L7`007W>L57oo7P007g>L2@003goo1`007g>L37oo000:OolO000026mkLia_
Ng>LKg]cW6mkLi`2000=Ool02000Kg]cW6mkLia_Ng>LKg/O00007VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Aooah0000OKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0037oo2000
01m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0<Ool000Yooal000YcW08000Yoo`03001cW7>L00IcW1l001icW1Aooah001mcW0d000Uoo`T0
01mcW0aoo`002Woo7`0000a_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`30002Ool500002FmkLia_Ng>L
Kg]cW6mkLia_N`0O00007VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW1Aooah0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/07`0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0<Ool000Yooal000mcW08000icW1l001ic
W1Aooah001mcW1l001mcW0aoo`002Woo7`0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0O00007VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Aooah0000OKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/07`0001m_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0<Ool0
00Yooal001mcW1l001icW1Aooah001mcW1l001mcW0aoo`002Woo7`0001m_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0O00007VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Aooah0000O
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/07`0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0<Ool000YooamcW1l001mcW1h001AooaicW1l001mcW1l000aoo`002Woo01mcW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O
00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L01h001Aoo`0NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L7`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000<Ool000YooamcW1l001mcW1h001Aoo`YcW0X000YcW1l0
01mcW1l000aoo`002Woo01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X000Yoo`X001Aoo`0:Kg]cW6mkLia_Ng>LKg]cW6mk
000:Ool2000026mkLia_Ng>LKg]cW6mkLi`O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l000aoo`002Woo7g>L7`007g>L2@003Goo
200057oo27>L00<007ooOol02goo0P001W>L7`007g>L7`0037oo000:Ool07g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l0000OLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02000
47oo1P0057oo00Q_Ng>LKg]cW6mkLia_N`0047oo00H007>LKg]cW6mkLi`O00007g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l000aoo`00
2Woo7g>L7`007g>L1`004Goo1P0057oo1W>L00<007ooOol03goo00<007>LLi`00g>L7`007g>L7`00
37oo000:Ool07g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L01l0000OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`01P004goo1@0057oo00I_Ng>LKg]cW6mk000COol01@00Kg]cW6mk
Li`07`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00O000<Ool000YooamcW1l001mcW0H001Aoo`@001Aoo`EcW003001oogoo019oo`04
001cW7>LLi`O000OLi`O000<Ool000Yoo`0OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW005000FOol3000DOol01FmkLia_Ng>L
00005Woo00<006mkLi`07`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000<Ool000YooamcW1l001mcW0D001Ioo`<001Aoo`AcW003
001oogoo01Aoo`03001cW7>L01l001mcW1l000aoo`002Woo01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O00007g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@001Moo`<001Ao
o`04Kg]cW6mk000GOol00`00Kg]cW00O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l000aoo`002Woo7g>L7`007g>L10002Goo1000
2Woo0`0057oo0g>L00<007ooOol01goo10002Woo00<007>LLi`07`007g>L7`0037oo000:Ool07g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01l0000OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`010002Goo1@002Goo0`0057oo00A_Ng>LKg/000Uoo`D000Uoo`03001_Ng>L01l0000O
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`07`0037oo000:OolOLi`O000OLi`40008Ool60009Ool3000DOol3Li`00`00Oomoo`06Ool60009
Ool00`00LiacW00O000OLi`O000<Ool000Yoo`0OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040009Ool50009Ool3000DOol0
16mkLia_N`002Goo1@002Goo00<006mkLi`07`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000<Ool000YooamcW1l001mcW0@000Uo
o`@000Yoo`<001Aoo`=cW003001oogoo00Moo`@000Yoo`03001cW7>L01l001mcW1l000aoo`002Woo
01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00@001Moo`<001Aoo`04Kg]cW6mk000GOol00`00Kg]cW00O00007g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l000ao
o`002Woo7g>L7`007g>L10005Woo100057oo0g>L00<007ooOol057oo00@007>LLiacW1l001mcW1l0
00aoo`002Woo01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00@001Ioo`@001Aoo`04Kg]cW6mk000FOol01000Lia_Ng>L7`00
01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00O000<Ool000YooamcW1l001mcW0D001Aoo`D001Aoo`AcW003001oogoo019oo`03001cW7>L
009cW1l001mcW1l000aoo`002Woo01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00H001=oo`D001Aoo`06Kg]cW6mkLia_N`00
4goo00D006mkLia_Ng>L01l0000OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0037oo000:OolOLi`O000OLi`7000AOol6000DOol6Li`0
0`00Oomoo`0?Ool00`00LiacW003Li`O000OLi`O000<Ool000Yoo`0OLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0001mcW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW008000@Ool6
000DOol026mkLia_Ng>LKg]cW6mk000@Ool01P00Lia_Ng>LKg]cW1l0000OLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0037oo000:OolO
Li`O000OLi`:000<Ool8000DOol8Li`2000<Ool20006Li`O000OLi`O000<Ool000Yoo`0OLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`00
01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00<0008Ool:000DOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L0P0027oo0P0000Q_Ng>LKg]cW6mk
Lia_Ng>L7`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00O000<Ool000YooamcW1l001mcW1h001Aoo`acW0P000YcW1l001mcW1l000ao
o`002Woo01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01h001Aoo`0NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L7`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000<Ool000YooamcW1l001mcW1h001Ao
oaicW1l001mcW1l000aoo`002Woo01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01h001Aoo`0NKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L7`0001mcW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000<Ool000Yo
oal001mcW1l001icW1Aooah001mcW1l001mcW0aoo`002Woo7`0001m_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0O00007VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Aooah0000OKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
7`0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0<Ool000Yooal001mcW1l001icW1Aooah001mcW1l001mcW0aoo`002Woo7`0001m_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0O
00007VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW1Aooah0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/07`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00T0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0<Ool000Yoo`X000Yoo`/001mcW1l001icW1Aooah001mcW1l000UcW08000Uoo`80
00UcW0aoo`002Woo2@003Goo2@0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0O00007VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Aooah0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/07`0000U_Ng>LKg]cW6mkLia_
Ng>L00003Goo0P0000M_Ng>LKg]cW6mkLia_N`0<Ool000Yoo`P0011oo`L001mcW1l001icW1Aooah0
01mcW1l000McW003001oogoo00ioo`03001cW7>L00AcW0aoo`002Woo1`004Woo1P0001m_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0O0000
7VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W1Aooah0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/07`0000M_Ng>LKg]cW6mkLi`0000BOol01P00Kg]cW6mkLia_N`aoo`002Woo1P00
57oo1@007g>L7`007W>L57oo7P007g>L7`001G>L00<007ooOol04Woo00<007>LLi`00W>L37oo000:
Ool6000DOol500007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk01l0000NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L57oo7P0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0O00001VmkLia_Ng>LKg/001Aoo`05001cW6mk
Lia_N`0<Ool000Yoo`D001Ioo`@001mcW1l001icW1Aooah001mcW1l000AcW003001oogoo01Aoo`04
001cW7>LLi`<Ool000Yoo`D001Ioo`@0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/07`0001i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`DOolN00007fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01l00005Kg]cW6mkLi`0
000FOol01000Kg]cW6mk37oo000:Ool4000GOol4000OLi`O000NLi`DOolN000OLi`O0004Li`00`00
Oomoo`0DOol01000LiacW7>L37oo000:Ool40009Ool5000:Ool300007fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01l0000NKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L57oo7P0001m_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0O00001FmkLia_Ng>L00002Goo10002Woo00<007>LKg/037oo000:Ool40009Ool5000:Ool3000O
Li`O000NLi`DOolN000OLi`O0003Li`00`00Oomoo`08Ool50009Ool00`00LiacW00<Ool000Yoo`@0
00Qoo`H000Yoo`<0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/07`0001i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`DOolN00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01l00004Kg]cW6mk0009Ool60009Ool00`00
Lia_N`0<Ool000Yoo`@000Uoo`D000Uoo`@001mcW1l001icW1Aooah001mcW1l000=cW003001oogoo
00Moo`H000Uoo`03001cW7>L00aoo`002Woo10002Goo1@002Goo100001m_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0O00007VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Aooah0000O
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/07`0000A_Ng>LKg/000Uoo`D000Yoo`03001cW6mk00aoo`002Woo10005goo10007g>L7`007W>L
57oo7P007g>L7`000g>L00<007ooOol05Woo00<007>LLi`037oo000:Ool5000FOol400007fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01l0
000NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L57oo7P0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0O00001FmkLia_Ng>L00005Woo00@006mkLia_N`aoo`002Woo1@005Woo1000
7g>L7`007W>L57oo7P007g>L7`0017>L00<007ooOol057oo00@007>LLiacW0aoo`002Woo1P0057oo
1@0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0O00007VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW1Aooah0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/07`0000I_Ng>LKg]cW6mk000DOol01@00Lia_Ng>LKg/037oo
000:Ool6000DOol5000OLi`O000NLi`DOolN000OLi`O0006Li`00`00Oomoo`0AOol00`00LiacW002
Li`<Ool000Yoo`L0019oo`H0000OKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/07`0001i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`DOolN00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01l00008Kg]cW6mkLia_Ng>LKg/0
015oo`06001_Ng>LKg]cW6mk37oo000:Ool8000@Ool7000OLi`O000NLi`DOolN000OLi`O0007Li`0
0`00Oomoo`0>Ool00`00LiacW004Li`<Ool000Yoo`X000aoo`T0000OKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/07`0001i_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`DOolN00007fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01l00008Kg]cW6mkLia_Ng>LKg]cW08000aoo`800007Kg]cW6mkLia_Ng>LKg/037oo000:Ool<0008
Ool;000OLi`O000NLi`DOolN000OLi`O000:Li`30007Ool20009Li`<Ool000Yooal0000OKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/07`00
01i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`DOolN00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk01l0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00aoo`002Woo7`007g>L7`007W>L57oo7P007g>L7`007g>L37oo000:OolO0000
7fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01l0000NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L57oo7P0001m_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0O00007fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00aoo`002Woo7`007g>L7`007W>L57oo7P007g>L7`00
7g>L37oo000:Ool07g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01l0000OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07P0057oo01i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`O00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l000aoo`002Woo7g>L7`007g>L
7P0057oo7W>L7`007g>L7`0037oo000:Ool07g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l0000?Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L0080000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1h001Aoo`0NKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L7`0001mcW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000<
Ool000YooamcW1l000YcW0D0009oo`<000]cW1h001AooaicW100009oo`d001mcW1l000aoo`002Woo
01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00O00002W>LKg]cW6mkLia_Ng>LKg]cW0002Woo0P0000UcW6mkLia_Ng>LKg]cW6mkLi`07P00
57oo01i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`;0009Ool;00007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01l000aoo`002Woo7g>L7`0027>L00<007ooOol02goo0P001g>L7P00
57oo7W>L2P003Goo20007g>L7`0037oo000:Ool07g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l00006Lia_Ng>LKg]cW6mk0P0047oo00L0
06mkLia_Ng>LKg]cW00N000DOol07VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0T0011oo`H0000OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0037oo000:OolOLi`O0005Li`00`00
Oomoo`0AOol00`00LiacW003Li`N000DOolNLi`7000BOol6000OLi`O000<Ool000Yoo`0OLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`00
00IcW6mkLia_Ng>L000DOol01@00Kg]cW6mkLi`07P0057oo01i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`7000COol500007g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l000aoo`00
2Woo7g>L7`0017>L00<007ooOol04goo00<007>LLi`00W>L7P0057oo7W>L1P005Goo10007g>L7`00
37oo000:Ool07g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L01l00005Lia_Ng>LKg/0000FOol01000Lia_Ng>L7P0057oo01i_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`6000FOol30000
7g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L01l000aoo`002Woo7g>L7`000g>L00<007ooOol05Goo00@007>LLiacW1h001AooaicW0D001Mo
o`<001mcW1l000aoo`002Woo01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000017>LKg]cW0005goo00@007>LKg]cW1h001Aoo`0NKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L1@00
5goo0`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00O000<Ool000YooamcW1l000=cW003001oogoo00Moo`@000Yoo`04001cW7>LLi`N
000DOolNLi`50009Ool4000:Ool3000OLi`O000<Ool000Yoo`0OLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0000AcW6mkLi`000Qoo`H0
00Uoo`04001cW6mkLi`N000DOol07VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0D000Qoo`H000Uoo`<0000OLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0037oo000:OolOLi`O0003
Li`00`00Oomoo`06Ool60009Ool01000LiacW7>L7P0057oo7W>L1@0027oo1P002Goo0`007g>L7`00
37oo000:Ool07g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L01l00004Lia_Ng>L0009Ool50009Ool01000Lia_Ng>L7P0057oo01i_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`50009Ool5
0009Ool300007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L01l000aoo`002Woo7g>L7`000g>L00<007ooOol01goo10002Woo00@007>LLiac
W1h001AooaicW0D000Uoo`@000Yoo`<001mcW1l000aoo`002Woo01mcW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000017>LKg]cW0005goo
00@007>LKg]cW1h001Aoo`0NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L1@005goo0`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000<Ool000YooamcW1l000AcW003001oogoo
01=oo`03001cW7>L009cW1h001AooaicW0D001Ioo`@001mcW1l000aoo`002Woo01mcW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O00001G>L
Kg]cW6mk00005Goo00D006mkLia_Ng>L01h001Aoo`0NKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L1@005Woo100001mcW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00O000<Ool000Yooamc
W1l000EcW003001oogoo015oo`03001cW7>L00=cW1h001AooaicW0H001Aoo`D001mcW1l000aoo`00
2Woo01mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00O00001W>LKg]cW6mkLi`001=oo`06001cW6mkLia_Ng>L7P0057oo01i_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`7000COol50000
7g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L01l000aoo`002Woo7g>L7`001W>L00<007ooOol03goo00<007>LLi`017>L7P0057oo7W>L2000
4Goo1P007g>L7`0037oo000:Ool07g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l00008Lia_Ng>LKg]cW6mkLi`0011oo`07001_Ng>LKg]c
W6mkLi`07P0057oo01i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`9000?Ool700007g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l000aoo`002Woo7g>L7`0027>L0P0037oo0P001g>L
7P0057oo7W>L2`002goo2@007g>L7`0037oo000:Ool07g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01l0000:Lia_Ng>LKg]cW6mkLia_Ng>L
Kg/20007Ool300002G>LKg]cW6mkLia_Ng>LKg]cW00N000DOol07VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d000Moo`/0000OLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0037oo
000:OolOLi`O000<Li`7000<Li`N000DOolNLi`O000OLi`O000<Ool000Yoo`0OLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0001mcW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00N
000DOol07VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW1l0000OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`07`0037oo000:OolOLi`O000OLi`N000DOolNLi`O000OLi`O000<Ool000Yo
o`0OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`07`0001mcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00N000DOol07VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW1l0000OLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`07`0037oo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {136.125, 0}} -> {-0.0541876, -0.0238146, 
  0.00734626, 0.00734626}, {{7.375, 137}, {132.875, 3.1875}} -> {0.66102, 
  0.793664, 0.0324015, 0.0324015}, {{149.938, 279.625}, {132.875, 
  3.1875}} -> {-3.95588, 0.794727, 0.0323859, 0.0323859}}],

Cell[OutputFormData["\<\
GraphicsArray[{Graphics[{{{GrayLevel[0], 
       {{Rectangle[{1, 1}, {2, 2}], Rectangle[{1, 3}, {2, 4}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}}}, AspectRatio -> 1]}]\
\>", "\<\
-GraphicsArray-\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The (5 \[Times] 5)-board", "Subsection"],

Cell[CellGroupData[{

Cell["qs = QueensSolution[5] //Timing", "Input"],

Cell[OutputFormData["\<\
{0.04999999999999715*Second, {{1, 3, 5, 2, 4}, {1, 4, 2, 5, 3}, {2, 4, 1, 3, \
5}, 
   {2, 5, 3, 1, 4}, {3, 1, 4, 2, 5}, {3, 5, 2, 4, 1}, {4, 1, 3, 5, 2}, 
   {4, 2, 5, 3, 1}, {5, 2, 4, 1, 3}, {5, 3, 1, 4, 2}}}\
\>", "\<\
{0.05 Second, {{1, 3, 5, 2, 4}, {1, 4, 2, 5, 3}, {2, 4, 1, 3, 5}, {2, 5, 3, \
1, 4}, 
 
   {3, 1, 4, 2, 5}, {3, 5, 2, 4, 1}, {4, 1, 3, 5, 2}, {4, 2, 5, 3, 1}, 
 
   {5, 2, 4, 1, 3}, {5, 3, 1, 4, 2}}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["t5 = qs[[1]]", "Input"],

Cell[OutputFormData["\<\
0.04999999999999715*Second\
\>", "\<\
0.05 Second\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[qs[[2]]]", "Input"],

Cell[OutputFormData["\<\
10\
\>", "\<\
10\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsg = QueensPlot[#]& /@ qs[[2]]", "Input"],

Cell[OutputFormData["\<\
{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, {Circle[{2.5, \
5.5}, 0.4]}}\\
, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, {GrayLevel[0], {Disk[{3.5, 2.5}, \
0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, {GrayLevel[0], {Disk[{2.5, \
5.5}, 0.1]}}}
}, AspectRatio -> 1]}\
\>", "\<\
{-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsga = Partition[qsg,3]", "Input"],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \"qsga\"
     is similar to existing symbol \"qsg\".\
\>", "Message"],

Cell[OutputFormData["\<\
{{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, \

        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}}}, AspectRatio -> 1]}}\
\>", "\<\
{{-Graphics-, -Graphics-, -Graphics-}, {-Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[GraphicsArray[qsga]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.321429 0.321429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.69048 .11905 m
.69048 .11905 .07619 0 365.73 arc
F
.11905 .30952 m
.11905 .30952 .07619 0 365.73 arc
F
.5 .5 m
.5 .5 .07619 0 365.73 arc
F
.88095 .69048 m
.88095 .69048 .07619 0 365.73 arc
F
.30952 .88095 m
.30952 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.69048 .11905 .07619 0 365.73 arc
s
newpath
.11905 .30952 .07619 0 365.73 arc
s
newpath
.5 .5 .07619 0 365.73 arc
s
newpath
.88095 .69048 .07619 0 365.73 arc
s
newpath
.30952 .88095 .07619 0 365.73 arc
s
.69048 .11905 m
.69048 .11905 .01905 0 365.73 arc
F
.11905 .30952 m
.11905 .30952 .01905 0 365.73 arc
F
.5 .5 m
.5 .5 .01905 0 365.73 arc
F
.88095 .69048 m
.88095 .69048 .01905 0 365.73 arc
F
.30952 .88095 m
.30952 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.0238095 0.64881 0.321429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.69048 .11905 m
.69048 .11905 .07619 0 365.73 arc
F
.30952 .30952 m
.30952 .30952 .07619 0 365.73 arc
F
.88095 .5 m
.88095 .5 .07619 0 365.73 arc
F
.5 .69048 m
.5 .69048 .07619 0 365.73 arc
F
.11905 .88095 m
.11905 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.69048 .11905 .07619 0 365.73 arc
s
newpath
.30952 .30952 .07619 0 365.73 arc
s
newpath
.88095 .5 .07619 0 365.73 arc
s
newpath
.5 .69048 .07619 0 365.73 arc
s
newpath
.11905 .88095 .07619 0 365.73 arc
s
.69048 .11905 m
.69048 .11905 .01905 0 365.73 arc
F
.30952 .30952 m
.30952 .30952 .01905 0 365.73 arc
F
.88095 .5 m
.88095 .5 .01905 0 365.73 arc
F
.5 .69048 m
.5 .69048 .01905 0 365.73 arc
F
.11905 .88095 m
.11905 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.0238095 0.97619 0.321429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.88095 .11905 m
.88095 .11905 .07619 0 365.73 arc
F
.30952 .30952 m
.30952 .30952 .07619 0 365.73 arc
F
.69048 .5 m
.69048 .5 .07619 0 365.73 arc
F
.11905 .69048 m
.11905 .69048 .07619 0 365.73 arc
F
.5 .88095 m
.5 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.88095 .11905 .07619 0 365.73 arc
s
newpath
.30952 .30952 .07619 0 365.73 arc
s
newpath
.69048 .5 .07619 0 365.73 arc
s
newpath
.11905 .69048 .07619 0 365.73 arc
s
newpath
.5 .88095 .07619 0 365.73 arc
s
.88095 .11905 m
.88095 .11905 .01905 0 365.73 arc
F
.30952 .30952 m
.30952 .30952 .01905 0 365.73 arc
F
.69048 .5 m
.69048 .5 .01905 0 365.73 arc
F
.11905 .69048 m
.11905 .69048 .01905 0 365.73 arc
F
.5 .88095 m
.5 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.35119 0.321429 0.64881 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.30952 .11905 m
.30952 .11905 .07619 0 365.73 arc
F
.88095 .30952 m
.88095 .30952 .07619 0 365.73 arc
F
.5 .5 m
.5 .5 .07619 0 365.73 arc
F
.11905 .69048 m
.11905 .69048 .07619 0 365.73 arc
F
.69048 .88095 m
.69048 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.30952 .11905 .07619 0 365.73 arc
s
newpath
.88095 .30952 .07619 0 365.73 arc
s
newpath
.5 .5 .07619 0 365.73 arc
s
newpath
.11905 .69048 .07619 0 365.73 arc
s
newpath
.69048 .88095 .07619 0 365.73 arc
s
.30952 .11905 m
.30952 .11905 .01905 0 365.73 arc
F
.88095 .30952 m
.88095 .30952 .01905 0 365.73 arc
F
.5 .5 m
.5 .5 .01905 0 365.73 arc
F
.11905 .69048 m
.11905 .69048 .01905 0 365.73 arc
F
.69048 .88095 m
.69048 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.35119 0.64881 0.64881 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.5 .11905 m
.5 .11905 .07619 0 365.73 arc
F
.11905 .30952 m
.11905 .30952 .07619 0 365.73 arc
F
.69048 .5 m
.69048 .5 .07619 0 365.73 arc
F
.30952 .69048 m
.30952 .69048 .07619 0 365.73 arc
F
.88095 .88095 m
.88095 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .11905 .07619 0 365.73 arc
s
newpath
.11905 .30952 .07619 0 365.73 arc
s
newpath
.69048 .5 .07619 0 365.73 arc
s
newpath
.30952 .69048 .07619 0 365.73 arc
s
newpath
.88095 .88095 .07619 0 365.73 arc
s
.5 .11905 m
.5 .11905 .01905 0 365.73 arc
F
.11905 .30952 m
.11905 .30952 .01905 0 365.73 arc
F
.69048 .5 m
.69048 .5 .01905 0 365.73 arc
F
.30952 .69048 m
.30952 .69048 .01905 0 365.73 arc
F
.88095 .88095 m
.88095 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.35119 0.97619 0.64881 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.5 .11905 m
.5 .11905 .07619 0 365.73 arc
F
.88095 .30952 m
.88095 .30952 .07619 0 365.73 arc
F
.30952 .5 m
.30952 .5 .07619 0 365.73 arc
F
.69048 .69048 m
.69048 .69048 .07619 0 365.73 arc
F
.11905 .88095 m
.11905 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .11905 .07619 0 365.73 arc
s
newpath
.88095 .30952 .07619 0 365.73 arc
s
newpath
.30952 .5 .07619 0 365.73 arc
s
newpath
.69048 .69048 .07619 0 365.73 arc
s
newpath
.11905 .88095 .07619 0 365.73 arc
s
.5 .11905 m
.5 .11905 .01905 0 365.73 arc
F
.88095 .30952 m
.88095 .30952 .01905 0 365.73 arc
F
.30952 .5 m
.30952 .5 .01905 0 365.73 arc
F
.69048 .69048 m
.69048 .69048 .01905 0 365.73 arc
F
.11905 .88095 m
.11905 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678571 0.321429 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.11905 .11905 m
.11905 .11905 .07619 0 365.73 arc
F
.5 .30952 m
.5 .30952 .07619 0 365.73 arc
F
.88095 .5 m
.88095 .5 .07619 0 365.73 arc
F
.30952 .69048 m
.30952 .69048 .07619 0 365.73 arc
F
.69048 .88095 m
.69048 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.11905 .11905 .07619 0 365.73 arc
s
newpath
.5 .30952 .07619 0 365.73 arc
s
newpath
.88095 .5 .07619 0 365.73 arc
s
newpath
.30952 .69048 .07619 0 365.73 arc
s
newpath
.69048 .88095 .07619 0 365.73 arc
s
.11905 .11905 m
.11905 .11905 .01905 0 365.73 arc
F
.5 .30952 m
.5 .30952 .01905 0 365.73 arc
F
.88095 .5 m
.88095 .5 .01905 0 365.73 arc
F
.30952 .69048 m
.30952 .69048 .01905 0 365.73 arc
F
.69048 .88095 m
.69048 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.678571 0.64881 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.11905 .11905 m
.11905 .11905 .07619 0 365.73 arc
F
.69048 .30952 m
.69048 .30952 .07619 0 365.73 arc
F
.30952 .5 m
.30952 .5 .07619 0 365.73 arc
F
.88095 .69048 m
.88095 .69048 .07619 0 365.73 arc
F
.5 .88095 m
.5 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.11905 .11905 .07619 0 365.73 arc
s
newpath
.69048 .30952 .07619 0 365.73 arc
s
newpath
.30952 .5 .07619 0 365.73 arc
s
newpath
.88095 .69048 .07619 0 365.73 arc
s
newpath
.5 .88095 .07619 0 365.73 arc
s
.11905 .11905 m
.11905 .11905 .01905 0 365.73 arc
F
.69048 .30952 m
.69048 .30952 .01905 0 365.73 arc
F
.30952 .5 m
.30952 .5 .01905 0 365.73 arc
F
.88095 .69048 m
.88095 .69048 .01905 0 365.73 arc
F
.5 .88095 m
.5 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.678571 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.30952 .11905 m
.30952 .11905 .07619 0 365.73 arc
F
.69048 .30952 m
.69048 .30952 .07619 0 365.73 arc
F
.11905 .5 m
.11905 .5 .07619 0 365.73 arc
F
.5 .69048 m
.5 .69048 .07619 0 365.73 arc
F
.88095 .88095 m
.88095 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.30952 .11905 .07619 0 365.73 arc
s
newpath
.69048 .30952 .07619 0 365.73 arc
s
newpath
.11905 .5 .07619 0 365.73 arc
s
newpath
.5 .69048 .07619 0 365.73 arc
s
newpath
.88095 .88095 .07619 0 365.73 arc
s
.30952 .11905 m
.30952 .11905 .01905 0 365.73 arc
F
.69048 .30952 m
.69048 .30952 .01905 0 365.73 arc
F
.11905 .5 m
.11905 .5 .01905 0 365.73 arc
F
.5 .69048 m
.5 .69048 .01905 0 365.73 arc
F
.88095 .88095 m
.88095 .88095 .01905 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{403, 403},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0001Ta000`40O003h00OogooU7oo003oOonD
Ool00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00
ogooU7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol000aooaL0000FKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo5P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01L000ioo`0037oo5`005W>L5`002W>L0`002W>L5`004Woo5P005g>L5`002G>L10002W>L5P00
4Woo5`005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L5`0000McW6mkLia_Ng>LKg]cW0030003Ool400001VmkLia_Ng>LKg]cW1L0
019ooaH0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G0000
1g>LKg]cW6mkLia_Ng>L008000Aoo`<00007Lia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0:0003Ool:000>Ool000aooaL001IcW1L000Mc
W003001oogoo00Moo`03001cW7>L00=cW1L0019ooaH001McW1L000IcW003001oogoo00Moo`03001c
W7>L00AcW1H0019ooaL001McW1H001McW0P000Uoo`H000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00007Lia_Ng>LKg]cW6mk00002goo00D006mk
Lia_Ng>L01L0019ooaH0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00G00001W>LKg]cW6mkLi`000]oo`06001cW6mkLia_Ng>L5P004Woo5`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`07000;Ool5000>Ool000aooaL001IcW1L000AcW080
00eoo`04001cW7>LLi`G000BOolF000GLi`G0004Li`00`00Oomoo`0;Ool00`00LiacW002Li`F000B
OolG000GLi`F000GLi`6000=Ool4000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`G000017>LKg]cW00047oo00<006mkLi`05`004Woo5P0001McW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L00004Lia_Ng>L000?Ool0
1000Lia_Ng>L5P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`04
000@Ool3000>Ool000aooaL001IcW1L000=cW003001oogoo00ioo`03001cW7>L01L0019ooaH001Mc
W1L000=cW003001oogoo00ioo`03001cW7>L01H0019ooaL001McW1H001McW0@0011oo`<000ioo`00
37oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_
Ng>L000@Ool00`00Kg]cW00G000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`05`0000=cW6mk00004Goo00<006mkLi`05P004Woo5`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`04000@Ool3000>Ool000aooaL001IcW1L000=cW003
001oogoo00Eoo`8000Qoo`03001cW00001H0019ooaH001McW1L0009cW003001oogoo00Eoo`8000Qo
o`03001cW7>L01H0019ooaL001McW1H001McW0@000Moo`8000Qoo`8000ioo`0037oo5`0001I_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_Ng>L0005Ool40008
Ool00`00Li`0000F000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`05`0000=cW6mk00001Woo10001goo00<006mkLi`05P004Woo5`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`040005Ool40008Ool2000>Ool000aooaL001IcW1L0
00=cW003001oogoo00Aoo`<000Qoo`03001cW00001H0019ooaH001McW1L0009cW003001oogoo00Eo
o`<000Moo`03001cW7>L01H0019ooaL001McW1H001McW0@000Ioo`<000Qoo`8000ioo`0037oo5`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_Ng>L0007
Ool20008Ool00`00Li`0000F000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`05`0000=cW6mk00001goo0P0027oo00<006mkLi`05P004Woo5`0001McW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`040007Ool20008Ool2000>Ool000aooaL0
01IcW1L000=cW003001oogoo00ioo`03001cW7>L01L0019ooaH001McW1L000=cW003001oogoo00io
o`03001cW7>L01H0019ooaL001McW1H001McW0@0011oo`<000ioo`0037oo5`0001I_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_Ng>L000@Ool00`00Kg]cW00G
000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`00
00AcW6mkLi`0011oo`03001_Ng>L01H0019ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/0100047oo0`003Woo000<OolG000FLi`G0004Li`00`00Oomoo`0<Ool01000Liac
W7>L5`004Woo5P005g>L5`000g>L00<007ooOol03Goo00@007>LLiacW1H0019ooaL001McW1H001Mc
W0D000ioo`@000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW1L00005Lia_Ng>LKg/0000>Ool01000Lia_Ng>L5`004Woo5P0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L00005Lia_Ng>LKg/0000>Ool01000Lia_
Ng>L5P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`05000>Ool4
000>Ool000aooaL001IcW1L000EcW003001oogoo00Yoo`03001cW7>L009cW1L0019ooaH001McW1L0
00EcW003001oogoo00Yoo`03001cW7>L009cW1H0019ooaL001McW1H001McW0H000aoo`D000ioo`00
37oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00006Lia_
Ng>LKg]cW6mk0P0027oo0P0000EcW6mkLia_Ng>L01L0019ooaH0000GLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00001W>LKg]cW6mkLia_N`8000Qoo`800005Lia_
Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00P0
00Qoo`L000ioo`0037oo5`005W>L5`0027>L20001g>L5`004Woo5P005g>L5`0027>L20001g>L5P00
4Woo5`005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L01L0019ooaH0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P00
4Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000G
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL0
01IcW1L001McW1L0019ooaH001McW1L001McW1H0019ooaL001McW1H001McW1L000ioo`0037oo5`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G000BOolF00005g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolGLi`F000GLi`G000GLi`BOolFLi`G000GLi`G000F
Li`BOolGLi`G000FLi`G000GLi`>Ool000aoo`09Lia_Ng>LKg]cW6mkLia_Ng>L00H00008Kg]cW6mk
Lia_Ng>LKg]cW1H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01Ic
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo
000<Ool6Li`30006Ool00`00LiacW005Li`F000GLi`G000GLi`BOolFLi`:0005Ool8000GLi`G000F
Li`BOolGLi`90006Ool8000FLi`G000GLi`>Ool000aoo`06Lia_Ng>LKg]cW0002Woo0P0000EcW6mk
Lia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01IcW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`L000Yoo`H0000GKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00H000Yoo`L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`03Woo000<Ool4Li`00`00Oomoo`0;Ool00`00LiacW002Li`F000GLi`G000GLi`BOolFLi`6
000=Ool4000GLi`G000FLi`BOolGLi`5000=Ool5000FLi`G000GLi`>Ool000aoo`05Lia_Ng>LKg/0
000>Ool01000Lia_Ng>L5P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B
Ool05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk1@003goo0`0001M_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01@003Woo100001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00>Ool000aoo`=cW003001oogoo00eoo`04001cW7>LLi`F000GLi`G000GLi`B
OolFLi`4000@Ool3000GLi`G000FLi`BOolGLi`4000?Ool4000FLi`G000GLi`>Ool000aoo`04Lia_
Ng>L000@Ool00`00Kg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/4000@Ool30000
5fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`04000@Ool300005VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo0W>L00<007ooOol03goo00<007>LLi`05P005g>L5`005g>L
4Woo5W>L10004Goo0P005g>L5`005W>L4Woo5g>L0`004Goo0`005W>L5`005g>L3Woo000<Ool00g>L
Kg/00007Ool20008Ool00`00Kg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/40007
Ool20008Ool200005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`030007Ool20008Ool300005Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo0W>L00<007ooOol017oo1@00
1Woo00<007>LLi`05P005g>L5`005g>L4Woo5W>L10001Goo1@001goo0P005g>L5`005W>L4Woo5g>L
0`001Woo1@001Woo0`005W>L5`005g>L3Woo000<Ool00g>LKg/00007Ool30007Ool00`00Kg]cW00F
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk019oo`0FLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/40006Ool30008Ool200005fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`030007Ool30007Ool300005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00ioo`0037oo0W>L00<007ooOol03goo00<007>LLi`05P005g>L5`005g>L4Woo5W>L
10004Goo0P005g>L5`005W>L4Woo5g>L0`004Goo0`005W>L5`005g>L3Woo000<Ool017>LKg]cW000
47oo00<006mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0BOol0
5W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk100047oo0`0001M_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0100047oo0`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00>Ool000aoo`=cW003001oogoo00ioo`03001cW7>L01H001McW1L001McW19ooaIc
W0@0011oo`<001McW1L001IcW19ooaMcW0@0011oo`<001IcW1L001McW0ioo`0037oo00EcW6mkLia_
N`0000ioo`04001cW6mkLi`F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/5000>Ool40000
5fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`05000>Ool400005VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo1G>L00<007ooOol02goo00@007>LLiacW1H001McW1L001Mc
W19ooaIcW0H000eoo`@001McW1L001IcW19ooaMcW0H000eoo`@001IcW1L001McW0ioo`0037oo00Ic
W6mkLia_Ng>LKg/2000:Ool01@00Kg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk20002Woo1@0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/020002Woo1@0001I_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aoo`QcW003001oogoo00Eoo`8000EcW1H0
01McW1L001McW19ooaIcW0X000Moo`H001McW1L001IcW19ooaMcW0T000Moo`L001IcW1L001McW0io
o`0037oo00UcW6mkLia_Ng>LKg]cW6mkLi`01`0000McW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W19oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L5P005g>L5`005g>L4Woo
5W>L5`005g>L5`005W>L4Woo5g>L5`005W>L5`005g>L3Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk5`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000F
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00>Ool000aooaMcW1H001McW1L001McW19ooaIcW1L001McW1L001IcW19o
oaMcW1L001IcW1L001McW0ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00G000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019o
oaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolG000F
Li`G000GLi`G000BOolF000GLi`G000GLi`F000BOolG000GLi`F0008Li`70008Li`G000>Ool000ao
oaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`80007Ool80000
5g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo5P0001Mc
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0070008Ool7000BOolG00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0000Q_Ng>LKg]cW6mkLia_
N`001goo0P0000IcW6mkLia_Ng>LKg/G000>Ool000aooaL001IcW0L000Yoo`H001McW1L0019ooaH0
01McW1L001McW0H000Yoo`H0019ooaL001McW1H000IcW003001oogoo00Qoo`8000AcW1L000ioo`00
37oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0H000eoo`@0
000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G000BOolF0000
5g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00D000eoo`@0019ooaL0000GLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00001VmkLia_Ng>LKg/0
00eoo`04001_Ng>LKg/G000>Ool000aooaL001IcW0H000ioo`<001McW1L0019ooaH001McW1L001Mc
W0D000ioo`<0019ooaL001McW1H000EcW003001oogoo00aoo`03001cW7>L01L000ioo`0037oo5`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0D000moo`<0000GLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G000BOolF00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000moo`<0019ooaL0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00001FmkLia_Ng>L00003goo00<0
07>LKg/05`003Woo000<OolG000FLi`5000@Ool2000GLi`G000BOolF000GLi`G000GLi`4000@Ool2
000BOolG000GLi`F0004Li`00`00Oomoo`0>Ool00`00Li`0000F000>Ool000aooaL0000FKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`4000AOol200005g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo5P0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW003000AOol2000BOolG00005g>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0000A_Ng>LKg/0015oo`03001_N`0001H000io
o`0037oo5`005W>L10001goo0P0027oo0P005g>L5`004Woo5P005g>L5`005g>L0`001goo0P0027oo
0P004Woo5`005g>L5P000g>L00<007ooOol01Goo0P0027oo00<007>L00005P003Woo000<OolG0000
5VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10001Woo10001goo0P00
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0019ooaH0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001Woo10001goo0P004Woo5`00
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H00004Kg]cW6mk
0006Ool40007Ool00`00Kg/0000F000>Ool000aooaL001IcW0@000Moo`8000Qoo`8001McW1L0019o
oaH001McW1L001McW0<000Moo`8000Qoo`80019ooaL001McW1H000=cW003001oogoo00Eoo`8000Qo
o`03001cW00001H000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0@0015oo`80000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00G000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<0
015oo`80019ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00F000016mkLia_N`004Goo00<006mk00005P003Woo000<OolG000FLi`4000@Ool3000GLi`G000B
OolF000GLi`G000GLi`3000@Ool3000BOolG000GLi`F0003Li`00`00Oomoo`0>Ool00`00LiacW00G
000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`4
000?Ool400005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`00
4Woo5P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW003000?Ool4000BOolG
00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0000A_Ng>L
Kg/000moo`04001_Ng>LKg/G000>Ool000aooaL001IcW0D000ioo`@001McW1L0019ooaH001McW1L0
01McW0@000ioo`@0019ooaL001McW1H000AcW003001oogoo00aoo`04001cW7>LLi`G000>Ool000ao
oaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`6000<Ool50000
5g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo5P0001Mc
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW005000<Ool5000BOolG00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0000I_Ng>LKg]cW6mk000<
Ool01@00Lia_Ng>LKg/05`003Woo000<OolG000FLi`80008Ool7000GLi`G000BOolF000GLi`G000G
Li`70009Ool6000BOolG000GLi`F0006Li`20008Ool20005Li`G000>Ool000aooaL0000FKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`:0005Ool800005g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo5P0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0090005Ool8000BOolG00005g>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0000Q_Ng>LKg]cW6mkLia_Ng>L0P001Goo00P0
06mkLia_Ng>LKg]cW6mk5`003Woo000<OolG000FLi`G000GLi`G000BOolF000GLi`G000GLi`F000B
OolG000GLi`F000:Li`50008Li`G000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05`004Woo5P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
5P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`00
37oo5`005W>L5`005g>L5`004Woo5P005g>L5`005g>L5P004Woo5`005g>L5P005g>L5`003Woo000<
Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000GKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk5`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aooaMcW1H001McW1L001Mc
W19ooaIcW1L001McW1L001IcW19ooaMcW1L001IcW1L001McW0ioo`0037oo01McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000026mkLia_Ng>LKg]cW6mkLi`7000027>LKg]cW6mk
Lia_Ng>LKg/BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk5`00
00Q_Ng>LKg]cW6mkLia_Ng>L1`0000QcW6mkLia_Ng>LKg]cW6mk5`0001I_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`08Kg]cW6mkLia_Ng>LKg]cW0L00008Lia_Ng>L
Kg]cW6mkLia_NaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G
00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo000<OolG
Li`F000GLi`G0006Li`20007Ool20006Li`BOolFLi`G0006Li`20007Ool20006Li`G000FLi`BOol6
Li`20007Ool20006Li`G000FLi`G000GLi`>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/05`0000I_Ng>LKg]cW6mk000;Ool01P00Kg]cW6mkLia_Na9oo`0FLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/G00001VmkLia_Ng>LKg/000]oo`06
001_Ng>LKg]cW6mk5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W19oo`06Kg]cW6mkLia_N`002goo00H006mkLia_Ng>LKg/G00005VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L5P005g>L5`0017>L00<007ooOol02goo00<007>LLi`0
0W>L4Woo5W>L5`0017>L00<007ooOol02goo00<007>LLi`00W>L5`005W>L4Woo17>L00<007ooOol0
2goo00<007>LLi`00W>L5`005W>L5`005g>L3Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk01L00005Kg]cW6mkLi`0000>Ool01000Kg]cW6mk4Woo01IcW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL00005Kg]cW6mkLi`0000>Ool01000Kg]c
W6mk5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`05Kg]c
W6mkLi`0000>Ool01000Kg]cW6mk5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00>Ool000aooaMcW1H001McW1L000=cW003001oogoo00ioo`03001cW7>L019ooaIcW1L000=cW003
001oogoo00ioo`03001cW7>L01L001IcW19oo`=cW003001oogoo00ioo`03001cW7>L01L001IcW1L0
01McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000016mk
Lia_N`0047oo00<007>LKg/04Woo01IcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_NaL00004Kg]cW6mk000@Ool00`00Lia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo00A_Ng>LKg/0011oo`03001cW6mk01L0000FKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo000<OolGLi`F000GLi`G0003Li`00`00Oomoo`05
Ool20008Ool00`00Liaoo`0AOolFLi`G0003Li`00`00Oomoo`05Ool20008Ool00`00Li`0000F000F
Li`BOol3Li`00`00Oomoo`05Ool20008Ool00`00Li`0000F000FLi`G000GLi`>Ool000aoo`0GLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0000=_Ng>L00001goo0`0027oo00<0
06mkOol04Goo01IcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL00003
Kg]cW00000Moo`<000Qoo`03001_N`0001H0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`BOol00fmkLi`00007Ool30008Ool00`00Kg/0000F00005VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L5P005g>L5`000W>L00<007ooOol017oo
1@001goo00<007>LOol04Goo5W>L5`000W>L00<007ooOol017oo1@001goo00<007>L00005P005W>L
4Woo0W>L00<007ooOol017oo1@001goo00<007>L00005P005W>L5`005g>L3Woo000<Ool05g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L00003Kg]cW00000Moo`<000Moo`800003
Kg]oogoo011oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/G0000
0fmkLi`00007Ool30007Ool200000fmk0000000E00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L4Woo00=_Ng>L00001goo0`001goo0P0000=_N`0000005@0001I_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aooaMcW1H001McW1L0009cW003001o
ogoo00moo`03001cW7>L019ooaIcW1L0009cW003001oogoo00moo`03001cW7>L01L001IcW19oo`9c
W003001oogoo00moo`03001cW7>L01L001IcW1L001McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000016mkLia_N`0047oo00<007>LKg/04Woo01IcW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL00004Kg]cW6mk000@Ool00`00Lia_
N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo00A_Ng>L
Kg/0011oo`03001cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo
000<OolGLi`F000GLi`G0004Li`00`00Oomoo`0<Ool01000LiacW7>L4Woo5W>L5`0017>L00<007oo
Ool037oo00@007>LLiacW1L001IcW19oo`AcW003001oogoo00aoo`04001cW7>LLi`G000FLi`G000G
Li`>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0000E_Ng>L
Kg]cW00000ioo`04001_Ng>LKg/BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk5`0000E_Ng>LKg]cW00000ioo`04001_Ng>LKg/G00005VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo00E_Ng>LKg]cW00000ioo`04001_Ng>LKg/G0000
5VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L5P005g>L5`001G>L
00<007ooOol02Woo00<007>LLi`00W>L4Woo5W>L5`001G>L00<007ooOol02Woo00<007>LLi`00W>L
5`005W>L4Woo1G>L00<007ooOol02Woo00<007>LLi`00W>L5`005W>L5`005g>L3Woo000<Ool05g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L00006Kg]cW6mkLia_Ng>L0P0027oo
0P0000E_Ng>LKg]cW6mk019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/G00001VmkLia_Ng>LKg]cW08000Qoo`800005Kg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo00I_Ng>LKg]cW6mkLi`20008Ool20000
1FmkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000ao
oaMcW1H001McW1L000QcW003001oogoo00Aoo`03001cW7>L00EcW19ooaIcW1L000QcW003001oogoo
00Aoo`03001cW7>L00EcW1L001IcW19oo`QcW003001oogoo00Aoo`03001cW7>L00EcW1L001IcW1L0
01McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00002Fmk
Lia_Ng>LKg]cW6mkLia_N`06000027>LKg]cW6mkLia_Ng>LKg/BOol05W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk5`0000U_Ng>LKg]cW6mkLia_Ng>LKg/01P0000QcW6mk
Lia_Ng>LKg]cW6mk5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W19oo`09Kg]cW6mkLia_Ng>LKg]cW6mk00H00008Lia_Ng>LKg]cW6mkLia_NaL0000FKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo000<OolGLi`F000GLi`G000GLi`BOolFLi`G000G
Li`G000FLi`BOolGLi`G000FLi`G000GLi`>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/G0000
5fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00ioo`0037oo5`005W>L5`005g>L5`004Woo5P005g>L5`005g>L5P004Woo5`005g>L
5P005g>L5`003Woo000<OolG00002FmkLia_Ng>LKg]cW6mkLia_N`0400002G>LKg]cW6mkLia_Ng>L
Kg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`00
4Woo5P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`0027>L00<007oo
Ool00Woo0`001W>L5`005g>L5`004Woo2@0017oo2@005g>L5`005g>L5P004Woo5`005g>L2@0017oo
2@005g>L5`003Woo000<OolG00001VmkLia_Ng>LKg]cW08000Qoo`06001cW6mkLia_Ng>L5`0001Mc
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0019oo`L000Uoo`H0
000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00P000Qoo`H0000GKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL000EcW003001o
ogoo00Uoo`03001cW7>L009cW1L001McW1L0019oo`H000]oo`D001McW1L001McW1H0019ooaL001Mc
W0H000]oo`D001McW1L000ioo`0037oo5`0000E_Ng>LKg]cW00000eoo`04001cW6mkLi`G00005g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo1@003Goo1000
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@003Goo100001M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`0017>L00<007oo
Ool037oo00<007>LLi`05`005g>L5`004Woo1@003Woo0`005g>L5`005g>L5P004Woo5`005g>L1@00
3Woo0`005g>L5`003Woo000<OolG000016mkLia_N`0047oo00<007>L00005P0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0019oo`@0011oo`80000GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@0011oo`80000GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL0009cW003001oogoo00moo`03
001cW00001H001McW1L0019oo`<0015oo`8001McW1L001McW1H0019ooaL001McW0<0015oo`8001Mc
W1L000ioo`0037oo5`0000=_Ng>L00001goo0P0027oo00<007>L00005P0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0019oo`<000Moo`8000Qoo`80000GLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Moo`8000Qoo`80000GKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL0009cW003001o
ogoo00Aoo`<000Qoo`03001cW00001H001McW1L0019oo`<000Ioo`<000Qoo`8001McW1L001McW1H0
019ooaL001McW0<000Ioo`<000Qoo`8001McW1L000ioo`0037oo5`0000=_Ng>L00001goo0`001goo
00<007>L00005P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01L0019oo`<000Moo`<000Moo`80000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00<000Moo`<000Moo`80000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0G000>Ool000aooaL0009cW003001oogoo00Eoo`8000Qoo`03001cW00001H001McW1L0019o
o`<000Moo`8000Qoo`8001McW1L001McW1H0019ooaL001McW0<000Moo`8000Qoo`8001McW1L000io
o`0037oo5`0000=_Ng>L000047oo00<006mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0019oo`<0011oo`<0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00<0011oo`<0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL000=cW003001oogoo00eoo`03001cW7>L01L001McW1L0
019oo`<0011oo`<001McW1L001McW1H0019ooaL001McW0<0011oo`<001McW1L000ioo`0037oo5`00
00A_Ng>LKg/000ioo`04001cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`05`004Woo10003Woo100001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`010003Woo100001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01L000ioo`0037oo5`000g>L00<007ooOol037oo00@007>LLiacW1L001McW1L0019oo`@0
00ioo`@001McW1L001McW1H0019ooaL001McW0@000ioo`@001McW1L000ioo`0037oo5`0000E_Ng>L
Kg]cW00000aoo`05001_Ng>LKg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`05`004Woo1@0037oo1@0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`01@0037oo1@0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01L000ioo`0037oo5`001G>L0P0027oo0P001G>L5`005g>L5`004Woo1`002Goo1P005g>L
5`005g>L5P004Woo5`005g>L1`0027oo1`005g>L5`003Woo000<OolG00001fmkLia_Ng>LKg]cW6mk
00@0009oo`800007Lia_Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01L0019oo`/00003Ool0000000P0000GLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0009oo`T0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL000]cW08000UcW1L001McW1L0019ooaH001McW1L0
01McW1H0019ooaL001McW1H001McW1L000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00G000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L01H0019ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo
000<OolG000FLi`G000GLi`G000BOolF000GLi`G000GLi`F000BOolG000GLi`F000GLi`G000>Ool0
0?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00ogoo
U7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol0
0?mooiAoo`00ogooU7oo003oOonDOol000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`05`004Goo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F
000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P00
01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo
5`0027>L1`001g>L5`005g>L5`004Goo5`005g>L5`005g>L5P004Woo5`005g>L5P005g>L5`003Woo
000<OolG00001VmkLia_Ng>LKg]cW08000Moo`07001_Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0015ooaL0000GLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0080007Ool800005g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00P000Moo`L0000GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL000EcW003001oogoo00Qoo`80
00AcW1L001McW1L0015ooaL001McW0H000]oo`H001McW1H0019ooaL001McW0H000Yoo`H001McW1L0
00ioo`0037oo5`0000E_Ng>LKg]cW00000eoo`04001cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Goo5`0001McW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00D000eoo`D0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@003Goo100001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`0017>L00<007ooOol037oo00<007>LLi`0
5`005g>L5`004Goo5`005g>L1@003Woo10005g>L5P004Woo5`005g>L1@003Woo0`005g>L5`003Woo
000<OolG000016mkLia_N`003goo00<006mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0015ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW004000?Ool400005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00@000moo`<0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL000=cW003001oogoo00ioo`03001cW00001H001McW1L0
015ooaL001McW0@0011oo`<001McW1H0019ooaL001McW0@0011oo`8001McW1L000ioo`0037oo5`00
00=_Ng>L00004Goo00<007>L00005P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L01L0015ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW004000AOol200005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00<0015oo`80000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0G000>Ool000aooaL0009cW003001oogoo00Eoo`8000Qoo`03001cW00001H001McW1L0015o
oaL001McW0<000Qoo`8000Qoo`8001McW1H0019ooaL001McW0<000Moo`8000Qoo`8001McW1L000io
o`0037oo5`0000=_Ng>L00001Woo10001goo00<007>L00005P0001McW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0015ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030006Ool50007Ool200005g>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Ioo`@000Moo`80000GKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL0009cW003001oogoo00Eo
o`8000Qoo`03001cW00001H001McW1L0015ooaL001McW0<000Moo`<000Moo`<001McW1H0019ooaL0
01McW0<000Moo`8000Qoo`8001McW1L000ioo`0037oo5`0000=_Ng>L00004Goo00<007>L00005P00
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0015ooaL0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW003000AOol300005g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<0015oo`80000GKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL000=cW003
001oogoo00eoo`03001cW7>L01L001McW1L0015ooaL001McW0@0011oo`<001McW1H0019ooaL001Mc
W0<0011oo`<001McW1L000ioo`0037oo5`0000A_Ng>LKg/000ioo`04001cW6mkLi`G00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Goo5`0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000moo`@0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`003goo100001M_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`000g>L00<007ooOol0
37oo00@007>LLiacW1L001McW1L0015ooaL001McW0D000ioo`@001McW1H0019ooaL001McW0@000io
o`@001McW1L000ioo`0037oo5`0000E_Ng>LKg]cW00000aoo`05001_Ng>LKg]cW00G00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Goo5`0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00H000aoo`D0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@0037oo1@0001M_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`001G>L0P0027oo0P00
1G>L5`005g>L5`004Goo5`005g>L200027oo1`005g>L5P004Woo5`005g>L1`0027oo1`005g>L5`00
3Woo000<OolG00001fmkLia_Ng>LKg]cW6mk008000Eoo`08001cW6mkLia_Ng>LKg]cW1L0000GLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G000AOolG00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02@001Woo200001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019ooaL0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0090005Ool800005fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolG0009Li`50008Li`G
000GLi`G000AOolG000GLi`G000GLi`F000BOolG000GLi`F000GLi`G000>Ool000aooaL0000FKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Goo5`0001McW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`005g>L5`004Goo5`005g>L5`005g>L5P004Woo
5`005g>L5P005g>L5`003Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0AOol0
5fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00>Ool000aooaMcW1H001McW1L001McW15ooaMcW1L001McW1L001IcW19ooaMcW1L001IcW1L001Mc
W0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0
000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000026mkLia_
Ng>LKg]cW6mkLi`7000027>LKg]cW6mkLia_Ng>LKg/AOol026mkLia_Ng>LKg]cW6mkLi`7000027>L
Kg]cW6mkLia_Ng>LKg/G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0G
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0000QcW6mkLia_Ng>LKg]cW6mk1`00
00Q_Ng>LKg]cW6mkLia_Ng>L3Woo000<OolGLi`F000GLi`G0006Li`20007Ool20006Li`AOol7Li`0
0`00Oomoo`05Ool20006Li`G000GLi`G000FLi`BOolGLi`G000FLi`G0007Li`00`00Oomoo`05Ool2
0006Li`>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0000I_
Ng>LKg]cW6mk000;Ool01P00Kg]cW6mkLia_Na5oo`07Kg]cW6mkLia_Ng>L00002Woo0P0000AcW6mk
Lia_NaL0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G0000
5VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00001g>LKg]cW6mkLia_N`0000Yoo`800004Kg]cW6mk
Li`>Ool000aooaMcW1H001McW1L000AcW003001oogoo00]oo`03001cW7>L009cW15oo`EcW003001o
ogoo00]oo`04001cW7>LLi`G000GLi`G000FLi`BOolGLi`G000FLi`G0005Li`00`00Oomoo`0;Ool0
1000LiacW7>L3Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0
0005Kg]cW6mkLi`0000>Ool01000Kg]cW6mk4Goo00I_Ng>LKg]cW6mk000>Ool00`00Lia_N`0G0000
5fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L5`0000EcW6mkLia_N`0000moo`03001_Ng>L00ioo`0037oo5g>L5P00
5g>L5`000g>L00<007ooOol03Woo00<007>LLi`04Goo17>L00<007ooOol03Woo00<007>L00005P00
5g>L5`005W>L4Woo5g>L5`005W>L5`000g>L00<007ooOol03Woo00<007>LLi`03Woo000<Ool05g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L00004Kg]cW6mk000@Ool00`00Lia_
N`0AOol016mkLia_N`004Goo00<006mk00005P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_Ng>L
000@Ool00`00Kg]cW00>Ool000aooaMcW1H001McW1L000=cW003001oogoo00Eoo`8000Qoo`03001c
W7oo011oo`=cW003001oogoo00Eoo`8000Qoo`03001cW00001H001McW1L001IcW19ooaMcW1L001Ic
W1L000=cW003001oogoo00Eoo`8000Qoo`03001cW7oo00eoo`0037oo01McW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00000fmkLi`00007Ool30008Ool00`00Kg]oo`0@Ool016mk
Lia_N`001goo0P0027oo00<006mk00005P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_Ng>L0006
Ool30008Ool00`00Liaoo`0=Ool000aooaMcW1H001McW1L0009cW003001oogoo00Aoo`D000Moo`03
001cW7oo011oo`=cW003001oogoo00Aoo`@000Moo`03001cW00001H001McW1L001IcW19ooaMcW1L0
01IcW1L000=cW003001oogoo00=oo`D000Moo`03001cW7oo00eoo`0037oo01McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00000fmkLi`00007Ool30007Ool200000fmkOomoo`0?
Ool016mkLia_N`001goo0P0027oo00<006mk00005P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_
Ng>L0006Ool30008Ool00`00Liaoo`0=Ool000aooaMcW1H001McW1L0009cW003001oogoo00moo`03
001cW7>L015oo`=cW003001oogoo00moo`03001cW00001H001McW1L001IcW19ooaMcW1L001IcW1L0
00=cW003001oogoo00moo`03001cW7oo00eoo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0G000016mkLia_N`0047oo00<007>LKg/04Goo00A_Ng>LKg/0011oo`03001c
W6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G0000
5VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G000017>LKg]cW00047oo00<006mkLi`03Woo000<OolG
Li`F000GLi`G0004Li`00`00Oomoo`0<Ool01000LiacW7>L4Goo17>L00<007ooOol037oo00@007>L
LiacW1L001McW1L001IcW19ooaMcW1L001IcW1L000AcW003001oogoo00aoo`04001cW7>LLi`>Ool0
00aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0000E_Ng>LKg]cW000
00ioo`04001_Ng>LKg/AOol01FmkLia_Ng>L00003Woo00@006mkLia_NaL0000GKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`G00001G>LKg]cW6mk00003Woo00@007>LKg]cW0ioo`0037oo5g>L5P005g>L5`001G>L00<0
07ooOol02Woo00<007>LLi`00W>L4Goo1G>L00<007ooOol02Woo00<007>LLi`00W>L5`005g>L5`00
5W>L4Woo5g>L5`005W>L5`001G>L00<007ooOol02Woo00<007>LLi`00W>L3Woo000<Ool05g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L00006Kg]cW6mkLia_Ng>L0P0027oo0P00
00E_Ng>LKg]cW6mk015oo`06Kg]cW6mkLia_Ng>L0P0027oo0P0000E_Ng>LKg]cW6mk01L0000GKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`G00001W>LKg]cW6mkLia_N`8000Qoo`800005Lia_Ng>LKg]cW00>Ool000ao
oaMcW1H001McW1L000QcW003001oogoo00Aoo`03001cW7>L00EcW15oo`QcW08000Eoo`03001cW7>L
00EcW1L001McW1L001IcW19ooaMcW1L001IcW1L000QcW08000Eoo`03001cW7>L00EcW0ioo`0037oo
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00002FmkLia_Ng>LKg]cW6mk
Lia_N`06000027>LKg]cW6mkLia_Ng>LKg/AOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L1@0000QcW6mk
Lia_Ng>LKg]cW6mk5`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000:Lia_Ng>LKg]cW6mkLia_Ng>LKg/5
000026mkLia_Ng>LKg]cW6mkLi`>Ool000aooaMcW1H001McW1L001McW15ooaMcW1L001McW1L001Ic
W19ooaMcW1L001IcW1L001McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
4Goo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000GKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`03Woo000<OolG000FLi`G000GLi`G000AOolG000GLi`G000GLi`F000BOolG000GLi`F000G
Li`G000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Goo
5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L00009Lia_
Ng>LKg]cW6mkLia_Ng>L00@0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`F000BOolG00002G>LKg]cW6mk
Lia_Ng>LKg]cW00400002VmkLia_Ng>LKg]cW6mkLia_Ng>L5P0001M_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L2P0017oo2@005g>L5`00
4Goo5`005g>L5`0027>L00<007ooOol00Woo0`001g>L5P004Woo5`0027>L00<007ooOol00Woo0`00
1g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L20002Goo1P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L01L0015ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00G00001W>LKg]cW6mkLia_N`8000Qoo`07001_Ng>LKg]cW6mkLi`05P004Woo5`0000IcW6mk
Lia_Ng>LKg/20008Ool01`00Kg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL001IcW0L000]oo`D001McW1L0015ooaL0
01McW1L000EcW003001oogoo00Uoo`03001cW7>L00=cW1H0019ooaL000EcW003001oogoo00Uoo`03
001cW7>L00=cW1H001McW1L000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0H000eoo`@0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00G000AOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05`0000EcW6mkLia_N`0000eoo`05001_Ng>LKg]cW00F000BOolG00001G>LKg]c
W6mk00003Goo00D006mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL001IcW0H000ioo`<001McW1L0015ooaL001McW1L000Ac
W003001oogoo00aoo`04001cW7>LLi`F000BOolG0004Li`00`00Oomoo`0<Ool01000LiacW7>L5P00
5g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L1@0047oo0P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01L0015ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G
000017>LKg]cW00047oo00<006mkLi`05P004Woo5`0000AcW6mkLi`0011oo`03001_Ng>L01H0000G
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL0
01IcW0@0015oo`8001McW1L0015ooaL001McW1L0009cW003001oogoo00moo`03001cW7>L01H0019o
oaL0009cW003001oogoo00moo`03001cW7>L01H001McW1L000ioo`0037oo5`0001I_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0@000Moo`8000Qoo`80000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G000AOolG00005g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`0000=cW6mk00001goo0P0027oo00<0
06mkLi`05P004Woo5`0000=cW6mk00001goo0P0027oo00<006mkLi`05P0001M_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L10001Woo0`00
27oo0P005g>L5`004Goo5`005g>L5`000W>L00<007ooOol017oo10001goo00<007>LLi`05P004Woo
5`000W>L00<007ooOol017oo10001goo00<007>LLi`05P005g>L5`003Woo000<OolG00005VmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10001goo0`001goo0P0001McW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0015ooaL0000GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00000g>LKg/00007Ool40006
Ool00`00Kg]cW00F000BOolG00000g>LKg/00007Ool40006Ool00`00Kg]cW00F00005fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolG000FLi`40007
Ool20008Ool2000GLi`G000AOolG000GLi`G0002Li`00`00Oomoo`05Ool30007Ool00`00LiacW00F
000BOolG0002Li`00`00Oomoo`05Ool30007Ool00`00LiacW00F000GLi`G000>Ool000aooaL0000F
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`4000@Ool300005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Goo5`0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L00003Lia_N`00015oo`03001_
Ng>L01H0019ooaL00003Lia_N`00015oo`03001_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL001IcW0@0011oo`<001McW1L0015o
oaL001McW1L000=cW003001oogoo00ioo`03001cW7>L01H0019ooaL000=cW003001oogoo00ioo`03
001cW7>L01H001McW1L000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0D000ioo`@0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00G000AOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`05`0000AcW6mkLi`000moo`04001cW6mkLi`F000BOolG00001G>LKg]cW6mk00003Woo
00@007>LKg]cW1H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0G000>Ool000aooaL001IcW0D000ioo`@001McW1L0015ooaL001McW1L000AcW003001oogoo00ao
o`04001cW7>LLi`F000BOolG0004Li`00`00Oomoo`0<Ool01000LiacW7>L5P005g>L5`003Woo000<
OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L1P0037oo1@00
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0015ooaL0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00001W>LKg]cW6mk
Li`000aoo`05001_Ng>LKg]cW00F000BOolG00001W>LKg]cW6mkLi`000aoo`05001_Ng>LKg]cW00F
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<
OolG000FLi`80008Ool7000GLi`G000AOolG000GLi`G0006Li`20008Ool20005Li`F000BOolG0006
Li`20008Ool20005Li`F000GLi`G000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`<0003Ool800005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`05`004Goo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01L00008Lia_Ng>LKg]cW6mkLia_N`<000Aoo`08001cW6mkLia_Ng>LKg]c
W1H0019ooaL00008Lia_Ng>LKg]cW6mkLia_N`<000Aoo`08001cW6mkLia_Ng>LKg]cW1H0000GKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL001Ic
W1L001McW1L0015ooaL001McW1L000]cW0@000QcW1H0019ooaL000]cW0@000QcW1H001McW1L000io
o`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G000AOolG00005g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019ooaL0000GLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolG000FLi`G000GLi`G000AOolG000G
Li`G000GLi`F000BOolG000GLi`F000GLi`G000>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk015oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo2G>L10002W>L5P005g>L5`005g>L4Goo5g>L5`005g>L5`00
5W>L4Woo5g>L5`005W>L5`005g>L3Woo000<Ool01W>LKg]cW6mkLia_N`<000Aoo`<00007Lia_Ng>L
Kg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0AOol05fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/02P000goo2P0001M_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0X000Aoo`T0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00>Ool000aoo`EcW003001oogoo00Qoo`8000EcW1H001McW1L001McW15ooaMcW0L0
00Yoo`H001McW1L001IcW19ooaMcW1L001IcW0L000Yoo`H001McW0ioo`0037oo00EcW6mkLia_N`00
00eoo`05001_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
015oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`06000=Ool4
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L1P003Goo100001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo17>L00<007ooOol037oo00@007>LLiacW1H001McW1L0
01McW15ooaMcW0D000moo`<001McW1L001IcW19ooaMcW1L001IcW0H000ioo`<001McW0ioo`0037oo
00AcW6mkLi`000moo`04001cW6mkLi`F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk015oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`04
000@Ool300005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L1@003goo0`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo0g>L00<007ooOol03Woo00<007>LLi`05P00
5g>L5`005g>L4Goo5g>L100047oo0`005g>L5`005W>L4Woo5g>L5`005W>L1@0047oo0P005g>L3Woo
000<Ool00g>LKg/0000AOol00`00Kg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk015oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`04000@Ool300005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10004Goo0P0001McW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo0W>L00<007ooOol01Goo0P0027oo00<0
07>LLi`05P005g>L5`005g>L4Goo5g>L10001goo0P0027oo0P005g>L5`005W>L4Woo5g>L5`005W>L
10001goo0P0027oo0P005g>L3Woo000<Ool00g>LKg/00006Ool40007Ool00`00Kg]cW00F00005fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk015oo`0GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`040005Ool40008Ool200005fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L10001Woo0`0027oo0P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00ioo`0037oo0W>L00<007ooOol01Goo0`001goo00<007>LLi`05P005g>L5`005g>L4Goo
5g>L10001Woo0`0027oo0P005g>L5`005W>L4Woo5g>L5`005W>L10001goo0P0027oo0P005g>L3Woo
000<Ool00g>LKg/00007Ool20008Ool00`00Kg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk015oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`040007Ool20008Ool200005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W19oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10001goo0P0027oo0P0001Mc
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo0g>L00<0
07ooOol03Woo00<007>LLi`05P005g>L5`005g>L4Goo5g>L100047oo0`005g>L5`005W>L4Woo5g>L
5`005W>L100047oo0`005g>L3Woo000<Ool017>LKg]cW00047oo00<006mkLi`05P0001M_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000GKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0AOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0100047oo0`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0@0011oo`<0
000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aoo`Ac
W003001oogoo00aoo`04001cW7>LLi`F000GLi`G000GLi`AOolGLi`5000>Ool4000GLi`G000FLi`B
OolGLi`G000FLi`5000>Ool4000GLi`>Ool000aoo`05Lia_Ng>LKg/0000>Ool01000Lia_Ng>L5P00
01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000GKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0AOol05fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01@003Woo100001M_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W0D000ioo`@0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>
Ool000aoo`EcW003001oogoo00Yoo`03001cW7>L009cW1H001McW1L001McW15ooaMcW0H000aoo`D0
01McW1L001IcW19ooaMcW1L001IcW0H000aoo`D001McW0ioo`0037oo00IcW6mkLia_Ng>LKg/20008
Ool200001G>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0AOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0200027oo
1`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0P000Qoo`L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aoo`QcW0P000McW1H001McW1L001McW15ooaMcW1L001Mc
W1L001IcW19ooaMcW1L001IcW1L001McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/04Goo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0
000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`03Woo000<OolGLi`F000GLi`G000GLi`AOolGLi`G000GLi`G000FLi`BOolGLi`G
000FLi`G000GLi`>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
5`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk015oo`0GKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00io
o`0037oo5`005W>L5`005g>L5`004Goo5`005g>L5`005g>L5P004Woo5`005g>L5P005g>L5`003Woo
000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0000Qc
W6mkLia_Ng>LKg]cW6mk1`0000Q_Ng>LKg]cW6mkLia_Ng>L5`004Goo5`0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`001g>L00<007ooOol01Goo0P001W>L5`00
4Goo5`005g>L5`005g>L20001goo1`004Woo20001goo20005g>L5P005g>L5`003Woo000<OolG0000
5VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0000McW6mkLia_Ng>L
Kg/0000:Ool2000016mkLia_Ng>L5`004Goo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW006000:Ool6000BOol6000;Ool600005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`001G>L00<007ooOol02goo00@007>LLiacW1L0
015ooaL001McW1L001McW0D000eoo`@0019oo`D000eoo`D001McW1H001McW1L000ioo`0037oo5`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00005Lia_Ng>LKg/0
000?Ool00`00Kg]cW00G000AOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00D000ioo`<0019oo`D000ioo`@0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/05`003Woo000<OolG000FLi`G0003Li`00`00Oomoo`0>Ool00`00LiacW00G000AOolG000G
Li`G000GLi`4000?Ool3000BOol4000?Ool4000GLi`F000GLi`G000>Ool000aooaL0000FKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G000017>LKg]cW00047oo00<006mk
Li`05`004Goo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW004000@Ool2
000BOol4000@Ool300005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000io
o`0037oo5`005W>L5`000g>L00<007ooOol03goo00<007>L00005P004Goo5`005g>L5`005g>L0`00
4Goo0P004Woo10004Goo0P005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0000AcW6mkLi`000Moo`8000Qoo`03001cW00001H0
015ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G0000
5g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001goo0P0027oo
0P004Woo10001goo0P0027oo0P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0G000>Ool000aooaL001IcW1L000=cW003001oogoo00=oo`D000Moo`03001cW00001H0015ooaL0
01McW1L001McW0<000Ioo`@000Moo`80019oo`<000Ioo`D000Moo`8001McW1H001McW1L000ioo`00
37oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_
Ng>L0006Ool30008Ool00`00Li`0000F000AOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00<000Moo`8000Qoo`80019oo`<000Moo`<000Moo`<0000GLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolG000FLi`G0003Li`00`00Oomoo`0?
Ool00`00Li`0000F000AOolG000GLi`G000GLi`3000AOol2000BOol3000AOol3000GLi`F000GLi`G
000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G
000017>LKg]cW00047oo00<006mkLi`05`004Goo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW003000@Ool3000BOol4000@Ool300005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`000g>L00<007ooOol03Woo00<007>LLi`0
5`004Goo5`005g>L5`005g>L0`0047oo0`004Woo100047oo0`005g>L5P005g>L5`003Woo000<OolG
00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0000EcW6mkLia_
N`0000ioo`04001cW6mkLi`G000AOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00@000ioo`@0019oo`D000ioo`@0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/05`003Woo000<OolG000FLi`G0005Li`00`00Oomoo`0;Ool01000LiacW7>L5`004Goo
5`005g>L5`005g>L1@003Goo10004Woo1P003Goo10005g>L5P005g>L5`003Woo000<OolG00005Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0000IcW6mkLia_Ng>LKg/2
000:Ool01@00Kg]cW6mkLi`05`004Goo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW007000:Ool5000BOol8000:Ool500005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`0027>L0P001Woo0P001G>L5`004Goo5`005g>L5`00
5g>L2@001Woo1`004Woo2@001goo1`005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0000YcW6mkLia_Ng>LKg]cW6mkLia_N`H0
0007Lia_Ng>LKg]cW6mkLi`05`004Goo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0
00ioo`0037oo5`005W>L5`005g>L5`004Goo5`005g>L5`005g>L5P004Woo5`005g>L5P005g>L5`00
3Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`00
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0015ooaL0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool008mooaL001McW1L001McW1H0099oo`00
ogooU7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonD
Ool00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00
ogooU7oo003oOonDOol000aooaL001IcW1L001McW1L0019ooaH001McW1L001McW1H0019ooaL001Mc
W1H001McW1L000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G
000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`00
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019ooaL0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00200002VmkLia_Ng>LKg]cW6mkLia_Ng>L5P0001M_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo2`000Woo2P00
5W>L5`005g>L5`004Woo2`000Woo2@005g>L5`005g>L5P004Woo5`0027>L0`000Woo0`001g>L5P00
5g>L5`003Woo000<Ool80008Ool700005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01L0019oo`L000Uoo`H0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P00
4Woo5`0000IcW6mkLia_Ng>LKg/20008Ool01`00Kg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aoo`H000]oo`H001IcW1L0
01McW1L0019oo`H000]oo`D001McW1L001McW1H0019ooaL000EcW003001oogoo00Uoo`03001cW7>L
00=cW1H001McW1L000ioo`0037oo1@003Goo1@0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00G000BOol5000=Ool400005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L01H0019ooaL00005Lia_Ng>LKg/0000=Ool01@00Kg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo1@003Woo10005W>L5`00
5g>L5`004Woo1@003Woo0`005g>L5`005g>L5P004Woo5`0017>L00<007ooOol037oo00@007>LLiac
W1H001McW1L000ioo`0037oo100047oo0`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00G000BOol4000@Ool200005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01H0019ooaL00004Lia_Ng>L000@Ool00`00Kg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<Ool3000AOol3000FLi`G000GLi`G000BOol3
000AOol2000GLi`G000GLi`F000BOolG0002Li`00`00Oomoo`0?Ool00`00LiacW00F000GLi`G000>
Ool000aoo`<000Moo`8000Qoo`<0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
5`004Woo0`001goo0P0027oo0P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00F000BOolG00000g>LKg/00007Ool20008Ool00`00Kg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<Ool30006Ool40007Ool3000FLi`G
000GLi`G000BOol30006Ool30008Ool2000GLi`G000GLi`F000BOolG0002Li`00`00Oomoo`04Ool4
0007Ool00`00LiacW00F000GLi`G000>Ool000aoo`<000Moo`@000Ioo`<0000FKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo0`001goo0`001goo0P0001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00000g>LKg/00007Ool40006Ool00`00Kg]c
W00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo
000<Ool30007Ool30007Ool3000FLi`G000GLi`G000BOol30007Ool20008Ool2000GLi`G000GLi`F
000BOolG0002Li`00`00Oomoo`05Ool30007Ool00`00LiacW00F000GLi`G000>Ool000aoo`<0015o
o`<0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo0`0047oo0`0001Mc
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00000g>LKg/0000AOol0
0`00Kg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
5`003Woo000<Ool4000@Ool3000FLi`G000GLi`G000BOol3000@Ool3000GLi`G000GLi`F000BOolG
0003Li`00`00Oomoo`0>Ool00`00LiacW00F000GLi`G000>Ool000aoo`D000ioo`@0000FKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo10003Woo100001McW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00001G>LKg]cW6mk00003Woo00@007>LKg]c
W1H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool0
00aoo`D000ioo`@001IcW1L001McW1L0019oo`@000ioo`@001McW1L001McW1H0019ooaL000AcW003
001oogoo00aoo`04001cW7>LLi`F000GLi`G000>Ool000aoo`H000aoo`D0000FKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo1@0037oo1@0001McW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00001W>LKg]cW6mkLi`000aoo`05001_Ng>LKg]cW00F
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<
Ool80008Ool7000FLi`G000GLi`G000BOol70009Ool6000GLi`G000GLi`F000BOolG0006Li`20008
Ool20005Li`F000GLi`G000>Ool000aoo`/000Aoo`P0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05`004Woo2`000goo200001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00F000BOolG000027>LKg]cW6mkLia_Ng>LKg/30004Ool02000Lia_Ng>LKg]cW6mkLi`F
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<
OolG000FLi`G000GLi`G000BOolF000GLi`G000GLi`F000BOolG000;Li`40008Li`F000GLi`G000>
Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G0000
5g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo5P0001Mc
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`005g>L5`004Woo5P00
5g>L5`005g>L5P004Woo5`005g>L5P005g>L5`003Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
5`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00>Ool000aooaMcW1H000YcW0@000UcW1L001McW19ooaIcW1L001McW1L001Ic
W19ooaMcW1L001IcW1L001McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01H00007Kg]cW6mkLia_Ng>LKg/00`0017oo0`0000IcW6mkLia_Ng>LKg/G
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01IcW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`090004Ool:00005VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`:0004Ool900005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`03Woo000<OolGLi`F0007Li`00`00Oomoo`07Ool20004Li`G000GLi`BOolFLi`G000GLi`7
0009Ool7000FLi`BOolGLi`G000FLi`80009Ool6000GLi`>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00001fmkLia_Ng>LKg]cW00000aoo`04001_
Ng>LKg/G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo
01IcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`06000<Ool500005VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`7000<Ool400005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`03Woo000<OolGLi`F0005Li`00`00Oomoo`0<Ool00`00LiacW00G000GLi`BOolF
Li`G000GLi`5000>Ool4000FLi`BOolGLi`G000FLi`6000>Ool3000GLi`>Ool000aoo`0GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00001FmkLia_Ng>L00003goo
00<007>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/G00005fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/010003goo100001I_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L1@003goo0`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L5P0017>L00<007ooOol03Woo00<007>L00005P005g>L
4Woo5W>L5`005g>L100047oo0`005W>L4Woo5g>L5`005W>L1@0047oo0P005g>L3Woo000<Ool05g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0000A_Ng>LKg/0015o
o`03001_N`0001H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk5`0001M_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<0015oo`<0000FKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0@0015oo`80000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00>Ool000aooaMcW1H000=cW003001oogoo00Eoo`8000Qoo`03001cW000
01H001McW19ooaIcW1L001McW0<000Moo`8000Qoo`<001IcW19ooaMcW1L001IcW0@000Moo`8000Qo
o`8001McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L01H00004Kg]cW6mk0006Ool30008Ool00`00Kg/0000F00005fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01IcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`030006Ool40007Ool300005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`40006Ool30008
Ool200005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo000<
OolGLi`F0003Li`00`00Oomoo`05Ool20008Ool00`00Li`0000F000GLi`BOolFLi`G000GLi`30007
Ool30007Ool3000FLi`BOolGLi`G000FLi`40007Ool20008Ool2000GLi`>Ool000aoo`0GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000016mkLia_N`001goo0P00
27oo00<006mk00005P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/G00005fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/00`001goo0P0027oo0`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0GKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10001goo0P0027oo0P0001McW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L5P000g>L00<007ooOol03Woo
00<007>LLi`05`005g>L4Woo5W>L5`005g>L100047oo0`005W>L4Woo5g>L5`005W>L100047oo0`00
5g>L3Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
5P0000A_Ng>LKg/0011oo`03001cW6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk5`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@0
011oo`<0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`BOol05fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0@0011oo`<0000GLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aooaMcW1H000AcW003001oogoo00ao
o`04001cW7>LLi`G000GLi`BOolFLi`G000GLi`4000?Ool4000FLi`BOolGLi`G000FLi`5000>Ool4
000GLi`>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00F00001FmkLia_Ng>L00003Woo00@006mkLia_NaL0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0BOol05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk5`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00D000ioo`@0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B
Ool05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001I_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0D000ioo`@0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aooaMcW1H000EcW003001o
ogoo00Yoo`03001cW7>L009cW1L001McW19ooaIcW1L001McW0H000aoo`D001IcW19ooaMcW1L001Ic
W0H000aoo`D001McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L01H00006Kg]cW6mkLia_Ng>L0P0027oo0P0000E_Ng>LKg]cW6mk01L0000GKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0BOol05W>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk5`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00P000Qoo`L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0P0
00Qoo`L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool0
00aooaMcW1H000QcW0P000McW1L001McW19ooaIcW1L001McW1L001IcW19ooaMcW1L001IcW1L001Mc
W0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0
000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01IcW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo000<OolGLi`F000G
Li`G000GLi`BOolFLi`G000GLi`G000FLi`BOolGLi`G000FLi`G000GLi`>Ool000aoo`0GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0G
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5`005W>L5`005g>L5`004Woo5P005g>L
5`005g>L5P004Woo5`005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01L0019ooaH00008Lia_Ng>LKg]cW6mkLia_N`L00008Kg]cW6mkLia_Ng>L
Kg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000B
OolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`00
5W>L5`005g>L20001goo20004Woo5P001g>L00<007ooOol01Goo0P001W>L5`005g>L5P004Woo2000
1goo20005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00H000]oo`H0019ooaH00007Lia_Ng>LKg]cW6mk00002Woo0P0000A_Ng>LKg]cW1L0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOol6000;Ool6
00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L
5`005g>L1@003Goo1@004Woo5P001G>L00<007ooOol02goo00@007>LLiacW1L001McW1H0019oo`D0
00eoo`D001McW1H001McW1L000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW005000>Ool4000BOolF00001G>LKg]cW6mk00003goo00<006mkLi`05`0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019oo`D000ioo`@0000GLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolG000FLi`G000GLi`4
000?Ool4000BOolF0003Li`00`00Oomoo`0>Ool00`00LiacW00G000GLi`F000BOol4000?Ool4000G
Li`F000GLi`G000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
100047oo0`004Woo5P0000AcW6mkLi`0011oo`03001_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOol4000@Ool300005g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`005g>L10004Goo0P004Woo
5P000g>L00<007ooOol03goo00<007>L00005P005g>L5P004Woo10004Goo0P005g>L5P005g>L5`00
3Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`00
01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000Moo`8000Qo
o`80019ooaH00004Lia_Ng>L0007Ool20008Ool00`00Li`0000F00005g>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo10001goo0P0027oo0P0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL001IcW1L001McW0<000Io
o`D000Moo`80019ooaH000=cW003001oogoo00=oo`D000Moo`03001cW00001H001McW1H0019oo`<0
00Ioo`D000Moo`8001McW1H001McW1L000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0030007Ool30007Ool3000BOolF000017>LKg]cW0001Woo0`0027oo00<007>L
00005P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019o
o`<000Moo`<000Moo`<0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`00
3Woo000<OolG000FLi`G000GLi`3000AOol3000BOolF0003Li`00`00Oomoo`0?Ool00`00Li`0000F
000GLi`F000BOol3000AOol3000GLi`F000GLi`G000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`0100047oo0`004Woo5P0000AcW6mkLi`0011oo`03001_Ng>L01L0
000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOol4000@
Ool300005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`00
5W>L5`005g>L100047oo0`004Woo5P000g>L00<007ooOol03Woo00<007>LLi`05`005g>L5P004Woo
100047oo0`005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00D000ioo`@0019ooaH00005Lia_Ng>LKg/0000>Ool01000Lia_Ng>L5`0001McW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019oo`D000ioo`@0000G
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolG000FLi`G000G
Li`6000=Ool4000BOolF0005Li`00`00Oomoo`0;Ool01000LiacW7>L5`005g>L5P004Woo1P003Goo
10005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00P000Yoo`D0019ooaH00006Lia_Ng>LKg]cW6mk0P002Woo00D006mkLia_Ng>L01L0000GLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOol8000:Ool50000
5g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`00
5g>L2@001goo1`004Woo5P0027>L0P001goo00<007>LLi`00g>L5`005g>L5P004Woo2@001goo1`00
5g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01L0019ooaH0000:Lia_Ng>LKg]cW6mkLia_Ng>LKg/700001VmkLia_Ng>LKg]cW1L0000GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L000ioo`0037oo5`005W>L5`005g>L5`004Woo
5P005g>L5`005g>L5P004Woo5`005g>L5P005g>L5`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01L0019ooaH0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0G000>Ool000aooaL001IcW1L001McW1L0019ooaH001McW1L001McW1H0019ooaL001McW1H001Mc
W1L000ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01IcW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01L0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G0000
5g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo000<OolGLi`F
000GLi`G000GLi`BOolFLi`G000GLi`G0007Li`80007Li`BOolGLi`G0008Li`70007Li`G000GLi`>
Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0080007
Ool700005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk019oo`0FLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/G00005fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0000M_Ng>LKg]cW6mkLi`00008Ool01`00Kg]cW6mk
Lia_Ng>L019oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G
00001VmkLia_Ng>LKg]cW08000Moo`07001_Ng>LKg]cW6mkLi`05`0001McW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L1P002Woo1P005g>L5`005g>L
4Woo5W>L5`005g>L5`001G>L00<007ooOol027oo0P0017>L4Woo5g>L5`001G>L00<007ooOol027oo
0P0017>L5`005g>L3Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`01@003Goo100001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B
Ool05W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk5`0001M_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L00005Kg]cW6mkLi`0000=Ool0
1000Lia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01L00005Kg]cW6mkLi`0000=Ool01000Lia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L1@003Woo0`005g>L5`005g>L4Woo5W>L5`00
5g>L5`0017>L00<007ooOol037oo00<007>LLi`04Woo5g>L5`0017>L00<007ooOol037oo00<007>L
Li`05`005g>L3Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`010003goo0`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0BOol0
5W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk5`0001M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L00004Kg]cW6mk000?Ool00`00Kg]c
W00BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0000A_
Ng>LKg/000moo`03001_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00>Ool000aooaMcW0@0011oo`8001McW1L001McW19ooaIcW1L001McW1L000=cW003
001oogoo00ioo`03001cW7oo015ooaMcW1L000=cW003001oogoo00ioo`03001cW00001H001McW0io
o`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<0015o
o`80000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01IcW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00000fmkLi`0000AOol00`00Liaoo`0AOol05fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0000=_Ng>L00004Goo00<0
07>L00005P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00io
o`0037oo5g>L0`001goo0P0027oo0P005g>L5`005g>L4Woo5W>L5`005g>L5`000W>L00<007ooOol0
1Goo0P0027oo00<007>LOol04Goo5g>L5`000W>L00<007ooOol01Goo0P0027oo00<007>L00005P00
5g>L3Woo000<Ool05g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
0`001Woo10001goo0P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01L0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0BOol0
5W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk5`0001M_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L00003Kg]cW00000Ioo`@000Moo`03
001cW7oo015oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G
00000fmkLi`00006Ool40007Ool00`00Li`0000F00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo000<OolGLi`30007Ool20008Ool2000GLi`G000GLi`BOolF
Li`G000GLi`G0002Li`00`00Oomoo`05Ool20008Ool00`00Liaoo`0AOolGLi`G0002Li`00`00Oomo
o`05Ool20008Ool00`00Li`0000F000GLi`>Ool000aoo`0GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW003000AOol200005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0000=_
Ng>L00004Goo00<007>LOol04Goo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk01L00003Kg]cW000015oo`03001cW00001H0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aooaMcW0@000moo`<001McW1L001McW19ooaIc
W1L001McW1L0009cW003001oogoo00ioo`03001cW7>L019ooaMcW1L0009cW003001oogoo00ioo`03
001cW7>L01L001McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00@000ioo`@0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
4Woo01IcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00000fmkLi`0000?Ool01000
Lia_Ng>L4Woo01M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01L0
0003Kg]cW00000moo`04001cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`03Woo000<OolGLi`4000>Ool4000GLi`G000GLi`BOolFLi`G000GLi`G0003
Li`00`00Oomoo`0<Ool01000LiacW7>L4Woo5g>L5`000g>L00<007ooOol037oo00@007>LLiacW1L0
01McW0ioo`0037oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00D000aoo`D0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G
00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01IcW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00001FmkLia_Ng>L000037oo00D006mkLia_
Ng>L019oo`0GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G0000
1FmkLia_Ng>L000037oo00D006mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00>Ool000aooaMcW0L000Qoo`L001McW1L001McW19ooaIcW1L001Mc
W1L000EcW08000Uoo`03001cW7>L00=cW19ooaMcW1L000EcW08000Qoo`8000EcW1L001McW0ioo`00
37oo01McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00T000Eoo`P0
000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04Woo01IcW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NaL0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00001fmkLia_Ng>LKg]cW6mk008000Eoo`<00005Lia_Ng>L
Kg]cW00BOol05fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`00
00M_Ng>LKg]cW6mkLia_N`020005Ool02000Lia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03Woo000<OolGLi`F000GLi`G000GLi`BOolF
Li`G000GLi`G0009Li`50008Li`BOolGLi`G0009Li`50008Li`G000GLi`>Ool000aoo`0GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk019oo`0FLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/G00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/05`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW19oo`0G
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G00005VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00ioo`0037oo5g>L5P005g>L5`005g>L4Woo5W>L5`00
5g>L5`005W>L4Woo5g>L5`005W>L5`005g>L3Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01L0019ooaH0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0G000>
Ool000aooaL001IcW1L001McW1L0019ooaH001McW1L001McW1H0019ooaL001McW1H001McW1L000io
o`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00008
Lia_Ng>LKg]cW6mkLia_N`L00008Kg]cW6mkLia_Ng>LKg]cW1L0019ooaH0000GLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00G00005g>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0G000>Ool000aooaL001IcW1L000McW003001oogoo00Eoo`8000IcW1L0
019ooaH001McW0P000Moo`P001McW1H0019ooaL001McW1H001McW0P000Moo`P000ioo`0037oo5`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00007Lia_Ng>LKg]c
W6mk00002Woo0P0000A_Ng>LKg]cW1L0019ooaH0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW006000;Ool600005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`07000:Ool6000>Ool000aooaL001IcW1L000EcW003001oogoo00]oo`04001cW7>LLi`G
000BOolF000GLi`5000=Ool5000GLi`F000BOolG000GLi`F000GLi`6000=Ool4000>Ool000aooaL0
000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00001G>LKg]cW6mk
00003goo00<006mkLi`05`004Woo5P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00D000ioo`@0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00D000moo`<000ioo`0037oo5`005W>L5`000g>L00<007ooOol03Woo00<007>LLi`05`004Woo5P00
5g>L100047oo0`005g>L5P004Woo5`005g>L5P005g>L100047oo0`003Woo000<OolG00005VmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L5`0000AcW6mkLi`0011oo`03001_
Ng>L01L0019ooaH0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W004000@Ool300005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
5P004Woo5`0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0
000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`04000@Ool3000>
Ool000aooaL001IcW1L000=cW003001oogoo00Eoo`8000Qoo`03001cW00001H0019ooaH001McW0@0
00Moo`8000Qoo`8001McW1H0019ooaL001McW1H001McW0@000Moo`8000Qoo`8000ioo`0037oo5`00
01I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1L00004Lia_Ng>L0006
Ool30008Ool00`00Li`0000F000BOolF00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`00`001goo0`0027oo0P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01H0019ooaL0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/010001Woo0`0027oo0P003Woo000<OolG000FLi`G0003Li`00`00Oomoo`03Ool50007
Ool00`00Li`0000F000BOolF000GLi`30006Ool50007Ool2000GLi`F000BOolG000GLi`F000GLi`4
0005Ool50007Ool2000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`G000017>LKg]cW0001Woo0`0027oo00<007>L00005P004Woo5P0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Moo`<000Moo`<0000GLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F000BOolG00005g>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@000Ioo`<000Qoo`8000ioo`0037oo5`00
5W>L5`000g>L00<007ooOol03Woo00<007>LLi`05`004Woo5P005g>L0`004Goo0`005g>L5P004Woo
5`005g>L5P005g>L100047oo0`003Woo000<OolG00005VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L5`0000AcW6mkLi`0011oo`03001_Ng>L01L0019ooaH0000GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW004000@Ool300005g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`04000@Ool3000>Ool000aooaL001IcW1L000AcW003
001oogoo00aoo`04001cW7>LLi`G000BOolF000GLi`5000>Ool4000GLi`F000BOolG000GLi`F000G
Li`5000>Ool4000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`G00001G>LKg]cW6mk00003Woo00@007>LKg]cW1L0019ooaH0000GLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW005000>Ool400005g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`05000>Ool4000>Ool000aooaL001IcW1L000EcW003001oogoo
00Yoo`03001cW7>L009cW1L0019ooaH001McW0H000aoo`D001McW1H0019ooaL001McW1H001McW0H0
00aoo`D000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW1L00006Lia_Ng>LKg]cW6mk0P0027oo0P0000EcW6mkLia_Ng>L01L0019ooaH0000GLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0080008Ool700005g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05P004Woo5`0001McW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0000GKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`080008Ool7000>Ool000aooaL001IcW1L000QcW080
00Eoo`03001cW7>L00EcW1L0019ooaH001McW0T000Ioo`P001McW1H0019ooaL001McW1H001McW0X0
00Eoo`P000ioo`0037oo5`0001I_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW1L0000:Lia_Ng>LKg]cW6mkLia_Ng>LKg/5000026mkLia_Ng>LKg]cW6mkLi`G000BOolF0000
5g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`05`0001McW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01H0019ooaL0000GLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00F00005fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/05`003Woo000<OolG000FLi`G000GLi`G000BOolF
000GLi`G000GLi`F000BOolG000GLi`F000GLi`G000>Ool000aooaL0000FKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`G00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`05`004Woo5P0001McW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01L0000GLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00F000BOolG00005g>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`05P0001M_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01L000ioo`00ogooU7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00ogoo
U7oo003oOonDOol00?mooiAoo`00ogooU7oo003oOonDOol00?mooiAoo`00\
\>"],
  ImageRangeCache->{{{0, 402}, {402, 0}} -> {-0.0750158, -0.0750158, 
  0.00783591, 0.00783591}, {{9.5625, 129.188}, {392.375, 272.75}} -> {
  0.455301, 0.452558, 0.0438876, 0.0438876}, {{141.125, 260.813}, {392.375, 
  272.75}} -> {-5.32004, 0.452558, 0.0438876, 0.0438876}, {{272.75, 
  392.375}, {392.375, 272.75}} -> {-11.0954, 0.452558, 0.0438876, 
  0.0438876}, {{9.5625, 129.188}, {260.813, 141.125}} -> {0.455301, -5.32278, 
  0.0438876, 0.0438876}, {{141.125, 260.813}, {260.813, 
  141.125}} -> {-5.31543, -5.31817, 0.0438647, 0.0438647}, {{272.75, 
  392.375}, {260.813, 141.125}} -> {-11.0954, -5.32278, 0.0438876, 
  0.0438876}, {{9.5625, 129.188}, {129.188, 9.5625}} -> {0.455301, -11.0981, 
  0.0438876, 0.0438876}, {{141.125, 260.813}, {129.188, 
  9.5625}} -> {-5.32004, -11.0981, 0.0438876, 0.0438876}, {{272.75, 
  392.375}, {129.188, 9.5625}} -> {-11.0954, -11.0981, 0.0438876, 0.0438876}}],\


Cell[OutputFormData["\<\
GraphicsArray[{{Graphics[{{{GrayLevel[0], 
        {{Rectangle[{1, 1}, {2, 2}], Rectangle[{1, 3}, {2, 4}], 
          Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, \
5}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}}}, AspectRatio -> 1]}}]\
\>", "\<\
-GraphicsArray-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[qsg[[10]]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 -0.166667 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.02381 .02381 m
.02381 .21429 L
.21429 .21429 L
.21429 .02381 L
F
.02381 .40476 m
.02381 .59524 L
.21429 .59524 L
.21429 .40476 L
F
.02381 .78571 m
.02381 .97619 L
.21429 .97619 L
.21429 .78571 L
F
.40476 .02381 m
.40476 .21429 L
.59524 .21429 L
.59524 .02381 L
F
.40476 .40476 m
.40476 .59524 L
.59524 .59524 L
.59524 .40476 L
F
.40476 .78571 m
.40476 .97619 L
.59524 .97619 L
.59524 .78571 L
F
.78571 .02381 m
.78571 .21429 L
.97619 .21429 L
.97619 .02381 L
F
.78571 .40476 m
.78571 .59524 L
.97619 .59524 L
.97619 .40476 L
F
.78571 .78571 m
.78571 .97619 L
.97619 .97619 L
.97619 .78571 L
F
.9 g
.02381 .21429 m
.02381 .40476 L
.21429 .40476 L
.21429 .21429 L
F
.02381 .59524 m
.02381 .78571 L
.21429 .78571 L
.21429 .59524 L
F
.40476 .21429 m
.40476 .40476 L
.59524 .40476 L
.59524 .21429 L
F
.40476 .59524 m
.40476 .78571 L
.59524 .78571 L
.59524 .59524 L
F
.78571 .21429 m
.78571 .40476 L
.97619 .40476 L
.97619 .21429 L
F
.78571 .59524 m
.78571 .78571 L
.97619 .78571 L
.97619 .59524 L
F
0 g
.21429 .21429 m
.21429 .40476 L
.40476 .40476 L
.40476 .21429 L
F
.21429 .59524 m
.21429 .78571 L
.40476 .78571 L
.40476 .59524 L
F
.59524 .21429 m
.59524 .40476 L
.78571 .40476 L
.78571 .21429 L
F
.59524 .59524 m
.59524 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.9 g
.21429 .02381 m
.21429 .21429 L
.40476 .21429 L
.40476 .02381 L
F
.21429 .40476 m
.21429 .59524 L
.40476 .59524 L
.40476 .40476 L
F
.21429 .78571 m
.21429 .97619 L
.40476 .97619 L
.40476 .78571 L
F
.59524 .02381 m
.59524 .21429 L
.78571 .21429 L
.78571 .02381 L
F
.59524 .40476 m
.59524 .59524 L
.78571 .59524 L
.78571 .40476 L
F
.59524 .78571 m
.59524 .97619 L
.78571 .97619 L
.78571 .78571 L
F
1 g
.88095 .11905 m
.88095 .11905 .07619 0 365.73 arc
F
.5 .30952 m
.5 .30952 .07619 0 365.73 arc
F
.11905 .5 m
.11905 .5 .07619 0 365.73 arc
F
.69048 .69048 m
.69048 .69048 .07619 0 365.73 arc
F
.30952 .88095 m
.30952 .88095 .07619 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.88095 .11905 .07619 0 365.73 arc
s
newpath
.5 .30952 .07619 0 365.73 arc
s
newpath
.11905 .5 .07619 0 365.73 arc
s
newpath
.69048 .69048 .07619 0 365.73 arc
s
newpath
.30952 .88095 .07619 0 365.73 arc
s
.88095 .11905 m
.88095 .11905 .01905 0 365.73 arc
F
.5 .30952 m
.5 .30952 .01905 0 365.73 arc
F
.11905 .5 m
.11905 .5 .01905 0 365.73 arc
F
.69048 .69048 m
.69048 .69048 .01905 0 365.73 arc
F
.30952 .88095 m
.30952 .88095 .01905 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{194, 194},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000320000`Q000`40O003h00O`Woo0032Ool00<9o
o`00`Woo0032Ool00<9oo`0017oo9@009G>L90009G>L9@001Woo0004OolU00009FmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo0004OolU000ULi`T000ULi`U0006Ool000AoobD0
000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000AoobD002EcW2@002Ec
W10000Qoo`d000Ioo`0017oo9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00d0
00eoo`/000Ioo`0017oo9@009G>L90009G>L2P004Woo2@001Woo0004OolU00009FmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02@0057oo20001Woo0004OolU000ULi`T000ULi`9000EOol7
0006Ool000AoobD0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW008000GOol60006
Ool000AoobD002EcW2@002EcW0L001Qoo`H000Ioo`0017oo9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T0000
9G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00H001Yoo`D000Ioo`0017oo9@009G>L90009G>L1P006Woo1@001Woo0004
OolU00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@0077oo10001Woo0004OolU
000ULi`T000ULi`5000LOol40006Ool000AoobD0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW005000;Ool5000<Ool40006Ool000AoobD002EcW2@002EcW0D000]oo`D000aoo`@000Io
o`0017oo9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00D000Yoo`L000]oo`@0
00Ioo`0017oo9@009G>L90009G>L1@002Woo1`002goo10001Woo0004OolU00009FmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@002goo1@0037oo10001Woo0004OolU000ULi`T000ULi`5
000;Ool5000<Ool40006Ool000AoobD0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W005000LOol40006Ool000AoobD002EcW2@002EcW0H001Yoo`D000Ioo`0017oo9@0002E_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00H001Yoo`D000Ioo`0017oo9@009G>L90009G>L1P00
6Woo1@001Woo0004OolU00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01`0067oo
1P001Woo0004OolU000ULi`T000ULi`8000GOol60006Ool000AoobD0000UKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW009000EOol70006Ool000AoobD002EcW2@002EcW0X001=oo`P000Io
o`0017oo9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0015oo`T000Ioo`00
17oo9@009G>L90009G>L30003Woo2`001Woo0004OolU00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk02@0000ULia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`03P002Goo3P001Woo0004OolU000ULi`T000ULi`U0006Ool000AoobD0000UKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000AoobD002EcW2@002EcW2D000Io
o`0017oo9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D000Ioo`0017oo9@00
9G>L90009G>L9@001Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D0000TLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk9@0002E_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D002AcW2D002EcW0Ioo`0017oo02EcW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00U000097>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_NbD0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01Woo0004OolULi`U000<Li`<000<
Li`U000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@0000acW6mkLia_Ng>LKg]cW6mkLia_Ng>L
000<Ool200002W>LKg]cW6mkLia_Ng>LKg]cW6mk9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`06Ool000AoobEc
W2D000UcW08000moo`03001cW7>L00McW2D002EcW0Ioo`0017oo02EcW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0000
2G>LKg]cW6mkLia_Ng>LKg/0000BOol02@00Lia_Ng>LKg]cW6mkLia_N`0U00009FmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00Ioo`0017oo9G>L9@001g>L00<007ooOol04Woo00<007>LLi`01G>L9@009G>L1Woo0004Ool0
9G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L02D00007Lia_Ng>LKg]cW6mk00005Woo00L007>LKg]cW6mkLia_N`0U0000
9FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@001W>L00<007ooOol05Goo00<007>LLi`00g>L9@00
9G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D00006Lia_Ng>LKg]cW0006Goo00D007>LKg]cW6mk
02D0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/01Woo0004OolULi`U0005Li`00`00Oomoo`0GOol00`00LiacW002
Li`U000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@0000IcW6mkLia_Ng>L000JOol01000Kg]c
W6mk9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D000AcW003001oogoo01Uoo`04001cW7>L
Li`U000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@0000EcW6mkLia_N`0001]oo`04001_Ng>L
Kg/U00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@0017>L00<007ooOol027oo1P0037oo00<0
07>LLi`09@009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D00004Lia_Ng>L000;Ool6000<Ool0
0`00Lia_N`0U00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@000g>L00<007ooOol027oo2000
2goo00<007>LLi`09@009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D00004Lia_Ng>L000:Ool8
000;Ool00`00Lia_N`0U00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@000g>L00<007ooOol0
2Goo1P002goo0P000W>L9@009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D00004Lia_Ng>L000;
Ool6000;Ool01000Kg]cW6mk9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D000AcW003001o
ogoo01Uoo`04001cW7>LLi`U000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@0000EcW6mkLia_
N`0001]oo`04001_Ng>LKg/U00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@0017>L00<007oo
Ool06Goo00@007>LLiacW2D002EcW0Ioo`0017oo02EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U00001W>LKg]cW6mk
Li`001Uoo`05001cW6mkLia_N`0U00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@001G>L00<0
07ooOol05goo00<007>LLi`00W>L9@009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D00007Lia_
Ng>LKg]cW6mk00005goo00H006mkLia_Ng>LKg/U00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L
9@001g>L00<007ooOol04goo00<007>LLi`017>L9@009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
02D00009Lia_Ng>LKg]cW6mkLia_N`0001=oo`08001_Ng>LKg]cW6mkLia_NbD0000UKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/01Woo0004OolULi`U0009Li`00`00Oomoo`0?Ool00`00LiacW006Li`U000ULi`6Ool000Ao
o`0ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`09@0000YcW6mkLia_Ng>LKg]cW6mkLia_N`8000eoo`800009Kg]cW6mk
Lia_Ng>LKg]cW6mk02D0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01Woo0004OolULi`U000<Li`20009Ool2000;
Li`U000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk2@0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0U00009FmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Io
o`0017oo9G>L9@0097>L9@009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D0000TLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D002AcW2D002EcW0Ioo`0017oo02EcW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00U000097>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_NbD0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01Woo0004OolU000U
Li`T000ULi`U0006Ool000AoobD0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U
0006Ool000AoobD002EcW2@002EcW2D000Ioo`0017oo40001Goo400002E_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T
00009G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L02D000Ioo`0017oo3@002goo3@009G>L90009G>L9@001Woo0004Ool;
000?Ool;00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo0004Ool:000B
Ool9000ULi`T000ULi`U0006Ool000Aoo`T001Aoo`P0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00U0006Ool000Aoo`P001Ioo`L002EcW2@002EcW2D000Ioo`0017oo1`0067oo1P00
02E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D000Ioo`0017oo1`0067oo1P009G>L
90009G>L9@001Woo0004Ool6000JOol500009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk02@0000ULia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`09@001Woo0004Ool6000JOol5000ULi`T000ULi`U0006Ool000Aoo`D001aoo`@0000UKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000Aoo`D000]oo`@000eoo`@002EcW2@0
02EcW2D000Ioo`0017oo1@002goo1@0037oo100002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L02D000Ioo`0017oo1@002Woo1`002goo10009G>L90009G>L9@001Woo0004Ool5000:Ool7
000;Ool400009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo0004Ool5000;
Ool6000;Ool4000ULi`T000ULi`U0006Ool000Aoo`D000]oo`D000aoo`@0000UKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000Aoo`D000aoo`@000aoo`@002EcW2@002EcW2D0
00Ioo`0017oo1P006goo100002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D000Io
o`0017oo1P006Woo1@009G>L90009G>L9@001Woo0004Ool6000JOol500009FmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo0004Ool7000HOol6000ULi`T000ULi`U0006Ool000Ao
o`L001Qoo`H0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000Aoo`P0
01Ioo`L002EcW2@002EcW2D000Ioo`0017oo2@005Goo1`0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L02D000Ioo`0017oo2P004Woo2@009G>L90009G>L9@001Woo0004Ool<000>Ool;
00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo0004Ool>000;Ool<000U
Li`T000ULi`U0006Ool000Aooa4000=ooa40000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00U0006Ool000AoobD002EcW2@002EcW2D000Ioo`0017oo9@0002E_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T
00009G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L02D000Ioo`0017oo9@009G>L90009G>L9@001Woo0004OolU00009Fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo0004OolULi`U000TLi`U000ULi`6
Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@0002AcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/U00009FmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00Ioo`0017oo9G>L9@0097>L9@009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D0000TLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D002AcW10000Ioo`l002EcW0Ioo`00
17oo02EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00U000097>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d000]oo`d0000UKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/01Woo0004OolULi`U000TLi`;000@Ool:000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@00
02AcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/:000COol800009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@0097>L2@00
5Goo1`009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D0000TLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk20005goo1P00
02E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D002AcW0P001Moo`H002EcW0Ioo`0017oo02EcW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00U000097>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`L001Uoo`D0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01Woo0004
OolULi`U000TLi`7000JOol4000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@0002AcW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/6000KOol400009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@0097>L1P006goo10009G>L
1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D0000TLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk1P002Woo1P002goo100002E_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D002AcW0D000]oo`H000]oo`@002EcW0Ioo`0017oo02Ec
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00U000097>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`D000Yoo`L000]oo`@0000UKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/01Woo0004OolULi`U000TLi`5000:Ool7000;Ool4000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`09@0002AcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/5000;Ool6000;Ool400009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo
9G>L9@0097>L1@002goo1@0037oo10009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D0000TLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk1@0077oo100002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D002AcW0H001Yoo`D0
02EcW0Ioo`0017oo02EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U000097>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`H001Yoo`D0000UKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/01Woo0004OolULi`U000TLi`6000JOol5000ULi`6Ool000Aoo`0ULia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`09@0002AcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/7000HOol600009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L
9@0097>L20005goo1P009G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D0000TLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
20005Woo1`0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`06Ool000AoobEcW2D002AcW0T001Aoo`P002EcW0Ioo`00
17oo02EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00U000097>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`X0019oo`T0000UKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/01Woo0004OolULi`U000TLi`<000>Ool;000ULi`6Ool000Aoo`0ULia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@00
02AcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/?0008Ool>00009FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00Ioo`0017oo9G>L9@0097>L9@00
9G>L1Woo0004Ool09G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D0000TLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk9@0002E_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`06Ool000AoobEcW2D002AcW2D002EcW0Ioo`0017oo02EcW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U000097>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_NbD0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/01Woo0004OolULi`U000TLi`U000ULi`6Ool000Ao
obD0000UKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000AoobD002EcW2@0
02EcW2D000Ioo`0017oo9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D000Io
o`0017oo9@003g>L2@003G>L90009G>L9@001Woo0004OolU00003FmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk008000Uoo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
02D000Ioo`0017oo9@002W>L0`003Goo00<007>LLi`027>L90009G>L9@001Woo0004OolU00002Vmk
Lia_Ng>LKg]cW6mkLia_N`004Goo00X006mkLia_Ng>LKg]cW6mkLia_Nb@0000ULia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`09@001Woo0004OolU0008Li`00`00Oomoo`0AOol20007Li`T000ULi`U0006Ool000AoobD00009
Kg]cW6mkLia_Ng>LKg]cW00001Eoo`07001cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U
0006Ool000AoobD000McW003001oogoo01Eoo`03001cW7>L00=cW2@002EcW2D000Ioo`0017oo9@00
00M_Ng>LKg]cW6mkLi`0000HOol01P00Kg]cW6mkLia_Nb@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo
0004OolU0005Li`00`00Oomoo`0GOol00`00LiacW003Li`T000ULi`U0006Ool000AoobD00006Kg]c
W6mkLia_N`006Woo00D007>LKg]cW6mk02@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo0004OolU0004
Li`00`00Oomoo`0IOol00`00LiacW002Li`T000ULi`U0006Ool000AoobD00005Kg]cW6mkLi`0000K
Ool01@00Lia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000AoobD000AcW003001oogoo
00Uoo`D000aoo`04001cW7>LLi`T000ULi`U0006Ool000AoobD00005Kg]cW6mkLi`0000;Ool5000<
Ool01000Kg]cW6mk900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000AoobD000AcW003001oogoo00Qo
o`L000]oo`04001cW7>LLi`T000ULi`U0006Ool000AoobD00005Kg]cW6mkLi`0000:Ool7000;Ool0
1000Kg]cW6mk900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000AoobD000AcW003001oogoo00Uoo`H0
00]oo`04001cW7>LLi`T000ULi`U0006Ool000AoobD00005Kg]cW6mkLi`0000;Ool5000<Ool01000
Kg]cW6mk900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000AoobD000AcW003001oogoo01Yoo`04001c
W7>LLi`T000ULi`U0006Ool000AoobD00005Kg]cW6mkLi`0000KOol01@00Lia_Ng>LKg/0900002Ec
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00U0006Ool000AoobD000AcW003001oogoo01Uoo`03001cW7>L009cW2@002Ec
W2D000Ioo`0017oo9@0000I_Ng>LKg]cW6mk000IOol01P00Kg]cW6mkLia_Nb@0000ULia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`09@001Woo0004OolU0006Li`00`00Oomoo`0FOol00`00LiacW003Li`T000ULi`U0006Ool0
00AoobD00007Kg]cW6mkLia_Ng>L00005goo00L007>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L02D000Ioo`0017oo9@001g>L00<007ooOol04goo00<007>LLi`01G>L90009G>L9@001Woo0004
OolU00001fmkLia_Ng>LKg]cW6mk008001Aoo`08001_Ng>LKg]cW6mkLia_Nb@0000ULia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`09@001Woo0004OolU0009Li`2000@Ool20008Li`T000ULi`U0006Ool000AoobD0000<Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`003Woo00/007>LKg]cW6mkLia_Ng>LKg]cW6mk02@0000ULia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`09@001Woo0004OolU000<Li`20009Ool3000;Li`T000ULi`U0006Ool000AoobD0000>
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0T0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Nb@0000ULia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`09@001Woo0004OolU000ULi`T000ULi`U0006Ool000AoobD0000U
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/0900002EcW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00U0006Ool000AoobD002EcW2@002EcW2D0
00Ioo`0017oo9@0002E_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0T00009G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02D000Ioo`00`Woo
0032Ool00<9oo`00`Woo0000\
\>"],
  ImageRangeCache->{{{0, 193}, {193, 0}} -> {0.874976, 0.874976, 0.0272024, 
  0.0272024}}],

Cell[OutputFormData["\<\
Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], Rectangle[{1, 3}, {2, \
4}], 
       Rectangle[{1, 5}, {2, 6}]}, 
      {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
       Rectangle[{3, 5}, {4, 6}]}, 
      {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
       Rectangle[{5, 5}, {6, 6}]}}}, 
    {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}]}, \

      {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}]}, 
      {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}]}}}, 
    {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}]}, 
      {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}]}}}, 
    {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], 
       Rectangle[{2, 5}, {3, 6}]}, 
      {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
       Rectangle[{4, 5}, {5, 6}]}}}}, 
   {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
    {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
    {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
    {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, {GrayLevel[1], {Disk[{2.5, 5.5}, \
0.4]}}}\\
, {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, {Circle[{1.5, 3.5}, \
0.4]}, 
    {Circle[{4.5, 4.5}, 0.4]}, {Circle[{2.5, 5.5}, 0.4]}}, 
   {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, {GrayLevel[0], {Disk[{3.5, 2.5}, \
0.1]}}, 
    {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, {GrayLevel[0], {Disk[{4.5, 4.5}, \
0.1]}}, 
    {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}}}, {AspectRatio -> 1}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The (6 \[Times] 6)-board", "Subsection"],

Cell[CellGroupData[{

Cell["qs = QueensSolution[6] //Timing", "Input"],

Cell[OutputFormData["\<\
{0.2199999999999988*Second, {{2, 4, 6, 1, 3, 5}, {3, 6, 2, 5, 1, 4}, 
   {4, 1, 5, 2, 6, 3}, {5, 3, 1, 6, 4, 2}}}\
\>", "\<\
{0.22 Second, {{2, 4, 6, 1, 3, 5}, {3, 6, 2, 5, 1, 4}, {4, 1, 5, 2, 6, 3}, 
 
   {5, 3, 1, 6, 4, 2}}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["t6 = qs[[1]]", "Input"],

Cell[OutputFormData["\<\
0.2199999999999988*Second\
\>", "\<\
0.22 Second\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[qs[[2]]]", "Input"],

Cell[OutputFormData["\<\
4\
\>", "\<\
4\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsg = QueensPlot[#]& /@ qs[[2]]", "Input"],

Cell[OutputFormData["\<\
{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, {GrayLevel[0], {Disk[{2.5, \
6.5}, 0.1]}}}
}, AspectRatio -> 1]}\
\>", "\<\
{-Graphics-, -Graphics-, -Graphics-, -Graphics-}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsga = Partition[qsg,2]", "Input"],

Cell[OutputFormData["\<\
{{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}}}, AspectRatio -> 1]}}\
\>", "\<\
{{-Graphics-, -Graphics-}, {-Graphics-, -Graphics-}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[GraphicsArray[qsga]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0238095 0.136054 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.15986 .15986 m
.15986 .29592 L
.29592 .29592 L
.29592 .15986 L
F
.15986 .43197 m
.15986 .56803 L
.29592 .56803 L
.29592 .43197 L
F
.15986 .70408 m
.15986 .84014 L
.29592 .84014 L
.29592 .70408 L
F
.43197 .15986 m
.43197 .29592 L
.56803 .29592 L
.56803 .15986 L
F
.43197 .43197 m
.43197 .56803 L
.56803 .56803 L
.56803 .43197 L
F
.43197 .70408 m
.43197 .84014 L
.56803 .84014 L
.56803 .70408 L
F
.70408 .15986 m
.70408 .29592 L
.84014 .29592 L
.84014 .15986 L
F
.70408 .43197 m
.70408 .56803 L
.84014 .56803 L
.84014 .43197 L
F
.70408 .70408 m
.70408 .84014 L
.84014 .84014 L
.84014 .70408 L
F
.9 g
.15986 .29592 m
.15986 .43197 L
.29592 .43197 L
.29592 .29592 L
F
.15986 .56803 m
.15986 .70408 L
.29592 .70408 L
.29592 .56803 L
F
.15986 .84014 m
.15986 .97619 L
.29592 .97619 L
.29592 .84014 L
F
.43197 .29592 m
.43197 .43197 L
.56803 .43197 L
.56803 .29592 L
F
.43197 .56803 m
.43197 .70408 L
.56803 .70408 L
.56803 .56803 L
F
.43197 .84014 m
.43197 .97619 L
.56803 .97619 L
.56803 .84014 L
F
.70408 .29592 m
.70408 .43197 L
.84014 .43197 L
.84014 .29592 L
F
.70408 .56803 m
.70408 .70408 L
.84014 .70408 L
.84014 .56803 L
F
.70408 .84014 m
.70408 .97619 L
.84014 .97619 L
.84014 .84014 L
F
0 g
.29592 .29592 m
.29592 .43197 L
.43197 .43197 L
.43197 .29592 L
F
.29592 .56803 m
.29592 .70408 L
.43197 .70408 L
.43197 .56803 L
F
.29592 .84014 m
.29592 .97619 L
.43197 .97619 L
.43197 .84014 L
F
.56803 .29592 m
.56803 .43197 L
.70408 .43197 L
.70408 .29592 L
F
.56803 .56803 m
.56803 .70408 L
.70408 .70408 L
.70408 .56803 L
F
.56803 .84014 m
.56803 .97619 L
.70408 .97619 L
.70408 .84014 L
F
.84014 .29592 m
.84014 .43197 L
.97619 .43197 L
.97619 .29592 L
F
.84014 .56803 m
.84014 .70408 L
.97619 .70408 L
.97619 .56803 L
F
.84014 .84014 m
.84014 .97619 L
.97619 .97619 L
.97619 .84014 L
F
.9 g
.29592 .15986 m
.29592 .29592 L
.43197 .29592 L
.43197 .15986 L
F
.29592 .43197 m
.29592 .56803 L
.43197 .56803 L
.43197 .43197 L
F
.29592 .70408 m
.29592 .84014 L
.43197 .84014 L
.43197 .70408 L
F
.56803 .15986 m
.56803 .29592 L
.70408 .29592 L
.70408 .15986 L
F
.56803 .43197 m
.56803 .56803 L
.70408 .56803 L
.70408 .43197 L
F
.56803 .70408 m
.56803 .84014 L
.70408 .84014 L
.70408 .70408 L
F
.84014 .15986 m
.84014 .29592 L
.97619 .29592 L
.97619 .15986 L
F
.84014 .43197 m
.84014 .56803 L
.97619 .56803 L
.97619 .43197 L
F
.84014 .70408 m
.84014 .84014 L
.97619 .84014 L
.97619 .70408 L
F
1 g
.63605 .22789 m
.63605 .22789 .05442 0 365.73 arc
F
.22789 .36395 m
.22789 .36395 .05442 0 365.73 arc
F
.77211 .5 m
.77211 .5 .05442 0 365.73 arc
F
.36395 .63605 m
.36395 .63605 .05442 0 365.73 arc
F
.90816 .77211 m
.90816 .77211 .05442 0 365.73 arc
F
.5 .90816 m
.5 .90816 .05442 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.63605 .22789 .05442 0 365.73 arc
s
newpath
.22789 .36395 .05442 0 365.73 arc
s
newpath
.77211 .5 .05442 0 365.73 arc
s
newpath
.36395 .63605 .05442 0 365.73 arc
s
newpath
.90816 .77211 .05442 0 365.73 arc
s
newpath
.5 .90816 .05442 0 365.73 arc
s
.63605 .22789 m
.63605 .22789 .01361 0 365.73 arc
F
.22789 .36395 m
.22789 .36395 .01361 0 365.73 arc
F
.77211 .5 m
.77211 .5 .01361 0 365.73 arc
F
.36395 .63605 m
.36395 .63605 .01361 0 365.73 arc
F
.90816 .77211 m
.90816 .77211 .01361 0 365.73 arc
F
.5 .90816 m
.5 .90816 .01361 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0238095 0.136054 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.15986 .15986 m
.15986 .29592 L
.29592 .29592 L
.29592 .15986 L
F
.15986 .43197 m
.15986 .56803 L
.29592 .56803 L
.29592 .43197 L
F
.15986 .70408 m
.15986 .84014 L
.29592 .84014 L
.29592 .70408 L
F
.43197 .15986 m
.43197 .29592 L
.56803 .29592 L
.56803 .15986 L
F
.43197 .43197 m
.43197 .56803 L
.56803 .56803 L
.56803 .43197 L
F
.43197 .70408 m
.43197 .84014 L
.56803 .84014 L
.56803 .70408 L
F
.70408 .15986 m
.70408 .29592 L
.84014 .29592 L
.84014 .15986 L
F
.70408 .43197 m
.70408 .56803 L
.84014 .56803 L
.84014 .43197 L
F
.70408 .70408 m
.70408 .84014 L
.84014 .84014 L
.84014 .70408 L
F
.9 g
.15986 .29592 m
.15986 .43197 L
.29592 .43197 L
.29592 .29592 L
F
.15986 .56803 m
.15986 .70408 L
.29592 .70408 L
.29592 .56803 L
F
.15986 .84014 m
.15986 .97619 L
.29592 .97619 L
.29592 .84014 L
F
.43197 .29592 m
.43197 .43197 L
.56803 .43197 L
.56803 .29592 L
F
.43197 .56803 m
.43197 .70408 L
.56803 .70408 L
.56803 .56803 L
F
.43197 .84014 m
.43197 .97619 L
.56803 .97619 L
.56803 .84014 L
F
.70408 .29592 m
.70408 .43197 L
.84014 .43197 L
.84014 .29592 L
F
.70408 .56803 m
.70408 .70408 L
.84014 .70408 L
.84014 .56803 L
F
.70408 .84014 m
.70408 .97619 L
.84014 .97619 L
.84014 .84014 L
F
0 g
.29592 .29592 m
.29592 .43197 L
.43197 .43197 L
.43197 .29592 L
F
.29592 .56803 m
.29592 .70408 L
.43197 .70408 L
.43197 .56803 L
F
.29592 .84014 m
.29592 .97619 L
.43197 .97619 L
.43197 .84014 L
F
.56803 .29592 m
.56803 .43197 L
.70408 .43197 L
.70408 .29592 L
F
.56803 .56803 m
.56803 .70408 L
.70408 .70408 L
.70408 .56803 L
F
.56803 .84014 m
.56803 .97619 L
.70408 .97619 L
.70408 .84014 L
F
.84014 .29592 m
.84014 .43197 L
.97619 .43197 L
.97619 .29592 L
F
.84014 .56803 m
.84014 .70408 L
.97619 .70408 L
.97619 .56803 L
F
.84014 .84014 m
.84014 .97619 L
.97619 .97619 L
.97619 .84014 L
F
.9 g
.29592 .15986 m
.29592 .29592 L
.43197 .29592 L
.43197 .15986 L
F
.29592 .43197 m
.29592 .56803 L
.43197 .56803 L
.43197 .43197 L
F
.29592 .70408 m
.29592 .84014 L
.43197 .84014 L
.43197 .70408 L
F
.56803 .15986 m
.56803 .29592 L
.70408 .29592 L
.70408 .15986 L
F
.56803 .43197 m
.56803 .56803 L
.70408 .56803 L
.70408 .43197 L
F
.56803 .70408 m
.56803 .84014 L
.70408 .84014 L
.70408 .70408 L
F
.84014 .15986 m
.84014 .29592 L
.97619 .29592 L
.97619 .15986 L
F
.84014 .43197 m
.84014 .56803 L
.97619 .56803 L
.97619 .43197 L
F
.84014 .70408 m
.84014 .84014 L
.97619 .84014 L
.97619 .70408 L
F
1 g
.77211 .22789 m
.77211 .22789 .05442 0 365.73 arc
F
.5 .36395 m
.5 .36395 .05442 0 365.73 arc
F
.22789 .5 m
.22789 .5 .05442 0 365.73 arc
F
.90816 .63605 m
.90816 .63605 .05442 0 365.73 arc
F
.63605 .77211 m
.63605 .77211 .05442 0 365.73 arc
F
.36395 .90816 m
.36395 .90816 .05442 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.77211 .22789 .05442 0 365.73 arc
s
newpath
.5 .36395 .05442 0 365.73 arc
s
newpath
.22789 .5 .05442 0 365.73 arc
s
newpath
.90816 .63605 .05442 0 365.73 arc
s
newpath
.63605 .77211 .05442 0 365.73 arc
s
newpath
.36395 .90816 .05442 0 365.73 arc
s
.77211 .22789 m
.77211 .22789 .01361 0 365.73 arc
F
.5 .36395 m
.5 .36395 .01361 0 365.73 arc
F
.22789 .5 m
.22789 .5 .01361 0 365.73 arc
F
.90816 .63605 m
.90816 .63605 .01361 0 365.73 arc
F
.63605 .77211 m
.63605 .77211 .01361 0 365.73 arc
F
.36395 .90816 m
.36395 .90816 .01361 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0238095 0.136054 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.15986 .15986 m
.15986 .29592 L
.29592 .29592 L
.29592 .15986 L
F
.15986 .43197 m
.15986 .56803 L
.29592 .56803 L
.29592 .43197 L
F
.15986 .70408 m
.15986 .84014 L
.29592 .84014 L
.29592 .70408 L
F
.43197 .15986 m
.43197 .29592 L
.56803 .29592 L
.56803 .15986 L
F
.43197 .43197 m
.43197 .56803 L
.56803 .56803 L
.56803 .43197 L
F
.43197 .70408 m
.43197 .84014 L
.56803 .84014 L
.56803 .70408 L
F
.70408 .15986 m
.70408 .29592 L
.84014 .29592 L
.84014 .15986 L
F
.70408 .43197 m
.70408 .56803 L
.84014 .56803 L
.84014 .43197 L
F
.70408 .70408 m
.70408 .84014 L
.84014 .84014 L
.84014 .70408 L
F
.9 g
.15986 .29592 m
.15986 .43197 L
.29592 .43197 L
.29592 .29592 L
F
.15986 .56803 m
.15986 .70408 L
.29592 .70408 L
.29592 .56803 L
F
.15986 .84014 m
.15986 .97619 L
.29592 .97619 L
.29592 .84014 L
F
.43197 .29592 m
.43197 .43197 L
.56803 .43197 L
.56803 .29592 L
F
.43197 .56803 m
.43197 .70408 L
.56803 .70408 L
.56803 .56803 L
F
.43197 .84014 m
.43197 .97619 L
.56803 .97619 L
.56803 .84014 L
F
.70408 .29592 m
.70408 .43197 L
.84014 .43197 L
.84014 .29592 L
F
.70408 .56803 m
.70408 .70408 L
.84014 .70408 L
.84014 .56803 L
F
.70408 .84014 m
.70408 .97619 L
.84014 .97619 L
.84014 .84014 L
F
0 g
.29592 .29592 m
.29592 .43197 L
.43197 .43197 L
.43197 .29592 L
F
.29592 .56803 m
.29592 .70408 L
.43197 .70408 L
.43197 .56803 L
F
.29592 .84014 m
.29592 .97619 L
.43197 .97619 L
.43197 .84014 L
F
.56803 .29592 m
.56803 .43197 L
.70408 .43197 L
.70408 .29592 L
F
.56803 .56803 m
.56803 .70408 L
.70408 .70408 L
.70408 .56803 L
F
.56803 .84014 m
.56803 .97619 L
.70408 .97619 L
.70408 .84014 L
F
.84014 .29592 m
.84014 .43197 L
.97619 .43197 L
.97619 .29592 L
F
.84014 .56803 m
.84014 .70408 L
.97619 .70408 L
.97619 .56803 L
F
.84014 .84014 m
.84014 .97619 L
.97619 .97619 L
.97619 .84014 L
F
.9 g
.29592 .15986 m
.29592 .29592 L
.43197 .29592 L
.43197 .15986 L
F
.29592 .43197 m
.29592 .56803 L
.43197 .56803 L
.43197 .43197 L
F
.29592 .70408 m
.29592 .84014 L
.43197 .84014 L
.43197 .70408 L
F
.56803 .15986 m
.56803 .29592 L
.70408 .29592 L
.70408 .15986 L
F
.56803 .43197 m
.56803 .56803 L
.70408 .56803 L
.70408 .43197 L
F
.56803 .70408 m
.56803 .84014 L
.70408 .84014 L
.70408 .70408 L
F
.84014 .15986 m
.84014 .29592 L
.97619 .29592 L
.97619 .15986 L
F
.84014 .43197 m
.84014 .56803 L
.97619 .56803 L
.97619 .43197 L
F
.84014 .70408 m
.84014 .84014 L
.97619 .84014 L
.97619 .70408 L
F
1 g
.36395 .22789 m
.36395 .22789 .05442 0 365.73 arc
F
.63605 .36395 m
.63605 .36395 .05442 0 365.73 arc
F
.90816 .5 m
.90816 .5 .05442 0 365.73 arc
F
.22789 .63605 m
.22789 .63605 .05442 0 365.73 arc
F
.5 .77211 m
.5 .77211 .05442 0 365.73 arc
F
.77211 .90816 m
.77211 .90816 .05442 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.36395 .22789 .05442 0 365.73 arc
s
newpath
.63605 .36395 .05442 0 365.73 arc
s
newpath
.90816 .5 .05442 0 365.73 arc
s
newpath
.22789 .63605 .05442 0 365.73 arc
s
newpath
.5 .77211 .05442 0 365.73 arc
s
newpath
.77211 .90816 .05442 0 365.73 arc
s
.36395 .22789 m
.36395 .22789 .01361 0 365.73 arc
F
.63605 .36395 m
.63605 .36395 .01361 0 365.73 arc
F
.90816 .5 m
.90816 .5 .01361 0 365.73 arc
F
.22789 .63605 m
.22789 .63605 .01361 0 365.73 arc
F
.5 .77211 m
.5 .77211 .01361 0 365.73 arc
F
.77211 .90816 m
.77211 .90816 .01361 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0238095 0.136054 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.15986 .15986 m
.15986 .29592 L
.29592 .29592 L
.29592 .15986 L
F
.15986 .43197 m
.15986 .56803 L
.29592 .56803 L
.29592 .43197 L
F
.15986 .70408 m
.15986 .84014 L
.29592 .84014 L
.29592 .70408 L
F
.43197 .15986 m
.43197 .29592 L
.56803 .29592 L
.56803 .15986 L
F
.43197 .43197 m
.43197 .56803 L
.56803 .56803 L
.56803 .43197 L
F
.43197 .70408 m
.43197 .84014 L
.56803 .84014 L
.56803 .70408 L
F
.70408 .15986 m
.70408 .29592 L
.84014 .29592 L
.84014 .15986 L
F
.70408 .43197 m
.70408 .56803 L
.84014 .56803 L
.84014 .43197 L
F
.70408 .70408 m
.70408 .84014 L
.84014 .84014 L
.84014 .70408 L
F
.9 g
.15986 .29592 m
.15986 .43197 L
.29592 .43197 L
.29592 .29592 L
F
.15986 .56803 m
.15986 .70408 L
.29592 .70408 L
.29592 .56803 L
F
.15986 .84014 m
.15986 .97619 L
.29592 .97619 L
.29592 .84014 L
F
.43197 .29592 m
.43197 .43197 L
.56803 .43197 L
.56803 .29592 L
F
.43197 .56803 m
.43197 .70408 L
.56803 .70408 L
.56803 .56803 L
F
.43197 .84014 m
.43197 .97619 L
.56803 .97619 L
.56803 .84014 L
F
.70408 .29592 m
.70408 .43197 L
.84014 .43197 L
.84014 .29592 L
F
.70408 .56803 m
.70408 .70408 L
.84014 .70408 L
.84014 .56803 L
F
.70408 .84014 m
.70408 .97619 L
.84014 .97619 L
.84014 .84014 L
F
0 g
.29592 .29592 m
.29592 .43197 L
.43197 .43197 L
.43197 .29592 L
F
.29592 .56803 m
.29592 .70408 L
.43197 .70408 L
.43197 .56803 L
F
.29592 .84014 m
.29592 .97619 L
.43197 .97619 L
.43197 .84014 L
F
.56803 .29592 m
.56803 .43197 L
.70408 .43197 L
.70408 .29592 L
F
.56803 .56803 m
.56803 .70408 L
.70408 .70408 L
.70408 .56803 L
F
.56803 .84014 m
.56803 .97619 L
.70408 .97619 L
.70408 .84014 L
F
.84014 .29592 m
.84014 .43197 L
.97619 .43197 L
.97619 .29592 L
F
.84014 .56803 m
.84014 .70408 L
.97619 .70408 L
.97619 .56803 L
F
.84014 .84014 m
.84014 .97619 L
.97619 .97619 L
.97619 .84014 L
F
.9 g
.29592 .15986 m
.29592 .29592 L
.43197 .29592 L
.43197 .15986 L
F
.29592 .43197 m
.29592 .56803 L
.43197 .56803 L
.43197 .43197 L
F
.29592 .70408 m
.29592 .84014 L
.43197 .84014 L
.43197 .70408 L
F
.56803 .15986 m
.56803 .29592 L
.70408 .29592 L
.70408 .15986 L
F
.56803 .43197 m
.56803 .56803 L
.70408 .56803 L
.70408 .43197 L
F
.56803 .70408 m
.56803 .84014 L
.70408 .84014 L
.70408 .70408 L
F
.84014 .15986 m
.84014 .29592 L
.97619 .29592 L
.97619 .15986 L
F
.84014 .43197 m
.84014 .56803 L
.97619 .56803 L
.97619 .43197 L
F
.84014 .70408 m
.84014 .84014 L
.97619 .84014 L
.97619 .70408 L
F
1 g
.5 .22789 m
.5 .22789 .05442 0 365.73 arc
F
.90816 .36395 m
.90816 .36395 .05442 0 365.73 arc
F
.36395 .5 m
.36395 .5 .05442 0 365.73 arc
F
.77211 .63605 m
.77211 .63605 .05442 0 365.73 arc
F
.22789 .77211 m
.22789 .77211 .05442 0 365.73 arc
F
.63605 .90816 m
.63605 .90816 .05442 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .22789 .05442 0 365.73 arc
s
newpath
.90816 .36395 .05442 0 365.73 arc
s
newpath
.36395 .5 .05442 0 365.73 arc
s
newpath
.77211 .63605 .05442 0 365.73 arc
s
newpath
.22789 .77211 .05442 0 365.73 arc
s
newpath
.63605 .90816 .05442 0 365.73 arc
s
.5 .22789 m
.5 .22789 .01361 0 365.73 arc
F
.90816 .36395 m
.90816 .36395 .01361 0 365.73 arc
F
.36395 .5 m
.36395 .5 .01361 0 365.73 arc
F
.77211 .63605 m
.77211 .63605 .01361 0 365.73 arc
F
.22789 .77211 m
.22789 .77211 .01361 0 365.73 arc
F
.63605 .90816 m
.63605 .90816 .01361 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol001]ooa80000BKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB
000BLi`A0007Li`40007Li`B000ALi`UOolB000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@0000EcW6mkLia_Ng>L008000Aoo`<00004
Lia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0L000Aoo`L0000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
2goo000KOolB000BLi`A0004Li`00`00Oomoo`07Ool20002Li`B000ALi`UOolB000BLi`A000BLi`5
0008Ool5000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
4@0000EcW6mkLia_N`0000Yoo`03001cW6mk0180000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00UOolB00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na40000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L1@002Woo0`00019_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`;Ool001]ooa80019cW14000=cW003001oogoo00Yoo`03001cW000
0140015cW2Eooa80019cW140019cW0@000]oo`<0019cW0]oo`006goo4P00019_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`A000017>LKg]cW00037oo00<006mk00004@00015cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02Eooa80000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk4@00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`4000<Ool2
00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0]oo`006goo4P004W>L4@000W>L
00<007ooOol00goo0P001Woo00<007>L00004@004G>L9Goo4P004W>L4@004W>L0`001Goo0P001Woo
0P004W>L2goo000KOolB00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1400003
Lia_N`0000Aoo`@000Eoo`03001_N`000140000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00UOolB00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na40000BKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0`0017oo10001Goo0P00019_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;Ool001]ooa80019cW140009cW003001oogoo00=oo`8000Io
o`03001cW0000140015cW2Eooa80019cW140019cW0<000Eoo`8000Ioo`80019cW0]oo`006goo4P00
019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`A00000g>LKg/0000=Ool00`00Kg/0
000A00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0<000aoo`<0000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000K
OolB000BLi`A0003Li`00`00Oomoo`0:Ool00`00Li`0000A000ALi`UOolB000BLi`A000BLi`4000;
Ool3000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00
00AcW6mkLi`000]oo`03001cW6mk0180000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00UOolB00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na40000BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10002Woo1000019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`;Ool001]ooa80019cW14000AcW08000Qoo`04001cW7>LLi`B000ALi`UOolB
000BLi`A000BLi`60008Ool4000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L4@0000IcW6mkLia_Ng>LKg/20005Ool01@00Lia_Ng>LKg/04P00015cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02Eooa80000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk4@00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`80005Ool5
00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0]oo`006goo4P004W>L4@0027>L
1@001G>L4P004G>L9Goo4P004W>L4@004W>L4P004W>L2goo000KOolB00004VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW140000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02Eooa80000BLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`B00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0]oo`006goo4P00
4W>L4@004W>L4P004G>L9Goo4P004W>L4@004W>L4P004W>L2goo000KOol04VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0B00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L0180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOol6
Li`70005Li`B000ALi`B000BLi`A000UOolBLi`B0005Li`80004Li`B000BLi`B000;Ool001]oo`04
Kg]cW6mkLi`20007Ool01@00Kg]cW6mkLi`04P00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk0180000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@009Goo019cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00001G>LKg]cW6mk000027oo00@007>LKg]c
W180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOol4Li`00`00
Oomoo`07Ool01000LiacW7>L4P004G>L4P004W>L4@009Goo4W>L4P000g>L00<007ooOol027oo00<0
07>LLi`04P004W>L4P002goo000KOol016mkLia_N`002goo00<006mkLi`04P00015_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0180000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B000017>LKg]c
W0002Woo00<006mkLi`04P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B000;
Ool001]oo`=cW003001oogoo00Uoo`03001cW7>L0180015cW180019cW14002Eooa9cW180009cW003
001oogoo00Yoo`03001cW0000140019cW18000]oo`006goo00A_Ng>LKg/000aoo`03001cW0000140
000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk4P0000=cW6mk000037oo00<007>L00004@00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`B000;Ool001]oo`9cW003001oogoo00=oo`8000Ioo`03001cW0000140015cW180019c
W14002Eooa9cW1800003Li`007oo00Eoo`8000Iooa<0019cW18000]oo`006goo00=_Ng>L000017oo
10001Goo00<007>L00004@00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0180000B
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/B00000g>L001oo`04Ool30006OolC00004VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW18000]oo`006goo0W>L00<007ooOol00goo0P001Goo00<007>L
Li`04P004G>L4P004W>L4@009Goo4W>L4P000W>L00<007ooOol00goo0P001Goo00<007>L00004@00
4W>L4P002goo000KOol00fmkLi`0000<Ool00`00Kg]cW00B00004FmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/04P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A000U
Ool04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na800003Lia_N`0000aoo`03001c
W0000140000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOol3Li`0
0`00Oomoo`09Ool00`00LiacW00B000ALi`B000BLi`A000UOolBLi`B0002Li`00`00Oomoo`0:Ool0
0`00Li`0000A000BLi`B000;Ool001]oo`04Kg]cW6mk000:Ool01000Lia_Ng>L4P00015_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0180000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B000017>L
Kg]cW0002Woo00<006mkLi`04P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B
000;Ool001]oo`AcW08000Qoo`04001cW7>LLi`B000ALi`B000BLi`A000UOolBLi`B0003Li`20008
Ool20002Li`B000BLi`B000;Ool001]oo`06Kg]cW6mkLia_Ng>L0P000goo0`0000A_Ng>LKg]cW180
000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk4P0000EcW6mkLia_Ng>L00<0009oo`<00004Kg]cW6mkLi`B00004VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW18000]oo`006goo27>L0`001g>L4P004G>L4P004W>L4@009Goo4W>L
4P0027>L0P001g>L4P004W>L4P002goo000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0180000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOolBLi`B000ALi`B000BLi`A
000UOolBLi`B000ALi`B000BLi`B000;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180
000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`8
0003Ool7000ALi`UOol90002Ool7000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/60007Ool500004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo1P00
1goo1@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L2goo000KOolB000BLi`A000BLi`4000:Ool4000ALi`UOol5000:Ool3000BLi`A000BLi`B
000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/3000<Ool300004G>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo100037oo0P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`3000=Ool2
000ALi`UOol4000<Ool2000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/3000=Ool200004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo0`003Goo0P00
019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
2goo000KOolB000BLi`A000BLi`30004Ool30006Ool2000ALi`UOol30004Ool30006Ool2000BLi`A
000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/30005Ool20006Ool200004G>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo0`001Goo0P001Woo0P00019cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB
000BLi`A000BLi`3000<Ool3000ALi`UOol4000<Ool2000BLi`A000BLi`B000BLi`;Ool001]ooa80
000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/3000<Ool300004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`09Goo100037oo0P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A0000
4VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`4000;Ool3000ALi`UOol4000;Ool3
000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/50009Ool400004G>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo1@002Woo0`00019cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A
000BLi`60007Ool5000ALi`UOol60008Ool4000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/80003Ool700004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
9Goo20000goo1`00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B000ALi`UOolB000BLi`A000BLi`B000BLi`;
Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`09Goo4P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L2goo000KOolBLi`B000ALi`B000BLi`A000UOolBLi`B000ALi`B000BLi`B
000;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P00015_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0180000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`04P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`B000;Ool001]ooa9cW0H000Eoo`L0015cW180019cW14002Eooa9cW180015c
W180019cW0H000Eoo`L000]oo`006goo019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`50008Ool500004FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04P00019cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Na80000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B00004Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0D000Qoo`D000]oo`006goo4W>L10002Woo
10004G>L4P004W>L4@009Goo4W>L4P004G>L4P004W>L10002Woo10002goo000KOol04VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0<000aoo`<0000AKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eo
o`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L0180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
0`0037oo0`002goo000KOolBLi`3000<Ool3000ALi`B000BLi`A000UOolBLi`B000ALi`B000BLi`3
000<Ool3000;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0`001Goo
0P001Goo0`00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0180000BLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`04P00019_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`30005Ool20005Ool3000;Ool001]ooa9cW0<0
00Aoo`<000Ioo`80015cW180019cW14002Eooa9cW180015cW180019cW0<000Aoo`<000Ioo`8000]o
o`006goo019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`30005Ool20006Ool20000
4FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04P00019cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Na80000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B00004VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0<000Eoo`8000Ioo`8000]oo`006goo4W>L0`0037oo0`004G>L
4P004W>L4@009Goo4W>L4P004G>L4P004W>L0`0037oo0`002goo000KOol04VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0<000aoo`<0000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0B00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L0180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0`0037oo
0`002goo000KOolBLi`3000;Ool4000ALi`B000BLi`A000UOolBLi`B000ALi`B000BLi`3000;Ool4
000;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10002Woo1000015_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0180000BLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B
00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`04P00019_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`4000:Ool4000;Ool001]ooa9cW0H000Ioo`H0015cW180019cW140
02Eooa9cW180015cW180019cW0H000Ioo`H000]oo`006goo019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`B00004FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04P00019c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Na80000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B
00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW18000]oo`006goo4W>L4P004G>L
4P004W>L4@009Goo4W>L4P004G>L4P004W>L4P002goo000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B0000
4W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
0180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOolB000BLi`A
000BLi`B000ALi`UOolB000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/B00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L9Goo4P00019cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/A00001fmkLia_Ng>LKg]cW6mk00@00007Lia_Ng>LKg]cW6mkLi`0
4P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;Ool001]ooa80019cW140019c
W18000EcW003001oogoo00=oo`8000AcW2Eooa80019cW14000IcW003001oogoo009oo`<000AcW180
019cW0]oo`006goo4P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`A00004W>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na800005Lia_Ng>LKg/00008Ool200000fmk
Liaoo`0TOolB00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na400006Kg]cW6mk
Lia_N`0027oo0P0000=_Ng>L00004@00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`;Ool001]ooa80019cW140019cW18000=cW003001oogoo00Qoo`03001cW7>L02Eooa80019cW140
00AcW003001oogoo00Qoo`03001cW7>L0180019cW0]oo`006goo4P00019_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`A00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Na800003Lia_N`0000aoo`03001cW7oo02Aooa80000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk4@0000A_Ng>LKg/000aoo`03001cW0000140000BKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B0002Li`00`00Oomoo`0:Ool00`00Liao
o`0TOolB000BLi`A0003Li`00`00Oomoo`0:Ool00`00Li`0000A000BLi`;Ool001]ooa80000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/B00000g>L001oo`05Ool20005Ool00`00Liaoo`0TOolB00004W>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na400003Kg]cW00000Eoo`8000Ioo`03001cW0000140
000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B
00000g>L001oo`04Ool30006Ool00`00Oomoo`0SOolB000BLi`A0002Li`00`00Oomoo`02Ool40005
Ool00`00Li`0000A000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00000g>LKg/00005
Ool00`00Oomoo`05Ool00`00Oomoo`0SOolB00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Na400004Kg]cW6mk0004Ool20006Ool00`00Li`0000A00004VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0]oo`006goo4P004W>L4@004W>L4P000W>L00<007ooOol02Woo00<0
07>LOol097oo4P004W>L4@000g>L00<007ooOol02Woo00<007>L00004@004W>L2goo000KOolB0000
4VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW140000BLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk4P0000=cW6mk000037oo00<007>LOol097oo4P00019cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A000016mkLia_N`0037oo00<007>L00004@00019_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;Ool001]ooa80019cW140019cW18000=cW003
001oogoo00Qoo`03001cW7>L02Eooa80019cW14000AcW003001oogoo00Qoo`03001cW7>L0180019c
W0]oo`006goo4P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`A00004W>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na800003Lia_Ng>L008000Qoo`04001cW6mkLi`U
OolB00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na400004Kg]cW6mkLi`20008
Ool01000Lia_Ng>L4P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;Ool001]o
oa80019cW140019cW18000EcW0<0009oo`<000AcW2Eooa80019cW14000IcW08000=oo`<000AcW180
019cW0]oo`006goo4P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`A00004W>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na800008Lia_Ng>LKg]cW6mkLia_N`800007
Lia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A
000026mkLia_Ng>LKg]cW6mkLi`300001g>LKg]cW6mkLia_Ng>L0180000BKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B000ALi`UOolB000BLi`A000B
Li`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00
019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolBLi`B0008Li`30006Li`B000BLi`A000UOolB
Li`B000ALi`B000BLi`B000;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L4P0000E_Ng>LKg]cW6mk00<000=oo`800004Lia_Ng>LKg/B00004W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk20000goo1`00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0180000BKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOolBLi`B0004Li`00`00Oomoo`06
Ool01000LiacW7>L4P004W>L4@009Goo4W>L1P001goo1@004G>L4P004W>L4P002goo000KOol04Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1800004Kg]cW6mk000:Ool00`00Lia_N`0B
00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk10002Woo1000015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L0180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000K
OolBLi`B0002Li`00`00Oomoo`0:Ool00`00Li`0000A000BLi`A000UOolBLi`3000<Ool3000ALi`B
000BLi`B000;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P0000=_
Ng>L000037oo00<006mk00004@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A
000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`<000eoo`80000ALia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW18000]oo`006goo4W>L4P0000=cW000Ool037oo00<007>L00004@004W>L4@009Goo
4W>L0`003Goo0P004G>L4P004W>L4P002goo000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW1800003Kg/007oo00Aoo`<000Eoo`03001_N`000140000BLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/30004Ool30006Ool200004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`04P00
019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B000;Ool001]ooa9cW1800003Li`0
07oo00Eoo`8000Eoo`03001cW0000140019cW14002Eooa9cW0<000Eoo`<000Eoo`80015cW180019c
W18000]oo`006goo019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00000fmkLi`0
000<Ool00`00Kg/0000A00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eo
o`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0`0037oo0`00015cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L4P002goo000KOolBLi`B0002Li`00`00Oomoo`0:Ool00`00Li`0000A000BLi`A000UOolB
Li`3000<Ool3000ALi`B000BLi`B000;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L4P0000=_Ng>L00002goo00<007>LKg/04P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`@0
00]oo`<0000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B00004VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW18000]oo`006goo4W>L4P000g>L00<007ooOol027oo00<0
07>LLi`04P004W>L4@009Goo4W>L1@002Goo10004G>L4P004W>L4P002goo000KOol04VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1800005Kg]cW6mkLi`00008Ool01000Kg]cW6mk4P00
019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`H000Moo`D0000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00B00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW18000]oo`006goo
4W>L4P001G>L0P000goo0`0017>L4P004W>L4@009Goo4W>L20000goo1`004G>L4P004W>L4P002goo
000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW1800007Kg]cW6mkLia_Ng>L
Kg/00`0000M_Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L4P002goo000KOolBLi`B000ALi`B000BLi`A000UOolBLi`B000ALi`B000BLi`B000;
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
6goo4P004W>L4@004W>L4P004G>L9Goo4P004W>L4@004W>L4P004W>L2goo000KOolB000026mkLia_
Ng>LKg]cW6mkLi`300001g>LKg]cW6mkLia_Ng>L0140000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02Eooa80000B
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@00019_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`B00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0]o
o`006goo4P001G>L0`000goo0P001G>L4@004W>L4P004G>L9Goo4P004W>L20000goo1P004W>L4P00
4W>L2goo000KOolB00001FmkLia_Ng>L000027oo00D006mkLia_Ng>L0140000BLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L02Eooa80000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk1@0027oo1000019_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0]oo`006goo4P000g>L00<007ooOol027oo00@007>LLiacW140019cW180
015cW2Eooa80019cW0@000Yoo`<0019cW180019cW0]oo`006goo4P0000=_Ng>L000037oo00<006mk
Li`04@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/3000<Ool200004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000B
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB0002Li`00`00Oomoo`0:
Ool00`00LiacW00A000BLi`B000ALi`UOolB000BLi`3000<Ool2000BLi`B000BLi`;Ool001]ooa80
0003Kg]cW00000Eoo`8000Eoo`03001_Ng>L0140000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02Eooa80000BLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0P001Woo0P001Goo0P00019_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0]oo`006goo4P000W>L00<007ooOol00Woo0`001Woo00<007>L000040004W>L4P004G>L
9Goo4P004W>L0P001Goo0`001Woo00<007>LLi`047>L4P004W>L2goo000KOolB00000fmkLi`00005
Ool20006Ool00`00Li`0000@00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na80
000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00UOolB00004W>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`8000Ioo`8000Ioo`0C001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`04P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;Ool0
01]ooa80009cW003001oogoo00Yoo`03001cW7>L0140019cW180015cW2Eooa80019cW0<000aoo`80
019cW180019cW0]oo`006goo4P0000=_Ng>L000037oo00<006mkLi`04@00019cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`09Goo4P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/3000<Ool200004Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L2goo000KOolB0002Li`00`00Oomoo`09Ool01000LiacW7>L4@004W>L4P00
4G>L9Goo4P004W>L0`002goo0`004W>L4P004W>L2goo000KOolB000016mkLia_N`002Woo00@007>L
Kg]cW140000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L02Eooa80000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk10002Woo0`00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B0000
4VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0]oo`006goo4P0017>L0P001Woo0P00
17>L4@004W>L4P004G>L9Goo4P004W>L1P001Woo1@004W>L4P004W>L2goo000KOolB00001VmkLia_
Ng>LKg]cW0H00006Kg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB
000BLi`A000BLi`B000ALi`UOolB000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000K
OolBLi`B000ALi`B000BLi`A000UOolBLi`B000ALi`B000BLi`B000;Ool001]oo`0BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk0180000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@009Goo019cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`04P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B000;Ool0
01]ooa9cW180015cW0L000Aoo`L0019cW14002Eooa9cW180015cW180019cW0H000Eoo`L000]oo`00
6goo019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004FmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/01@002Goo1000019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na80000ALia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0D000Qoo`D000]oo`006goo4W>L4P004G>L1@002Woo0`004W>L4@009Goo4W>L
4P004G>L4P004W>L10002Woo10002goo000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`04000<Ool200004W>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0180
000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0`0037oo0`002goo000KOolBLi`B
000ALi`4000<Ool2000BLi`A000UOolBLi`B000ALi`B000BLi`3000<Ool3000;Ool001]oo`0BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00<000Eoo`8000Ioo`80000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`04P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`30005Ool20005Ool3000;Ool001]ooa9cW180015cW0<000Aoo`@000Eoo`80019c
W14002Eooa9cW180015cW180019cW0<000Aoo`<000Ioo`8000]oo`006goo019_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/00`001Goo0P001Woo0P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A000U
Ool04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na80000ALia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00B00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W0<000Eoo`8000Ioo`8000]oo`006goo4W>L4P004G>L0`003Goo0P004W>L4@009Goo4W>L4P004G>L
4P004W>L0`0037oo0`002goo000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`04000<Ool200004W>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0180000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0`0037oo0`002goo000KOolBLi`B000ALi`4
000;Ool3000BLi`A000UOolBLi`B000ALi`B000BLi`4000:Ool4000;Ool001]oo`0BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00H000Qoo`@0000BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@009Goo
019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`04P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`5
0009Ool4000;Ool001]ooa9cW180015cW0P000Eoo`D0019cW14002Eooa9cW180015cW180019cW0P0
00Aoo`H000]oo`006goo019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004Fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na80
000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B00004VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW18000]oo`006goo4W>L4P004G>L4P004W>L4@009Goo4W>L4P004G>L
4P004W>L4P002goo000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000A
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0180000BKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOolB000BLi`A000BLi`B000ALi`UOolB000BLi`A
000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00001G>LKg]cW6mkLi`02000
00A_Ng>LKg]cW2Eooa800006Lia_Ng>LKg]cW6mk1`0000E_Ng>LKg]cW6mk0140000BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`;Ool001]ooa80019cW140019cW18000AcW003001oogoo00Ioo`04001cW7>LLi`UOolB
0004Li`20007Ool00`00LiacW002Li`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/B000017>LKg]cW0002Woo00<006mkLi`09Goo4P0000AcW6mkLi`000Yoo`04001_Ng>LKg/A
00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B0003Li`00`00Oomoo`08Ool0
0`00LiacW00UOolB0003Li`00`00Oomoo`09Ool00`00LiacW00A000BLi`B000BLi`;Ool001]ooa80
000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/B00000g>LKg/0000<Ool00`00Liaoo`0TOolB00000g>LKg/0000<
Ool00`00Lia_N`0A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B0002Li`0
0`00Oomoo`0:Ool00`00Liaoo`0TOolB0002Li`00`00Oomoo`0;Ool00`00Li`0000@000BLi`B000B
Li`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00000g>L001oo`05Ool20006Ool00`00Oomo
o`0SOolB00000g>LKg/00005Ool20006Ool00`00Kg/0000@00004VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo
000KOolB000BLi`A000BLi`B00000g>L001oo`04Ool30006Ool00`00Oomoo`0SOolB0002Li`00`00
Oomoo`02Ool40005Ool00`00Li`0000@000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/B00000g>LKg/0000<Ool00`00Liaoo`0TOolB00000g>LKg/0000<Ool00`00Lia_N`0A0000
4VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B0002Li`00`00Oomoo`0:Ool00`00
Liaoo`0TOolB0002Li`00`00Oomoo`0:Ool00`00LiacW00A000BLi`B000BLi`;Ool001]ooa80000B
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/B00000g>LKg/0000;Ool00`00Kg]cW00UOolB000017>LKg]cW0002goo
00<007>LKg/04@00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004VmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0]oo`006goo4P004W>L4@004W>L4P000g>L00<0
07ooOol027oo00<007>LLi`09Goo4P0017>L00<007ooOol01goo00@007>LLiacW140019cW180019c
W0]oo`006goo4P00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`A00004W>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na800004Lia_Ng>LKg/20007Ool01000Lia_Ng>L
9Goo4P0000IcW6mkLia_Ng>L0007Ool200000fmkLia_N`0A00004VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo
000KOolB000BLi`A000BLi`B0006Li`20002Ool30004Li`UOolB0006Li`20003Ool20005Li`A000B
Li`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00
019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B000027>LKg]cW6mkLia_Ng>LKg/2
00001g>LKg]cW6mkLia_Ng>L02Eooa800008Lia_Ng>LKg]cW6mkLia_N`<00007Kg]cW6mkLia_Ng>L
Kg/04@00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0]oo`006goo4P004W>L4@004W>L4P004G>L9Goo4P004W>L
4@004W>L4P004W>L2goo000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180
000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0180000BKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOol8Li`30007Li`B000ALi`B000BLi`A000U
OolBLi`B000ALi`B0009Li`20007Li`B000;Ool001]oo`06Kg]cW6mkLia_Ng>L0P000goo0P0000Ec
W6mkLia_Ng>L0180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B00004W>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01800006
Kg]cW6mkLia_Ng>L0`000Woo0P0000EcW6mkLia_Ng>L018000]oo`006goo17>L0P001goo00<007>L
Li`00W>L4P004G>L4P004W>L4@009Goo4W>L4P004G>L4P0017>L0P001goo00<007>LLi`00W>L4P00
2goo000KOol01FmkLia_Ng>L00002Goo00@007>LKg]cW180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eo
o`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01800005Kg]cW6mkLi`00009Ool01000Lia_Ng>L4P002goo000KOol3
Li`00`00Oomoo`09Ool00`00LiacW00B000ALi`B000BLi`A000UOolBLi`B000ALi`B0003Li`00`00
Oomoo`09Ool00`00LiacW00B000;Ool001]oo`04Kg]cW6mk000<Ool00`00Li`0000A00004FmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na80000A
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B000016mkLia_N`0037oo00<007>L0000
4@002goo000KOol2Li`00`00Oomoo`0;Ool00`00Li`0000A000ALi`B000BLi`A000UOolBLi`B000A
Li`B0002Li`00`00Oomoo`0;Ool00`00Li`0000A000;Ool001]oo`03Kg]cW00000Aoo`<000Ioo`03
001cW0000140000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B00004W>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01800003Kg]c
W00000Aoo`<000Ioo`03001cW000014000]oo`006goo0W>L00<007ooOol00goo0P001Woo00<007>L
00004@004G>L4P004W>L4@009Goo4W>L4P004G>L4P000W>L00<007ooOol00goo0P001Woo00<007>L
00004@002goo000KOol00fmkLi`0000<Ool00`00Kg]cW00B00004FmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/04P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A000U
Ool04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na80000ALia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00B00000fmkLi`0000<Ool00`00Kg]cW00B000;Ool001]oo`9cW003
001oogoo00Yoo`03001cW7>L0180015cW180019cW14002Eooa9cW180015cW180009cW003001oogoo
00Yoo`03001cW7>L018000]oo`006goo00A_Ng>LKg/000Yoo`04001cW6mkLi`B00004FmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na80000ALia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B000016mkLia_N`002Woo00@007>LKg]cW180
00]oo`006goo17>L00<007ooOol01goo00@007>LLiacW180015cW180019cW14002Eooa9cW180015c
W18000AcW003001oogoo00Moo`04001cW7>LLi`B000;Ool001]oo`06Kg]cW6mkLia_N`001goo00D0
06mkLia_Ng>L0180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B00004W>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01800006
Kg]cW6mkLia_N`001goo00D006mkLia_Ng>L018000]oo`006goo1W>L1`001G>L4P004G>L4P004W>L
4@009Goo4W>L4P004G>L4P001W>L1`001G>L4P002goo000KOol04VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW180000AKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0B0000
4W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na4002Eoo`0BLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
0180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOolBLi`B000A
Li`B000BLi`A000UOolBLi`B000ALi`B000BLi`B000;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000B
Li`A000BLi`B000ALi`UOolB000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L1P001Goo1P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo1`0017oo
1`00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L2goo000KOolB000BLi`50008Ool4000BLi`B000ALi`UOol50009Ool4000BLi`A000BLi`B000B
Li`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10002Woo0`00
019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`09Goo1@002Woo0`00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`3000<Ool2000BLi`B000A
Li`UOol4000<Ool2000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L0`0037oo0P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo100037oo0P00019c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo
000KOolB000BLi`20006Ool20005Ool2000BLi`B000ALi`UOol30005Ool20006Ool2000BLi`A000B
Li`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0P00
1Goo0`001Goo0P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo0`0017oo10001Goo0P00019cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000B
Li`20006Ool00`00Oomoo`04Ool2000BLi`B000ALi`UOol30005Ool20006Ool2000BLi`A000BLi`B
000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0`0037oo
0P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo100037oo0P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`3000<Ool2000BLi`B
000ALi`UOol4000<Ool2000BLi`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L10002Woo0`00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo1@002Woo0`00
019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
2goo000KOolB000BLi`50008Ool4000BLi`B000ALi`UOol60008Ool4000BLi`A000BLi`B000BLi`;
Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L1`001Goo1@00019c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`09Goo20001Goo1@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B000ALi`UOolB000B
Li`A000BLi`B000BLi`;Ool001]ooa80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L4@00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`09Goo4P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/A00004VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW180000BKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2goo000KOolB000BLi`A000BLi`B000ALi`UOolB
000BLi`A000BLi`B000BLi`;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L4P00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0180000BLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`04P00019_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B000;Ool001]ooa9cW180015cW18000IcW0L000Ec
W14002Eooa9cW180015cW180019cW18000]oo`006goo019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`B00004FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04P0000AcW6mk
Lia_N`8000Moo`05001cW6mkLia_N`0A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Na80000ALia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0060007Ool500004Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW18000]oo`006goo4W>L4P004G>L4P000g>L
00<007ooOol027oo00@007>LLiacW14002Eooa9cW180015cW0D000Yoo`<0019cW18000]oo`006goo
019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004FmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/04P0000AcW6mkLi`000]oo`03001cW6mk014002Eoo`0BLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00D000Yoo`<0000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo
000KOolBLi`B000ALi`B0002Li`00`00Oomoo`0:Ool00`00LiacW00A000UOolBLi`B000ALi`4000<
Ool2000BLi`B000;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P00
015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01800003Lia_N`0000eoo`03001_N`00
010002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000aoo`80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L4P002goo000KOolBLi`B000ALi`B0002Li`00`00Oomoo`03Ool20006Ool00`00
Li`0000@000UOolBLi`B000ALi`30005Ool20006Ool2000BLi`B000;Ool001]oo`0BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01800003Lia_N`0000Aoo`@000Eoo`03001_N`00010002Eoo`0BLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00<000Aoo`@000Eoo`80000BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo
000KOolBLi`B000ALi`B0002Li`00`00Oomoo`03Ool20005Ool00`00LiacW00A000UOolBLi`B000A
Li`40004Ool20006Ool2000BLi`B000;Ool001]oo`0BKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L4P00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01800003Lia_N`00
00aoo`03001cW6mk014002Eoo`0BLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk4P00
015cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000aoo`80000BKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P002goo000KOolBLi`B000ALi`B0003Li`00`00Oomoo`09
Ool00`00LiacW00A000UOolBLi`B000ALi`4000;Ool3000BLi`B000;Ool001]oo`0BKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L4P00015_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01800004Lia_Ng>L000:Ool01000Kg]cW6mk4@009Goo019cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@00
2Woo0`00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B000;Ool001]ooa9cW180
015cW18000AcW08000Moo`8000=cW14002Eooa9cW180015cW0H000Qoo`@0019cW18000]oo`006goo
019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004FmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/04P0000IcW6mkLia_Ng>LKg/20003Ool200001FmkLia_Ng>LKg/04@00
9Goo019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/B00004G>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`020000goo1`00019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`B000;Ool001]ooa9cW180015cW18000QcW0<000McW14002Eooa9cW180015cW180019c
W18000]oo`006goo019_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`B00004FmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/04P00019cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/A000UOol04W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Na80000A
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00B00004VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW18000]oo`006goo4W>L4P004G>L4P004W>L4@009Goo4W>L4P004G>L4P00
4W>L4P002goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500105, -0.0500105, 
  0.00731715, 0.00731715}, {{6.8125, 136.938}, {280.125, 
  150}} -> {-0.55984, -0.563371, 0.0564849, 0.0564849}, {{150, 280.125}, {
  280.125, 150}} -> {-8.64777, -0.563371, 0.0564849, 0.0564849}, {{6.8125, 
  136.938}, {136.938, 6.8125}} -> {-0.55984, -8.6513, 0.0564849, 
  0.0564849}, {{150, 280.125}, {136.938, 6.8125}} -> {-8.64777, -8.6513, 
  0.0564849, 0.0564849}}],

Cell[OutputFormData["\<\
GraphicsArray[{{Graphics[{{{GrayLevel[0], 
        {{Rectangle[{1, 1}, {2, 2}], Rectangle[{1, 3}, {2, 4}], 
          Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}}}, AspectRatio -> 1]}}]\
\>", "\<\
-GraphicsArray-\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The (7 \[Times] 7)-board", "Subsection"],

Cell[CellGroupData[{

Cell["qs = QueensSolution[7] //Timing", "Input"],

Cell[OutputFormData["\<\
{1.650000000000034*Second, {{1, 3, 5, 7, 2, 4, 6}, {1, 4, 7, 3, 6, 2, 5}, 
   {1, 5, 2, 6, 3, 7, 4}, {1, 6, 4, 2, 7, 5, 3}, {2, 4, 1, 7, 5, 3, 6}, 
   {2, 4, 6, 1, 3, 5, 7}, {2, 5, 1, 4, 7, 3, 6}, {2, 5, 3, 1, 7, 4, 6}, 
   {2, 5, 7, 4, 1, 3, 6}, {2, 6, 3, 7, 4, 1, 5}, {2, 7, 5, 3, 1, 6, 4}, 
   {3, 1, 6, 2, 5, 7, 4}, {3, 1, 6, 4, 2, 7, 5}, {3, 5, 7, 2, 4, 6, 1}, 
   {3, 6, 2, 5, 1, 4, 7}, {3, 7, 2, 4, 6, 1, 5}, {3, 7, 4, 1, 5, 2, 6}, 
   {4, 1, 3, 6, 2, 7, 5}, {4, 1, 5, 2, 6, 3, 7}, {4, 2, 7, 5, 3, 1, 6}, 
   {4, 6, 1, 3, 5, 7, 2}, {4, 7, 3, 6, 2, 5, 1}, {4, 7, 5, 2, 6, 1, 3}, 
   {5, 1, 4, 7, 3, 6, 2}, {5, 1, 6, 4, 2, 7, 3}, {5, 2, 6, 3, 7, 4, 1}, 
   {5, 3, 1, 6, 4, 2, 7}, {5, 7, 2, 4, 6, 1, 3}, {5, 7, 2, 6, 3, 1, 4}, 
   {6, 1, 3, 5, 7, 2, 4}, {6, 2, 5, 1, 4, 7, 3}, {6, 3, 1, 4, 7, 5, 2}, 
   {6, 3, 5, 7, 1, 4, 2}, {6, 3, 7, 4, 1, 5, 2}, {6, 4, 2, 7, 5, 3, 1}, 
   {6, 4, 7, 1, 3, 5, 2}, {7, 2, 4, 6, 1, 3, 5}, {7, 3, 6, 2, 5, 1, 4}, 
   {7, 4, 1, 5, 2, 6, 3}, {7, 5, 3, 1, 6, 4, 2}}}\
\>", "\<\
{1.65 Second, {{1, 3, 5, 7, 2, 4, 6}, {1, 4, 7, 3, 6, 2, 5}, {1, 5, 2, 6, 3, \
7, 4}, 
 
   {1, 6, 4, 2, 7, 5, 3}, {2, 4, 1, 7, 5, 3, 6}, {2, 4, 6, 1, 3, 5, 7}, 
 
   {2, 5, 1, 4, 7, 3, 6}, {2, 5, 3, 1, 7, 4, 6}, {2, 5, 7, 4, 1, 3, 6}, 
 
   {2, 6, 3, 7, 4, 1, 5}, {2, 7, 5, 3, 1, 6, 4}, {3, 1, 6, 2, 5, 7, 4}, 
 
   {3, 1, 6, 4, 2, 7, 5}, {3, 5, 7, 2, 4, 6, 1}, {3, 6, 2, 5, 1, 4, 7}, 
 
   {3, 7, 2, 4, 6, 1, 5}, {3, 7, 4, 1, 5, 2, 6}, {4, 1, 3, 6, 2, 7, 5}, 
 
   {4, 1, 5, 2, 6, 3, 7}, {4, 2, 7, 5, 3, 1, 6}, {4, 6, 1, 3, 5, 7, 2}, 
 
   {4, 7, 3, 6, 2, 5, 1}, {4, 7, 5, 2, 6, 1, 3}, {5, 1, 4, 7, 3, 6, 2}, 
 
   {5, 1, 6, 4, 2, 7, 3}, {5, 2, 6, 3, 7, 4, 1}, {5, 3, 1, 6, 4, 2, 7}, 
 
   {5, 7, 2, 4, 6, 1, 3}, {5, 7, 2, 6, 3, 1, 4}, {6, 1, 3, 5, 7, 2, 4}, 
 
   {6, 2, 5, 1, 4, 7, 3}, {6, 3, 1, 4, 7, 5, 2}, {6, 3, 5, 7, 1, 4, 2}, 
 
   {6, 3, 7, 4, 1, 5, 2}, {6, 4, 2, 7, 5, 3, 1}, {6, 4, 7, 1, 3, 5, 2}, 
 
   {7, 2, 4, 6, 1, 3, 5}, {7, 3, 6, 2, 5, 1, 4}, {7, 4, 1, 5, 2, 6, 3}, 
 
   {7, 5, 3, 1, 6, 4, 2}}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["t7 = qs[[1]]", "Input"],

Cell[OutputFormData["\<\
1.650000000000034*Second\
\>", "\<\
1.65 Second\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[qs[[2]]]", "Input"],

Cell[OutputFormData["\<\
40\
\>", "\<\
40\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsg = QueensPlot[#]& /@ qs[[2]]", "Input"],

Cell[OutputFormData["\<\
{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, {Circle[{2.5, \
7.5}, 0.4]}}\\
, {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, {GrayLevel[0], {Disk[{5.5, 2.5}, \
0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, {GrayLevel[0], {Disk[{2.5, \
7.5}, 0.1]}}}
}, AspectRatio -> 1]}\
\>", "\<\
{-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsga = Partition[qsg,5]", "Input"],

Cell[OutputFormData["\<\
{{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}}, {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}}\
\>", "\<\
{{-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[GraphicsArray[qsga]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.61111 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0383598 0.190476 [
[ 0 0 0 0 ]
[ 1 1.61111 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.61111 L
0 1.61111 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0383598 0.200176 0.214727 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.79762 .20238 m
.79762 .20238 .04762 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .04762 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .04762 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .04762 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .04762 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .04762 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.79762 .20238 .04762 0 365.73 arc
s
newpath
.55952 .32143 .04762 0 365.73 arc
s
newpath
.91667 .44048 .04762 0 365.73 arc
s
newpath
.20238 .55952 .04762 0 365.73 arc
s
newpath
.44048 .67857 .04762 0 365.73 arc
s
newpath
.67857 .79762 .04762 0 365.73 arc
s
newpath
.32143 .91667 .04762 0 365.73 arc
s
.79762 .20238 m
.79762 .20238 .0119 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .0119 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .0119 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .0119 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .0119 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .0119 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0383598 0.39418 0.214727 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.91667 .20238 m
.91667 .20238 .04762 0 365.73 arc
F
.32143 .32143 m
.32143 .32143 .04762 0 365.73 arc
F
.55952 .44048 m
.55952 .44048 .04762 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .04762 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .04762 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .04762 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.91667 .20238 .04762 0 365.73 arc
s
newpath
.32143 .32143 .04762 0 365.73 arc
s
newpath
.55952 .44048 .04762 0 365.73 arc
s
newpath
.79762 .55952 .04762 0 365.73 arc
s
newpath
.20238 .67857 .04762 0 365.73 arc
s
newpath
.44048 .79762 .04762 0 365.73 arc
s
newpath
.67857 .91667 .04762 0 365.73 arc
s
.91667 .20238 m
.91667 .20238 .0119 0 365.73 arc
F
.32143 .32143 m
.32143 .32143 .0119 0 365.73 arc
F
.55952 .44048 m
.55952 .44048 .0119 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .0119 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .0119 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .0119 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0383598 0.588183 0.214727 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.91667 .20238 m
.91667 .20238 .04762 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .04762 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .04762 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .04762 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .04762 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .04762 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.91667 .20238 .04762 0 365.73 arc
s
newpath
.44048 .32143 .04762 0 365.73 arc
s
newpath
.79762 .44048 .04762 0 365.73 arc
s
newpath
.32143 .55952 .04762 0 365.73 arc
s
newpath
.67857 .67857 .04762 0 365.73 arc
s
newpath
.20238 .79762 .04762 0 365.73 arc
s
newpath
.55952 .91667 .04762 0 365.73 arc
s
.91667 .20238 m
.91667 .20238 .0119 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .0119 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .0119 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .0119 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .0119 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .0119 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0383598 0.782187 0.214727 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.91667 .20238 m
.91667 .20238 .04762 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .04762 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .04762 0 365.73 arc
F
.67857 .55952 m
.67857 .55952 .04762 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .04762 0 365.73 arc
F
.79762 .79762 m
.79762 .79762 .04762 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.91667 .20238 .04762 0 365.73 arc
s
newpath
.55952 .32143 .04762 0 365.73 arc
s
newpath
.20238 .44048 .04762 0 365.73 arc
s
newpath
.67857 .55952 .04762 0 365.73 arc
s
newpath
.32143 .67857 .04762 0 365.73 arc
s
newpath
.79762 .79762 .04762 0 365.73 arc
s
newpath
.44048 .91667 .04762 0 365.73 arc
s
.91667 .20238 m
.91667 .20238 .0119 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .0119 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .0119 0 365.73 arc
F
.67857 .55952 m
.67857 .55952 .0119 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .0119 0 365.73 arc
F
.79762 .79762 m
.79762 .79762 .0119 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0383598 0.97619 0.214727 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.91667 .20238 m
.91667 .20238 .04762 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .04762 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .04762 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .04762 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .04762 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .04762 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.91667 .20238 .04762 0 365.73 arc
s
newpath
.67857 .32143 .04762 0 365.73 arc
s
newpath
.44048 .44048 .04762 0 365.73 arc
s
newpath
.20238 .55952 .04762 0 365.73 arc
s
newpath
.79762 .67857 .04762 0 365.73 arc
s
newpath
.55952 .79762 .04762 0 365.73 arc
s
newpath
.32143 .91667 .04762 0 365.73 arc
s
.91667 .20238 m
.91667 .20238 .0119 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .0119 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .0119 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .0119 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .0119 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .0119 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.232363 0.200176 0.40873 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.79762 .20238 m
.79762 .20238 .04762 0 365.73 arc
F
.32143 .32143 m
.32143 .32143 .04762 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .04762 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .04762 0 365.73 arc
F
.55952 .67857 m
.55952 .67857 .04762 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .04762 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.79762 .20238 .04762 0 365.73 arc
s
newpath
.32143 .32143 .04762 0 365.73 arc
s
newpath
.67857 .44048 .04762 0 365.73 arc
s
newpath
.20238 .55952 .04762 0 365.73 arc
s
newpath
.55952 .67857 .04762 0 365.73 arc
s
newpath
.91667 .79762 .04762 0 365.73 arc
s
newpath
.44048 .91667 .04762 0 365.73 arc
s
.79762 .20238 m
.79762 .20238 .0119 0 365.73 arc
F
.32143 .32143 m
.32143 .32143 .0119 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .0119 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .0119 0 365.73 arc
F
.55952 .67857 m
.55952 .67857 .0119 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .0119 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.232363 0.39418 0.40873 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.79762 .20238 m
.79762 .20238 .04762 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .04762 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .04762 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .04762 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .04762 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .04762 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.79762 .20238 .04762 0 365.73 arc
s
newpath
.44048 .32143 .04762 0 365.73 arc
s
newpath
.20238 .44048 .04762 0 365.73 arc
s
newpath
.55952 .55952 .04762 0 365.73 arc
s
newpath
.91667 .67857 .04762 0 365.73 arc
s
newpath
.67857 .79762 .04762 0 365.73 arc
s
newpath
.32143 .91667 .04762 0 365.73 arc
s
.79762 .20238 m
.79762 .20238 .0119 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .0119 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .0119 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .0119 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .0119 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .0119 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.232363 0.588183 0.40873 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.79762 .20238 m
.79762 .20238 .04762 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .04762 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .04762 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .04762 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .04762 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .04762 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.79762 .20238 .04762 0 365.73 arc
s
newpath
.44048 .32143 .04762 0 365.73 arc
s
newpath
.67857 .44048 .04762 0 365.73 arc
s
newpath
.91667 .55952 .04762 0 365.73 arc
s
newpath
.20238 .67857 .04762 0 365.73 arc
s
newpath
.55952 .79762 .04762 0 365.73 arc
s
newpath
.32143 .91667 .04762 0 365.73 arc
s
.79762 .20238 m
.79762 .20238 .0119 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .0119 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .0119 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .0119 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .0119 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .0119 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.232363 0.782187 0.40873 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.79762 .20238 m
.79762 .20238 .04762 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .04762 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .04762 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .04762 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .04762 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .04762 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.79762 .20238 .04762 0 365.73 arc
s
newpath
.44048 .32143 .04762 0 365.73 arc
s
newpath
.91667 .44048 .04762 0 365.73 arc
s
newpath
.55952 .55952 .04762 0 365.73 arc
s
newpath
.20238 .67857 .04762 0 365.73 arc
s
newpath
.67857 .79762 .04762 0 365.73 arc
s
newpath
.32143 .91667 .04762 0 365.73 arc
s
.79762 .20238 m
.79762 .20238 .0119 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .0119 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .0119 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .0119 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .0119 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .0119 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.232363 0.97619 0.40873 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.79762 .20238 m
.79762 .20238 .04762 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .04762 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .04762 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .04762 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .04762 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .04762 0 365.73 arc
F
.20238 .91667 m
.20238 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.79762 .20238 .04762 0 365.73 arc
s
newpath
.55952 .32143 .04762 0 365.73 arc
s
newpath
.32143 .44048 .04762 0 365.73 arc
s
newpath
.91667 .55952 .04762 0 365.73 arc
s
newpath
.67857 .67857 .04762 0 365.73 arc
s
newpath
.44048 .79762 .04762 0 365.73 arc
s
newpath
.20238 .91667 .04762 0 365.73 arc
s
.79762 .20238 m
.79762 .20238 .0119 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .0119 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .0119 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .0119 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .0119 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .0119 0 365.73 arc
F
.20238 .91667 m
.20238 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.426367 0.200176 0.602734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.67857 .20238 m
.67857 .20238 .04762 0 365.73 arc
F
.32143 .32143 m
.32143 .32143 .04762 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .04762 0 365.73 arc
F
.44048 .55952 m
.44048 .55952 .04762 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .04762 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .04762 0 365.73 arc
F
.20238 .91667 m
.20238 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.67857 .20238 .04762 0 365.73 arc
s
newpath
.32143 .32143 .04762 0 365.73 arc
s
newpath
.79762 .44048 .04762 0 365.73 arc
s
newpath
.44048 .55952 .04762 0 365.73 arc
s
newpath
.91667 .67857 .04762 0 365.73 arc
s
newpath
.55952 .79762 .04762 0 365.73 arc
s
newpath
.20238 .91667 .04762 0 365.73 arc
s
.67857 .20238 m
.67857 .20238 .0119 0 365.73 arc
F
.32143 .32143 m
.32143 .32143 .0119 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .0119 0 365.73 arc
F
.44048 .55952 m
.44048 .55952 .0119 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .0119 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .0119 0 365.73 arc
F
.20238 .91667 m
.20238 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.426367 0.39418 0.602734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.67857 .20238 m
.67857 .20238 .04762 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .04762 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .04762 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .04762 0 365.73 arc
F
.55952 .67857 m
.55952 .67857 .04762 0 365.73 arc
F
.32143 .79762 m
.32143 .79762 .04762 0 365.73 arc
F
.91667 .91667 m
.91667 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.67857 .20238 .04762 0 365.73 arc
s
newpath
.44048 .32143 .04762 0 365.73 arc
s
newpath
.20238 .44048 .04762 0 365.73 arc
s
newpath
.79762 .55952 .04762 0 365.73 arc
s
newpath
.55952 .67857 .04762 0 365.73 arc
s
newpath
.32143 .79762 .04762 0 365.73 arc
s
newpath
.91667 .91667 .04762 0 365.73 arc
s
.67857 .20238 m
.67857 .20238 .0119 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .0119 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .0119 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .0119 0 365.73 arc
F
.55952 .67857 m
.55952 .67857 .0119 0 365.73 arc
F
.32143 .79762 m
.32143 .79762 .0119 0 365.73 arc
F
.91667 .91667 m
.91667 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.426367 0.588183 0.602734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.67857 .20238 m
.67857 .20238 .04762 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .04762 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .04762 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .04762 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .04762 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .04762 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.67857 .20238 .04762 0 365.73 arc
s
newpath
.91667 .32143 .04762 0 365.73 arc
s
newpath
.32143 .44048 .04762 0 365.73 arc
s
newpath
.55952 .55952 .04762 0 365.73 arc
s
newpath
.79762 .67857 .04762 0 365.73 arc
s
newpath
.20238 .79762 .04762 0 365.73 arc
s
newpath
.44048 .91667 .04762 0 365.73 arc
s
.67857 .20238 m
.67857 .20238 .0119 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .0119 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .0119 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .0119 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .0119 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .0119 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.426367 0.782187 0.602734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.67857 .20238 m
.67857 .20238 .04762 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .04762 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .04762 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .04762 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .04762 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .04762 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.67857 .20238 .04762 0 365.73 arc
s
newpath
.91667 .32143 .04762 0 365.73 arc
s
newpath
.32143 .44048 .04762 0 365.73 arc
s
newpath
.79762 .55952 .04762 0 365.73 arc
s
newpath
.44048 .67857 .04762 0 365.73 arc
s
newpath
.20238 .79762 .04762 0 365.73 arc
s
newpath
.55952 .91667 .04762 0 365.73 arc
s
.67857 .20238 m
.67857 .20238 .0119 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .0119 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .0119 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .0119 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .0119 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .0119 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.426367 0.97619 0.602734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.79762 .20238 m
.79762 .20238 .04762 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .04762 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .04762 0 365.73 arc
F
.67857 .55952 m
.67857 .55952 .04762 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .04762 0 365.73 arc
F
.32143 .79762 m
.32143 .79762 .04762 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.79762 .20238 .04762 0 365.73 arc
s
newpath
.20238 .32143 .04762 0 365.73 arc
s
newpath
.44048 .44048 .04762 0 365.73 arc
s
newpath
.67857 .55952 .04762 0 365.73 arc
s
newpath
.91667 .67857 .04762 0 365.73 arc
s
newpath
.32143 .79762 .04762 0 365.73 arc
s
newpath
.55952 .91667 .04762 0 365.73 arc
s
.79762 .20238 m
.79762 .20238 .0119 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .0119 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .0119 0 365.73 arc
F
.67857 .55952 m
.67857 .55952 .0119 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .0119 0 365.73 arc
F
.32143 .79762 m
.32143 .79762 .0119 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.62037 0.200176 0.796737 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.55952 .20238 m
.55952 .20238 .04762 0 365.73 arc
F
.79762 .32143 m
.79762 .32143 .04762 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .04762 0 365.73 arc
F
.44048 .55952 m
.44048 .55952 .04762 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .04762 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .04762 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.55952 .20238 .04762 0 365.73 arc
s
newpath
.79762 .32143 .04762 0 365.73 arc
s
newpath
.20238 .44048 .04762 0 365.73 arc
s
newpath
.44048 .55952 .04762 0 365.73 arc
s
newpath
.67857 .67857 .04762 0 365.73 arc
s
newpath
.91667 .79762 .04762 0 365.73 arc
s
newpath
.32143 .91667 .04762 0 365.73 arc
s
.55952 .20238 m
.55952 .20238 .0119 0 365.73 arc
F
.79762 .32143 m
.79762 .32143 .0119 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .0119 0 365.73 arc
F
.44048 .55952 m
.44048 .55952 .0119 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .0119 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .0119 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.62037 0.39418 0.796737 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.55952 .20238 m
.55952 .20238 .04762 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .04762 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .04762 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .04762 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .04762 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .04762 0 365.73 arc
F
.20238 .91667 m
.20238 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.55952 .20238 .04762 0 365.73 arc
s
newpath
.91667 .32143 .04762 0 365.73 arc
s
newpath
.44048 .44048 .04762 0 365.73 arc
s
newpath
.79762 .55952 .04762 0 365.73 arc
s
newpath
.32143 .67857 .04762 0 365.73 arc
s
newpath
.67857 .79762 .04762 0 365.73 arc
s
newpath
.20238 .91667 .04762 0 365.73 arc
s
.55952 .20238 m
.55952 .20238 .0119 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .0119 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .0119 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .0119 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .0119 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .0119 0 365.73 arc
F
.20238 .91667 m
.20238 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.62037 0.588183 0.796737 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.55952 .20238 m
.55952 .20238 .04762 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .04762 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .04762 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .04762 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .04762 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .04762 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.55952 .20238 .04762 0 365.73 arc
s
newpath
.91667 .32143 .04762 0 365.73 arc
s
newpath
.67857 .44048 .04762 0 365.73 arc
s
newpath
.32143 .55952 .04762 0 365.73 arc
s
newpath
.79762 .67857 .04762 0 365.73 arc
s
newpath
.20238 .79762 .04762 0 365.73 arc
s
newpath
.44048 .91667 .04762 0 365.73 arc
s
.55952 .20238 m
.55952 .20238 .0119 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .0119 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .0119 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .0119 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .0119 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .0119 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.62037 0.782187 0.796737 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.67857 .20238 m
.67857 .20238 .04762 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .04762 0 365.73 arc
F
.55952 .44048 m
.55952 .44048 .04762 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .04762 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .04762 0 365.73 arc
F
.79762 .79762 m
.79762 .79762 .04762 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.67857 .20238 .04762 0 365.73 arc
s
newpath
.20238 .32143 .04762 0 365.73 arc
s
newpath
.55952 .44048 .04762 0 365.73 arc
s
newpath
.91667 .55952 .04762 0 365.73 arc
s
newpath
.44048 .67857 .04762 0 365.73 arc
s
newpath
.79762 .79762 .04762 0 365.73 arc
s
newpath
.32143 .91667 .04762 0 365.73 arc
s
.67857 .20238 m
.67857 .20238 .0119 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .0119 0 365.73 arc
F
.55952 .44048 m
.55952 .44048 .0119 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .0119 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .0119 0 365.73 arc
F
.79762 .79762 m
.79762 .79762 .0119 0 365.73 arc
F
.32143 .91667 m
.32143 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.62037 0.97619 0.796737 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.67857 .20238 m
.67857 .20238 .04762 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .04762 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .04762 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .04762 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .04762 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .04762 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.67857 .20238 .04762 0 365.73 arc
s
newpath
.20238 .32143 .04762 0 365.73 arc
s
newpath
.79762 .44048 .04762 0 365.73 arc
s
newpath
.55952 .55952 .04762 0 365.73 arc
s
newpath
.32143 .67857 .04762 0 365.73 arc
s
newpath
.91667 .79762 .04762 0 365.73 arc
s
newpath
.44048 .91667 .04762 0 365.73 arc
s
.67857 .20238 m
.67857 .20238 .0119 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .0119 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .0119 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .0119 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .0119 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .0119 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.814374 0.200176 0.990741 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.44048 .20238 m
.44048 .20238 .04762 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .04762 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .04762 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .04762 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .04762 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .04762 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.44048 .20238 .04762 0 365.73 arc
s
newpath
.91667 .32143 .04762 0 365.73 arc
s
newpath
.32143 .44048 .04762 0 365.73 arc
s
newpath
.55952 .55952 .04762 0 365.73 arc
s
newpath
.79762 .67857 .04762 0 365.73 arc
s
newpath
.20238 .79762 .04762 0 365.73 arc
s
newpath
.67857 .91667 .04762 0 365.73 arc
s
.44048 .20238 m
.44048 .20238 .0119 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .0119 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .0119 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .0119 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .0119 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .0119 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.814374 0.39418 0.990741 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.44048 .20238 m
.44048 .20238 .04762 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .04762 0 365.73 arc
F
.55952 .44048 m
.55952 .44048 .04762 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .04762 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .04762 0 365.73 arc
F
.32143 .79762 m
.32143 .79762 .04762 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.44048 .20238 .04762 0 365.73 arc
s
newpath
.91667 .32143 .04762 0 365.73 arc
s
newpath
.55952 .44048 .04762 0 365.73 arc
s
newpath
.20238 .55952 .04762 0 365.73 arc
s
newpath
.67857 .67857 .04762 0 365.73 arc
s
newpath
.32143 .79762 .04762 0 365.73 arc
s
newpath
.79762 .91667 .04762 0 365.73 arc
s
.44048 .20238 m
.44048 .20238 .0119 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .0119 0 365.73 arc
F
.55952 .44048 m
.55952 .44048 .0119 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .0119 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .0119 0 365.73 arc
F
.32143 .79762 m
.32143 .79762 .0119 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.814374 0.588183 0.990741 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.55952 .20238 m
.55952 .20238 .04762 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .04762 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .04762 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .04762 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .04762 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .04762 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.55952 .20238 .04762 0 365.73 arc
s
newpath
.20238 .32143 .04762 0 365.73 arc
s
newpath
.44048 .44048 .04762 0 365.73 arc
s
newpath
.79762 .55952 .04762 0 365.73 arc
s
newpath
.32143 .67857 .04762 0 365.73 arc
s
newpath
.91667 .79762 .04762 0 365.73 arc
s
newpath
.67857 .91667 .04762 0 365.73 arc
s
.55952 .20238 m
.55952 .20238 .0119 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .0119 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .0119 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .0119 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .0119 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .0119 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.814374 0.782187 0.990741 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.55952 .20238 m
.55952 .20238 .04762 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .04762 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .04762 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .04762 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .04762 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .04762 0 365.73 arc
F
.91667 .91667 m
.91667 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.55952 .20238 .04762 0 365.73 arc
s
newpath
.20238 .32143 .04762 0 365.73 arc
s
newpath
.67857 .44048 .04762 0 365.73 arc
s
newpath
.32143 .55952 .04762 0 365.73 arc
s
newpath
.79762 .67857 .04762 0 365.73 arc
s
newpath
.44048 .79762 .04762 0 365.73 arc
s
newpath
.91667 .91667 .04762 0 365.73 arc
s
.55952 .20238 m
.55952 .20238 .0119 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .0119 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .0119 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .0119 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .0119 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .0119 0 365.73 arc
F
.91667 .91667 m
.91667 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.814374 0.97619 0.990741 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.55952 .20238 m
.55952 .20238 .04762 0 365.73 arc
F
.32143 .32143 m
.32143 .32143 .04762 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .04762 0 365.73 arc
F
.67857 .55952 m
.67857 .55952 .04762 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .04762 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .04762 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.55952 .20238 .04762 0 365.73 arc
s
newpath
.32143 .32143 .04762 0 365.73 arc
s
newpath
.91667 .44048 .04762 0 365.73 arc
s
newpath
.67857 .55952 .04762 0 365.73 arc
s
newpath
.44048 .67857 .04762 0 365.73 arc
s
newpath
.20238 .79762 .04762 0 365.73 arc
s
newpath
.79762 .91667 .04762 0 365.73 arc
s
.55952 .20238 m
.55952 .20238 .0119 0 365.73 arc
F
.32143 .32143 m
.32143 .32143 .0119 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .0119 0 365.73 arc
F
.67857 .55952 m
.67857 .55952 .0119 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .0119 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .0119 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.00838 0.200176 1.18474 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.32143 .20238 m
.32143 .20238 .04762 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .04762 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .04762 0 365.73 arc
F
.44048 .55952 m
.44048 .55952 .04762 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .04762 0 365.73 arc
F
.79762 .79762 m
.79762 .79762 .04762 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.32143 .20238 .04762 0 365.73 arc
s
newpath
.91667 .32143 .04762 0 365.73 arc
s
newpath
.67857 .44048 .04762 0 365.73 arc
s
newpath
.44048 .55952 .04762 0 365.73 arc
s
newpath
.20238 .67857 .04762 0 365.73 arc
s
newpath
.79762 .79762 .04762 0 365.73 arc
s
newpath
.55952 .91667 .04762 0 365.73 arc
s
.32143 .20238 m
.32143 .20238 .0119 0 365.73 arc
F
.91667 .32143 m
.91667 .32143 .0119 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .0119 0 365.73 arc
F
.44048 .55952 m
.44048 .55952 .0119 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .0119 0 365.73 arc
F
.79762 .79762 m
.79762 .79762 .0119 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.00838 0.39418 1.18474 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.44048 .20238 m
.44048 .20238 .04762 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .04762 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .04762 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .04762 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .04762 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .04762 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.44048 .20238 .04762 0 365.73 arc
s
newpath
.20238 .32143 .04762 0 365.73 arc
s
newpath
.79762 .44048 .04762 0 365.73 arc
s
newpath
.32143 .55952 .04762 0 365.73 arc
s
newpath
.67857 .67857 .04762 0 365.73 arc
s
newpath
.91667 .79762 .04762 0 365.73 arc
s
newpath
.55952 .91667 .04762 0 365.73 arc
s
.44048 .20238 m
.44048 .20238 .0119 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .0119 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .0119 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .0119 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .0119 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .0119 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.00838 0.588183 1.18474 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.44048 .20238 m
.44048 .20238 .04762 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .04762 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .04762 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .04762 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .04762 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .04762 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.44048 .20238 .04762 0 365.73 arc
s
newpath
.20238 .32143 .04762 0 365.73 arc
s
newpath
.79762 .44048 .04762 0 365.73 arc
s
newpath
.55952 .55952 .04762 0 365.73 arc
s
newpath
.32143 .67857 .04762 0 365.73 arc
s
newpath
.91667 .79762 .04762 0 365.73 arc
s
newpath
.67857 .91667 .04762 0 365.73 arc
s
.44048 .20238 m
.44048 .20238 .0119 0 365.73 arc
F
.20238 .32143 m
.20238 .32143 .0119 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .0119 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .0119 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .0119 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .0119 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.00838 0.782187 1.18474 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.44048 .20238 m
.44048 .20238 .04762 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .04762 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .04762 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .04762 0 365.73 arc
F
.55952 .67857 m
.55952 .67857 .04762 0 365.73 arc
F
.79762 .79762 m
.79762 .79762 .04762 0 365.73 arc
F
.20238 .91667 m
.20238 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.44048 .20238 .04762 0 365.73 arc
s
newpath
.67857 .32143 .04762 0 365.73 arc
s
newpath
.91667 .44048 .04762 0 365.73 arc
s
newpath
.32143 .55952 .04762 0 365.73 arc
s
newpath
.55952 .67857 .04762 0 365.73 arc
s
newpath
.79762 .79762 .04762 0 365.73 arc
s
newpath
.20238 .91667 .04762 0 365.73 arc
s
.44048 .20238 m
.44048 .20238 .0119 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .0119 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .0119 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .0119 0 365.73 arc
F
.55952 .67857 m
.55952 .67857 .0119 0 365.73 arc
F
.79762 .79762 m
.79762 .79762 .0119 0 365.73 arc
F
.20238 .91667 m
.20238 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.00838 0.97619 1.18474 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.44048 .20238 m
.44048 .20238 .04762 0 365.73 arc
F
.79762 .32143 m
.79762 .32143 .04762 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .04762 0 365.73 arc
F
.67857 .55952 m
.67857 .55952 .04762 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .04762 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .04762 0 365.73 arc
F
.91667 .91667 m
.91667 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.44048 .20238 .04762 0 365.73 arc
s
newpath
.79762 .32143 .04762 0 365.73 arc
s
newpath
.32143 .44048 .04762 0 365.73 arc
s
newpath
.67857 .55952 .04762 0 365.73 arc
s
newpath
.20238 .67857 .04762 0 365.73 arc
s
newpath
.55952 .79762 .04762 0 365.73 arc
s
newpath
.91667 .91667 .04762 0 365.73 arc
s
.44048 .20238 m
.44048 .20238 .0119 0 365.73 arc
F
.79762 .32143 m
.79762 .32143 .0119 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .0119 0 365.73 arc
F
.67857 .55952 m
.67857 .55952 .0119 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .0119 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .0119 0 365.73 arc
F
.91667 .91667 m
.91667 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.20238 0.200176 1.37875 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.32143 .20238 m
.32143 .20238 .04762 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .04762 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .04762 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .04762 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .04762 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .04762 0 365.73 arc
F
.91667 .91667 m
.91667 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.32143 .20238 .04762 0 365.73 arc
s
newpath
.55952 .32143 .04762 0 365.73 arc
s
newpath
.79762 .44048 .04762 0 365.73 arc
s
newpath
.20238 .55952 .04762 0 365.73 arc
s
newpath
.44048 .67857 .04762 0 365.73 arc
s
newpath
.67857 .79762 .04762 0 365.73 arc
s
newpath
.91667 .91667 .04762 0 365.73 arc
s
.32143 .20238 m
.32143 .20238 .0119 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .0119 0 365.73 arc
F
.79762 .44048 m
.79762 .44048 .0119 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .0119 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .0119 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .0119 0 365.73 arc
F
.91667 .91667 m
.91667 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.20238 0.39418 1.37875 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.32143 .20238 m
.32143 .20238 .04762 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .04762 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .04762 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .04762 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .04762 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .04762 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.32143 .20238 .04762 0 365.73 arc
s
newpath
.67857 .32143 .04762 0 365.73 arc
s
newpath
.20238 .44048 .04762 0 365.73 arc
s
newpath
.55952 .55952 .04762 0 365.73 arc
s
newpath
.91667 .67857 .04762 0 365.73 arc
s
newpath
.44048 .79762 .04762 0 365.73 arc
s
newpath
.79762 .91667 .04762 0 365.73 arc
s
.32143 .20238 m
.32143 .20238 .0119 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .0119 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .0119 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .0119 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .0119 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .0119 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.20238 0.588183 1.37875 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.32143 .20238 m
.32143 .20238 .04762 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .04762 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .04762 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .04762 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .04762 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .04762 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.32143 .20238 .04762 0 365.73 arc
s
newpath
.67857 .32143 .04762 0 365.73 arc
s
newpath
.44048 .44048 .04762 0 365.73 arc
s
newpath
.20238 .55952 .04762 0 365.73 arc
s
newpath
.91667 .67857 .04762 0 365.73 arc
s
newpath
.55952 .79762 .04762 0 365.73 arc
s
newpath
.79762 .91667 .04762 0 365.73 arc
s
.32143 .20238 m
.32143 .20238 .0119 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .0119 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .0119 0 365.73 arc
F
.20238 .55952 m
.20238 .55952 .0119 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .0119 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .0119 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.20238 0.782187 1.37875 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.32143 .20238 m
.32143 .20238 .04762 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .04762 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .04762 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .04762 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .04762 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .04762 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.32143 .20238 .04762 0 365.73 arc
s
newpath
.67857 .32143 .04762 0 365.73 arc
s
newpath
.91667 .44048 .04762 0 365.73 arc
s
newpath
.55952 .55952 .04762 0 365.73 arc
s
newpath
.20238 .67857 .04762 0 365.73 arc
s
newpath
.44048 .79762 .04762 0 365.73 arc
s
newpath
.79762 .91667 .04762 0 365.73 arc
s
.32143 .20238 m
.32143 .20238 .0119 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .0119 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .0119 0 365.73 arc
F
.55952 .55952 m
.55952 .55952 .0119 0 365.73 arc
F
.20238 .67857 m
.20238 .67857 .0119 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .0119 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.20238 0.97619 1.37875 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.32143 .20238 m
.32143 .20238 .04762 0 365.73 arc
F
.79762 .32143 m
.79762 .32143 .04762 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .04762 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .04762 0 365.73 arc
F
.55952 .67857 m
.55952 .67857 .04762 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .04762 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.32143 .20238 .04762 0 365.73 arc
s
newpath
.79762 .32143 .04762 0 365.73 arc
s
newpath
.44048 .44048 .04762 0 365.73 arc
s
newpath
.91667 .55952 .04762 0 365.73 arc
s
newpath
.55952 .67857 .04762 0 365.73 arc
s
newpath
.20238 .79762 .04762 0 365.73 arc
s
newpath
.67857 .91667 .04762 0 365.73 arc
s
.32143 .20238 m
.32143 .20238 .0119 0 365.73 arc
F
.79762 .32143 m
.79762 .32143 .0119 0 365.73 arc
F
.44048 .44048 m
.44048 .44048 .0119 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .0119 0 365.73 arc
F
.55952 .67857 m
.55952 .67857 .0119 0 365.73 arc
F
.20238 .79762 m
.20238 .79762 .0119 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.39638 0.200176 1.57275 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.20238 .20238 m
.20238 .20238 .04762 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .04762 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .04762 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .04762 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .04762 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .04762 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.20238 .20238 .04762 0 365.73 arc
s
newpath
.44048 .32143 .04762 0 365.73 arc
s
newpath
.67857 .44048 .04762 0 365.73 arc
s
newpath
.91667 .55952 .04762 0 365.73 arc
s
newpath
.32143 .67857 .04762 0 365.73 arc
s
newpath
.55952 .79762 .04762 0 365.73 arc
s
newpath
.79762 .91667 .04762 0 365.73 arc
s
.20238 .20238 m
.20238 .20238 .0119 0 365.73 arc
F
.44048 .32143 m
.44048 .32143 .0119 0 365.73 arc
F
.67857 .44048 m
.67857 .44048 .0119 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .0119 0 365.73 arc
F
.32143 .67857 m
.32143 .67857 .0119 0 365.73 arc
F
.55952 .79762 m
.55952 .79762 .0119 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.39638 0.39418 1.57275 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.20238 .20238 m
.20238 .20238 .04762 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .04762 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .04762 0 365.73 arc
F
.44048 .55952 m
.44048 .55952 .04762 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .04762 0 365.73 arc
F
.32143 .79762 m
.32143 .79762 .04762 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.20238 .20238 .04762 0 365.73 arc
s
newpath
.55952 .32143 .04762 0 365.73 arc
s
newpath
.91667 .44048 .04762 0 365.73 arc
s
newpath
.44048 .55952 .04762 0 365.73 arc
s
newpath
.79762 .67857 .04762 0 365.73 arc
s
newpath
.32143 .79762 .04762 0 365.73 arc
s
newpath
.67857 .91667 .04762 0 365.73 arc
s
.20238 .20238 m
.20238 .20238 .0119 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .0119 0 365.73 arc
F
.91667 .44048 m
.91667 .44048 .0119 0 365.73 arc
F
.44048 .55952 m
.44048 .55952 .0119 0 365.73 arc
F
.79762 .67857 m
.79762 .67857 .0119 0 365.73 arc
F
.32143 .79762 m
.32143 .79762 .0119 0 365.73 arc
F
.67857 .91667 m
.67857 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.39638 0.588183 1.57275 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.20238 .20238 m
.20238 .20238 .04762 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .04762 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .04762 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .04762 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .04762 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .04762 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.20238 .20238 .04762 0 365.73 arc
s
newpath
.67857 .32143 .04762 0 365.73 arc
s
newpath
.32143 .44048 .04762 0 365.73 arc
s
newpath
.79762 .55952 .04762 0 365.73 arc
s
newpath
.44048 .67857 .04762 0 365.73 arc
s
newpath
.91667 .79762 .04762 0 365.73 arc
s
newpath
.55952 .91667 .04762 0 365.73 arc
s
.20238 .20238 m
.20238 .20238 .0119 0 365.73 arc
F
.67857 .32143 m
.67857 .32143 .0119 0 365.73 arc
F
.32143 .44048 m
.32143 .44048 .0119 0 365.73 arc
F
.79762 .55952 m
.79762 .55952 .0119 0 365.73 arc
F
.44048 .67857 m
.44048 .67857 .0119 0 365.73 arc
F
.91667 .79762 m
.91667 .79762 .0119 0 365.73 arc
F
.55952 .91667 m
.55952 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.39638 0.782187 1.57275 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.20238 .20238 m
.20238 .20238 .04762 0 365.73 arc
F
.79762 .32143 m
.79762 .32143 .04762 0 365.73 arc
F
.55952 .44048 m
.55952 .44048 .04762 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .04762 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .04762 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .04762 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.20238 .20238 .04762 0 365.73 arc
s
newpath
.79762 .32143 .04762 0 365.73 arc
s
newpath
.55952 .44048 .04762 0 365.73 arc
s
newpath
.32143 .55952 .04762 0 365.73 arc
s
newpath
.91667 .67857 .04762 0 365.73 arc
s
newpath
.67857 .79762 .04762 0 365.73 arc
s
newpath
.44048 .91667 .04762 0 365.73 arc
s
.20238 .20238 m
.20238 .20238 .0119 0 365.73 arc
F
.79762 .32143 m
.79762 .32143 .0119 0 365.73 arc
F
.55952 .44048 m
.55952 .44048 .0119 0 365.73 arc
F
.32143 .55952 m
.32143 .55952 .0119 0 365.73 arc
F
.91667 .67857 m
.91667 .67857 .0119 0 365.73 arc
F
.67857 .79762 m
.67857 .79762 .0119 0 365.73 arc
F
.44048 .91667 m
.44048 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.39638 0.97619 1.57275 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.14286 .14286 m
.14286 .2619 L
.2619 .2619 L
.2619 .14286 L
F
.14286 .38095 m
.14286 .5 L
.2619 .5 L
.2619 .38095 L
F
.14286 .61905 m
.14286 .7381 L
.2619 .7381 L
.2619 .61905 L
F
.14286 .85714 m
.14286 .97619 L
.2619 .97619 L
.2619 .85714 L
F
.38095 .14286 m
.38095 .2619 L
.5 .2619 L
.5 .14286 L
F
.38095 .38095 m
.38095 .5 L
.5 .5 L
.5 .38095 L
F
.38095 .61905 m
.38095 .7381 L
.5 .7381 L
.5 .61905 L
F
.38095 .85714 m
.38095 .97619 L
.5 .97619 L
.5 .85714 L
F
.61905 .14286 m
.61905 .2619 L
.7381 .2619 L
.7381 .14286 L
F
.61905 .38095 m
.61905 .5 L
.7381 .5 L
.7381 .38095 L
F
.61905 .61905 m
.61905 .7381 L
.7381 .7381 L
.7381 .61905 L
F
.61905 .85714 m
.61905 .97619 L
.7381 .97619 L
.7381 .85714 L
F
.85714 .14286 m
.85714 .2619 L
.97619 .2619 L
.97619 .14286 L
F
.85714 .38095 m
.85714 .5 L
.97619 .5 L
.97619 .38095 L
F
.85714 .61905 m
.85714 .7381 L
.97619 .7381 L
.97619 .61905 L
F
.85714 .85714 m
.85714 .97619 L
.97619 .97619 L
.97619 .85714 L
F
.9 g
.14286 .2619 m
.14286 .38095 L
.2619 .38095 L
.2619 .2619 L
F
.14286 .5 m
.14286 .61905 L
.2619 .61905 L
.2619 .5 L
F
.14286 .7381 m
.14286 .85714 L
.2619 .85714 L
.2619 .7381 L
F
.38095 .2619 m
.38095 .38095 L
.5 .38095 L
.5 .2619 L
F
.38095 .5 m
.38095 .61905 L
.5 .61905 L
.5 .5 L
F
.38095 .7381 m
.38095 .85714 L
.5 .85714 L
.5 .7381 L
F
.61905 .2619 m
.61905 .38095 L
.7381 .38095 L
.7381 .2619 L
F
.61905 .5 m
.61905 .61905 L
.7381 .61905 L
.7381 .5 L
F
.61905 .7381 m
.61905 .85714 L
.7381 .85714 L
.7381 .7381 L
F
.85714 .2619 m
.85714 .38095 L
.97619 .38095 L
.97619 .2619 L
F
.85714 .5 m
.85714 .61905 L
.97619 .61905 L
.97619 .5 L
F
.85714 .7381 m
.85714 .85714 L
.97619 .85714 L
.97619 .7381 L
F
0 g
.2619 .2619 m
.2619 .38095 L
.38095 .38095 L
.38095 .2619 L
F
.2619 .5 m
.2619 .61905 L
.38095 .61905 L
.38095 .5 L
F
.2619 .7381 m
.2619 .85714 L
.38095 .85714 L
.38095 .7381 L
F
.5 .2619 m
.5 .38095 L
.61905 .38095 L
.61905 .2619 L
F
.5 .5 m
.5 .61905 L
.61905 .61905 L
.61905 .5 L
F
.5 .7381 m
.5 .85714 L
.61905 .85714 L
.61905 .7381 L
F
.7381 .2619 m
.7381 .38095 L
.85714 .38095 L
.85714 .2619 L
F
.7381 .5 m
.7381 .61905 L
.85714 .61905 L
.85714 .5 L
F
.7381 .7381 m
.7381 .85714 L
.85714 .85714 L
.85714 .7381 L
F
.9 g
.2619 .14286 m
.2619 .2619 L
.38095 .2619 L
.38095 .14286 L
F
.2619 .38095 m
.2619 .5 L
.38095 .5 L
.38095 .38095 L
F
.2619 .61905 m
.2619 .7381 L
.38095 .7381 L
.38095 .61905 L
F
.2619 .85714 m
.2619 .97619 L
.38095 .97619 L
.38095 .85714 L
F
.5 .14286 m
.5 .2619 L
.61905 .2619 L
.61905 .14286 L
F
.5 .38095 m
.5 .5 L
.61905 .5 L
.61905 .38095 L
F
.5 .61905 m
.5 .7381 L
.61905 .7381 L
.61905 .61905 L
F
.5 .85714 m
.5 .97619 L
.61905 .97619 L
.61905 .85714 L
F
.7381 .14286 m
.7381 .2619 L
.85714 .2619 L
.85714 .14286 L
F
.7381 .38095 m
.7381 .5 L
.85714 .5 L
.85714 .38095 L
F
.7381 .61905 m
.7381 .7381 L
.85714 .7381 L
.85714 .61905 L
F
.7381 .85714 m
.7381 .97619 L
.85714 .97619 L
.85714 .85714 L
F
1 g
.32143 .20238 m
.32143 .20238 .04762 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .04762 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .04762 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .04762 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .04762 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .04762 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .04762 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.32143 .20238 .04762 0 365.73 arc
s
newpath
.55952 .32143 .04762 0 365.73 arc
s
newpath
.20238 .44048 .04762 0 365.73 arc
s
newpath
.91667 .55952 .04762 0 365.73 arc
s
newpath
.67857 .67857 .04762 0 365.73 arc
s
newpath
.44048 .79762 .04762 0 365.73 arc
s
newpath
.79762 .91667 .04762 0 365.73 arc
s
.32143 .20238 m
.32143 .20238 .0119 0 365.73 arc
F
.55952 .32143 m
.55952 .32143 .0119 0 365.73 arc
F
.20238 .44048 m
.20238 .44048 .0119 0 365.73 arc
F
.91667 .55952 m
.91667 .55952 .0119 0 365.73 arc
F
.67857 .67857 m
.67857 .67857 .0119 0 365.73 arc
F
.44048 .79762 m
.44048 .79762 .0119 0 365.73 arc
F
.79762 .91667 m
.79762 .91667 .0119 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{518.75, 835.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000860003@a000`40O003h00Oogooogoo27oo003o
OoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo
27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00
ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomo
o`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool0
0?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOooo
Ool8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo
000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/00004Kg]cW6mkLi`3000017>LKg]cW6mk2`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
6Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`;0003Li`01000Oomoogoo
0P000W>L2`0067oo2`002g>L2`002g>L2`002g>L0`000goo10006Goo2`002W>L2`002g>L2`002g>L
10000goo100067oo2`002g>L2`002g>L2`002W>L10000goo10006Goo2P002g>L2`002g>L2`002g>L
0`0017oo10003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/00004Kg]cW6mk0005Ool00`00Kg/0000:000HOol;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0030005Ool2000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030006Ool2000HOol;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mk
Lia_Ng>LKg]cW6mkLi`40005Ool2000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030006Ool2000?
Ool001Uoo`/000]cW0X000]cW0/0009cW003001oogoo00Eoo``001Qoo`/000]cW0/000]cW0/000]c
W08000Moo`03001oogoo01Moo`/000YcW0/000]cW0/000]cW08000Qoo`03001oogoo01Ioo`/000]c
W0/000]cW0/000YcW0<000Moo`03001oogoo01Moo`X000]cW0/000]cW0/000]cW08000Moo`8000mo
o`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00000fmk001oo`02Ool30002Ool<000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020002Ool3
0002Ool00`00Oomoo`0GOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020002Ool30003Ool00`00Oomoo`0F
Ool;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`20003Ool30002Ool00`00Oomoo`0GOol:00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`020002Ool30003Ool00`00Oomoo`0=Ool001Uoo`/000]cW0X000]cW0/00003Li`0
07oo00Moo``001Qoo`/000]cW0/000]cW0/000]cW08000Moo`03001oogoo01Moo`/000YcW0/000]c
W0/000]cW08000Moo`8001Qoo`/000]cW0/000]cW0/000YcW08000Qoo`03001oogoo01Moo`X000]c
W0/000]cW0/000]cW08000Moo`8000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLi`00007Ool<000HOol;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0020007Ool00`00Oomoo`0GOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool2000H
Ool;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`30007Ool00`00Oomoo`0GOol:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`020007Ool2000?Ool001Uoo`/000]cW0X000]cW0/0009cW08000Eoo`03001cW00000X001Qo
o`/000]cW0/000]cW0/000]cW0<000Eoo`8001Uoo`/000YcW0/000]cW0/000]cW0@000Aoo`<001Qo
o`/000]cW0/000]cW0/000YcW0@000Eoo`8001Uoo`X000]cW0/000]cW0/000]cW0<000Eoo`<000mo
o`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;000016mkLia_Ng>L0P0000Eoo`00000006mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00D0009oo`<001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00D0009oo`@001Qoo`/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0H00003Ool00000008001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00D0009oo`@000mo
o`006Goo2`002g>L2P002g>L2`001W>L00<007>LLi`00W>L2`0067oo2`002g>L2`002g>L2`002g>L
2P006Goo2`002W>L2`002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`002W>L2`006Goo2P002g>L
2`002g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`]cW0/000Yc
W0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0/000YcW1Uoo`]cW0X000AcW0@000=cW0/000]c
W0/000]cW1Qoo`]cW0/000]cW0/000]cW0X000]cW1Uoo`YcW0/000]cW0/000AcW0@000=cW0/000]c
W0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`4
0004Ool300002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040004Ool300002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol0
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000A_Ng>LKg/000Aoo`800003Kg/0000000T0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030005Ool300002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000AcW6mkLi`000Aoo`800003
Li`0000000T0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0<000Moo`03
001cW7>L00UcW0/000]cW1Qoo`]cW0<000Moo`03001cW7>L00UcW0/000]cW0/000YcW1Uoo`]cW0X0
009cW003001oogoo00Eoo``000]cW0/000]cW1Qoo`]cW0/000]cW08000Moo`8000]cW0X000]cW1Uo
o`YcW0/000]cW0/0009cW003001oogoo00Eoo``000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`30007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
0`001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00000fmk
Li`00007Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
0P001goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003
Lia_N`0000Moo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0<0009o
o`<0009oo`03001cW7>L00UcW0/000]cW1Qoo`]cW08000=oo`<0009oo`03001cW7>L00UcW0/000]c
W0/000YcW1Uoo`]cW0X0009cW003001oogoo00<0009oo``000]cW0/000]cW1Qoo`]cW0/000]cW080
009oo`<000=oo`03001cW7>L00UcW0X000]cW1Uoo`YcW0/000]cW0/00004Li`007ooOol40002Ool<
000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Qoo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol0
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`80000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`07Ool<00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`03goo000IOol;Li`;000:Li`30007Ool00`00LiacW009Li`;000;Li`HOol;Li`30007
Ool00`00LiacW009Li`;000;Li`;000:Li`IOol;Li`:0002Li`00`00Oomoo`05Ool<000;Li`;000;
Li`HOol;Li`;000;Li`20007Ool2000;Li`:000;Li`IOol:Li`;000;Li`;00000g>L001oo`07Ool<
000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L10001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/010001Goo0P0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X00004Kg]cW6mk0005Ool00`00Kg/0000:00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001Goo0`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>L
Kg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_N`000005Ool00`00
Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`600000goo0000
0002000;Li`;000;Li`HOol;Li`50002Ool4000;Li`;000;Li`;000:Li`IOol;Li`:0004Li`20000
0goo00000002Li`;000;Li`;000;Li`HOol;Li`;000;Li`50002Ool4000;Li`:000;Li`IOol:Li`;
000;Li`;0004Li`00`00Oomoo`020002Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>L
001cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0I
Ool02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00005Lia_
Ng>LKg]cW002000016mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L
2`002W>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L2`002W>L6Goo2g>L2P002g>L2`002g>L
2`002g>L67oo2g>L2`002g>L2`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`002g>L3goo000I
Ool;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000=cW6mkLi`01@0000=cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000AcW6mk
Lia_N`@00003Lia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`002g>L100017oo0`0067oo2`002g>L
2`000W>L00<007ooOol00goo0P0000=cW00000002@002g>L2P006Goo2`002W>L2`002g>L2`000g>L
00<007ooOol00Woo0P0000=cW00000002@0067oo100017oo0`002g>L2`002g>L2`002W>L2`006Goo
2P002g>L100017oo0`002g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`03
0007Ool00`00Oomoo`0FOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW000Ool01Woo
00<007>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>L
Kg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mk00001goo300067oo0`00
1goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030007
Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?
Ool001Uoo`/000]cW0X000]cW0/000]cW0<000Moo`03001oogoo01Ioo`/000]cW0/00003Li`007oo
00Ioo`03001cW00000X000]cW0X001Uoo`/000YcW0/000]cW0/0009cW003001oogoo00Eoo``001Qo
o`<000Moo`03001cW7>L00UcW0/000]cW0/000YcW0/001Uoo`X000]cW0<000Moo`03001cW7>L00Uc
W0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000Woo10000Woo00<007oo
Ool05Woo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Li`007ooOol30003Ool<00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>L001oogoo10000Woo300067oo0P000goo0`000Woo00`0
06mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020003Ool30002
Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?
Ool001Uoo`/000]cW0X000]cW0/000]cW08000Qoo`03001oogoo01Ioo`/000]cW0/00003Li`007oo
00Ioo`d000]cW0X001Uoo`/000YcW0/000]cW0/00003Li`007oo00Moo``001Qoo`8000Qoo`03001c
W7>L00UcW0/000]cW0/000YcW0/001Uoo`X000]cW08000Qoo`03001cW7>L00UcW0/000]cW0/000mo
o`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P0027oo00<007ooOol05Woo2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW00000X0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/00003Li`007oo00Moo``001Qoo`<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00`001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`;000;Li`40005
Ool2000HOol;000;Li`;0002Li`20004Ool00`00LiacW00;000;Li`:000IOol;000:Li`;000;Li`;
0002Li`20005Ool00`00Li`0000:000HOol40005Ool2000;Li`;000;Li`;000:Li`;000IOol:000;
Li`40005Ool2000;Li`;000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00D0009o
o`@001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00001G>LKg]cW6mk00000Woo00@007>L
Kg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00005Lia_Ng>LKg/00002Ool200000fmkLi`0
000:000HOol50002Ool400002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/01P0000=oo`0000000P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0/000]cW0/001Qoo`/000]cW0/0
00EcW08000AcW0/000]cW0X001Uoo`/000YcW0/000]cW0/000EcW08000AcW0/001Qoo`/000]cW0/0
00]cW0/000YcW0/001Uoo`X000]cW0/000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`003goo000IOol3Li`50003Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`;
000:Li`IOol;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;0003Li`40004Li`:000;Li`I
Ool3Li`40003Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`03Kg]cW00000Eoo`800003Kg/00000
00T0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Aoo`@0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`0017oo0`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00000g>LKg/00004Ool200000fmkLi`0000900002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/06Goo00=_Ng>L000017oo0P0000=cW00000002@0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo
000IOol00g>L001oo`06Ool00`00Li`0000:000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;
Li`20007Ool2000:Li`IOol;Li`20007Ool00`00LiacW009Li`;000;Li`;000;Li`HOol;Li`;000;
Li`;00000g>L001oo`06Ool00`00Li`00009000;Li`IOol00g>L001oo`06Ool<000;Li`;000;Li`;
000;Li`?Ool001Uoo`03Kg/007oo00Ioo`03001_N`0000X0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk008000Moo`80000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`00P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW000Ool01Woo00<0
07>L00002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`03Kg/007oo00Ioo``0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00moo`006Goo00AcW000Oomoo`<000=oo``000YcW0/000]cW0/000]cW1Qoo`]c
W0/000]cW0/000]cW080009oo`<0009oo`8000YcW1Uoo`]cW080009oo`<0009oo`03001cW7>L00Uc
W0/000]cW0/000]cW1Qoo`]cW0/000]cW0/00004Li`007ooOol30002Ool00`00Li`00009000;Li`I
Ool017>L001oogoo0`000Woo30002g>L2`002g>L2`002g>L3goo000IOol00fmk001oo`06Ool00`00
Kg/0000:00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool20000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`0<001_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0IOol00fmk001oo`06Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`03Li`007oo
00Ioo`03001cW00000X000YcW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW08000Moo`8000Yc
W1Uoo`]cW08000Moo`03001cW7>L00UcW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/00003Li`007oo
00Ioo`03001cW00000T000]cW1Uoo`03Li`007oo00Ioo``000]cW0/000]cW0/000]cW0moo`006Goo
00A_Ng>L000000Aoo`03001cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00<000Eoo`<0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`00`001Goo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00005Ool00`00Kg]cW00:0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00=_Ng>L00001Goo00<007>L00002P0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`03goo000IOol4Li`40003Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;
000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;0003Li`50003Li`:
000;Li`IOol3Li`50002Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002Vmk
Lia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;
000;Li`:000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:Li`;000;Li`;
000;Li`;000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;Li`;000?Ool0
01Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0
01Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/00004Kg]cW6mkLi`400000fmkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>L
Kg]cW0@00003Kg]cW6mk00/000moo`006Goo2`002g>L0`0017oo0`002g>L2`002g>L2`0067oo1000
17oo0`002g>L2`002g>L2`002g>L2P006Goo2`002W>L2`002g>L100017oo0`002g>L2`0067oo2`00
0g>L00<007ooOol00Woo0P0000=cW00000002@002g>L2`002W>L2`006Goo2P002g>L2`002g>L2`00
0W>L0P0017oo0P0000=cW00000002@003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
0P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0067oo0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001goo00`007>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`;000HOol;00000fmkLi`00007Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01goo30003goo000IOol;000;Li`20007Ool0
0`00LiacW009Li`;000;Li`;000HOol30007Ool00`00LiacW009Li`;000;Li`;000;Li`:000IOol;
000:Li`;000;Li`30007Ool00`00LiacW009Li`;000HOol;0002Li`00`00Oomoo`05Ool<000;Li`;
000:Li`;000IOol:000;Li`;000;Li`;00000g>L001oo`07Ool<000?Ool001Uoo`/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0020002Ool30002Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol20003Ool30002Ool03000Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W0020003Ool30002Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Qoo`/00004Kg/007ooOol4
0002Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0
01Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000A_N`00Oomoo`<000=oo``000moo`006Goo2`002g>L0P001goo00<007>LLi`02G>L2`002g>L
2`0067oo0`001goo00<007>LLi`02G>L2`002g>L2`002g>L2P006Goo2`002W>L2`002g>L0`001goo
00<007>LLi`02G>L2`0067oo2`0000=cW000Ool01Woo00<007>L00002P002g>L2`002W>L2`006Goo
2P002g>L2`002g>L2`0000=cW000Ool01Woo00<007>L00002P003goo000IOol;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`00P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0067oo0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:
Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001goo00`007>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000HOol;00000fmk001oo`06Ool00`00Kg/0000:00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo
00<006mk00002P003goo000IOol;000;Li`30005Ool2000;Li`;000;Li`;000HOol40005Ool2000;
Li`;000;Li`;000;Li`:000IOol;000:Li`;000;Li`40005Ool2000;Li`;000HOol;0002Li`20005
Ool00`00Li`0000:000;Li`;000:Li`;000IOol:000;Li`;000;Li`;0002Li`20004Ool00`00Liac
W00;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/00004Kg]cW6mkLi`500000g>L
Kg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0
01Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000A_Ng>LKg]cW0@00003Kg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`002g>L2`0067oo
2`002g>L2`002g>L2`002g>L2P006Goo2`002W>L2`002g>L2`002g>L2`0067oo2`002g>L2`002g>L
2`002W>L2`006Goo2P002g>L2`002g>L2`002g>L2`003goo000IOol02fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00005Lia_Ng>LKg]cW002000016mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
1FmkLia_Ng>LKg/00P0000AcW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002Vmk
Lia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>L001cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;
Li`;000:Li`;0004Li`00`00Oomoo`020002Li`;000;Li`HOol;Li`;0004Li`00`00Oomoo`020002
Li`;000;Li`;000:Li`IOol3Li`200000goo00000003Li`:000;Li`;000;Li`;000;Li`HOol;Li`;
000;Li`;000;Li`500000goo00000002000;Li`IOol:Li`;000;Li`50002Ool4000;Li`;000;Li`?
Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00AcW6mkLi`000Eoo`03001cW00000X0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>LKg/000Eoo`03001_N`0000X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00=cW6mk00001Goo0P0000=cW000
0000200000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001Goo0P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`010001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/0009cW003001oogoo00Eoo``000]c
W1Qoo`]cW0/0009cW003001oogoo00Eoo``000]cW0/000YcW1Uoo`03Li`007oo00Ioo`03001cW000
00T000]cW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW08000Moo`03001cW7>L00UcW1Uoo`Yc
W0/000]cW0<000Moo`03001cW7>L00UcW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00000g>LKg/00007Ool<00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW00000Moo``0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00=cW000Ool0
1Woo00<007>L00002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
0P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L2`0000=cW000Ool00Woo0`00
0Woo30002g>L67oo2g>L2`0000AcW000Oomoo`@0009oo``000]cW0/000YcW1Uoo`04Li`007ooOol3
0002Ool<000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`20002Ool30002Ool00`00Liac
W009Li`IOol:Li`;000;Li`20003Ool30002Ool00`00LiacW009Li`;000;Li`?Ool001Uoo`0;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000=cW6mk00001goo
300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
0fmk001oo`06Ool00`00Kg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]c
W6mkLia_Ng>LKg]cW1Uoo`03Li`007oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk6Goo
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030007Ool03000
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]c
W0/000YcW0/0009cW003001oogoo00Aoo`03001cW00000X000]cW1Qoo`]cW0/00003Li`007oo00Io
o`03001cW00000X000]cW0/000YcW1Uoo`03Li`007oo00Eoo`03001cW7>L00X000]cW0/000]cW0/0
00]cW1Qoo`]cW0/000]cW0/000]cW08000Ioo`8000]cW1Uoo`YcW0/000]cW0<000Ioo`8000]cW0/0
00]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mk
Li`;000017>LKg]cW0001Goo00<007>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLi`000001Goo00<006mk00002P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol00g>LKg/00005Ool00`00
Kg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030005Ool2
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0040005Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L2`0017>L1@000W>L2`002g>L67oo
2g>L2`0017>L1@000W>L2`002g>L2`002W>L6Goo0g>L1@000g>L2P002g>L2`002g>L2`002g>L67oo
2g>L2`002g>L2`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`002g>L3goo000IOol02fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00moo`006Goo2`001G>L00<007>LLi`00g>L2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`00
2g>L2P006Goo2`002W>L2`001G>L0P0017>L2`002g>L2`0067oo2`002g>L2`002g>L2`002W>L2`00
6Goo2P001W>L00<007>LLi`00W>L2`002g>L2`002g>L2`003goo000IOol;00000g>LKg/000020000
1Woo000007>LKg]cW0X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0050002Ool400002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0/00003Lia_Ng>L0080009oo`800003Kg]cW00000X0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/01@000Woo100000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00000fmk
Lia_N`0300001Goo000007>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/0009cW003001oogoo00=oo`03001cW7>L00X000]c
W0/000]cW0/001Qoo`/000]cW0/000]cW0<000Ioo`8000]cW0X001Uoo`/000YcW0/000=cW003001o
ogoo00=oo`03001cW00000X000]cW0/001Qoo`/000]cW0<000Ioo`8000]cW0/000YcW0/001Uoo`X0
00=cW003001oogoo00=oo`03001cW00000X000]cW0/000]cW0/000moo`006Goo2`0000=cW000Ool0
1Woo00<007>L00002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L008000Moo`80000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L2`0000=cW6mk00001goo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
01Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020008Ool03000Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00000fmkLi`00007Ool<00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`00
00=cW000Ool01Woo00<007>L00002@002g>L2`002g>L2`0067oo2`002g>L2`002g>L0P0027oo00<0
07>LLi`02G>L2P006Goo2`002W>L2`0000=cW000Ool01goo30002g>L2`0067oo2`002g>L0P0027oo
00<007>LLi`02G>L2`002W>L2`006Goo2P000W>L00<007ooOol01Goo30002g>L2`002g>L2`003goo
000IOol;000017>L001oogoo0`000Woo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L0080009oo`<000=oo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
2P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00003Li`007oo009oo`<0009oo``0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000Woo
0`000goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
6Goo2P0000=_Ng>L00000Woo0`000Woo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/00003Li`007oo00Ioo`03001cW00000T000]c
W0/000]cW0/001Qoo`/000]cW0/000]cW08000Moo`8000]cW0X001Uoo`/000YcW0/0009cW003001o
ogoo00Eoo``000]cW0/001Qoo`/000]cW08000Moo`8000]cW0/000YcW0/001Uoo`X0009cW003001o
ogoo00Eoo``000]cW0/000]cW0/000moo`006Goo2`0000=cW000Ool01Goo00<006mkLi`02P0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Ioo`<0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00=cW6mk00001Woo00<007>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020006Ool300002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X00003Kg]cW00000Ioo`03001_N`0000X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;
0002Li`00`00Oomoo`03Ool00`00LiacW00:000;Li`;000;Li`;000HOol;000;Li`;000;Li`30005
Ool3000;Li`:000IOol;000:Li`;0003Li`00`00Oomoo`03Ool00`00Li`0000:000;Li`;000HOol;
000;Li`40004Ool3000;Li`;000:Li`;000IOol:0003Li`00`00Oomoo`03Ool00`00Li`0000:000;
Li`;000;Li`;000?Ool001Uoo`/00003Lia_Ng>L00D00003Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00004Lia_Ng>LKg/500000fmk
Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`006Goo2P0000A_Ng>LKg]cW0D00003Lia_N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`;000;Li`;000H
Ool;000;Li`;000;Li`;000;Li`:000IOol;000:Li`;000;Li`;000;Li`;000HOol;000;Li`;000;
Li`;000:Li`;000IOol:000;Li`;000;Li`;000;Li`;000?Ool00?mooomoo`Qoo`00ogooogoo27oo
003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogoo
ogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qo
o`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mo
oomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8
Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uo
o`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`0017>L10000g>L
2`0067oo2`002g>L2`002g>L2`000g>L100017>L2P006Goo2`002W>L2`002g>L2`0017>L10000g>L
2`0067oo2`002g>L2`002g>L2`000g>L10000g>L2`006Goo2P002g>L2`002g>L2`0017>L10000g>L
2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/00004Kg]cW6mk0004Ool200000fmk00000009000HOol;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Lia_N`0000Aoo`800003Kg]c
W00000T001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000AcW6mkLi`000Aoo`800003Li`0000000T001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L000017oo0P0000=cW0000000
2@006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;000016mkLi`0000017oo0P0000=_N`0000002@003goo000IOol;000;Li`:000;Li`;0002Li`0
0`00Oomoo`05Ool<000HOol;000;Li`;000;Li`;00000g>L001oo`06Ool00`00Li`00009000IOol;
000:Li`;000;Li`;0002Li`00`00Oomoo`05Ool<000HOol;000;Li`;000;Li`;00000g>L001oo`06
Ool<000IOol:000;Li`;000;Li`;00000g>L001oo`07Ool<000?Ool001Uoo`/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L00001goo3000
67oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00000g>L001oo`06Ool00`00Li`00009000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Lia_N`0000Moo``001Qoo`/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo30006Goo
2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
0fmk001oo`07Ool<000?Ool001Uoo`/000]cW0X000]cW0/00003Li`007oo009oo`<0009oo``001Qo
o`/000]cW0/000]cW0/00004Li`007ooOol30002Ool00`00Li`00009000IOol;000:Li`;000;Li`;
000017>L001oogoo10000Woo300067oo2`002g>L2`002g>L2`0000AcW000Oomoo`<0009oo``001Uo
o`X000]cW0/000]cW0/00004Li`007ooOol30003Ool<000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L00001goo300067oo
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
0g>L001oo`06Ool00`00Li`00009000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Moo``001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo30006Goo2P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk
001oo`06Ool00`00Kg/0000:000?Ool001Uoo`/000]cW0X000]cW0/0009cW003001oogoo00Eoo``0
01Qoo`/000]cW0/000]cW0/00003Li`007oo00Ioo`03001cW00000T001Uoo`/000YcW0/000]cW0/0
0003Li`007oo00Moo``001Qoo`/000]cW0/000]cW0/00003Li`007oo00Ioo``001Uoo`X000]cW0/0
00]cW0/00003Li`007oo00Ioo`03001cW00000X000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLi`000001Goo00<006mk0000
2P0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00000g>LKg/00005Ool00`00Kg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_N`000005Ool00`00Li`0000:000HOol;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]c
W00000Eoo`03001cW00000X001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>L000000Aoo`03001cW6mk00/000moo`006Goo2`002g>L
2P002g>L2`0017>L1@000W>L2`0067oo2`002g>L2`002g>L2`000g>L1@000g>L2P006Goo2`002W>L
2`002g>L2`0017>L1@000W>L2`0067oo2`002g>L2`002g>L2`000g>L1@000W>L2`006Goo2P002g>L
2`002g>L2`0017>L10000g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`]c
W0/000YcW0/000]cW0/000]cW1Qoo`]cW0/000EcW08000AcW0/000]cW0/000YcW1Uoo`]cW0X000Ic
W003001cW7>L009cW0/000]cW0/000]cW1Qoo`]cW0/000EcW08000AcW0/000]cW0X000]cW1Uoo`Yc
W0/000]cW0/000]cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00D00003Ool0
000000<0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk
Lia_N`020002Ool200000g>LKg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>L
Kg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00000fmkLia_N`030000
1Goo000007>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mk00000P000Woo0P0000=_
Ng>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00D0009o
o`@0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo
000IOol;Li`30005Ool3000:Li`;000;Li`;000;Li`HOol;Li`;0003Li`00`00Oomoo`03Ool00`00
Li`0000:000;Li`;000:Li`IOol;Li`:0003Li`00`00Oomoo`03Ool00`00Li`0000:000;Li`;000;
Li`HOol;Li`;0002Li`00`00Oomoo`04Ool00`00Li`0000:000;Li`:000;Li`IOol:Li`;000;Li`4
0005Ool2000;Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool20000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L00001goo
300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000=cW000Ool01goo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00moo`006Goo2g>L0P001goo0P002W>L2`002g>L2`002g>L67oo2g>L2`000W>L00<007ooOol0
1Goo30002g>L2`002W>L6Goo2g>L2P000W>L00<007ooOol01Goo30002g>L2`002g>L67oo2g>L2`00
00=cW000Ool01goo30002g>L2P002g>L6Goo2W>L2`002g>L0`001goo00<007>LLi`02G>L2`002g>L
3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000Woo0`000Woo0P0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg/007ooOol40002Ool<00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00:00000fmkLi`00002Ool30002Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
000017>L001oogoo0`000goo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L008000=oo`<0009oo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00moo`006Goo2g>L0P001goo0P002W>L2`002g>L2`002g>L67oo2g>L2`0000=c
W000Ool01Woo00<007>L00002P002g>L2`002W>L6Goo2g>L2P000W>L00<007ooOol01Goo30002g>L
2`002g>L67oo2g>L2`0000=cW000Ool01Woo00<007>L00002P002g>L2P002g>L6Goo2W>L2`002g>L
0`001goo00<007>LLi`02G>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P00
1Woo0`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/0
07oo00Ioo`03001_N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X00003Kg]cW00000Ioo`03001_N`00
00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Eoo`03001_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030006Ool200002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L0`001Goo0`00
2W>L2`002g>L2`002g>L67oo2g>L2`000W>L0P001Goo00<007>L00002P002g>L2`002W>L6Goo2g>L
2P000g>L00<007ooOol00goo00<007>L00002P002g>L2`002g>L67oo2g>L2`000W>L0P0017oo00<0
07>LLi`02`002g>L2P002g>L6Goo2W>L2`002g>L10001Goo0P002g>L2`002g>L3goo000IOol02fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/00004Kg]cW6mkLi`500000g>LKg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:0000
16mkLia_Ng>L1@0000=cW6mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000AcW6mkLia_N`@0
0003Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`00
6Goo2g>L2`002W>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L2`002W>L6Goo2g>L2P002g>L
2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`002g>L
3goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000I
Ool:000016mkLia_Ng>L0`0000AcW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`40003Ool4000;Li`;
000HOol40003Ool4000;Li`;000;Li`;000;Li`:000IOol;000:Li`;000;Li`40003Ool4000;Li`;
000HOol;000;Li`;000;Li`;000:Li`40003Ool4000IOol:0003Li`01000Oomoogoo0P000W>L2`00
2g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00@000Eoo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol40005
Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000Eoo`80000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`40005Ool2000IOol:000016mkLia_N`001Goo00<006mk
00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
000?Ool001Uoo`/000]cW0X000]cW0<000Moo`03001cW7>L00UcW0/001Qoo`<000Moo`03001cW7>L
00UcW0/000]cW0/000]cW0X001Uoo`/000YcW0/000]cW0<000Moo`03001cW7>L00UcW0/001Qoo`/0
00]cW0/000]cW0/000YcW0<000Moo`03001oogoo01Moo`X0009cW003001oogoo00Eoo``000]cW0/0
00]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`020008Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/001Qoo`8000Qoo`0<001c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L008000Qoo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0067oo2`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L0P0027oo00<007ooOol05goo2P0000=_Ng>L00001goo300000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]c
W0X000]cW08000=oo`<0009oo`03001cW7>L00UcW0/001Qoo`8000=oo`<0009oo`03001cW7>L00Uc
W0/000]cW0/000]cW0X001Uoo`/000YcW0/000]cW08000=oo`<0009oo`03001cW7>L00UcW0/001Qo
o`/000]cW0/000]cW0/000YcW08000=oo`<0009oo`03001oogoo01Moo`X0009cW003001oogoo00<0
009oo``000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030007Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/001Qo
o`<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
2`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00<007ooOol05goo2P0000=_Ng>L00001goo
300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?
Ool001Uoo`/000]cW0X000]cW0<000Ioo`8000]cW0/001Qoo`<000Ioo`8000]cW0/000]cW0/000]c
W0X001Uoo`/000YcW0/000]cW0<000Ioo`8000]cW0/001Qoo`/000]cW0/000]cW0/000YcW0<000Io
o`8001Uoo`X0009cW003001oogoo00Aoo`03001cW00000X000]cW0/000]cW0/000moo`006Goo2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040005Ool2
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo10001Goo0P0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W0040005Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L10001Goo0P006Goo2P0000A_Ng>LKg/000Eoo`03001_N`0000X0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`;
000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:Li`;000;Li`;000;Li`;000HOol;
000;Li`;000;Li`;000:Li`;000IOol:0004Li`50002Li`;000;Li`;000;Li`;000?Ool001Uoo`/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/000moo`006Goo0g>L100017>L2`002W>L2`002g>L2`002g>L67oo2g>L
2`002g>L2`002g>L2`002W>L6Goo2g>L2P002g>L2`002g>L2`0017>L0`0017>L67oo2g>L2`002g>L
2`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`000g>L100017>L3goo000IOol00fmkLi`00004
Ool200000g>LKg/0000:00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Aoo`@0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_
Ng>LKg/000=oo`800003Lia_Ngoo01Moo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`00`0017oo100000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00004Ool20000
0fmkLiaoo`0>Ool001Uoo`9cW003001oogoo00Aoo`03001cW00000X000YcW0/000]cW0/000]cW1Qo
o`]cW0/000]cW0<000Ioo`8000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/0009cW003001oogoo
00Aoo`03001cW7oo01Moo`]cW0/000]cW0<000Ioo`8000]cW0X000]cW1Uoo`YcW0/000]cW0/000]c
W0/0009cW003001oogoo00Aoo`03001cW7oo00ioo`006Goo00=_N`00Ool01Woo00<006mk00002P00
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`020007Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]c
W6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Moo`03001oogoo
01Ioo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P00
1goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0I
Ool02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`06Ool00`00Liaoo`0>Ool001Uoo`04Li`007oo
Ool30003Ool<000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`20002Ool30003Ool00`00LiacW009
Li`;000:Li`IOol;Li`:000;Li`;000;Li`;000017>L001oogoo0`000goo00<007ooOol05Woo2g>L
2`002g>L0P000Woo0`000goo00<007>LLi`02G>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`0000Ac
W000Oomoo`<000=oo`03001oogoo00eoo`006Goo00=_N`00Ool01Woo3@0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`02
0007Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uo
o`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Ioo`8001Qoo`0;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P001goo0P0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_
Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00000g>L001oo`06Ool2000?Ool001Uoo`03Li`007oo00Ioo`03001cW00000X000YcW0/000]cW0/0
00]cW1Qoo`]cW0/000]cW08000Moo`8000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/00003Li`0
07oo00Ioo`03001cW7oo01Moo`]cW0/000]cW08000Moo`8000]cW0X000]cW1Uoo`YcW0/000]cW0/0
00]cW0/00003Li`007oo00Ioo`03001cW7oo00ioo`006Goo00A_Ng>L000000Aoo`03001cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/0100017oo0`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mk
Lia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLi`0000017oo00<007>L
Kg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW003
0005Ool300002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Lia_N`0000Eoo`03001_Ng>L00moo`006Goo17>L00D0
07ooOomoo`00009cW0/000YcW0/000]cW0/000]cW1Qoo`]cW0/000]cW0D000=oo`<000]cW0/000Yc
W1Uoo`]cW0X000]cW0/000]cW0/000AcW005001oogooOol00002Li`HOol;Li`;000;Li`50003Ool3
000;Li`:000;Li`IOol:Li`;000;Li`;000;Li`;0003Li`20003Ool00`00LiacW00?Ool001Uoo`05
Kg]cW6mkLia_N`0300000fmkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00E_Ng>LKg]cW6mk00<00003Kg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00001G>LKg]cW6mkLi`00`0000=c
W6mkLi`03goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`;000:Li`I
Ool;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`:000;Li`IOol:Li`;000;Li`;
000;Li`;000;Li`?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000016mkLia_Ng>L
0`0000AcW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000=cW004
001oogooOol20002Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`30003Ool4000IOol30003
Ool5000:Li`;000;Li`;000;Li`;000HOol40003Ool4000;Li`;000;Li`;000:Li`;000IOol:000;
Li`;000;Li`40003Ool4000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00000fmkLi`00006Ool00`00Kg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`00P001Woo0P006Goo0P001Woo0`0000Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0067oo0`001Woo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030006Ool200002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`003goo000IOol;000;Li`:0002Li`00`00Oomoo`05Ool<000;Li`;000HOol;000;
Li`;000;Li`;000;Li`20007Ool00`00Oomoo`0GOol20007Ool2000:Li`;000;Li`;000;Li`;000H
Ool30007Ool00`00LiacW009Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`30007Ool00`00
LiacW009Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00000fmkLi`00002
Ool30002Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`00P000Woo0`000Woo00<007ooOol05goo0P000Woo0`000Woo0P0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0067oo0P000goo0`000Woo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000Woo10000Woo00`006mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/;000?Ool001Uoo`/000]cW0X0009cW003001oogoo00Eoo``000]c
W0/001Qoo`/000]cW0/000]cW0/000]cW08000Moo`03001oogoo01Moo`8000Moo`8000YcW0/000]c
W0/000]cW0/001Qoo`8000Qoo`03001cW7>L00UcW0/000]cW0/000YcW0/001Uoo`X000]cW0/000]c
W08000Qoo`03001cW7>L00UcW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0
0003Kg]cW00000Moo``0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0020007Ool00`00Oomoo`0GOol20007Ool200002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000H
Ool30007Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020008Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`/000moo`006Goo2`002g>L2P000g>L00<007ooOol00goo00<007>L00002P002g>L2`0067oo2`00
2g>L2`002g>L2`002g>L0`001Goo0P006Goo0`001Goo0`002W>L2`002g>L2`002g>L2`0067oo1000
1Goo0P002g>L2`002g>L2`002W>L2`006Goo2P002g>L2`002g>L10001Goo0P002g>L2`003goo000I
Ool;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000A_Ng>LKg]cW0800005Ool00000Lia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@00
0Woo0`006Goo1@000Woo100000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo1@000Woo100000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`050002Ool400002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;
Li`:0006Li`00`00LiacW002Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:
Li`;000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;
Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2g>L2`002W>L2`002g>L2`00
17>L10000g>L67oo2g>L2`002g>L2`000g>L1@000g>L2`002W>L6Goo2g>L2P002g>L2`002g>L2`00
2g>L67oo2g>L2`002g>L2`000g>L100017>L2P002g>L6Goo2W>L2`0017>L10000g>L2`002g>L2`00
2g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>LKg]cW00017oo0P0000=cW7ooOol05Woo
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk
Li`00005Ool200000fmk0000000900002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040004Ool300002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mk000017oo0P0000=_
Ng>L00002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;
000017>LKg]cW00017oo0P0000=cW00000002@0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0/0009cW003001oogoo
00Eoo`03001oogoo01Ioo`]cW0/000]cW0/00003Li`007oo00Ioo`03001cW00000X000YcW1Uoo`]c
W0X000]cW0<000Moo`03001cW7>L00UcW0/000]cW1Qoo`]cW0/000]cW0/00003Li`007oo00Ioo`03
001cW00000T000]cW1Uoo`YcW0/0009cW003001oogoo00Eoo``000]cW0/000]cW0moo`006Goo00]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000=cW6mk00001goo00<007ooOol05Woo00]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool00`00Kg/0000:
00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`030007Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000=cW6mk00001goo300000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000Yc
W0/000]cW0/00004Li`007ooOol40002Ool00`00Oomoo`0FOol;Li`;000;Li`;000017>L001oogoo
0`000goo30002W>L6Goo2g>L2P002g>L0P000goo0`000Woo00<007>LLi`02G>L2`002g>L67oo2g>L
2`002g>L2`0000AcW000Oomoo`<0009oo`03001cW00000T000]cW1Uoo`YcW0/00003Li`007oo009o
o`<0009oo``000]cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW000Ool01goo
00<007ooOol05Woo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00000fmk001oo`06Ool=00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020008Ool03000Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW000
00T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000=c
W000Ool01goo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0/00003Li`007oo00Moo`03001oogoo01Ioo`]cW0/0
00]cW0/00003Li`007oo00Ioo`03001cW00000X000YcW1Uoo`]cW0X000]cW0<000Moo`03001cW7>L
00UcW0/000]cW1Qoo`]cW0/000]cW0/00003Li`007oo00Ioo`03001cW00000T000]cW1Uoo`YcW0/0
009cW003001oogoo00Eoo``000]cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000Ac
W6mk000000Eoo`03001cW7oo01Moo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000=_Ng>L00001Goo00<007>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
10001Goo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
0003Lia_N`0000Eoo`03001_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_
Ng>LKg]cW6mkLia_Ng>L2`0000AcW6mkLi`000Eoo`03001cW00000X0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`;000;Li`;
0004Li`00`00Oomoo`020002Li`HOol;Li`;000;Li`;0003Li`20002Ool01000LiacW7>L2`002W>L
6Goo2g>L2P002g>L1P0000=oo`0000000P002g>L2`002g>L67oo2g>L2`002g>L2`000g>L0P000Woo
00@007>LLiacW0X000]cW1Uoo`YcW0/000AcW0800003Ool00000009cW0/000]cW0/000]cW0moo`00
6Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000EcW6mkLia_Ng>L00800004Kg]cW6mkLi`HOol02fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00005Kg]cW6mkLia_
N`02000017>LKg]cW6mk2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00005Lia_Ng>LKg]cW002000016mkLia_Ng>L2P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]c
W6mkLia_N`00Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]c
W0/000YcW1Uoo`]cW0X000]cW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0X000]cW1Uoo`Yc
W0/000]cW0/000]cW0/000]cW0moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`00
00AcW6mkLia_N`@00003Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000=_Ng>LKg/0100000=cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;000016mkLia_
Ng>L100000=_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>L
Kg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0<000Ao
o`<000]cW0/000]cW0/001Qoo`/000=cW003001oogoo009oo`800003Li`0000000T000]cW0/000]c
W0X001Uoo`/0009cW003001oogoo009oo`800003Li`0000000T000]cW0/000]cW0/001Qoo`/000=c
W003001oogoo009oo`800003Li`0000000T000]cW0/000YcW0/001Uoo`<000Aoo`<000]cW0/000]c
W0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`0<001_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/00003Lia_
N`0000Moo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P006Goo2`0000=_N`00Ool01Woo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00000fmkLi`00007Ool<00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`8000Moo`0<001_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;000?Ool001Uoo`/000]cW08000Moo`03001cW7>L00UcW0/000]cW0/001Qoo`/0009c
W003001oogoo00Eoo``000]cW0/000]cW0X001Uoo`/00003Li`007oo00Ioo``000]cW0/000]cW0/0
01Qoo`/0009cW003001oogoo00Eoo``000]cW0/000YcW0/001Uoo`8000Moo`03001cW7>L00UcW0/0
00]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0080009oo`<0009o
o`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qo
o`/00003Li`007oo009oo`<0009oo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000A_N`00Oomoo`<0009oo``0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000A_N`00Oomoo`@0
009oo``0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
6Goo0P000Woo0`000Woo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L0P001goo
00<007>LLi`02G>L2`002g>L2`0067oo2`0000=cW000Ool01goo30002g>L2`002g>L2P006Goo2`00
00=cW000Ool01Woo30002g>L2`002g>L2`0067oo2`0000=cW000Ool01Woo3@002g>L2`002W>L2`00
6Goo0P001goo00<007>LLi`02G>L2`002g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`00P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0067oo2`0000=cW6mk00001goo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00000fmk001oo`06Ool<00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/00003Kg/0
07oo00Ioo`03001_N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`006Goo0P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L
0`001Goo0P002g>L2`002g>L2`0067oo2`000W>L0P001Goo00<007>L00002P002g>L2`002g>L2P00
6Goo2`000W>L00<007ooOol00goo00<007>L00002P002g>L2`002g>L2`0067oo2`000W>L0P001Goo
00<007>L00002P002g>L2`002W>L2`006Goo0`001Goo0P002g>L2`002g>L2`002g>L2`003goo000I
Ool;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;000017>LKg]cW6mk1@0000=_Ng>L00002P00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;
00000fmkLia_N`0500000fmkLi`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/00004Kg]cW6mkLi`500000g>LKg/0000:00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L
2`002g>L2P006Goo2`002W>L2`002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`002W>L2`006Goo
2P002g>L2`002g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool00?mooomo
o`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool0
0?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOooo
Ool8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo
003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogoo
ogoo27oo003oOoooOol8Ool001Uoo`/000]cW0X000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/0
00]cW0X001Uoo`/000YcW0/000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/000YcW0/001Uoo`X0
00]cW0/000]cW0/000AcW0@000=cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040004Ool300002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0030005Ool300002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040004Ool300002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`030004Ool400002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLi`00000
17oo0P0000=_N`0000002@003goo000IOol;000;Li`:000;Li`30007Ool00`00LiacW009Li`;000H
Ool;000;Li`;000;Li`20007Ool2000;Li`:000IOol;000:Li`;000;Li`30007Ool00`00LiacW009
Li`;000HOol;000;Li`;000;Li`20007Ool2000:Li`;000IOol:000;Li`;000;Li`;00000g>L001o
o`07Ool<000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/00`001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;000HOol;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`80000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0067oo2`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool2
00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`07Ool<000?Ool001Uoo`/000]cW0X0
00]cW08000=oo`<0009oo`03001cW7>L00UcW0/001Qoo`/000]cW0/000]cW080009oo`<000=oo`03
001cW7>L00UcW0X001Uoo`/000YcW0/000]cW08000=oo`<0009oo`03001cW7>L00UcW0/001Qoo`/0
00]cW0/000]cW080009oo`<0009oo`8000YcW0/001Uoo`X000]cW0/000]cW0/00004Li`007ooOol3
0003Ool<000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/00P0027oo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;000HOol;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`80000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L008000Qoo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0067oo2`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool2
00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool=000?Ool001Uoo`/000]cW0X0
00]cW0<000Moo`03001cW7>L00UcW0/001Qoo`/000]cW0/000]cW08000Moo`8000]cW0X001Uoo`/0
00YcW0/000]cW0<000Moo`03001cW7>L00UcW0/001Qoo`/000]cW0/000]cW08000Moo`8000YcW0/0
01Uoo`X000]cW0/000]cW0/00003Li`007oo00Ioo`03001cW00000X000moo`006Goo2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040005Ool200002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030005Ool300002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
6Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040005
Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030005Ool300002VmkLia_Ng>LKg]cW6mkLia_
Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;000016mkLi`0000017oo00<007>LKg/02`003goo000IOol;000;Li`:000;Li`600000goo
00000002000;Li`;000HOol;000;Li`;000;Li`50002Ool4000;Li`:000IOol;000:Li`;000;Li`6
00000goo00000002000;Li`;000HOol;000;Li`;000;Li`50002Ool4000:Li`;000IOol:000;Li`;
000;Li`;0004Li`01000Oomoo`000g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000H
Ool;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00005Kg]cW6mkLia_N`02000017>LKg]cW6mk2`003goo
000IOol;000;Li`:000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:Li`;
000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;Li`;
000?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol0
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>LKg]cW0@00003Kg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000A_Ng>LKg]cW0@00003Kg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X00004
Kg]cW6mkLi`400000fmkLia_N`0IOol00fmkLia_N`0400000g>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00?Ool001Uoo`]cW0<000Aoo`@000YcW0/000]cW0/000]cW1Qoo`]cW0/000=cW003001o
ogoo009oo`800003Li`0000000T000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/0009cW08000Ao
o`800003Liaoogoo01Ioo`]cW0/000]cW0/000]cW0X000=cW003001oogoo009oo`800003Liaoogoo
01Moo`9cW003001oogoo009oo`800003Li`0000000T000]cW0/000]cW0/000]cW0moo`006Goo00]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Moo`80000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00000fmkLi`00007Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo
00Moo`03001oogoo01Ioo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X00003Kg]cW00000Moo`03001oogoo
01Moo`03Kg/007oo00Ioo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L0P001goo0P00
2W>L2`002g>L2`002g>L67oo2g>L2`000W>L00<007ooOol01Goo30002g>L2`002W>L6Goo2g>L2P00
2g>L2`002g>L2`0000=cW000Ool01goo00<007ooOol05Woo2g>L2`002g>L2`002g>L2P000W>L00<0
07ooOol01Goo00<007ooOol05goo00=cW000Ool01Woo30002g>L2`002g>L2`002g>L3goo000IOol0
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000Woo0`000Woo0P0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg/007ooOol40002Ool<00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/00004Kg/007ooOol30003Ool00`00Oomoo`0FOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00000fmk
001oo`02Ool30002Ool00`00Oomoo`0GOol016mk001oogoo0`000Woo300000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`03goo000IOol;Li`20007Ool2000:Li`;000;Li`;000;Li`HOol;Li`;00000g>L001oo`06
Ool=000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;00000g>L001oo`06Ool2000HOol;Li`;000;
Li`;000;Li`:00000g>L001oo`07Ool00`00Oomoo`0GOol00g>L001oo`06Ool<000;Li`;000;Li`;
000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool200002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo00<006mk00002P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool00`00Kg]oo`0GOol02g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00:00000fmkLi`00007Ool00`00Oomoo`0GOol00fmk001oo`06Ool<00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00?Ool001Uoo`]cW0<000Eoo`<000YcW0/000]cW0/000]cW1Qoo`]cW0/0009cW08000Eoo`03
001cW00000X000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/0009cW08000Aoo`03001cW7>L01Qo
o`]cW0/000]cW0/000]cW0X000=cW003001oogoo00=oo`03001cW7oo01Qoo`9cW003001oogoo00=o
o`03001cW00000X000]cW0/000]cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00D0009oo`@0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
1FmkLia_Ng>L00000Woo0P0000=cW6mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:
Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00001FmkLia_Ng>L0000
0Woo00@006mkLia_NaQoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X00004Kg]cW6mkLi`200001Goo0000
07>LKg/06Goo00=_Ng>LKg/00P000Woo00<006mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo
000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;0005Li`20004Li`;000;Li`;000:Li`IOol;
Li`:000;Li`;000;Li`;0005Li`20004Li`HOol;Li`;000;Li`;000;Li`:0006Li`00`00LiacW002
Li`IOol5Li`20003Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0I
Ool02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;000;
Li`:000;Li`;0004Li`40003Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;0003Li`40003
Li`;000;Li`;000;Li`;000HOol;0004Li`40003Li`;000;Li`;000:Li`;000IOol:000;Li`;000;
Li`;000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000A_Ng>LKg/000Aoo`800003Kg/0000000T001Qoo`@000Aoo`<0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/00003Kg]cW00000Aoo`800003Li`0000000T0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000A_
Ng>LKg/000Aoo`800003Kg/0000000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@000Aoo`<0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000I
Ool;000;Li`:000;Li`;0002Li`00`00Oomoo`05Ool<000HOol30007Ool00`00LiacW009Li`;000;
Li`;000;Li`:000IOol;00000g>L001oo`06Ool<000;Li`;000;Li`;000HOol;0002Li`00`00Oomo
o`05Ool<000;Li`;000:Li`;000IOol:000;Li`30007Ool00`00LiacW009Li`;000;Li`;000?Ool0
01Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000=_Ng>L00001goo300067oo0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/00003
Kg/007oo00Ioo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0067oo2`0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:
Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00`001goo
00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo
000IOol;000;Li`:000;Li`;00000g>L001oo`02Ool30002Ool<000HOol20003Ool30002Ool00`00
LiacW009Li`;000;Li`;000;Li`:000IOol;000017>L001oogoo0`000Woo30002g>L2`002g>L2`00
67oo2`0000AcW000Oomoo`@0009oo``000]cW0/000YcW0/001Uoo`X000]cW08000=oo`<0009oo`03
001cW7>L00UcW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`07Ool<000HOol20008Ool03000Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02P006Goo2`0000=_N`00Ool01Woo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00000fmk001oo`06Ool00`00Kg/0000:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020008Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0/0009cW003001o
ogoo00Eoo``001Qoo`<000Moo`03001cW7>L00UcW0/000]cW0/000]cW0X001Uoo`/00003Li`007oo
00Ioo``000]cW0/000]cW0/001Qoo`/00003Li`007oo00Ioo`03001cW00000X000]cW0/000YcW0/0
01Uoo`X000]cW0<000Moo`03001cW7>L00UcW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLi`000001Goo00<0
06mk00002P0067oo10001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000=_Ng>L0000
1Goo00<007>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;000HOol;000016mkLi`000001Goo00<006mk00002P0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/010001Goo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0/000AcW0D0009cW0/001Qoo`/000]cW0/000]c
W0/000]cW0X001Uoo`/000=cW0D0009cW0/000]cW0/000]cW0/001Qoo`/000AcW0D0009cW0/000]c
W0/000YcW0/001Uoo`X000]cW0/000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`003goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`;000:Li`IOol;
Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`:000;Li`IOol:Li`;000;Li`;000;
Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLia_N`0400000g>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000AcW6mkLia_N`@00003Lia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/0009cW003001oogoo009oo`800003Li`00000
00T000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0<000Aoo`@000YcW1Uoo`]cW0X000]cW0@000Ao
o`<000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0<000Aoo`<000]cW1Uoo`YcW0/000]cW0/000=c
W003001oogoo009oo`800003Li`0000000T000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/00003Kg/007oo00Ioo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P001goo0P0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/00`001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003
Lia_N`0000Moo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/00003Li`007oo
00Ioo``000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW08000Moo`8000YcW1Uoo`]cW0X000]cW0<0
00Moo`03001cW7>L00UcW0/000]cW1Qoo`]cW0/000]cW0/000]cW08000Moo`03001cW7>L00UcW1Uo
o`YcW0/000]cW0/0009cW003001oogoo00Eoo``000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/00004Kg/007ooOol30002Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0080009oo`<0009oo`80
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk008000=oo`<0009oo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0080009oo`<0009o
o`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk6Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>L001oogoo10000Woo300000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00moo`006Goo2g>L2`0000=cW000Ool01Woo30002g>L2`002g>L67oo2g>L2`002g>L2`00
2g>L0P001goo0P002W>L6Goo2g>L2P002g>L0`001goo00<007>LLi`02G>L2`002g>L67oo2g>L2`00
2g>L2`002g>L0P001goo00<007>LLi`02G>L6Goo2W>L2`002g>L2`0000=cW000Ool01goo30002g>L
3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo300000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`020007Ool200002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030007Ool03000Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW002
0007Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_NaUoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW000Ool01goo300000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00moo`006Goo2g>L2`000W>L00<007ooOol00goo00<007>L00002P002g>L2`002g>L67oo
2g>L2`002g>L2`002g>L0`001Goo0`002W>L6Goo2g>L2P002g>L10001Goo0P002g>L2`002g>L67oo
2g>L2`002g>L2`002g>L0`001Goo0P002g>L6Goo2W>L2`002g>L2`000W>L0P001Goo00<007>L0000
2P002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>LKg/01@0000=_Ng>L
00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00H
Ool02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>LKg/500000fmkLi`0000:00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;
000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`:000;Li`I
Ool:Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qo
o`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00001G>LKg]cW6mkLi`00P0000A_Ng>LKg]cW0/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00005Lia_Ng>LKg]cW002000016mkLia_Ng>L2`0067oo
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000I
Ool;000;Li`:000;Li`;000;Li`50002Ool4000HOol;000;Li`;0003Li`20002Ool20002Li`;000;
Li`:000IOol;000:Li`;000;Li`;0004Li`00`00Oomoo`020002Li`;000HOol;000;Li`50002Ool4
000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;Li`50002Ool4000?Ool001Uoo`/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00@000Eoo`8001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
0g>LKg/00006Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>LKg]cW000
1Goo00<007>L00002P0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Ioo`80000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/00`001Woo0P003goo000IOol;000;Li`:000;Li`;000;Li`30007Ool00`00
Oomoo`0FOol;000;Li`;00000g>L001oo`06Ool00`00Li`0000:000;Li`:000IOol;000:Li`;000;
Li`;0002Li`00`00Oomoo`05Ool<000HOol;000;Li`20008Ool00`00LiacW009Li`;000:Li`;000I
Ool:000;Li`;000;Li`;000;Li`20007Ool2000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00<000Moo`03001oogoo01Ioo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`07
Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00007Ool<000HOol;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/00P0027oo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P0027oo00<007ooOol0
3Goo000IOol;000;Li`:000;Li`;000;Li`20002Ool40002Ool00`00Oomoo`0FOol;000;Li`;0000
17>L001oogoo0`000goo30002g>L2P006Goo2`002W>L2`002g>L2`0000AcW000Oomoo`@0009oo``0
01Qoo`/000]cW080009oo`<000=oo`03001cW7>L00UcW0/000YcW0/001Uoo`X000]cW0/000]cW0/0
00]cW080009oo`<000=oo`03001oogoo00eoo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P00
27oo00<007ooOol05Woo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03
001cW00000X0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Moo``001Qoo`/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Moo`80
00moo`006Goo2`002g>L2P002g>L2`002g>L0P001goo0P0067oo2`002g>L2`0000=cW000Ool01Goo
00<007>LLi`02`002g>L2P006Goo2`002W>L2`002g>L2`0000=cW000Ool01Woo00<007>L00002P00
67oo2`002g>L0P001Woo0`002g>L2`002W>L2`006Goo2P002g>L2`002g>L2`002g>L0P001Woo0`00
3goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040005Ool2000HOol;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000AcW6mk000000Aoo`03001_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/00004Lia_N`000005Ool00`00Li`0000:000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/0100017oo0`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mk
Li`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030005Ool3000?Ool001Uoo`/000]cW0X000]c
W0/000]cW0/001Qoo`/000]cW0/000AcW0@000=cW0/000]cW0X001Uoo`/000YcW0/000]cW0/000Ac
W0D0009cW0/001Qoo`/000]cW0/000]cW0/000YcW0/001Uoo`X000]cW0/000]cW0/000]cW0/000mo
o`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo
2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;
Li`;000;Li`;000;Li`;000:Li`IOol5Li`00`00LiacW003Li`:000;Li`;000;Li`;000;Li`HOol5
Li`20004Li`;000;Li`;000;Li`:000;Li`IOol:Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`0;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L1P0000=oo`000000
0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol0
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/01@000Woo100000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00=cW6mk
00000P0000Ioo`00001cW6mkLi`:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol00g>LKg]cW0020002
Ool200000fmkLi`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_
Ng>L1P0000=oo`0000000P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`40005
Ool2000;Li`;000;Li`HOol;Li`40005Ool2000;Li`;000;Li`;000:Li`IOol2Li`00`00Oomoo`03
Ool200000g>L00000008000;Li`;000;Li`;000;Li`HOol3Li`00`00Oomoo`03Ool00`00Li`0000:
000;Li`;000;Li`:000;Li`IOol:Li`40005Ool2000;Li`;000;Li`;000;Li`?Ool001Uoo`0;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol00g>L001oo`06Ool00`00Li`0
000900002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol00g>LKg/00007Ool<00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00mo
o`006Goo2g>L2`002W>L0`001goo00<007>LLi`02G>L2`002g>L67oo2g>L0P0027oo00<007>LLi`0
2G>L2`002g>L2`002W>L6Goo00=cW000Ool01Woo00<007>L00002@002g>L2`002g>L2`002g>L67oo
00=cW000Ool01goo30002g>L2`002g>L2P002g>L6Goo2W>L0`001goo00<007>LLi`02G>L2`002g>L
2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0<0009oo`<0009oo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020003Ool30002Ool03000Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L6Goo00AcW000Oomoo`<0009oo``0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`03Li`0
07oo009oo`<0009oo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mk
Li`30002Ool30002Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`30007Ool0
0`00LiacW009Li`;000;Li`HOol;Li`30007Ool00`00LiacW009Li`;000;Li`;000:Li`IOol00g>L
001oo`06Ool00`00Li`00009000;Li`;000;Li`;000;Li`HOol2Li`00`00Oomoo`05Ool<000;Li`;
000;Li`:000;Li`IOol:Li`30007Ool00`00LiacW009Li`;000;Li`;000;Li`?Ool001Uoo`0;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001Woo0P0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/00`001Woo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00=cW000Ool01Goo00<0
06mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00=cW6mk00001Woo00<007>L00002P0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0<000Ioo`80000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L10001Goo0P002g>L2`002g>L67oo2g>L10001Goo
0P002g>L2`002g>L2`002W>L6Goo0W>L00<007ooOol00goo00<007>LLi`02P002g>L2`002g>L2`00
2g>L67oo0W>L0P001Goo00<007>L00002P002g>L2`002g>L2P002g>L6Goo2W>L10001Goo0P002g>L
2`002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`03
Lia_Ng>L00D00003Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`04Lia_Ng>LKg/50000
0fmkLi`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;
Li`;000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`:000;
Li`IOol:Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
01Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qo
o`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLia_N`04000017>LKg]cW6mk2`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mk
Lia_Ng>L0`0000AcW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`<0
00Aoo`@000]cW0X000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/000]cW0<000=oo`@001Uoo`/0
00YcW0@000=oo`@000]cW0/000]cW0/001Qoo`/000]cW0/0009cW003001oogoo009oo`80009cW0/0
00YcW0/001Uoo`X000]cW0/000=cW004001oogooOol20002Li`;000;Li`;000?Ool001Uoo`<000Io
o`80000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Eo
o`8001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`40005Ool200002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00000fmkLi`00006Ool00`00Kg/0000:00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
6Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg]cW6mk0005Ool00`00Kg/0000:0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol20007Ool2000;Li`:000;Li`;000;Li`;
000HOol;000;Li`;000;Li`;000;Li`20007Ool00`00Oomoo`0GOol;000:Li`30007Ool00`00Liac
W009Li`;000;Li`;000HOol;000;Li`;00000g>L001oo`06Ool00`00Li`0000:000:Li`;000IOol:
000;Li`;0002Li`00`00Oomoo`05Ool<000;Li`;000?Ool001Uoo`8000Qoo`0<001cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool00`00Oomoo`0GOol;0000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003
Kg/007oo00Moo``0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000=_N`00Ool01goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`00
6Goo0P000goo00<007ooOol00Woo00<007>LLi`02G>L2P002g>L2`002g>L2`0067oo2`002g>L2`00
2g>L2`002g>L0P000goo00D007ooOomoo`0001Uoo`/000YcW0<000=oo`05001oogooOol0000;Li`;
000;Li`;000HOol;000;Li`;00000g>L001oo`02Ool00`00Oomoo`02Ool<000:Li`;000IOol:000;
Li`;00000g>L001oo`03Ool01000Oomoogoo30002g>L2`003goo000IOol20007Ool200002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool00`00Oomoo`0G
Ool;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/00003Kg/007oo00Ioo`03001_N`0000X0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/000moo`006Goo100017oo0`002g>L2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L
2`002g>L0`001Goo0P006Goo2`002W>L10001Goo0P002g>L2`002g>L2`0067oo2`002g>L2`000W>L
00<007ooOol00goo00<007>LLi`02`002W>L2`006Goo2P002g>L2`000W>L0P001Goo00<007>L0000
2P002g>L2`003goo000IOol50003Ool300002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0050003Ool2000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L1P000goo
0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000H
Ool;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>LKg/00P000goo00<007>LKg/02`00
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
16mkLia_Ng>L0P000goo00<006mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`00
6Goo2`002g>L2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`002g>L2P006Goo2`002W>L2`00
2g>L2`002g>L2`0067oo2`002g>L2`001G>L0`000g>L2`002W>L2`006Goo2P002g>L2`001W>L0`00
0W>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>L
Kg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool00?mooomoo`Qoo`00ogoo
ogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qo
o`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mo
oomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8
Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003o
OoooOol8Ool001Uoo`/000]cW0X000IcW003001cW7>L009cW0/000]cW0/001Qoo`/000]cW0/000Ec
W08000AcW0/000]cW0X001Uoo`/000YcW0/000EcW08000AcW0/000]cW0/001Qoo`/000]cW0/000]c
W0/000YcW0/001Uoo`X000]cW0/000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X00003Kg]cW6mk00<00005Ool00000Lia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Lia_N`000080009oo`80
0003Kg]cW00000X0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`0000=cW6mkLi`00P000Woo0P0000=_Ng>L00002P0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/01@0000=oo`0000000`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/01@000Woo100000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P000g>L00<007ooOol00goo00<0
07>L00002P002g>L2`0067oo2`002g>L2`000W>L00<007ooOol017oo00<007>L00002P002g>L2P00
6Goo2`002W>L2`000g>L00<007ooOol00goo00<007>L00002P002g>L2`0067oo2`002g>L2`002g>L
0`001Goo0`002W>L2`006Goo2P002g>L2`002g>L10001Goo0P002g>L2`003goo000IOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`06Ool00`00Li`0
000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/00003Lia_N`0000Moo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Moo`80000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`003goo000I
Ool;000;Li`:0002Li`00`00Oomoo`05Ool<000;Li`;000HOol;000;Li`;00000g>L001oo`07Ool<
000;Li`:000IOol;000:Li`;0002Li`00`00Oomoo`05Ool<000;Li`;000HOol;000;Li`;000;Li`2
0007Ool2000:Li`;000IOol:000;Li`;000;Li`30007Ool00`00LiacW009Li`;000?Ool001Uoo`/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00000fmkLi`00002Ool30002Ool<00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Li`007oo
Ool30003Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/00003Li`007oo009oo`<0009oo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000H
Ool;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0080
009oo`<0009oo`80000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0080009oo`@0009oo`0<001_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk2`003goo000IOol;000;Li`:0002Li`00`00Oomoo`05Ool<000;Li`;000H
Ool;000;Li`;00000g>L001oo`06Ool00`00Li`0000:000;Li`:000IOol;000:Li`;0002Li`00`00
Oomoo`05Ool<000;Li`;000HOol;000;Li`;000;Li`20007Ool2000:Li`;000IOol:000;Li`;000;
Li`20008Ool00`00LiacW009Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00000fmkLi`00006Ool00`00Kg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Eoo`03001_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000=cW6mk0000
1Woo00<007>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P001Woo0`0000Y_Ng>LKg]c
W6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/00P001goo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo
2`002g>L2P000g>L00<007ooOol00goo00<007>L00002P002g>L2`0067oo2`002g>L2`000W>L0P00
17oo00<007>LLi`02`002g>L2P006Goo2`002W>L2`000g>L00<007ooOol00goo00<007>L00002P00
2g>L2`0067oo2`002g>L2`002g>L0`001Goo0`002W>L2`006Goo2P002g>L2`002g>L10001Goo0P00
2g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000A_Ng>LKg]cW0D00003
Lia_N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000AcW6mkLia_N`@00003Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000AcW6mkLia_N`D00003Kg]cW00000X0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0/000]cW0/001Qoo`/0
00]cW0/000]cW0/000]cW0X001Uoo`/000YcW0/000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/0
00YcW0/001Uoo`X000]cW0/000]cW0/000]cW0/000moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW6mk
00<00004Kg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLia_Ng>L0`0000AcW6mk
Lia_NaQoo`04Lia_Ng>LKg/3000016mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00=_
Ng>LKg/00`0000A_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L
2`002g>L10000goo10002g>L67oo2g>L2`002g>L2`002g>L2`000W>L00@007ooOomoo`80009cW1Uo
o`]cW0X000]cW0/000]cW0/000=cW004001oogooOol20002Li`HOol3Li`01000Oomoogoo0P000W>L
2`002g>L2`002g>L2P002g>L6Goo0W>L00@007ooOomoo`80009cW0/000]cW0/000]cW0/000]cW0mo
o`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`010001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qo
o`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW00000Eoo`03001cW7oo01Qoo`0;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/00003Kg]cW00000Ioo`03001_Ngoo01Moo`04Lia_Ng>L0005Ool00`00Li`0000:
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol00fmkLi`00005Ool00`00Li`0000:00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0<000Moo`03001cW7>L00UcW1Qoo`]cW0/0
00]cW0/000]cW0/00003Li`007oo00Ioo`03001oogoo01Moo`]cW0X000]cW0/000]cW0/00003Li`0
07oo00Moo`03001oogoo01Ioo`9cW003001oogoo00Eoo``000]cW0/000]cW0X000]cW1Uoo`03Li`0
07oo00Ioo``000]cW0/000]cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P0027oo00`0
07>LKg]cW6mkLia_Ng>LKg]cW6mkLi`HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06
Ool00`00Oomoo`0GOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`07Ool00`00Oomoo`0F
Ool00g>L001oo`07Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol00fmk001oo`06Ool<00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW08000=oo`<0009oo`03001cW7>L
00UcW1Qoo`]cW0/000]cW0/000]cW0/00004Li`007ooOol30002Ool00`00Oomoo`0GOol;Li`:000;
Li`;000;Li`;000017>L001oogoo0`000goo00<007ooOol05Woo00=cW000Ool00Woo0`000Woo3000
2g>L2`002g>L2P002g>L6Goo00AcW000Oomoo`<0009oo``000]cW0/000]cW0/000]cW0moo`006Goo
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`00`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`HOol02fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool00`00Oomoo`0GOol02g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00000fmk001oo`06Ool00`00Kg]oo`0GOol00g>LKg/00007Ool<00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0IOol00fmk001oo`06Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000Yc
W0/000]cW0<000Ioo`8000]cW1Qoo`]cW0/000]cW0/000]cW0/00003Li`007oo00Eoo`03001cW7oo
01Qoo`]cW0X000]cW0/000]cW0/00003Li`007oo00Eoo`03001cW7>L01Qoo`9cW003001oogoo00Ao
o`03001cW00000X000]cW0/000]cW0X000]cW1Uoo`03Li`007oo00Eoo`03001cW00000X000]cW0/0
00]cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>L
Kg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`010001Goo0P0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW00000Eoo`03001cW7oo01Qo
o`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg]cW0000004Ool00`00Lia_N`0HOol017>LKg/00000
1Goo00<007>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00=_Ng>L00001Goo00<007>L0000
2P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;
000;Li`;000;Li`;0003Li`50002Li`IOol;Li`:000;Li`;000;Li`;0004Li`40003Li`HOol4Li`5
0002Li`;000;Li`;000;Li`:000;Li`IOol3Li`50002Li`;000;Li`;000;Li`;000;Li`?Ool001Uo
o`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`03goo000IOol;000;Li`:000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:
000IOol;000:Li`;000;Li`;000;Li`;000HOol;000;Li`;0003Li`40004Li`;000:Li`;000IOol:
000;Li`;000;Li`;0004Li`30004Li`;000?Ool001Uoo`<000Aoo`@0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040003Ool400002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`010000goo100000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLi`00004
Ool200000g>LKg/0000:00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLia_N`000goo0P00
00=cW6mk00002P003goo000IOol30006Ool2000;Li`:000;Li`;000;Li`;000HOol;000;Li`40005
Ool2000;Li`;000;Li`:000IOol;000:Li`;000;Li`40005Ool2000;Li`;000HOol;000;Li`;0002
Li`00`00Oomoo`04Ool00`00Li`0000:000:Li`;000IOol:000;Li`;000;Li`;0002Li`00`00Oomo
o`04Ool00`00Li`0000:000?Ool001Uoo`8000Moo`80000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qo
o`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
2`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Ioo`03001_N`0000X0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Moo``000moo`006Goo0P000Woo0`00
0goo00<007>LLi`02G>L2P002g>L2`002g>L2`0067oo2`002g>L0P000Woo10000Woo00<007>LLi`0
2G>L2`002g>L2P006Goo2`002W>L2`002g>L0P000goo0`000Woo00<007>LLi`02G>L2`0067oo2`00
2g>L2`0000AcW000Oomoo`<000=oo``000YcW0/001Uoo`X000]cW0/000]cW0/00004Li`007ooOol3
0003Ool<000?Ool001Uoo`8000Moo`80000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`00P0027oo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;000HOol;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo3@0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000=_N`00Ool01Woo3@003goo000IOol20007Ool2000;Li`:000;Li`;000;Li`;
000HOol;000;Li`20007Ool2000;Li`;000;Li`:000IOol;000:Li`;000;Li`30007Ool00`00Liac
W009Li`;000HOol;000;Li`;00000g>L001oo`06Ool00`00Li`0000:000:Li`;000IOol:000;Li`;
000;Li`;00000g>L001oo`06Ool00`00Li`0000:000?Ool001Uoo`@000Aoo`<0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040005Ool200002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`010001Goo0P0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk
Li`00005Ool00`00Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLi`0000017oo
00<007>LKg/02`003goo000IOol50003Ool3000;Li`:000;Li`;000;Li`;000HOol;000;Li`50004
Ool2000;Li`;000;Li`:000IOol;000:Li`;000;Li`60003Ool2000;Li`;000HOol;000;Li`;0003
Li`20003Ool00`00LiacW00;000:Li`;000IOol:000;Li`;000;Li`;0004Li`01@00Oomoogoo0000
0W>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000E_Ng>LKg]cW6mk00<00003Kg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mk
Li`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/00005Kg]cW6mkLia_N`0300000fmkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0/000]c
W0/001Qoo`/000]cW0/000]cW0/000]cW0X001Uoo`/000YcW0/000]cW0/000]cW0/001Qoo`/000]c
W0/000]cW0/000YcW0/001Uoo`X000]cW0/000]cW0/000]cW0/000moo`006Goo00]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/00003Kg]cW6mk00<00004Kg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000A_Ng>LKg]cW0<00004Lia_
Ng>LKg/IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000I
Ool;Li`;0002Li`01000Oomoogoo0P000W>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L0`00
0goo1@002W>L6Goo2g>L0`000goo10002g>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L2P00
0g>L00@007ooOomoo`80009cW1Uoo`YcW0/000]cW0@000=oo`@000]cW0/000]cW0moo`006Goo00]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Eoo`03001cW00000X0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/00P001Woo0`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0020006Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00000fmkLi`00006Ool00`00Kg]oo`0HOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00<000Ioo`80000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;00000g>L001oo`06Ool<000;Li`;000;Li`HOol;
Li`;000;Li`;000;Li`20007Ool2000:Li`IOol;Li`20007Ool00`00LiacW009Li`;000;Li`;000;
Li`HOol;Li`;000;Li`;000;Li`:0002Li`00`00Oomoo`05Ool00`00Oomoo`0GOol:Li`;000;Li`3
0007Ool00`00LiacW009Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
16mk001oogoo0`000Woo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020002Ool30002Ool200002VmkLia_Ng>L
Kg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0080009oo`<0009oo`0<001_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00000fmk001oo`02Ool30002Ool0
0`00Oomoo`0GOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
008000=oo`<0009oo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00moo`006Goo2g>L2`0000=cW000Ool01Woo30002g>L2`002g>L67oo2g>L2`002g>L2`00
2g>L0P001goo0P002W>L6Goo2g>L0P001goo00<007>LLi`02G>L2`002g>L2`002g>L67oo2g>L2`00
2g>L2`002g>L2P0000=cW000Ool01goo00<007ooOol05goo2W>L2`002g>L0P0027oo00<007>LLi`0
2G>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo3000
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`020007Ool200002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L008000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00:00000fmkLi`00007Ool00`00Oomoo`0GOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`000W>L00<007ooOol00goo00<007>L
00002P002g>L2`002g>L67oo2g>L2`002g>L2`002g>L0`001Goo0`002W>L6Goo2g>L0`001Goo0P00
2g>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L2P000g>L00<007ooOol00goo00<007>LOol0
67oo2W>L2`002g>L10001Goo0P002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000=_Ng>LKg/00P000Woo00<006mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`050002Ool40000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00D0009oo`<0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X00004Kg]cW6mkLi`20000
1Goo000007>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00600000goo0000000200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00moo`006Goo2g>L2`001G>L0P000g>L2`002g>L2`002g>L67oo2g>L2`002g>L
2`002g>L2`002W>L6Goo2g>L2P002g>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L2P001W>L
00<007>LLi`00W>L6Goo2W>L2`002g>L2`002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo
2`002g>L2P002g>L2`002g>L2`0067oo2`0017>L10000g>L2`002g>L2`002g>L2P006Goo2`002W>L
2`002g>L2`0017>L10000g>L2`0067oo2`002g>L2`002g>L2`002W>L2`006Goo2P0017>L10000g>L
2`002g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00@000Aoo`<0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;
000017>LKg]cW00017oo0P0000=cW00000002@0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>L0004Ool200000g>L00000009000HOol;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00`001Goo0`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:000016mkLia_N`0017oo0P0000=_N`0000002@00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool0
01Uoo`/000]cW0X000]cW0<000Moo`03001cW7>L00UcW0/001Qoo`/0009cW003001oogoo00Eoo``0
00]cW0/000]cW0X001Uoo`/000YcW0/000]cW0/0009cW003001oogoo00Eoo``001Qoo`/000]cW080
00Qoo`03001cW7>L00UcW0/000YcW0/001Uoo`X0009cW003001oogoo00Eoo``000]cW0/000]cW0/0
00moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`030007Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/001Qoo`/00003Lia_N`0000Moo``0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo
2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L
Kg/00007Ool<000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P0027oo00`006mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000=_Ng>L00001goo
300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?
Ool001Uoo`/000]cW0X000]cW08000=oo`<0009oo`03001cW7>L00UcW0/001Qoo`/00003Li`007oo
009oo`<0009oo``000]cW0/000]cW0X001Uoo`/000YcW0/000]cW0/00004Li`007ooOol40002Ool<
000HOol;000;Li`20002Ool30003Ool00`00LiacW009Li`;000:Li`;000IOol:0002Li`00`00Oomo
o`030002Ool<000;Li`;000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P0027oo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;
000HOol;00000g>L001oo`07Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000=cW000Ool01goo300067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk008000Moo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L2`006Goo2P0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0<000Moo`03001cW7>L00Uc
W0/001Qoo`/0009cW003001oogoo00Eoo``000]cW0/000]cW0X001Uoo`/000YcW0/000]cW0/00003
Li`007oo00Moo``001Qoo`/000]cW08000Moo`8000]cW0/000YcW0/001Uoo`X0009cW003001oogoo
00Eoo``000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040005Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
67oo2`0000AcW6mk000000Eoo`03001cW00000X0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>LKg/000001Goo00<007>L00002P0067oo2`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@000Aoo`<0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000A_Ng>LKg/000Eoo`03001_N`0000X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;
000;Li`:000;Li`600000goo00000002000;Li`;000HOol;0004Li`00`00Oomoo`020002Li`;000;
Li`;000;Li`:000IOol;000:Li`;000;Li`;0004Li`00`00Oomoo`020002Li`;000HOol;000;Li`5
0002Ool4000;Li`;000:Li`;000IOol:0004Li`20002Ool00`00LiacW00;000;Li`;000;Li`;000?
Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/00005Lia_Ng>LKg]cW002000016mk
Lia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/00005Lia_Ng>LKg]cW002000016mkLia_Ng>L2`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
6Goo2P0000I_Ng>LKg]cW6mkLi`200000fmkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`002g>L2`00
67oo2`002g>L2`002g>L2`002g>L2P006Goo2`002W>L2`002g>L2`002g>L2`0067oo2`002g>L2`00
2g>L2`002W>L2`006Goo2P002g>L2`002g>L2`002g>L2`003goo000IOol02fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;000017>LKg]cW6mk100000=cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLia_N`0500000fmkLia_N`0;00002VmkLia_Ng>L
Kg]cW6mkLia_Ng>L6Goo00=cW6mkLi`0100000A_Ng>LKg]cW0X0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02Vmk
Lia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00000g>LKg]cW00500000g>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]c
W0/000=cW003001oogoo009oo`800003Liaoogoo01Ioo`]cW0/000]cW0/0009cW003001oogoo00=o
o`800003Li`0000000T000YcW1Uoo`9cW003001oogoo009oo`<00003Li`0000000P000]cW0/000]c
W0/000]cW1Qoo`]cW0/000]cW0/000]cW0<000Aoo`<000]cW1Uoo`YcW0/000]cW0/000]cW0/0009c
W003001oogoo00=oo`800003Liaoogoo00eoo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mk
00001goo00<007ooOol05Woo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00000fmk001oo`06Ool00`00Kg/0000:00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
6Goo00=cW000Ool01Woo00<007>L00002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`00P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/IOol02VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00000g>L001oo`06Ool00`00Liaoo`0>Ool001Uoo`]cW0/000YcW0/000]cW0/0009cW003
001oogoo00Eoo`03001oogoo01Ioo`]cW0/000]cW0/00003Li`007oo00Ioo`03001cW00000X000Yc
W1Uoo`03Li`007oo00Ioo`03001cW00000T000]cW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]c
W08000Moo`03001cW7>L00UcW1Uoo`YcW0/000]cW0/000]cW0/00003Li`007oo00Ioo`03001cW7oo
00ioo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000AcW000Oomoo`@0009oo`03001oogoo01Ioo`0;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_N`00
Oomoo`<000=oo``0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol017>L001oogoo0`000Woo300000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P000Woo0`000Woo00`006mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>L001oogoo0`000goo
00<007ooOol03Goo000IOol;Li`;000:Li`;000;Li`;00000g>L001oo`07Ool00`00Oomoo`0FOol;
Li`;000;Li`;00000g>L001oo`06Ool=000:Li`IOol00g>L001oo`06Ool00`00Li`00009000;Li`;
000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`20007Ool00`00LiacW009Li`IOol:Li`;000;Li`;
000;Li`;00000g>L001oo`06Ool2000?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo
00Moo`03001oogoo01Ioo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000=_N`00Ool01Woo00<006mk00002P0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uo
o`03Li`007oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L008000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk6Goo00Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000=cW000Ool01Woo00<007>LOol03Woo000IOol;Li`;000:Li`;000;Li`;0002Li`20005
Ool00`00Liaoo`0GOol;Li`;000;Li`;0002Li`00`00Oomoo`03Ool00`00LiacW00;000:Li`IOol2
Li`00`00Oomoo`03Ool00`00LiacW00:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`3
0005Ool2000;Li`IOol:Li`;000;Li`;000;Li`;0002Li`00`00Oomoo`03Ool00`00LiacW00?Ool0
01Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>LKg/500000fmkLiaoo`0GOol02fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW6mk00D00003
Kg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol00g>LKg]cW00500000g>LKg]cW00:0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mkLi`01@0000=cW6mkLi`03goo
000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`;000:Li`IOol;Li`:000;
Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`:000;Li`IOol:Li`;000;Li`;000;Li`;000;
Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol0
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;0003Li`40004Li`:000;Li`;000;Li`;000HOol;000;
Li`;000;Li`;000;Li`:000IOol;000:Li`;000;Li`;000;Li`;000HOol;0004Li`40003Li`;000;
Li`;000:Li`;000IOol:000;Li`;000;Li`;000;Li`;000?Ool001Uoo`/00003Lia_N`0000Aoo`80
0003Kg]cW00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0067oo100017oo0`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]c
W6mkLia_Ng>LKg]cW0@000Aoo`<0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0067oo2`0000A_Ng>LKg/000Aoo`800003Kg/0000000T0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00@000Aoo`<0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;00000g>L001oo`06Ool00`00Li`00009000;Li`;
000;Li`;000HOol30007Ool00`00LiacW009Li`;000;Li`;000;Li`:000IOol;000:Li`30007Ool0
0`00LiacW009Li`;000;Li`;000HOol;0002Li`00`00Oomoo`05Ool<000;Li`;000:Li`;000IOol:
000;Li`30007Ool00`00LiacW009Li`;000;Li`;000?Ool001Uoo`/00003Li`007oo00Ioo`03001c
W00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0067oo0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`30007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;000HOol;00000fmkLi`00007Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030007Ool0
3000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool0
01Uoo`/00004Li`007ooOol30002Ool<000;Li`;000;Li`;000HOol20003Ool30002Ool00`00Liac
W009Li`;000;Li`;000;Li`:000IOol;000:Li`30002Ool30002Ool00`00LiacW009Li`;000;Li`;
000HOol;000017>L001oogoo10000Woo30002g>L2`002W>L2`006Goo2P002g>L0P000goo0`000Woo
00<007>LLi`02G>L2`002g>L2`003goo000IOol;00000g>L001oo`06Ool00`00Li`0000900002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`<000Mo
o`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo
00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo
2`0000=_N`00Ool01Woo00<006mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00`001goo00`0
06mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000I
Ool;00000g>L001oo`06Ool00`00Li`00009000;Li`;000;Li`;000HOol30007Ool00`00LiacW009
Li`;000;Li`;000;Li`:000IOol;000:Li`30007Ool00`00LiacW009Li`;000;Li`;000HOol;0000
0g>L001oo`06Ool00`00Li`0000:000;Li`;000:Li`;000IOol:000;Li`30007Ool00`00LiacW009
Li`;000;Li`;000?Ool001Uoo`/00003Lia_N`0000Eoo`03001_Ng>L00X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo10001Goo0P0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0@000Eoo`80000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000A_
Ng>L000000Eoo`03001_N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>L
Kg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@000Eoo`80000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;
0003Li`50003Li`:000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:Li`;
000;Li`;000;Li`;000HOol;0004Li`50002Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;
000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`00ogooogoo27oo003oOoooOol8
Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003o
OoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo
27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00
ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomo
o`Qoo`00ogooogoo27oo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000AcW6mkLia_N`@0
0003Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000=_Ng>LKg/01@0000=_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLia_Ng>L100000=_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L0`0017oo0`002g>L2`00
2g>L2`0067oo2`002g>L100017oo0`002g>L2`002g>L2P006Goo2`002W>L2`000g>L00<007ooOol0
0Woo0P0000=cW00000002@002g>L2`0067oo2`002g>L2`000W>L00<007ooOol00goo0P0000=cW000
00002@002W>L2`006Goo2P002g>L2`000g>L00<007ooOol00Woo0P0000=cW00000002@002g>L2`00
3goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P001goo00`006mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00000g>LKg/00007Ool<0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
0003Kg/007oo00Ioo`03001_N`0000X0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/000moo`006Goo2`002g>L0P001goo00<007>LLi`02G>L2`002g>L2`0067oo2`002g>L0`00
1goo00<007>LLi`02G>L2`002g>L2P006Goo2`002W>L2`000W>L00<007ooOol01Goo30002g>L2`00
67oo2`002g>L2`0000=cW000Ool01Woo00<007>L00002P002W>L2`006Goo2P002g>L2`000W>L00<0
07ooOol01Goo30002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P000Woo
0`000Woo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0080009oo`@0009oo`0<001cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;00000g>L001oo`02Ool30002Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg/007ooOol30003Ool<00002Vmk
Lia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/0
07oo009oo`<0009oo``0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW080
00Moo`03001cW7>L00UcW0/000]cW0/001Qoo`/000]cW08000Moo`8000]cW0/000]cW0X001Uoo`/0
00YcW0/00003Li`007oo00Moo``000]cW0/001Qoo`/000]cW0/00003Li`007oo00Ioo`d000YcW0/0
01Uoo`X000]cW0/00003Li`007oo00Moo``000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L008000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool200002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;00000g>LKg/00007Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Ioo`03001_N`0000X0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L0`00
1Goo0P002g>L2`002g>L2`0067oo2`002g>L10001Goo0P002g>L2`002g>L2P006Goo2`002W>L2`00
0g>L00<007ooOol00goo00<007>L00002P002g>L2`0067oo2`002g>L2`000W>L00<007ooOol00goo
00<007>LLi`02`002W>L2`006Goo2P002g>L2`000W>L0P001Goo00<007>L00002P002g>L2`003goo
000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@000Woo0`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`01@000Woo100000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000AcW6mkLia_N`800005
Ool00000Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/00003Kg]cW6mk0080009oo`04001_Ng>LKg/;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg]cW6mkLi`200001Goo
000007>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L
2`002g>L2`0067oo2`002g>L2`002g>L2`002g>L2P006Goo2`002W>L2`001W>L00<007>LLi`00W>L
2`002g>L2`0067oo2`002g>L2`001G>L0P0017>L2`002W>L2`006Goo2P002g>L2`001W>L00<007>L
Li`00W>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`]cW0/000Yc
W0/000]cW0/000AcW0@000=cW1Qoo`]cW0/000]cW0/000]cW0/000=cW0@000=cW1Uoo`=cW0@000Ac
W0X000]cW0/000]cW0/000]cW1Qoo`AcW0@000=cW0/000]cW0/000]cW0X000]cW1Uoo`YcW0/000]c
W0/000]cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000AcW6mkLi`000Aoo`800003
Liaoogoo01Ioo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW00000Aoo`800003Liaoogoo01Mo
o`03Lia_N`0000Aoo`<00003Li`0000000P0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`04Lia_Ng>L
0004Ool200000g>L0000000900002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mk
Lia_Ng>L100017oo0`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`;000;Li`;
0002Li`00`00Oomoo`05Ool00`00Oomoo`0FOol;Li`;000;Li`;000;Li`;00000g>L001oo`06Ool0
0`00Oomoo`0GOol00g>L001oo`06Ool00`00Li`00009000;Li`;000;Li`;000;Li`HOol2Li`00`00
Oomoo`05Ool<000;Li`;000;Li`:000;Li`IOol:Li`30007Ool00`00LiacW009Li`;000;Li`;000;
Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Lia_N`0000Moo`03001oogoo01Ioo`0;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Ioo`03001oogoo01Moo`03Li`007oo00Ioo`03001c
W00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`03Lia_N`0000Moo``0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`30007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
3goo000IOol;Li`;000:Li`;000;Li`;000017>L001oogoo10000Woo00<007ooOol05Woo2g>L2`00
2g>L2`002g>L2`0000AcW000Oomoo`<0009oo`03001oogoo01Moo`04Li`007ooOol30002Ool<000;
Li`;000;Li`;000;Li`HOol00g>L001oo`02Ool30002Ool<000;Li`;000;Li`:000;Li`IOol:Li`3
0002Ool30002Ool00`00LiacW009Li`;000;Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/00003Li`007oo00Moo`03001oogoo01Ioo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo
00Ioo`03001oogoo01Moo`03Li`007oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01Qoo`03Li`007oo00Moo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`30007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`;000;Li`;0000
0g>L001oo`07Ool00`00Oomoo`0FOol;Li`;000;Li`;000;Li`;00000g>L001oo`06Ool00`00Oomo
o`0GOol00g>L001oo`06Ool00`00Li`00009000;Li`;000;Li`;000;Li`HOol2Li`00`00Oomoo`05
Ool<000;Li`;000;Li`:000;Li`IOol:Li`30007Ool00`00LiacW009Li`;000;Li`;000;Li`?Ool0
01Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_N`000005Ool00`00Liaoo`0GOol02fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00000fmkLi`00005Ool00`00Liaoo`0HOol00g>LKg/00005Ool00`00Kg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol017>LKg/000001Goo00<007>L00002P0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0@000Eoo`80000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00moo`006Goo2g>L2`002W>L2`002g>L2`0017>L1@000W>L67oo2g>L2`002g>L2`002g>L
2`000g>L1@000W>L6Goo0g>L1@000g>L2P002g>L2`002g>L2`002g>L67oo17>L1@000W>L2`002g>L
2`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo
2g>L2`002W>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L2`002W>L6Goo2g>L2P002g>L2`00
2g>L2`002g>L67oo2g>L2`002g>L2`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`002g>L3goo
000IOol;00000g>LKg]cW004000016mkLia_Ng>L2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000=cW6mkLi`01@0000=cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`000W>L00<007ooOol00Woo0P000W>L2P002g>L2`00
2g>L2`0067oo2`002g>L2`000W>L00<007ooOol00goo0P0000=cW00000002@002g>L2P006Goo2`00
2W>L100017oo0`002g>L2`002g>L2`0067oo2`002g>L2`002g>L0`0017oo10002W>L2`006Goo2P00
2g>L2`002g>L2`002g>L0`001Goo0`003goo000IOol;00000g>L001oo`06Ool00`00Li`000090000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`06Ool00`00Li`0000:00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0<000Moo`0<001c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P001goo0P00
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Moo`80
00moo`006Goo2`0000=cW000Ool01Woo00<007>L00002@002g>L2`002g>L2`0067oo2`002g>L2`00
00=cW000Ool01Woo00<007>L00002P002g>L2P006Goo2`002W>L0`001goo00<007>LLi`02G>L2`00
2g>L2`0067oo2`002g>L2`002g>L0P001goo0P002W>L2`006Goo2P002g>L2`002g>L2`002g>L0P00
1goo0P003goo000IOol;000017>L001oogoo0`000Woo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000AcW000Oomoo`<000=oo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;0000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L0`000Woo0`000Woo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020002Ool30002Ool200002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000Woo0`000goo00<007ooOol03Goo
000IOol;00000g>L001oo`06Ool00`00Li`00009000;Li`;000;Li`;000HOol;000;Li`;00000g>L
001oo`06Ool00`00Li`0000:000;Li`:000IOol;000:Li`30007Ool00`00LiacW009Li`;000;Li`;
000HOol;000;Li`;000;Li`20007Ool2000:Li`;000IOol:000;Li`;000;Li`;000;Li`20007Ool2
000?Ool001Uoo`/00003Li`007oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/00003Li`007oo00Ioo`03001cW00000X0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000I
Ool;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool200002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P001goo0P003goo000IOol;0002Li`00`00Oomo
o`03Ool00`00LiacW00:000;Li`;000;Li`;000HOol;000;Li`;0002Li`20004Ool00`00LiacW00;
000;Li`:000IOol;000:Li`40005Ool2000;Li`;000;Li`;000HOol;000;Li`;000;Li`30005Ool3
000:Li`;000IOol:000;Li`;000;Li`;000;Li`30005Ool3000?Ool001Uoo`/00003Lia_Ng>L00D0
0003Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>LKg/400000g>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
3goo000IOol;000;Li`:000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:
Li`;000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;
Li`;000?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00H
Ool02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol4Li`40003
Li`;000;Li`;000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;
Li`:000;Li`IOol:Li`;000;Li`;0004Li`40003Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L100017oo0`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol016mkLia_N`0017oo0P0000=_
N`0000002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0100017oo0`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040004Ool3
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>L0004Ool200000g>L0000000900002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`30007Ool00`00LiacW009Li`;000;Li`HOol2Li`0
0`00Oomoo`05Ool<000;Li`;000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`30007Ool00`00Liac
W009Li`HOol;Li`30007Ool00`00LiacW009Li`;000;Li`:000;Li`IOol:Li`;000;Li`;0002Li`0
0`00Oomoo`05Ool<000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`067oo00=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/00`001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/HOol02g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`00`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>L
Kg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mk00001goo300000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L0`000Woo0`000Woo00<007>LLi`02G>L
2`002g>L67oo00=cW000Ool00Woo0`000Woo30002g>L2`002g>L2`002W>L6Goo2g>L2P002g>L2`00
2g>L0P000Woo10000Woo00<007>LLi`02G>L67oo2g>L0P000Woo10000Woo00<007>LLi`02G>L2`00
2g>L2P002g>L6Goo2W>L2`002g>L2`0000AcW000Oomoo`@0009oo``000]cW0moo`006Goo00]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`30007Ool03000Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol00fmkLi`00007Ool<
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:
Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020008Ool03000Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_NaQoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool200002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/00003Li`007oo00Moo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]c
W0/000YcW0<000Moo`03001cW7>L00UcW0/000]cW1Qoo`9cW003001oogoo00Eoo``000]cW0/000]c
W0/000YcW1Uoo`]cW0X000]cW0/000]cW08000Qoo`03001cW7>L00UcW1Qoo`]cW08000Moo`8000]c
W0/000]cW0X000]cW1Uoo`YcW0/000]cW0/00003Li`007oo00Moo``000]cW0moo`006Goo00]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`40005Ool200002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`04Kg]cW6mk0005
Ool00`00Kg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040005
Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@0
00Eoo`80000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000AcW6mk000000Eoo`03001cW00000X0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0/000]cW1Qoo`AcW0D0009cW0/000]c
W0/000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0X000]c
W1Uoo`YcW0/000]cW0/000AcW0D0009cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mk
Lia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uo
o`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`/000]c
W0X000]cW0/000EcW08000AcW0/001Qoo`/000]cW0/000]cW0/000]cW0X001Uoo`/000EcW003001c
W7>L009cW0/000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/000EcW003001cW7>L009cW0/001Uo
o`X000]cW0/000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLia_N`020002Ool200000g>LKg/0000:000H
Ool;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00D0
009oo`@0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00000fmkLi`0000200001Goo0000
06mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/00003Kg]cW00000800005Ool00000Kg]cW00;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/01@000Woo100000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0/000=cW003001oogoo00=oo`03001cW00000X0
01Qoo`/000]cW0/000]cW0<000Ioo`8000]cW0X001Uoo`/0009cW003001oogoo00=oo`03001cW000
00X000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/0009cW003001oogoo00=oo`03001cW00000X0
01Uoo`X000]cW0@000Eoo`8000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLi`00007Ool<000HOol;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`80
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00000fmk001oo`06Ool<00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo
30006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`00
00=cW000Ool01goo300067oo2`002g>L2`002g>L0P0027oo00<007>LLi`02G>L2P006Goo2`0000=c
W000Ool01Woo30002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`0000=cW000Ool01Woo30006Goo
2P002g>L0P0027oo00<007>LLi`02G>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo009oo`<0009oo``0
01Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
0P000Woo0`000goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`:000IOol;000016mk001oogoo0`00
0Woo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/00004Kg/007ooOol30002Ool<000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000goo
0`000Woo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`003goo000IOol;000;Li`:000;Li`;0002Li`00`00Oomoo`05Ool<000HOol;000;Li`;000;Li`2
0007Ool2000;Li`:000IOol;00000g>L001oo`06Ool<000;Li`;000;Li`;000HOol;000;Li`;000;
Li`;00000g>L001oo`06Ool<000IOol:000;Li`30007Ool00`00LiacW009Li`;000;Li`;000?Ool0
01Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000=_Ng>L00001Woo00<006mk00002P0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020006Ool300002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2P006Goo2`0000=_N`00Ool01Goo00<007>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Eoo`03001cW00000X001Uoo`X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030006Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`000W>L0P00
1Goo00<007>L00002P0067oo2`002g>L2`002g>L0`001Goo0`002g>L2P006Goo2`000W>L00<007oo
Ool00goo00<007>L00002P002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`000W>L00<007ooOol0
0goo00<007>L00002P006Goo2P002g>L10001Goo0P002g>L2`002g>L2`003goo000IOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg]cW6mk
Li`500000g>LKg/0000:000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00000fmkLia_
N`0500000fmkLi`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000=_Ng>LKg/01@0000=_Ng>L00002P006Goo2P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`003goo000IOol;000;Li`:000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:
000IOol;000:Li`;000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;
000;Li`;000;Li`;000?Ool001Uoo`03Kg]cW6mk00@00004Lia_Ng>LKg/;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>LKg]cW0<00004Lia_Ng>LKg/HOol02g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000=cW6mkLi`0100000A_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00=_Ng>LKg/00`0000A_Ng>LKg]cW0/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo0W>L00<007ooOol00Woo0P000W>L2`002W>L2`00
2g>L2`002g>L67oo2g>L10000goo10002g>L2`002g>L2`002W>L6Goo2g>L2P002g>L2`002g>L2`00
0g>L00@007ooOomoo`80009cW1Qoo`]cW0/0009cW003001oogoo009oo`80009cW0/000]cW0X000]c
W1Uoo`9cW004001oogooOol20002Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`03Kg]cW00000Io
o`03001_N`0000X0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`04
0005Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLi`0
0006Ool00`00Kg]oo`0GOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mk00001Woo00<0
07>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0IOol00fmkLi`00005Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`03
Li`007oo00Ioo`03001cW00000X000YcW0/000]cW0/000]cW1Qoo`]cW0<000Moo`03001cW7>L00Uc
W0/000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/00003Li`007oo00Moo`03001oogoo01Ioo`]c
W0/00003Li`007oo00Moo``000]cW0X000]cW1Uoo`03Li`007oo00Ioo``000]cW0/000]cW0/000]c
W0moo`006Goo00=_N`00Ool01goo300000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk008000Qoo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00000fmk001oo`07Ool00`00Oomoo`0FOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW000
Ool01goo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0IOol00fmk001oo`06Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`04Li`007ooOol3
0003Ool<000:Li`;000;Li`;000;Li`HOol;Li`20003Ool30002Ool00`00LiacW009Li`;000;Li`;
000:Li`IOol;Li`:000;Li`;000;Li`;000017>L001oogoo0`000goo00<007ooOol05Woo2g>L2`00
00AcW000Oomoo`<000=oo``000]cW0X000]cW1Uoo`04Li`007ooOol30002Ool<000;Li`;000;Li`;
000;Li`?Ool001Uoo`03Kg/007oo00Ioo`03001_N`0000X0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030007Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo00<006mkOol05goo00]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/00003Li`007oo00Ioo`03001cW00000X0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00=_N`00Ool01Woo300000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`03goo000IOol00g>L001oo`05Ool00`00LiacW00;000:Li`;000;Li`;000;Li`HOol;Li`30006
Ool2000;Li`;000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;00000g>L001oo`05Ool00`00Liac
W00HOol;Li`;00000g>L001oo`05Ool00`00LiacW00;000;Li`:000;Li`IOol00g>L001oo`05Ool0
0`00Li`0000:000;Li`;000;Li`;000;Li`?Ool001Uoo`04Kg]cW0000004Ool00`00Lia_N`0;0000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/010001Goo0P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>L
Kg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>L000000Aoo`03001cW6mk
01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>LKg/0000017oo00<006mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol00fmkLi`0
0005Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`AcW0@000=cW0/000Yc
W0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/000Ac
W0@000=cW1Qoo`]cW0/000AcW0@000=cW0/000]cW0X000]cW1Uoo`=cW0D0009cW0/000]cW0/000]c
W0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`/000]cW0X000]cW0/000]cW0/001Qoo`/000]c
W0/000]cW0/000=cW0<000EcW0X001Uoo`/000YcW0/000]cW0/000]cW0/001Qoo`/000]cW0/000]c
W0/000YcW0/001Uoo`X000]cW0/000]cW0/000AcW0<000AcW0/000moo`006Goo2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040003Ool400002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00003Ool200000g>LKg]cW00:000IOol;00002Vmk
Lia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000=oo`@0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`40003Ool4000IOol:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004
Kg]cW6mk0003Ool200000g>LKg/0000:000?Ool001Uoo`/000]cW0X000]cW0@000Eoo`8000]cW0/0
01Qoo`/000]cW0/000]cW0/0009cW003001oogoo00=oo`03001cW7>L00X001Uoo`/000YcW0/000]c
W0@000Eoo`8000]cW0/001Qoo`/000]cW0/000]cW0/000YcW0@000Eoo`8001Uoo`X000]cW0/000]c
W0/0009cW003001oogoo00Aoo`03001cW00000X000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030007Ool03000Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000=cW000Ool01Woo00<007>L00002@006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0<000Moo`03001oogoo01Moo`X0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01goo
30003goo000IOol;000;Li`:000;Li`20003Ool30002Ool00`00LiacW009Li`;000HOol;000;Li`;
000;Li`;000017>L001oogoo0`000Woo00<007>L00002@006Goo2`002W>L2`002g>L0P000goo0`00
0Woo00<007>LLi`02G>L2`0067oo2`002g>L2`002g>L2`002W>L0P000goo0`000Woo00<007ooOol0
5goo2P002g>L2`002g>L2`0000AcW000Oomoo`<000=oo``000moo`006Goo2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020008Ool03000Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000=cW000Ool01Woo00<007>L00002@006Goo2`0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020008Ool03000Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW08000Qoo`03001oogoo01Moo`X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00
Ool01Woo3@003goo000IOol;000;Li`:000;Li`30007Ool00`00LiacW009Li`;000HOol;000;Li`;
000;Li`;00000g>L001oo`06Ool00`00Li`00009000IOol;000:Li`;000;Li`30007Ool00`00Liac
W009Li`;000HOol;000;Li`;000;Li`;000:Li`30007Ool00`00Oomoo`0GOol:000;Li`;000;Li`;
00000g>L001oo`06Ool00`00Li`0000:000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/010001Goo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000=cW6mk00001Goo00<006mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040005Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L10001Goo0P006Goo2P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLi`0000017oo00<007>L
Kg/02`003goo000IOol;000;Li`:000;Li`600000goo00000002000;Li`;000HOol;000;Li`;000;
Li`;0003Li`20002Ool20002Li`:000IOol;000:Li`;000;Li`600000goo00000002000;Li`;000H
Ool;000;Li`;000;Li`;000:Li`600000goo00000002000IOol:000;Li`;000;Li`;0004Li`00`00
Oomoo`020002Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000EcW6mkLia_
Ng>L00800004Kg]cW6mkLi`:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/00005Kg]cW6mkLia_N`02000017>LKg]cW6mk2`003goo000IOol;000;Li`:
000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:Li`;000;Li`;000;Li`;
000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;Li`;000?Ool00?mooomo
o`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool0
0?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOooo
Ool8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo
003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogoo
ogoo27oo003oOoooOol8Ool001Uoo`/0000;Lia_Ng>LKg]cW000Lia_Ng>LKg]cW00:00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`000W>L0`00
00=oo`0000000g>L2P002g>L2`002g>L2`0067oo2`002g>L1@000Woo10002g>L2`002g>L2P006Goo
2`002W>L1P0000=oo`0000000P002g>L2`002g>L2`0067oo2`002g>L1@000Woo10002g>L2`002W>L
2`006Goo2P002g>L1@000Woo10002g>L2`002g>L2`003goo000IOol;00000g>LKg/00005Ool00`00
Kg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040005Ool200002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>L
Kg]cW6mkLi`40005Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030006Ool200002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`040005Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`0000=cW000Ool01Woo00<007>L00002@002g>L
2`002g>L2`0067oo2`002g>L0`001goo00<007>LLi`02G>L2`002g>L2P006Goo2`002W>L0`001goo
00<007>LLi`02G>L2`002g>L2`0067oo2`002g>L0P0027oo00<007>LLi`02G>L2`002W>L2`006Goo
2P002g>L0`001goo00<007>LLi`02G>L2`002g>L2`003goo000IOol;00000g>L001oo`06Ool00`00
Li`0000900002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020008Ool03000Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Qoo`0<001_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`020008Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;000?Ool001Uoo`/00004Li`007ooOol30002Ool<000;Li`;000;Li`;000HOol;
000;Li`20002Ool40002Ool00`00LiacW009Li`;000;Li`:000IOol;000:Li`30002Ool30002Ool0
0`00LiacW009Li`;000;Li`;000HOol;000;Li`20002Ool30003Ool00`00LiacW009Li`;000:Li`;
000IOol:000;Li`20003Ool30002Ool00`00LiacW009Li`;000;Li`;000?Ool001Uoo`/00003Li`0
07oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`80000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool2
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`030007Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/00003Li`007oo00Eoo`03001cW7>L
00X000]cW0/000]cW0/001Qoo`/000]cW08000Moo`8000]cW0/000]cW0X001Uoo`/000YcW0<000Io
o`8000]cW0/000]cW0/001Qoo`/000]cW08000Ioo`<000]cW0/000YcW0/001Uoo`X000]cW0<000Io
o`8000]cW0/000]cW0/000moo`006Goo2`0000=cW6mk00001Goo00<006mkLi`02P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`010001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L10001Goo0P00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0100017oo0`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
10001Goo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;000?Ool001Uoo`/000=cW0D000=cW0X000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/000]c
W0X001Uoo`/000YcW0/000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/000YcW0/001Uoo`X000]c
W0/000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>L
Kg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;Li`;000:
Li`;000;Li`;0004Li`30004Li`HOol4Li`30004Li`;000;Li`;000;Li`;000:Li`IOol3Li`30005
Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;0003Li`30005Li`:000;Li`IOol:Li`;000;
Li`;000;Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>L
Kg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>L0003Ool20000
0fmkLiaoo`0GOol016mkLia_N`000goo0P0000=cW6mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo
00=cW6mk00000goo0P0000=cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00003Ool2
00000g>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
10000goo100000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L2`002g>L2`00
0g>L00<007ooOol00goo00<007>LOol05goo0g>L00<007ooOol00goo00<007>L00002P002g>L2`00
2g>L2`002W>L6Goo0W>L00<007ooOol00goo0P0000=cW000000020002g>L2`002g>L2`002g>L67oo
2g>L2`002g>L2`000W>L00<007ooOol00goo00<007>LLi`02P002g>L6Goo2W>L2`002g>L2`002g>L
0`001Woo0P002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00007Ool00`00Oomo
o`0FOol00fmkLi`00007Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol00g>L001oo`06Ool00`00Li`0
000900002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020008Ool03000Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0moo`006Goo2g>L2`002W>L2`002g>L2`0000=cW000Ool01goo00<007ooOol05Woo00=c
W000Ool01goo30002g>L2`002g>L2`002W>L6Goo00=cW000Ool01Woo00<007>L00002@002g>L2`00
2g>L2`002g>L67oo2g>L2`002g>L2`0000=cW000Ool01Woo00<007>L00002@002g>L6Goo2W>L2`00
2g>L2`002g>L0P0027oo00<007>LLi`02G>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L
001oo`03Ool01@00Oomoogoo000067oo00=_N`00Ool00goo00@007ooOomoo``0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW1Uoo`03Li`007oo009oo`04001oogooOol<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol0
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`0
07oo009oo`06001oogooOol007>L2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mk
Lia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L008000=oo`03001oogoo009oo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3goo000I
Ool;Li`;000:Li`;000;Li`;00000g>L001oo`07Ool00`00Oomoo`0FOol2Li`00`00Oomoo`05Ool<
000;Li`;000;Li`;000:Li`IOol00g>L001oo`06Ool00`00Li`00009000;Li`;000;Li`;000;Li`H
Ool;Li`;000;Li`;00000g>L001oo`06Ool00`00Li`00009000;Li`IOol:Li`;000;Li`;000;Li`2
0007Ool2000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_N`000005Ool00`00Liao
o`0GOol016mkLia_N`001Goo00<006mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00=cW6mk0000
1Goo00<006mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00005Ool00`00Kg]cW00:0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0100017oo0`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L2`002g>L2`0017>L00<007ooOol00Woo
00<007>LOol05goo17>L0P000goo00<007>L00002P002g>L2`002g>L2`002W>L6Goo0g>L0P000goo
00<007>LLi`02P002g>L2`002g>L2`002g>L67oo2g>L2`002g>L2`000g>L0P000goo00<007>LLi`0
2P002g>L6Goo2W>L2`002g>L2`002g>L1@000goo0`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00001G>LKg]cW6mkLi`0100000=_Ng>LOol05goo00I_Ng>LKg]cW6mkLi`300000g>LKg/0000:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:
Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol01G>LKg]cW6mkLi`00`0000=cW6mkLi`02P0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00001G>LKg]cW6mkLi`00`0000=cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uo
o`]cW0/000YcW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0/000YcW1Uoo`]cW0X000]cW0/0
00]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0X000]cW1Uoo`YcW0/000]cW0/000]cW0/000]cW0mo
o`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg]cW00300001G>LKg]cW6mkLi`0
2P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
000017>LKg]cW6mk0`0000A_Ng>LKg]cW0/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0
0004Kg]cW6mkLi`3000017>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0@000=oo`@000]cW0/001Qo
o`/000]cW0/000]cW0/0009cW004001oogooOol20003Li`:000IOol;000:Li`;000;Li`;0003Li`0
1000Oomoogoo0P000W>L2`0067oo2`002g>L2`002g>L2`002W>L10000goo10006Goo2P000g>L00@0
07ooOomoo`80009cW0/000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040005Ool200002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00000g>LKg/00005Ool00`00Kg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>L0005Ool00`00Li`0000:000H
Ool;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`40005Ool2000IOol:000016mkLia_N`001Goo00<006mk0000
2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?
Ool001Uoo`/000]cW0X000]cW0<000Moo`03001cW7>L00UcW0/001Qoo`/000]cW0/000]cW0/00003
Li`007oo00Ioo`03001cW00000T001Uoo`/000YcW0/000]cW0/0009cW003001oogoo00Eoo``001Qo
o`/000]cW0/000]cW0/000YcW0<000Moo`03001oogoo01Moo`X0009cW003001oogoo00Eoo``000]c
W0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`020003Ool30002Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/001Qoo`/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000Ac
W000Oomoo`<0009oo`03001cW00000T001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000AcW000Oomoo`@0009oo``001Qoo`/0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW08000=oo`<0009oo`03001oogoo01Moo`X00003Kg]cW000009oo`<0009oo``0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;
000;Li`:000;Li`20008Ool00`00LiacW009Li`;000HOol;000;Li`;000;Li`;00000g>L001oo`06
Ool00`00Li`00009000IOol;000:Li`;000;Li`;00000g>L001oo`07Ool<000HOol;000;Li`;000;
Li`;000:Li`20008Ool00`00Oomoo`0GOol:0002Li`00`00Oomoo`05Ool<000;Li`;000;Li`;000?
Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/00`001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;000HOol;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW000
00T001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000=cW000Ool01goo300067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00<007ooOol05goo
2P0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0@000Eoo`8000]cW0/001Qoo`/000]cW0/0
00]cW0/0009cW003001oogoo00=oo`03001cW7>L00X001Uoo`/000YcW0/000]cW0/0009cW08000Eo
o`03001cW00000X001Qoo`/000]cW0/000]cW0/000YcW0@000Eoo`8001Uoo`X000=cW003001oogoo
00=oo`03001cW00000X000]cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0600000goo0000000200002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00000g>LKg]cW0020002Ool200000fmkLi`00009000IOol;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00005Lia_Ng>LKg/00002
Ool300000g>L00000009000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`600000goo00000002000IOol:
000016mkLia_Ng>L0P000Woo0P0000=_N`0000002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0/000]cW0/001Qo
o`/000]cW0/000]cW0/000EcW08000AcW0X001Uoo`/000YcW0/000]cW0/000EcW08000AcW0/001Qo
o`/000]cW0/000]cW0/000YcW0/001Uoo`X000IcW08000=cW0/000]cW0/000]cW0/000moo`006Goo
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo
2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;Li`;0003Li`40003Li`;000;Li`;000;Li`HOol;
Li`;000;Li`;000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;
Li`:000;Li`IOol:Li`;000;Li`;0004Li`40003Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00000fmkLi`00004Ool200000g>L0000000900002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`040004Ool300002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@000Aoo`<0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000Ao
o`<0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000AcW6mkLi`000Aoo`800003Li`0000000T0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/00003Li`007oo00Ioo``000]cW0/000]cW1Qoo`]cW0<0
00Moo`03001cW7>L00UcW0/000]cW0/000YcW1Uoo`]cW0X000]cW0<000Moo`03001cW7>L00UcW0/0
00]cW1Qoo`]cW0<000Moo`03001cW7>L00UcW0/000]cW0X000]cW1Uoo`YcW0/000]cW0/0009cW003
001oogoo00Eoo``000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo
00Ioo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
67oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<001_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0030007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00007Ool<00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000017>L001oogoo0`000Woo30002g>L2`00
2g>L67oo2g>L0P000goo0`000Woo00<007>LLi`02G>L2`002g>L2`002W>L6Goo2g>L2P002g>L0P00
0goo0`000Woo00<007>LLi`02G>L2`002g>L67oo2g>L0P000Woo10000Woo00<007>LLi`02G>L2`00
2g>L2P002g>L6Goo2W>L2`002g>L2`0000AcW000Oomoo`@0009oo``000]cW0moo`006Goo00]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Ioo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0080
00Qoo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk008000Qoo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool200002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/00003Li`007oo00Moo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uo
o`]cW0/00003Li`007oo00Ioo``000]cW0/000]cW1Qoo`]cW0<000Moo`03001cW7>L00UcW0/000]c
W0/000YcW1Uoo`]cW0X000]cW0<000Moo`03001cW7>L00UcW0/000]cW1Qoo`]cW08000Moo`8000]c
W0/000]cW0X000]cW1Uoo`YcW0/000]cW0/00003Li`007oo00Moo``000]cW0moo`006Goo00]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW00000Eoo`03001cW00000X0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00@000Eoo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/010001Goo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
10001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>LKg/000001Goo00<007>L00002P0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`000g>L0P000Woo00<007>LLi`02`002g>L2`002g>L
67oo2g>L1@000Woo10002g>L2`002g>L2`002W>L6Goo2g>L2P002g>L1P0000=oo`0000000P002g>L
2`002g>L67oo2g>L1@000Woo10002g>L2`002g>L2P002g>L6Goo2W>L2`002g>L2`0017>L00<007oo
Ool00P000W>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000E_Ng>LKg]c
W6mk00800003Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00001G>LKg]cW6mkLi`00P0000A_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0/0
00]cW1Qoo`]cW0/000]cW0/000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/000]cW1Qoo`]cW0/0
00]cW0/000]cW0X000]cW1Uoo`YcW0/000]cW0/000]cW0/000]cW0moo`006Goo2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000=_Ng>LKg/0
100000=cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>LKg/01@0000=_
Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/000moo`006Goo0`001Goo0`002g>L2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L0`001Goo
0`002g>L2P006Goo2`000W>L00<007ooOol00Woo0P0000=cW00000002@002g>L2`002g>L2`0067oo
2`002g>L2`000W>L00<007ooOol00goo0P0000=cW00000002@002W>L2`006Goo0`0017oo0`002g>L
2`002g>L2`002g>L2`003goo000IOol20007Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Mo
o`80000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00000fmk001oo`06Ool<00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool00`00Kg/0000:00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`006Goo0P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo0P001goo
0P002g>L2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L0P001goo0P002g>L2P006Goo2`0000=c
W000Ool01Woo30002g>L2`002g>L2`0067oo2`002g>L2`0000=cW000Ool01Woo00<007>L00002P00
2W>L2`006Goo0P001goo00<007>LLi`02G>L2`002g>L2`002g>L2`003goo000IOol20002Ool30003
Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020002Ool30003Ool03000Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0X001Uoo`/00004Kg/007ooOol30002Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
000016mk001oogoo0`000goo300000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`80009oo`<0009o
o`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`8000Moo`8000]cW0X000]cW0/000]cW0/0
01Qoo`/000]cW0/000]cW08000Moo`8000]cW0X001Uoo`/00003Li`007oo00Ioo``000]cW0/000]c
W0/001Qoo`/000]cW0/00003Li`007oo00Ioo`d000YcW0/001Uoo`8000Moo`03001cW7>L00UcW0/0
00]cW0/000]cW0/000moo`006Goo0P001goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool2
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000=_N`00Ool01Woo300000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo00<006mk00002P0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/001Uoo`8000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`@000Aoo`<0
00]cW0X000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0<000Eoo`<000]cW0X001Uoo`/0009cW003
001oogoo00=oo`03001cW00000X000]cW0/000]cW0/001Qoo`/000]cW0/0009cW003001oogoo00=o
o`03001cW7>L00/000YcW0/001Uoo`<000Eoo`8000]cW0/000]cW0/000]cW0/000moo`006Goo2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`00
00=_Ng>LKg/01@0000=_Ng>L00002P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L
Kg/01@0000=_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`00
2g>L2P006Goo2`002W>L2`002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`002W>L2`006Goo2P00
2g>L2`002g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mk
Lia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`]cW0/0
00YcW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0/000=cW0@000=cW1Uoo`]cW0X000]cW0/0
00]cW0/000AcW0@000=cW1Qoo`]cW0/000]cW0/000]cW0X000]cW1Uoo`YcW0/000]cW0/000]cW0/0
00]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mk
Li`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0100017oo0`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW00000Aoo`800003Liaoogoo01Moo`0;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg]cW0000004Ool200000fmkOomoo`0FOol02g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0030004Ool300002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0040004Ool300002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L2`00
2g>L0`001goo00<007>LLi`02G>L67oo2g>L2`002g>L2`002g>L2`0000=cW000Ool01Woo00<007oo
Ool05goo2g>L2P002g>L2`002g>L2`0000=cW000Ool01goo00<007ooOol05Woo2g>L2`002g>L2`00
2g>L0P001goo00<007>LLi`02G>L6Goo2W>L2`002g>L0`001goo00<007>LLi`02G>L2`002g>L3goo
000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW1Qoo`0;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Ioo`03001oogoo01Moo`0;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/00003Kg/007oo00Moo`03001oogoo01Ioo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Mo
o`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk6Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0030007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW08000=oo`<0009oo`03001c
W7>L00UcW1Qoo`]cW0/000]cW0/000]cW0/00004Li`007ooOol30002Ool00`00Oomoo`0GOol;Li`:
000;Li`;000;Li`;000017>L001oogoo0`000goo00<007ooOol05Woo2g>L2`002g>L2`002g>L0P00
0Woo0`000Woo00<007>LLi`02G>L6Goo2W>L2`002g>L0P000goo0`000Woo00<007>LLi`02G>L2`00
2g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020008Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W1Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Ioo`03001oogoo01Moo`0;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/00003Kg/007oo00Ioo`03001_Ngoo01Moo`0;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
008000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk6Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020008Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0<000Moo`03001c
W7>L00UcW1Qoo`]cW0/000]cW0/000]cW0/00003Li`007oo00Ioo`03001oogoo01Moo`]cW0X000]c
W0/000]cW0/00003Li`007oo00Ioo`03001cW7oo01Moo`]cW0/000]cW0/000]cW08000Moo`03001c
W7>L00UcW1Uoo`YcW0/000]cW0<000Moo`03001cW7>L00UcW0/000]cW0moo`006Goo00]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`010001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/00003Kg]cW00000Eoo`03001cW7oo01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004
Kg]cW0000004Ool00`00Lia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030005Ool200002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0040005Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L
2`000g>L1@000W>L6Goo2g>L2P002g>L2`002g>L2`0017>L10000g>L67oo2g>L2`002g>L2`002g>L
2P002g>L6Goo2W>L2`002g>L2`002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]c
W6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2`002g>L
2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`002g>L2P006Goo2`002W>L2`002g>L2`002g>L
2`0067oo2`002g>L2`002g>L2`002W>L2`006Goo2P002g>L2`002g>L2`002g>L2`003goo000IOol;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000A_Ng>LKg]cW0@00003Kg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=c
W6mkLi`01@0000=cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P000g>L00<007ooOol00Woo0P0000=cW00000002@00
2g>L2`0067oo2`002g>L2`000W>L00<007ooOol00goo0P0000=cW00000002@002g>L2P006Goo2`00
2W>L2`002g>L100017oo0`002g>L2`0067oo100017oo0`002g>L2`002g>L2`002W>L2`006Goo2P00
2g>L2`002g>L2`002g>L0`001Goo0`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2P0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`06Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0030007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Qoo`<000Moo`0<001_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool2000?Ool001Uoo`/0
00]cW0X0009cW003001oogoo00Eoo``000]cW0/001Qoo`/000]cW0/00003Li`007oo00Ioo`03001c
W00000X000]cW0X001Uoo`/000YcW0/000]cW0<000Moo`03001cW7>L00UcW0/001Qoo`<000Moo`03
001cW7>L00UcW0/000]cW0/000YcW0/001Uoo`X000]cW0/000]cW0/000]cW08000Moo`8000moo`00
6Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X00003Kg]cW000009oo`<0009oo``0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000Ac
W000Oomoo`<000=oo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00002VmkLia_Ng>L
Kg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000=oo`<0009oo`0<001cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L2`0067oo0P000goo0`000Woo00`006mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uo
o`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk0080009oo`<000=oo`03001oogoo00eoo`006Goo2`002g>L
2P000W>L00<007ooOol01Goo30002g>L2`0067oo2`002g>L2`0000=cW000Ool01Woo00<007>L0000
2P002g>L2P006Goo2`002W>L2`002g>L0`001goo00<007>LLi`02G>L2`0067oo0`001goo00<007>L
Li`02G>L2`002g>L2`002W>L2`006Goo2P002g>L2`002g>L2`002g>L0P001goo0P003goo000IOol;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`06Ool0
0`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030007Ool03000Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/001Qoo`<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`020007Ool2000?Ool001Uoo`/000]cW0X000=cW003001oogoo00=oo`03001cW00000X0
00]cW0/001Qoo`/000]cW0/0009cW08000Aoo`03001cW7>L00/000]cW0X001Uoo`/000YcW0/000]c
W0@000Eoo`8000]cW0/001Qoo`@000Eoo`8000]cW0/000]cW0/000YcW0/001Uoo`X000]cW0/000]c
W0/000]cW0<000Eoo`<000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X00004Kg]c
W6mkLi`500000g>LKg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>LKg/400000g>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`;
000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:Li`;000;Li`;000;Li`;000HOol;
000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;Li`;000?Ool00?mooomoo`Qoo`00
ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomo
o`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool0
0?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOooo
Ool8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo
003oOoooOol8Ool00?mooomoo`Qoo`006Goo2`000g>L100017>L2P002g>L2`002g>L2`0067oo2`00
17>L10000g>L2`002g>L2`002g>L2P006Goo2`000g>L10000g>L2`002g>L2`002g>L2`0067oo2`00
17>L10000g>L2`002g>L2`002W>L2`006Goo2P0017>L10000g>L2`002g>L2`002g>L2`003goo000I
Ool;00000g>LKg/00004Ool200000fmkLi`0000900002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/00004Lia_Ng>L0004Ool200000g>L00000009
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uo
o`/00003Kg]cW00000Aoo`800003Li`0000000T0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000A_Ng>LKg/000Aoo`800003Kg/0000000T0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P00
00A_Ng>LKg/000Aoo`800003Kg/0000000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;00000g>L001oo`06Ool00`00Li`00009000;
Li`;000;Li`;000HOol;0002Li`00`00Oomoo`05Ool<000;Li`;000;Li`:000IOol;00000g>L001o
o`06Ool<000;Li`;000;Li`;000HOol;0002Li`00`00Oomoo`05Ool<000;Li`;000:Li`;000IOol:
0002Li`00`00Oomoo`05Ool<000;Li`;000;Li`;000?Ool001Uoo`/00003Li`007oo00Ioo`03001c
W00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0067oo2`0000=cW6mk00001goo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00:000IOol;00000fmk001oo`06Ool<00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/00003Kg]cW00000Moo``0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000=_
Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;000?Ool001Uoo`/00004Li`007ooOol30002Ool<000;Li`;000;Li`;000HOol;00000g>L
001oo`02Ool30002Ool<000;Li`;000;Li`:000IOol;000017>L001oogoo0`000Woo30002g>L2`00
2g>L2`0067oo2`0000AcW000Oomoo`@0009oo``000]cW0/000YcW0/001Uoo`X0009cW003001oogoo
00<0009oo``000]cW0/000]cW0/000moo`006Goo2`0000=cW000Ool01Woo00<007>L00002@0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;0000
0g>L001oo`07Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X001Uoo`/00003Kg/007oo00Ioo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000=_N`00Ool01Woo3@0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00000fmkLi`00007Ool<
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000mo
o`006Goo2`0000=cW000Ool01Woo00<007>L00002@002g>L2`002g>L2`0067oo2`000W>L00<007oo
Ool01Goo30002g>L2`002g>L2P006Goo2`0000=cW000Ool01Woo30002g>L2`002g>L2`0067oo2`00
00=cW000Ool01Woo00<007>L00002P002g>L2`002W>L2`006Goo2P000W>L00<007ooOol01Goo3000
2g>L2`002g>L2`003goo000IOol;00000g>LKg/00005Ool00`00Kg]cW00:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/00004Lia_N`000005
Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X001Uoo`/00003Kg]cW00000Eoo`03001cW00000X0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000A_Ng>L000000Eoo`03001_
N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
6Goo2P0000A_Ng>LKg/000Eoo`03001_N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;0003Li`50003Li`:000;Li`;000;Li`;
000HOol;0004Li`50002Li`;000;Li`;000;Li`:000IOol;0003Li`50002Li`;000;Li`;000;Li`;
000HOol;0004Li`50002Li`;000;Li`;000:Li`;000IOol:0004Li`50002Li`;000;Li`;000;Li`;
000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0
01Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`002g>L2`00
67oo2`002g>L2`002g>L2`002g>L2P006Goo2`002W>L2`002g>L2`002g>L2`0067oo2`002g>L2`00
2g>L2`002W>L2`006Goo2P002g>L2`002g>L2`002g>L2`003goo000IOol02fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLia_N`0500000fmkLia_N`0;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;000016mkLia_Ng>L100000=_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000=cW6mkLi`0100000A_Ng>LKg]cW0X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02Vmk
Lia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`4
0004Ool3000;Li`;000;Li`HOol;Li`;000;Li`;0002Li`00`00Oomoo`03Ool200000g>L00000009
000:Li`IOol;Li`:000;Li`;0003Li`00`00Oomoo`02Ool200000g>L00000009000;Li`HOol;Li`;
000;Li`;0002Li`00`00Oomoo`02Ool20002Li`:000;Li`IOol:Li`;000;Li`;000;Li`40004Ool3
000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00000fmk001oo`06Ool00`00Kg/0000:00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLi`00007Ool<
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`06Ool00`00Li`0000900002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P0027oo00`007>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`?Ool001Uoo`]cW0/000YcW0<000Moo`03001cW7>L00UcW0/000]cW1Qoo`]cW0/000]c
W0/00003Li`007oo00Ioo`03001cW00000X000YcW1Uoo`]cW0X000]cW0/0009cW003001oogoo00Eo
o``000]cW1Qoo`]cW0/000]cW0/00003Li`007oo00Ioo`03001cW00000T000]cW1Uoo`YcW0/000]c
W0/000]cW08000Qoo`03001cW7>L00UcW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`30002Ool30002Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg/007ooOol30003Ool<00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00000fmk001oo`02Ool30002Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>L001o
ogoo0`000Woo00<007>L00002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L0080009oo`<000=oo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3goo000IOol;Li`;000:
Li`30007Ool00`00LiacW009Li`;000;Li`HOol;Li`;000;Li`;00000g>L001oo`06Ool00`00Li`0
000:000:Li`IOol;Li`:000;Li`;0002Li`00`00Oomoo`05Ool<000;Li`HOol;Li`;000;Li`;0000
0g>L001oo`06Ool00`00Li`00009000;Li`IOol:Li`;000;Li`;000;Li`20007Ool2000;Li`?Ool0
01Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo
00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001o
o`06Ool00`00Kg/0000:00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLi`00007Ool<00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00000g>L001oo`06Ool00`00Li`0000900002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P001goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00moo`006Goo2g>L2`002W>L10001Goo0P002g>L2`002g>L67oo2g>L2`002g>L2`000W>L00<007oo
Ool00goo00<007>LLi`02`002W>L6Goo2g>L2P002g>L2`000W>L0P001Goo00<007>L00002P002g>L
67oo2g>L2`002g>L2`000W>L00<007ooOol00goo00<007>LLi`02P002g>L6Goo2W>L2`002g>L2`00
2g>L100017oo0`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]c
W6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00000fmkLia_N`0500000fmkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLia_
Ng>L1@0000=cW6mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mkLi`01@0000=cW6mk
Li`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0/000]cW1Qoo`]cW0/000]c
W0/000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0X000]c
W1Uoo`YcW0/000]cW0/000]cW0/000]cW0moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
67oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000I
Ool;000;Li`:000;Li`;0004Li`40003Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:
Li`;000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;
Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000A_Ng>LKg/000Aoo`800003Kg/0000000T001Qoo`@000Aoo`<0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`40004Ool300002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]c
W6mkLia_Ng>LKg]cW0@000Aoo`<001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`040004Ool3
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000mo
o`006Goo2`002g>L2P002g>L2`000W>L00<007ooOol01Goo300067oo0`001goo00<007>LLi`02G>L
2`002g>L2`002g>L2P006Goo2`002W>L0`001goo00<007>LLi`02G>L2`002g>L2`0067oo2`002g>L
2`002g>L2`002W>L0`001goo00<007ooOol05goo2P002g>L0`001goo00<007>LLi`02G>L2`002g>L
2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/00003Kg]cW00000Moo``001Qoo`<000Moo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000I
Ool;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo
00<007ooOol05goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P00
2g>L2`0000=cW000Ool00Woo0`000Woo300067oo0P000goo0`000Woo00<007>LLi`02G>L2`002g>L
2`002g>L2P006Goo2`002W>L0`000Woo0`000Woo00<007>LLi`02G>L2`002g>L2`0067oo2`002g>L
2`002g>L2`002W>L0P000goo0`000Woo00<007ooOol05goo2P002g>L0P000goo0`000Woo00<007>L
Li`02G>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW00000Moo``001Qoo`<000Moo`0<001cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L0`001goo00<007ooOol05goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<
001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`00
6Goo2`002g>L2P002g>L2`000W>L00<007ooOol01Goo300067oo0`001goo00<007>LLi`02G>L2`00
2g>L2`002g>L2P006Goo2`002W>L0`001goo00<007>LLi`02G>L2`002g>L2`0067oo2`002g>L2`00
2g>L2`002W>L0`001goo00<007ooOol05goo2P002g>L0`001goo00<007>LLi`02G>L2`002g>L2`00
3goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/00004Kg]cW0000005Ool00`00Kg/0000:000HOol40005Ool200002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00:000IOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L10001Goo0P0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`40005Ool2000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/010001Goo0P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/0
00]cW0X000]cW0/000AcW0D0009cW0/001Qoo`/000]cW0/000]cW0/000]cW0X001Uoo`/000YcW0/0
00]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/000YcW0/001Uoo`X000]cW0/000]cW0/000]cW0/0
00moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
6Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol5Li`20004Li`;000:Li`;000;Li`;
000;Li`HOol;Li`;000;Li`;000;Li`;000:Li`IOol5Li`00`00LiacW003Li`:000;Li`;000;Li`;
000;Li`HOol;Li`;000;Li`;000;Li`:000;Li`IOol:Li`;000;Li`;000;Li`;0005Li`20004Li`?
Ool001Uoo`03Kg]cW0000080009oo`800003Lia_N`0000X0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/01@000Woo1000
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol00g>LKg/0
000200001Woo000007>LKg]cW0X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`01@000Woo100000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00000g>LKg/000020002Ool200000fmkLiaoo`0>Ool001Uoo`9cW003001oogoo00Aoo`03001c
W00000X000YcW0/000]cW0/000]cW1Qoo`]cW0/000]cW0<000Ioo`8000]cW0/000YcW1Uoo`9cW003
001oogoo00=oo`800003Li`0000000P000]cW0/000]cW0/000]cW1Qoo`]cW0/000]cW0<000Ioo`80
00]cW0X000]cW1Uoo`YcW0/000]cW0/000]cW0/0009cW003001oogoo00Aoo`03001cW7oo00ioo`00
6Goo00=_N`00Ool01Woo00<006mk00002P0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020007Ool200002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`03Li`007oo00Ioo`03001c
W00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P001goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>L001oo`06
Ool00`00Liaoo`0>Ool001Uoo`03Li`007oo00Moo``000YcW0/000]cW0/000]cW1Qoo`]cW0/000]c
W08000Qoo`03001cW7>L00UcW0/000YcW1Uoo`03Li`007oo00Ioo`03001cW00000T000]cW0/000]c
W0/000]cW1Qoo`]cW0/000]cW08000Qoo`03001cW7>L00UcW0X000]cW1Uoo`YcW0/000]cW0/000]c
W0/00003Li`007oo00Moo`03001oogoo00eoo`006Goo00A_N`00Oomoo`<000=oo``0000:Kg]cW6mk
Lia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/00P000Woo0`000goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L6Goo00AcW000Oomoo`<0009oo``0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P000Woo0`000goo
00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000AcW000Oomoo`<000=oo`03001oogoo00eoo`006Goo00=cW000Ool0
1Woo00<007>L00002P002W>L2`002g>L2`002g>L67oo2g>L2`002g>L0P001goo0P002g>L2`002W>L
6Goo00=cW000Ool01Woo00<007>L00002@002g>L2`002g>L2`002g>L67oo2g>L2`002g>L0P001goo
0P002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`0000=cW000Ool01Woo00<007>LOol03Woo000I
Ool00fmk001oo`05Ool00`00Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Ioo`<0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00=cW000Ool01Goo00<006mk
Li`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020006Ool300002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Eo
o`03001_Ng>L00moo`006Goo0W>L0P0017oo00<007>LLi`02`002W>L2`002g>L2`002g>L67oo2g>L
2`002g>L100017oo0`002g>L2`002W>L6Goo0W>L00<007ooOol00goo00<007>LLi`02P002g>L2`00
2g>L2`002g>L67oo2g>L2`002g>L0`001Goo0`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`00
0W>L00<007ooOol00goo00<007>LLi`03goo000IOol016mkLia_Ng>L100000=_Ng>LKg/02`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW1Uoo`03Lia_Ng>L00D00003Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00000g>LKg]cW00500000g>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0/000]cW1Qo
o`]cW0/000]cW0/000]cW0/000YcW1Uoo`]cW0X000]cW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/0
00]cW0X000]cW1Uoo`YcW0/000]cW0/000]cW0/000]cW0moo`006Goo2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/00004Kg]cW6mkLi`3000017>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
00moo`006Goo2`002g>L0`000goo10002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`002g>L0`00
0goo10006Goo2`002W>L2`002g>L2`002g>L10000goo100067oo10000goo10002g>L2`002g>L2`00
2W>L2`006Goo2P002g>L2`000g>L00@007ooOomoo`80009cW0/000]cW0/000moo`006Goo2`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Eoo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001Goo
0P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001Woo0P0067oo10001Goo0P0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg]cW6mk0005Ool00`00
Kg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`20007Ool00`00
LiacW009Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`20007Ool00`00Oomoo`0GOol;000:
Li`;000;Li`;000;Li`20008Ool00`00Oomoo`0FOol30007Ool00`00LiacW009Li`;000;Li`;000:
Li`;000IOol:000;Li`;0002Li`00`00Oomoo`05Ool<000;Li`;000?Ool001Uoo`/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0020007Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020007Ool00`00Oomo
o`0GOol;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020008Ool00`00Oomoo`0FOol20008Ool03000Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg/007oo00Moo``0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW080009oo`<0009oo`03001c
W7>L00UcW0/000]cW0/001Qoo`/000]cW0/000]cW0/000]cW080009oo`<0009oo`03001oogoo01Mo
o`/000YcW0/000]cW0/000]cW080009oo`<000=oo`03001oogoo01Ioo`8000=oo`<0009oo`03001c
W7>L00UcW0/000]cW0/000YcW0/001Uoo`X000]cW0/00003Li`007oo009oo`<0009oo``000]cW0/0
00moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`0<001_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L008000Moo`03001oogoo01Moo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`8001Qoo`<0
00Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00=_Ng>L00001goo300000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L0P00
1Woo0P002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`002g>L0P001Woo0P006Goo2`002W>L2`00
2g>L2`002g>L0P001Woo0`0067oo0`001Woo0P002g>L2`002g>L2`002W>L2`006Goo2P002g>L2`00
0W>L00<007ooOol017oo00<007>L00002P002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`00`001Goo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030005Ool2000IOol;00002Vmk
Lia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0040004Ool3000HOol40005Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>L000000Eoo`03001_N`0000X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000]cW0X000]cW0/000]cW0/001Qoo`/000]c
W0/000]cW0/000]cW0X001Uoo`/000YcW0/000]cW0/000]cW0/001Qoo`/000]cW0/000]cW0/000Yc
W0/001Uoo`X000]cW0/000AcW0D0009cW0/000]cW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`003goo000IOol;Li`;000:Li`;0004Li`30004Li`;000;Li`HOol;Li`;0004Li`30004Li`;000;
Li`;000:Li`IOol;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;0003Li`40004Li`;000;Li`:000;
Li`IOol3Li`30004Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000AcW6mkLi`000=oo`800003Kg]cW00000X0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_
Ng>LKg/000=oo`800003Lia_N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`040003Ool400002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00004Ool20000
0fmkLi`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk01Uoo`03Kg]cW00000=oo`800003Kg]cW00000X0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`00
6Goo2g>L2`002W>L2`000g>L00<007ooOol00goo00<007>L00002P002g>L67oo2g>L2`000g>L00<0
07ooOol00goo00<007>L00002P002g>L2`002W>L6Goo2g>L2P002g>L10001Goo0P002g>L2`002g>L
67oo2g>L2`000W>L00<007ooOol017oo00<007>L00002P002g>L2P002g>L6Goo0W>L00<007ooOol0
0goo00<007>L00002P002g>L2`002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00003Lia_N`0000Moo``0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L00001goo300000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00000g>L001oo`07Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uoo`03Kg/007oo00Ioo``0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00moo`006Goo2g>L2`002W>L2`0000=cW000Ool00Woo0`000Woo30002g>L67oo2g>L2`0000AcW000
Oomoo`@0009oo``000]cW0/000YcW1Uoo`]cW0X000]cW08000=oo`<0009oo`03001cW7>L00UcW0/0
00]cW1Qoo`]cW0/00004Li`007ooOol30003Ool<000;Li`:000;Li`IOol017>L001oogoo0`000Woo
30002g>L2`002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0/00003Li`007oo00Moo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00H
Ool02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_N`00Ool01Woo3@0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Qoo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
00000g>L001oo`06Ool=00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk01Uoo`03Kg/007oo00Ioo``0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L
2`002W>L2`000W>L00<007ooOol01Goo30002g>L67oo2g>L2`0000=cW000Ool01Woo00<007>L0000
2P002g>L2`002W>L6Goo2g>L2P002g>L0`001goo00<007>LLi`02G>L2`002g>L67oo2g>L2`0000=c
W000Ool01Woo00<007>L00002P002g>L2P002g>L6Goo00=cW000Ool01Woo30002g>L2`002g>L2`00
2g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/00004Lia_Ng>L0005Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg]cW0000005Ool00`00Kg/0000:00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/010001Goo0P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000AcW6mk000000Aoo`03001_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00=_Ng>L00001Goo00<007>L00002P0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`;0004Li`20003Ool00`00Li`0000:000;Li`H
Ool;Li`;0004Li`00`00Oomoo`02Ool00`00Li`0000:000;Li`;000:Li`IOol;Li`:000;Li`60003
Ool2000;Li`;000;Li`HOol;Li`;0004Li`01@00Oomoogoo00000W>L2`002g>L2P002g>L6Goo0g>L
0P000goo00<007>L00002P002g>L2`002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00006Lia_Ng>LKg]cW6mk0`0000=_Ng>L0000
2P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
1FmkLia_Ng>LKg/0100000=cW6mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00005Lia_Ng>LKg]cW00300000g>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01Uoo`05Kg]cW6mkLia_N`0300000fmkLi`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uo
o`]cW0/000YcW0/000]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0/000YcW1Uoo`]cW0X000]cW0/0
00]cW0/000]cW1Qoo`]cW0/000]cW0/000]cW0X000]cW1Uoo`YcW0/000]cW0/000]cW0/000]cW0mo
o`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg]cW00300001G>LKg]cW6mkLi`0
2P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
000017>LKg]cW6mk0`0000A_Ng>LKg]cW0/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>LKg/00`0000A_Ng>LKg]cW0/001Uoo`X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L2`002g>L10000goo1000
67oo2`002g>L2`002g>L2`000W>L00@007ooOomoo`8000=cW0X001Uoo`/000YcW0/000]cW0/000=c
W004001oogooOol20002Li`;000HOol;000;Li`;000;Li`;0002Li`01000Oomoogoo0P000W>L2`00
6Goo2P002g>L2`002g>L10000goo10002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`030006Ool2000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/00003Li`007oo00Eoo`03001_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mk00001Woo00<007>L00002P00
67oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00000fmk001oo`05Ool00`00Li`0000:000IOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Ioo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
000?Ool001Uoo`/000]cW0X000]cW0/000]cW0<000Moo`03001oogoo01Ioo`/000]cW0/000]cW0/0
0003Li`007oo00Ioo`03001cW00000T001Uoo`/000YcW0/000]cW0/0009cW003001oogoo00Eoo``0
01Qoo`/000]cW0/000]cW0/00003Li`007oo00Ioo``001Uoo`X000]cW0/000]cW0<000Moo`03001c
W7>L00UcW0/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000Woo10000Woo00<007oo
Ool05Woo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;000017>L001oogoo0`000Woo00<007>L00002@006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>L001oogoo10000Woo300067oo2`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mk001o
ogoo0`000Woo30006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`020002Ool40002Ool03000Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`/000moo`006Goo
2`002g>L2P002g>L2`002g>L0P0027oo00<007ooOol05Woo2`002g>L2`002g>L2`0000=cW000Ool0
1Woo00<007>L00002@006Goo2`002W>L2`002g>L2`0000=cW000Ool01goo300067oo2`002g>L2`00
2g>L2`0000=cW000Ool01Woo30006Goo2P002g>L2`002g>L0P0027oo00<007>LLi`02G>L2`003goo
000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`020008Ool00`00Oomoo`0FOol;00002g>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03
001cW00000T001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000=cW000Ool01goo300067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool<000IOol:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Qoo`0<001_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk2`003goo000IOol;000;Li`:000;Li`;000;Li`40005Ool2000HOol;000;Li`;
000;Li`;0002Li`00`00Oomoo`03Ool00`00LiacW00:000IOol;000:Li`;000;Li`;0002Li`20005
Ool00`00Li`0000:000HOol;000;Li`;000;Li`;0002Li`00`00Oomoo`03Ool00`00Li`0000:000I
Ool:000;Li`;000;Li`40005Ool2000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00D0009oo`@001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000=cW6mkLi`00P000Woo00@007>LKg]cW0X001Uoo`/0000:Kg]cW6mkLia_Ng>L
Kg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000EcW6mkLia_N`00009oo`800003
Kg]cW00000X001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000=_Ng>LKg/00P000Woo00<006mkLi`02`006Goo2P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`050002Ool400002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`;000;Li`;000HOol;000;Li`;000;Li`;
0005Li`20004Li`:000IOol;000:Li`;000;Li`;0005Li`20004Li`;000HOol;000;Li`;000;Li`;
0005Li`20003Li`;000IOol:000;Li`;000;Li`;000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/000moo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOooo
Ool8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo
003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogoo
ogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qo
o`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`006Goo2`002g>L2P002g>L2`002g>L2`00
67oo2`002g>L2`002g>L2`002g>L2P006Goo2`002W>L2`002g>L2`002g>L2`0067oo2`002g>L2`00
2g>L2`002W>L2`006Goo2P0017>L0`0017>L2`002g>L2`002g>L2`003goo000IOol30004Ool40000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol40003Ool400002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000I
Ool30003Ool500002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol40003Ool400002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mk
Li`;000IOol:000016mkLia_N`000goo0P0000=cW6mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`<000Ioo`8000]cW0X000]c
W0/000]cW0/001Qoo`@000Eoo`8000]cW0/000]cW0/000]cW0X001Uoo`<000Eoo`<000YcW0/000]c
W0/000]cW0/001Qoo`@000Eoo`8000]cW0/000]cW0/000YcW0/001Uoo`X000=cW003001oogoo00=o
o`03001cW00000X000]cW0/000]cW0/000moo`006Goo0P001goo0P0000]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0067oo0`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`8000Moo`80000:Kg]cW6mk
Lia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/001Qoo`<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:00000fmkLi`00007
Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
00moo`006Goo0P0027oo00<007>LLi`02G>L2P002g>L2`002g>L2`0067oo0P0027oo00<007>LLi`0
2G>L2`002g>L2`002g>L2P006Goo0P001goo0P002W>L2`002g>L2`002g>L2`0067oo0P0027oo00<0
07>LLi`02G>L2`002g>L2`002W>L2`006Goo2P000W>L00<007ooOol01Goo30002g>L2`002g>L2`00
3goo000IOol20003Ool00`00Oomoo`02Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0X0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo0P0017oo
010007ooOomoo`00Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo0P000goo00@007ooOomoo`80000:Kg]c
W6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/001Qoo`8000Aoo`0@001oogooOol006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0
0003Kg]cW00000=oo`04001oogooOol<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo0P001goo0P002g>L2P002g>L2`002g>L2`0067oo
0`001goo00<007>LLi`02G>L2`002g>L2`002g>L2P006Goo0P001goo0P002W>L2`002g>L2`002g>L
2`0067oo0`001goo00<007>LLi`02G>L2`002g>L2`002W>L2`006Goo2P000W>L00<007ooOol01Goo
30002g>L2`002g>L2`003goo000IOol30005Ool300002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol4
0005Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol30005Ool300002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;000HOol30006Ool200002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;000IOol:000016mkLia_N`001Goo00<0
06mk00002P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;000?Ool001Uoo`@000Aoo`<000]cW0X000]cW0/000]cW0/001Qoo`@000Eoo`8000]cW0/000]c
W0/000]cW0X001Uoo`<000Eoo`<000YcW0/000]cW0/000]cW0/001Qoo`@000Eoo`8000]cW0/000]c
W0/000YcW0/001Uoo`X000=cW003001oogoo00=oo`03001cW00000X000]cW0/000]cW0/000moo`00
6Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
6Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P00
00A_Ng>LKg]cW0D00003Lia_N`0000X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`;000;Li`;000HOol;000;Li`;
000;Li`;000;Li`:000IOol;000:Li`;000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000:Li`;
000IOol:000;Li`;000;Li`;000;Li`;000?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00000fmkLia_N`03000016mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;000016mkLia_Ng>L0`0000AcW6mkLia_N`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0H
Ool02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`000W>L00@0
07ooOomoo`80009cW0/000]cW0/000]cW1Qoo`]cW0/000]cW0<000Aoo`@000]cW0/000YcW1Uoo`]c
W0X000]cW0/000=cW004001oogooOol20002Li`;000;Li`HOol;Li`;000;Li`;000;Li`30003Ool4
000;Li`IOol:Li`;000;Li`40003Ool4000;Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00000fmkLi`00005Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00`001Woo0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg]cW6mk0005Ool00`00Kg/0000:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001Goo0P0000]_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`010001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00?Ool001Uoo`]cW0/00003Li`007oo00Ioo``000]cW0/000]cW1Qoo`]cW0/000]cW08000Mo
o`8000]cW0/000YcW1Uoo`]cW0X000]cW0/0009cW003001oogoo00Eoo``000]cW1Qoo`]cW0/000]c
W0/000]cW08000Moo`03001cW7>L00UcW1Uoo`YcW0/000]cW0<000Moo`03001cW7>L00UcW0/000]c
W0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg/007ooOol30002Ool<00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L01Qoo`0;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000Woo0`000goo00`0
06mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`02Ool3
0002Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00P00
0Woo0`000Woo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000=oo`<0009oo`0<001cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`0000=cW000Ool01Woo
30002g>L2`002g>L67oo2g>L2`002g>L0P001goo0P002g>L2`002W>L6Goo2g>L2P002g>L2`0000=c
W000Ool01goo30002g>L67oo2g>L2`002g>L2`002g>L0P001goo00<007>LLi`02G>L6Goo2W>L2`00
2g>L0P0027oo00<007>LLi`02G>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000=_N`00Ool01Woo300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk008000Moo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00000fmkLi`00007Ool<00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/067oo00]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`00P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/IOol02VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Moo`0<001cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`000W>L00<007ooOol0
0goo00<007>L00002P002g>L2`002g>L67oo2g>L2`002g>L100017oo0`002g>L2`002W>L6Goo2g>L
2P002g>L2`000W>L0P001Goo00<007>L00002P002g>L67oo2g>L2`002g>L2`002g>L0`001Goo0P00
2g>L6Goo2W>L2`002g>L10001Goo0P002g>L2`002g>L3goo000IOol02fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000=_Ng>LKg/00P000Woo0P0000=cW00000002@0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00D0009oo`@0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000016mkLia_Ng>L0P0000Eoo`00000006mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0050002Ool300002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00600000goo0000000200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`001G>L0P000g>L2`002g>L2`002g>L67oo2g>L
2`002g>L2`002g>L2`002W>L6Goo2g>L2P002g>L2`001W>L00<007>LLi`00W>L2`002g>L67oo2g>L
2`002g>L2`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`002g>L3goo000IOol02fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00mo
o`006Goo2`002g>L2P002g>L2`002g>L2`0067oo2`002g>L2`002g>L2`002g>L2P006Goo2`000g>L
10000g>L2`002g>L2`002g>L2`0067oo2`002g>L2`000g>L1@000g>L2`002W>L2`006Goo2P002g>L
2`002g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00@000Aoo`<0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;
00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030004Ool3000IOol;00000fmkLi`00004Ool200000g>L0000
000900002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
01Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmkLi`00005Ool200000fmk00000009
00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo0`0017oo0`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`003goo000IOol;000;Li`:000;Li`30007Ool00`00LiacW009Li`;000HOol;000;Li`;000;Li`;
000;Li`20007Ool00`00Oomoo`0GOol;00000g>L001oo`06Ool<000;Li`;000;Li`;000HOol;000;
Li`;00000g>L001oo`06Ool00`00Li`0000:000:Li`;000IOol20007Ool00`00LiacW009Li`;000;
Li`;000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/00`001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;000HOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0020007Ool00`00Oomoo`0GOol;00000fmk001oo`06Ool<00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool00`00Kg/0000:00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`006Goo0P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L
2P002g>L0P000goo0`000Woo00<007>LLi`02G>L2`0067oo2`002g>L2`002g>L2`002g>L0P000Woo
0`000Woo00<007ooOol05goo2`0000AcW000Oomoo`<0009oo``000]cW0/000]cW0/001Qoo`/000]c
W0/00004Li`007ooOol30003Ool<000:Li`;000IOol20002Ool30002Ool00`00LiacW009Li`;000;
Li`;000;Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/00P0027oo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;000HOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0020007Ool00`00Oomoo`0GOol;00000fmk001oo`06Ool<00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool=00002VmkLia_Ng>LKg]cW6mkLia_Ng>L
2`006Goo0P001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`006Goo2`002g>L2P002g>L0`00
1goo00<007>LLi`02G>L2`0067oo2`002g>L2`002g>L2`002g>L0P001goo00<007ooOol05goo2`00
00=cW000Ool01Woo30002g>L2`002g>L2`0067oo2`002g>L2`0000=cW000Ool01Woo00<007>L0000
2P002W>L2`006Goo0P001goo00<007>LLi`02G>L2`002g>L2`002g>L2`003goo000IOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@000Eoo`80000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030005Ool2
000IOol;00000fmkLi`00005Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
00000fmkLi`00005Ool00`00Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo0`001Goo
0P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`003goo000IOol;000;Li`:000;Li`600000goo00000002
000;Li`;000HOol;000;Li`;000;Li`;000;Li`50002Ool3000IOol;0003Li`20002Ool00`00Liac
W00;000;Li`;000;Li`;000HOol;000;Li`;0003Li`20002Ool01000LiacW7>L2`002W>L2`006Goo
1@000Woo0`002g>L2`002g>L2`002g>L2`003goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:000IOol;00001FmkLia_Ng>LKg/00P0000=cW6mk
Li`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;
000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000E_Ng>LKg]cW6mk00800004Lia_Ng>L
Kg/;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`00
3goo000IOol;000;Li`:000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:
Li`;000;Li`;000;Li`;000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;
Li`;000?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00004Lia_Ng>LKg/400000g>LKg]cW00HOol0
2fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>LKg]cW0@00003Kg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg]cW005
00000g>LKg]cW00?Ool001Uoo`]cW0/000YcW0/000]cW0/000=cW003001oogoo009oo`800003Liao
ogoo01Ioo`]cW0/000=cW003001oogoo009oo`800003Li`0000000T000]cW0/000YcW1Uoo`]cW0X0
00]cW0/000]cW0@000Aoo`<000]cW1Qoo`]cW0@000Aoo`<000]cW0/000]cW0X000]cW1Uoo`YcW0/0
00]cW0/000]cW0/0009cW003001oogoo00=oo`800003Liaoogoo00eoo`006Goo00]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02`0000=cW6mk00001goo00<007ooOol05Woo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0
0003Kg]cW00000Moo``0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00`001goo00`006mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`00`001goo00`007>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Uo
o`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW7oo00ioo`006Goo2g>L2`002W>L
2`002g>L2`000W>L00<007ooOol01Goo00<007ooOol05Woo2g>L2`000W>L00<007ooOol01Goo3000
2g>L2`002W>L6Goo2g>L2P002g>L2`002g>L0`001goo00<007>LLi`02G>L67oo2g>L0`001goo00<0
07>LLi`02G>L2`002g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`0000=cW000Ool01Woo00<007>L
Ool03Woo000IOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>L001oogoo10000Woo00<007ooOol05Woo
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg/007ooOol40002Ool<00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
0080009oo`@0009oo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk67oo00]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L0080009oo`@0009oo`0<001cW6mkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mk
Lia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;000017>L001oogoo0`000goo00<007ooOol03Goo000IOol;Li`;000:Li`;000;Li`;00000g>L
001oo`07Ool00`00Oomoo`0FOol;Li`;00000g>L001oo`06Ool=000;Li`;000:Li`IOol;Li`:000;
Li`;000;Li`20008Ool00`00LiacW009Li`HOol;Li`20007Ool2000;Li`;000;Li`:000;Li`IOol:
Li`;000;Li`;000;Li`;00000g>L001oo`06Ool2000?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
0003Li`007oo00Moo`03001oogoo01Ioo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001o
o`06Ool00`00Kg/0000:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_
Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Qoo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk67oo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L008000Moo`80000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
01Uoo`0:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW7oo00ioo`006Goo2g>L2`00
2W>L2`002g>L2`000W>L0P001Goo00<007>LOol05goo2g>L2`000W>L0P001Goo00<007>L00002P00
2g>L2`002W>L6Goo2g>L2P002g>L2`002g>L10001Goo0P002g>L67oo2g>L10001Goo0P002g>L2`00
2g>L2P002g>L6Goo2W>L2`002g>L2`002g>L2`000W>L00<007ooOol00goo00<007>LLi`03goo000I
Ool02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;000017>LKg]cW6mk1@0000=_Ng>LOol05goo00]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/00004Kg]cW6mkLi`500000g>LKg/0000:00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0HOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mkLi`01@0000=cW6mkLi`0
3goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`;000:Li`IOol;Li`:
000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`:000;Li`IOol:Li`;000;Li`;000;Li`;
000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_
Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00H
Ool02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L6Goo00]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk01Qoo`0;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;0003Li`40004Li`:000;Li`;000;Li`;000HOol;
000;Li`;000;Li`;0003Li`40004Li`:000IOol;000:Li`;000;Li`;000;Li`;000HOol;000;Li`;
000;Li`;000:Li`;000IOol:000;Li`;000;Li`;000;Li`;000?Ool001Uoo`/00003Lia_N`0000Ao
o`800003Kg]cW00000T0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;00000g>LKg/00004Ool200000fmkLi`00009000IOol;00002VmkLia_Ng>LKg]c
W6mkLia_Ng>L100017oo0`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`40004Ool3000IOol:00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@000Aoo`<0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/00003Li`007oo00Ioo`03001cW00000T000]c
W0/000]cW0/001Qoo`/000]cW0/000]cW0/00003Li`007oo00Ioo`03001cW00000T001Uoo`/000Yc
W0<000Moo`03001cW7>L00UcW0/000]cW0/001Qoo`/000]cW0/000]cW0/000YcW0<000Moo`03001o
ogoo01Moo`X000]cW0/000]cW0<000Moo`03001cW7>L00UcW0/000moo`006Goo2`0000=cW000Ool0
1Woo00<007>L00002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW00000T001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`30007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`30007Ool00`00Oomoo`0GOol:00002fmkLia_
Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk2`003goo000IOol;000017>L001oogoo0`000Woo30002g>L2`002g>L
2`0067oo2`002g>L2`002g>L2`0000AcW000Oomoo`<0009oo`03001cW00000T001Uoo`/000YcW0<0
009oo`<0009oo`03001cW7>L00UcW0/000]cW0/001Qoo`/000]cW0/000]cW0/000YcW08000=oo`<0
009oo`03001oogoo01Moo`X000]cW0/000]cW080009oo`@0009oo`03001cW7>L00UcW0/000moo`00
6Goo2`0000=cW000Ool01Woo00<007>L00002@0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000HOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW00000T001Uoo`/0000:
Kg]cW6mkLia_Ng>LKg]cW6mkLi`30007Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`20008Ool00`00Oomo
o`0GOol:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
008000Qoo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`003goo000IOol;00000g>L001oo`06Ool0
0`00Li`00009000;Li`;000;Li`;000HOol;000;Li`;000;Li`;00000g>L001oo`06Ool00`00Li`0
0009000IOol;000:Li`30007Ool00`00LiacW009Li`;000;Li`;000HOol;000;Li`;000;Li`;000:
Li`30007Ool00`00Oomoo`0GOol:000;Li`;000;Li`20008Ool00`00LiacW009Li`;000?Ool001Uo
o`/00003Lia_N`0000Eoo`03001_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg/00005Ool00`00Kg]cW00:000IOol;00002Vmk
Lia_Ng>LKg]cW6mkLia_Ng>L10001Goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00;000HOol;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`40005Ool2000IOol:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00@000Eo
o`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;000?Ool001Uoo`/000=cW0D000=cW0X000]cW0/0
00]cW0/001Qoo`/000]cW0/000]cW0/000=cW0D000=cW0X001Uoo`/000YcW0/000]cW0/000]cW0/0
01Qoo`/000]cW0/000]cW0/000YcW0/001Uoo`X000]cW0/000]cW0/000]cW0/000moo`006Goo2`00
00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`00
00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/02`003goo000IOol;Li`;000:Li`;000;Li`;000;Li`HOol;Li`;000;Li`;
000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;000;Li`HOol;Li`;000;Li`;000;Li`:000;Li`I
Ool:Li`;000;Li`;000;Li`;000;Li`?Ool001Uoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;0000
2VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mk
Lia_Ng>L6Goo00]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000A_Ng>LKg]cW0@00003Kg]cW6mk01Qoo`0;
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000=cW6mk
Li`0100000A_Ng>LKg]cW0X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]c
W6mkLia_Ng>L2`0000AcW6mkLia_N`@00003Lia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`40004Ool3000;Li`;
000;Li`HOol;Li`40004Ool3000;Li`;000;Li`;000:Li`IOol;Li`:000;Li`;000;Li`;0002Li`2
0004Ool200000g>LOomoo`0FOol;Li`;000;Li`;0002Li`00`00Oomoo`02Ool20002Li`:000;Li`I
Ool:Li`;0003Li`00`00Oomoo`02Ool200000g>L00000009000;Li`;000;Li`?Ool001Uoo`0;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`007>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00000fmk001oo`07Ool00`00Oomoo`0FOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW00000T0000;Kg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000=cW6mk00001goo300000]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool001Uoo`]c
W0/000YcW0<000Moo`03001cW7>L00UcW0/000]cW1Qoo`]cW0<000Moo`03001cW7>L00UcW0/000]c
W0/000YcW1Uoo`]cW0X000]cW0/000]cW0/00003Li`007oo00Moo`03001oogoo01Ioo`]cW0/000]c
W0/00003Li`007oo00Ioo`03001cW00000T000]cW1Uoo`YcW0/0009cW003001oogoo00Eoo``000]c
W0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]c
W6mkLi`30002Ool30002Ool03000Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0/0000;Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00HOol02fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/00P000goo0`000Woo00`006mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mk
Lia_Ng>LKg]cW1Uoo`0;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00004Kg/007ooOol30003Ool00`00Oomo
o`0FOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
0004Li`007ooOol30002Ool00`00Li`0000900002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0/00003Li`007oo009oo`<0009oo``0000;Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03goo000IOol;Li`;000:Li`30007Ool0
0`00LiacW009Li`;000;Li`HOol;Li`30007Ool00`00LiacW009Li`;000;Li`;000:Li`IOol;Li`:
000;Li`;000;Li`;00000g>L001oo`06Ool00`00Liaoo`0GOol;Li`;000;Li`;00000g>L001oo`06
Ool00`00Li`00009000;Li`IOol:Li`;0002Li`00`00Oomoo`05Ool<000;Li`;000;Li`?Ool001Uo
o`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L0`001goo00`0
07>LKg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`067oo00]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00<000Moo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000]_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0;00000fmk001oo`06Ool00`00Kg]oo`0GOol02g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/00003Li`007oo00Ioo`03001cW00000T0000;Kg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0IOol02VmkLia_Ng>LKg]cW6mkLia_Ng>L2`0000=cW6mk00001goo
300000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00?Ool0
01Uoo`]cW0/000YcW0@000Eoo`8000]cW0/000]cW1Qoo`]cW0@000Eoo`8000]cW0/000]cW0/000Yc
W1Uoo`]cW0X000]cW0/000]cW0/0009cW08000Aoo`03001cW7>L01Qoo`]cW0/000]cW0/0009cW003
001oogoo00=oo`03001cW7>L00X000]cW1Uoo`YcW0/000=cW003001oogoo00=oo`03001cW00000X0
00]cW0/000]cW0moo`006Goo00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>L
Kg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L01Qoo`0;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/0
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`IOol02g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;000016mkLia_Ng>L100000=_Ng>LKg/067oo00]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00000g>LKg]cW00500000g>LKg]c
W00:00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/06Goo00Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00004
Lia_Ng>LKg/500000fmkLi`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00moo`006Goo2g>L2`002W>L2`002g>L2`002g>L67oo2g>L2`002g>L2`00
2g>L2`002W>L6Goo2g>L2P002g>L2`002g>L2`002g>L67oo2g>L2`002g>L2`002g>L2P002g>L6Goo
2W>L2`002g>L2`002g>L2`002g>L3goo000IOol;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P00
00]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00005Kg]cW6mkLia_N`02000017>LKg]cW6mk2`0067oo
2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00005
Lia_Ng>LKg]cW002000016mkLia_Ng>L2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0
000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_
Ng>LKg]cW6mkLia_Ng>LKg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000E_Ng>LKg]cW6mk00800004Lia_Ng>LKg/;000?Ool001Uo
o`/000]cW0X000]cW0/000AcW003001oogoo0080009cW0/001Qoo`/000]cW0/000]cW0D0009oo`@0
00]cW0X001Uoo`/000YcW0/000AcW003001oogoo0080009cW0/000]cW0/001Qoo`/000]cW0D0009o
o`@000]cW0/000YcW0/001Uoo`X000]cW0/000]cW0/000AcW003001oogoo0080009cW0/000moo`00
6Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
000016mkLia_N`001Goo00<006mk00002P0067oo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/0
000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030006Ool200002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
2P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00004Lia_Ng>L0005Ool00`00Li`0000:0000
2g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00<0
00Ioo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`00
6Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;
000016mkLi`000001Goo00<006mk00002P003goo000IOol;000;Li`:000;Li`;0002Li`00`00Oomo
o`05Ool<000HOol;000;Li`;000;Li`20007Ool2000;Li`:000IOol;000:Li`;0002Li`00`00Oomo
o`05Ool<000;Li`;000HOol;000;Li`20008Ool00`00LiacW009Li`;000:Li`;000IOol:000;Li`;
000;Li`;00000g>L001oo`07Ool<000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:
00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000=_Ng>L00001goo300067oo2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0020008Ool03000Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00000g>LKg/00007
Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk008000Qoo`0<001_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]c
W0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/02`0000=_N`00Ool01goo30003goo000IOol;000;Li`:000;Li`;00000g>L001oo`02Ool30002
Ool<000HOol;000;Li`;000;Li`20002Ool30003Ool00`00LiacW009Li`:000IOol;000:Li`;0000
0g>L001oo`02Ool30002Ool<000;Li`;000HOol;000;Li`20002Ool30003Ool00`00LiacW009Li`;
000:Li`;000IOol:000;Li`;000;Li`;000017>L001oogoo0`000goo30003goo000IOol;00002g>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`02P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/00003Kg]cW000
00Moo``001Qoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`00P001goo0P0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_
Ng>LKg]cW6mkLi`;00000g>LKg/00007Ool<00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo
2`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk008000Moo`80000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0;00002VmkLia_Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
00/0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00000fmk001oo`06Ool00`00Kg/0000:000?Ool0
01Uoo`/000]cW0X000]cW0/0009cW003001oogoo00Aoo`03001cW00000X001Qoo`/000]cW0/000]c
W08000Ioo`<000]cW0X001Uoo`/000YcW0/0009cW003001oogoo00Aoo`03001cW00000X000]cW0/0
01Qoo`/000]cW08000Ioo`<000]cW0/000YcW0/001Uoo`X000]cW0/000]cW0/00003Li`007oo00Eo
o`03001cW7>L00/000moo`006Goo2`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00X0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;000016mkLi`000001Goo00<006mk00002P0067oo2`0000]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0030005Ool300002g>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`02P006Goo2`0000Y_Ng>LKg]cW6mkLia_Ng>LKg]cW0/00004Lia_Ng>L
0005Ool00`00Li`0000:00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0067oo2`0000]_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk00@000Aoo`<0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002VmkLia_
Ng>LKg]cW6mkLia_Ng>L2`006Goo2P0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/0000;Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`0;000016mkLi`0000017oo00<007>LKg/02`003goo000IOol;000;Li`:
000;Li`;0004Li`50002Li`;000HOol;000;Li`;000;Li`;000;Li`:000IOol;000:Li`;0004Li`5
0002Li`;000;Li`;000HOol;000;Li`;000;Li`;000:Li`;000IOol:000;Li`;000;Li`;0004Li`4
0003Li`;000?Ool001Uoo`/0000;Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00:00002fmkLia_Ng>LKg]c
W6mkLia_Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/001Qoo`/0000;Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00;00002g>LKg]cW6mkLia_Ng>LKg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L00X001Uoo`/0000:Kg]cW6mkLia_Ng>LKg]cW6mkLi`;00002g>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`02`0000]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00/001Qoo`/0000;Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_Ng>LKg/02`0000Y_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0/001Uoo`X0000;Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`0;00002fmkLia_Ng>LKg]cW6mkLia_
Ng>LKg/02`0000]_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00/000moo`00ogooogoo27oo003oOoooOol8
Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003o
OoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo
27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00
ogooogoo27oo003oOoooOol8Ool00?mooomoo`Qoo`00ogooogoo27oo0000\
\>"],
  ImageRangeCache->{{{0, 517.75}, {834.75, 0}} -> {-0.125026, -0.204462, 
  0.0101401, 0.0101401}, {{12.3125, 103.625}, {814.563, 
  723.25}} -> {-1.3327, -2.05714, 0.0919924, 0.0919924}, {{112.75, 204.063}, {
  814.563, 723.25}} -> {-10.5722, -2.05714, 0.0919924, 0.0919924}, {{213.188, 
  304.5}, {814.563, 723.25}} -> {-19.8117, -2.05714, 0.0919924, 0.0919924}, {{
  313.625, 404.938}, {814.563, 723.25}} -> {-29.0512, -2.05714, 0.0919924, 
  0.0919924}, {{414.063, 505.375}, {814.563, 723.25}} -> {-38.2906, -2.05714, 
  0.0919924, 0.0919924}, {{12.3125, 103.625}, {714.125, 
  622.813}} -> {-1.3327, -11.2966, 0.0919924, 0.0919924}, {{112.75, 
  204.063}, {714.125, 622.813}} -> {-10.5722, -11.2966, 0.0919924, 
  0.0919924}, {{213.188, 304.5}, {714.125, 622.813}} -> {-19.8117, -11.2966, 
  0.0919924, 0.0919924}, {{313.625, 404.938}, {714.125, 
  622.813}} -> {-29.0512, -11.2966, 0.0919924, 0.0919924}, {{414.063, 
  505.375}, {714.125, 622.813}} -> {-38.2906, -11.2966, 0.0919924, 
  0.0919924}, {{12.3125, 103.625}, {613.688, 522.375}} -> {-1.3327, -20.5361, 
  0.0919924, 0.0919924}, {{112.75, 204.063}, {613.688, 
  522.375}} -> {-10.5722, -20.5361, 0.0919924, 0.0919924}, {{213.188, 
  304.5}, {613.688, 522.375}} -> {-19.8117, -20.5361, 0.0919924, 
  0.0919924}, {{313.625, 404.938}, {613.688, 
  522.375}} -> {-29.0512, -20.5361, 0.0919924, 0.0919924}, {{414.063, 
  505.375}, {613.688, 522.375}} -> {-38.2906, -20.5361, 0.0919924, 
  0.0919924}, {{12.3125, 103.625}, {513.25, 421.938}} -> {-1.3327, -29.7756, 
  0.0919924, 0.0919924}, {{112.75, 204.063}, {513.25, 
  421.938}} -> {-10.5722, -29.7756, 0.0919924, 0.0919924}, {{213.188, 
  304.5}, {513.25, 421.938}} -> {-19.8117, -29.7756, 0.0919924, 0.0919924}, {{
  313.625, 404.938}, {513.25, 421.938}} -> {-29.0512, -29.7756, 0.0919924, 
  0.0919924}, {{414.063, 505.375}, {513.25, 421.938}} -> {-38.2906, -29.7756, 
  0.0919924, 0.0919924}, {{12.3125, 103.625}, {412.75, 
  321.438}} -> {-1.3327, -39.0208, 0.0919924, 0.0919924}, {{112.75, 
  204.063}, {412.75, 321.438}} -> {-10.5722, -39.0208, 0.0919924, 
  0.0919924}, {{213.188, 304.5}, {412.75, 321.438}} -> {-19.8117, -39.0208, 
  0.0919924, 0.0919924}, {{313.625, 404.938}, {412.75, 
  321.438}} -> {-29.0512, -39.0208, 0.0919924, 0.0919924}, {{414.063, 
  505.375}, {412.75, 321.438}} -> {-38.2906, -39.0208, 0.0919924, 
  0.0919924}, {{12.3125, 103.625}, {312.313, 221}} -> {-1.3327, -48.2603, 
  0.0919924, 0.0919924}, {{112.75, 204.063}, {312.313, 
  221}} -> {-10.5722, -48.2603, 0.0919924, 0.0919924}, {{213.188, 304.5}, {
  312.313, 221}} -> {-19.8117, -48.2603, 0.0919924, 0.0919924}, {{313.625, 
  404.938}, {312.313, 221}} -> {-29.0512, -48.2603, 0.0919924, 0.0919924}, {{
  414.063, 505.375}, {312.313, 221}} -> {-38.2906, -48.2603, 0.0919924, 
  0.0919924}, {{12.3125, 103.625}, {211.875, 120.563}} -> {-1.3327, -57.4998, 
  0.0919924, 0.0919924}, {{112.75, 204.063}, {211.875, 
  120.563}} -> {-10.5722, -57.4998, 0.0919924, 0.0919924}, {{213.188, 
  304.5}, {211.875, 120.563}} -> {-19.8117, -57.4998, 0.0919924, 
  0.0919924}, {{313.625, 404.938}, {211.875, 
  120.563}} -> {-29.0512, -57.4998, 0.0919924, 0.0919924}, {{414.063, 
  505.375}, {211.875, 120.563}} -> {-38.2906, -57.4998, 0.0919924, 
  0.0919924}, {{12.3125, 103.625}, {111.438, 20.125}} -> {-1.3327, -66.7393, 
  0.0919924, 0.0919924}, {{112.75, 204.063}, {111.438, 
  20.125}} -> {-10.5722, -66.7393, 0.0919924, 0.0919924}, {{213.188, 304.5}, {
  111.438, 20.125}} -> {-19.8117, -66.7393, 0.0919924, 0.0919924}, {{313.625, 
  404.938}, {111.438, 20.125}} -> {-29.0512, -66.7393, 0.0919924, 
  0.0919924}, {{414.063, 505.375}, {111.438, 20.125}} -> {-38.2906, -66.7393, 
  0.0919924, 0.0919924}}],

Cell[OutputFormData["\<\
GraphicsArray[{{Graphics[{{{GrayLevel[0], 
        {{Rectangle[{1, 1}, {2, 2}], Rectangle[{1, 3}, {2, 4}], 
          Rectangle[{1, 5}, {2, 6}], Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}}}, AspectRatio -> 1]}}]\
\>", "\<\
-GraphicsArray-\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The (8 \[Times] 8)-board", "Subsection"],

Cell[CellGroupData[{

Cell["qs = QueensSolution[8] //Timing", "Input"],

Cell[OutputFormData["\<\
{14.38999999999998*Second, {{1, 5, 8, 6, 3, 7, 2, 4}, {1, 6, 8, 3, 7, 4, 2, \
5}, 
   {1, 7, 4, 6, 8, 2, 5, 3}, {1, 7, 5, 8, 2, 4, 6, 3}, {2, 4, 6, 8, 3, 1, 7, \
5}, 
   {2, 5, 7, 1, 3, 8, 6, 4}, {2, 5, 7, 4, 1, 8, 6, 3}, {2, 6, 1, 7, 4, 8, 3, \
5}, 
   {2, 6, 8, 3, 1, 4, 7, 5}, {2, 7, 3, 6, 8, 5, 1, 4}, {2, 7, 5, 8, 1, 4, 6, \
3}, 
   {2, 8, 6, 1, 3, 5, 7, 4}, {3, 1, 7, 5, 8, 2, 4, 6}, {3, 5, 2, 8, 1, 7, 4, \
6}, 
   {3, 5, 2, 8, 6, 4, 7, 1}, {3, 5, 7, 1, 4, 2, 8, 6}, {3, 5, 8, 4, 1, 7, 2, \
6}, 
   {3, 6, 2, 5, 8, 1, 7, 4}, {3, 6, 2, 7, 1, 4, 8, 5}, {3, 6, 2, 7, 5, 1, 8, \
4}, 
   {3, 6, 4, 1, 8, 5, 7, 2}, {3, 6, 4, 2, 8, 5, 7, 1}, {3, 6, 8, 1, 4, 7, 5, \
2}, 
   {3, 6, 8, 1, 5, 7, 2, 4}, {3, 6, 8, 2, 4, 1, 7, 5}, {3, 7, 2, 8, 5, 1, 4, \
6}, 
   {3, 7, 2, 8, 6, 4, 1, 5}, {3, 8, 4, 7, 1, 6, 2, 5}, {4, 1, 5, 8, 2, 7, 3, \
6}, 
   {4, 1, 5, 8, 6, 3, 7, 2}, {4, 2, 5, 8, 6, 1, 3, 7}, {4, 2, 7, 3, 6, 8, 1, \
5}, 
   {4, 2, 7, 3, 6, 8, 5, 1}, {4, 2, 7, 5, 1, 8, 6, 3}, {4, 2, 8, 5, 7, 1, 3, \
6}, 
   {4, 2, 8, 6, 1, 3, 5, 7}, {4, 6, 1, 5, 2, 8, 3, 7}, {4, 6, 8, 2, 7, 1, 3, \
5}, 
   {4, 6, 8, 3, 1, 7, 5, 2}, {4, 7, 1, 8, 5, 2, 6, 3}, {4, 7, 3, 8, 2, 5, 1, \
6}, 
   {4, 7, 5, 2, 6, 1, 3, 8}, {4, 7, 5, 3, 1, 6, 8, 2}, {4, 8, 1, 3, 6, 2, 7, \
5}, 
   {4, 8, 1, 5, 7, 2, 6, 3}, {4, 8, 5, 3, 1, 7, 2, 6}, {5, 1, 4, 6, 8, 2, 7, \
3}, 
   {5, 1, 8, 4, 2, 7, 3, 6}, {5, 1, 8, 6, 3, 7, 2, 4}, {5, 2, 4, 6, 8, 3, 1, \
7}, 
   {5, 2, 4, 7, 3, 8, 6, 1}, {5, 2, 6, 1, 7, 4, 8, 3}, {5, 2, 8, 1, 4, 7, 3, \
6}, 
   {5, 3, 1, 6, 8, 2, 4, 7}, {5, 3, 1, 7, 2, 8, 6, 4}, {5, 3, 8, 4, 7, 1, 6, \
2}, 
   {5, 7, 1, 3, 8, 6, 4, 2}, {5, 7, 1, 4, 2, 8, 6, 3}, {5, 7, 2, 4, 8, 1, 3, \
6}, 
   {5, 7, 2, 6, 3, 1, 4, 8}, {5, 7, 2, 6, 3, 1, 8, 4}, {5, 7, 4, 1, 3, 8, 6, \
2}, 
   {5, 8, 4, 1, 3, 6, 2, 7}, {5, 8, 4, 1, 7, 2, 6, 3}, {6, 1, 5, 2, 8, 3, 7, \
4}, 
   {6, 2, 7, 1, 3, 5, 8, 4}, {6, 2, 7, 1, 4, 8, 5, 3}, {6, 3, 1, 7, 5, 8, 2, \
4}, 
   {6, 3, 1, 8, 4, 2, 7, 5}, {6, 3, 1, 8, 5, 2, 4, 7}, {6, 3, 5, 7, 1, 4, 2, \
8}, 
   {6, 3, 5, 8, 1, 4, 2, 7}, {6, 3, 7, 2, 4, 8, 1, 5}, {6, 3, 7, 2, 8, 5, 1, \
4}, 
   {6, 3, 7, 4, 1, 8, 2, 5}, {6, 4, 1, 5, 8, 2, 7, 3}, {6, 4, 2, 8, 5, 7, 1, \
3}, 
   {6, 4, 7, 1, 3, 5, 2, 8}, {6, 4, 7, 1, 8, 2, 5, 3}, {6, 8, 2, 4, 1, 7, 5, \
3}, 
   {7, 1, 3, 8, 6, 4, 2, 5}, {7, 2, 4, 1, 8, 5, 3, 6}, {7, 2, 6, 3, 1, 4, 8, \
5}, 
   {7, 3, 1, 6, 8, 5, 2, 4}, {7, 3, 8, 2, 5, 1, 6, 4}, {7, 4, 2, 5, 8, 1, 3, \
6}, 
   {7, 4, 2, 8, 6, 1, 3, 5}, {7, 5, 3, 1, 6, 8, 2, 4}, {8, 2, 4, 1, 7, 5, 3, \
6}, 
   {8, 2, 5, 3, 1, 7, 4, 6}, {8, 3, 1, 6, 2, 5, 7, 4}, {8, 4, 1, 3, 6, 2, 7, \
5}}}\
\>", "\<\
{14.39 Second, {{1, 5, 8, 6, 3, 7, 2, 4}, {1, 6, 8, 3, 7, 4, 2, 5}, 
 
   {1, 7, 4, 6, 8, 2, 5, 3}, {1, 7, 5, 8, 2, 4, 6, 3}, {2, 4, 6, 8, 3, 1, 7, \
5}, 
 
   {2, 5, 7, 1, 3, 8, 6, 4}, {2, 5, 7, 4, 1, 8, 6, 3}, {2, 6, 1, 7, 4, 8, 3, \
5}, 
 
   {2, 6, 8, 3, 1, 4, 7, 5}, {2, 7, 3, 6, 8, 5, 1, 4}, {2, 7, 5, 8, 1, 4, 6, \
3}, 
 
   {2, 8, 6, 1, 3, 5, 7, 4}, {3, 1, 7, 5, 8, 2, 4, 6}, {3, 5, 2, 8, 1, 7, 4, \
6}, 
 
   {3, 5, 2, 8, 6, 4, 7, 1}, {3, 5, 7, 1, 4, 2, 8, 6}, {3, 5, 8, 4, 1, 7, 2, \
6}, 
 
   {3, 6, 2, 5, 8, 1, 7, 4}, {3, 6, 2, 7, 1, 4, 8, 5}, {3, 6, 2, 7, 5, 1, 8, \
4}, 
 
   {3, 6, 4, 1, 8, 5, 7, 2}, {3, 6, 4, 2, 8, 5, 7, 1}, {3, 6, 8, 1, 4, 7, 5, \
2}, 
 
   {3, 6, 8, 1, 5, 7, 2, 4}, {3, 6, 8, 2, 4, 1, 7, 5}, {3, 7, 2, 8, 5, 1, 4, \
6}, 
 
   {3, 7, 2, 8, 6, 4, 1, 5}, {3, 8, 4, 7, 1, 6, 2, 5}, {4, 1, 5, 8, 2, 7, 3, \
6}, 
 
   {4, 1, 5, 8, 6, 3, 7, 2}, {4, 2, 5, 8, 6, 1, 3, 7}, {4, 2, 7, 3, 6, 8, 1, \
5}, 
 
   {4, 2, 7, 3, 6, 8, 5, 1}, {4, 2, 7, 5, 1, 8, 6, 3}, {4, 2, 8, 5, 7, 1, 3, \
6}, 
 
   {4, 2, 8, 6, 1, 3, 5, 7}, {4, 6, 1, 5, 2, 8, 3, 7}, {4, 6, 8, 2, 7, 1, 3, \
5}, 
 
   {4, 6, 8, 3, 1, 7, 5, 2}, {4, 7, 1, 8, 5, 2, 6, 3}, {4, 7, 3, 8, 2, 5, 1, \
6}, 
 
   {4, 7, 5, 2, 6, 1, 3, 8}, {4, 7, 5, 3, 1, 6, 8, 2}, {4, 8, 1, 3, 6, 2, 7, \
5}, 
 
   {4, 8, 1, 5, 7, 2, 6, 3}, {4, 8, 5, 3, 1, 7, 2, 6}, {5, 1, 4, 6, 8, 2, 7, \
3}, 
 
   {5, 1, 8, 4, 2, 7, 3, 6}, {5, 1, 8, 6, 3, 7, 2, 4}, {5, 2, 4, 6, 8, 3, 1, \
7}, 
 
   {5, 2, 4, 7, 3, 8, 6, 1}, {5, 2, 6, 1, 7, 4, 8, 3}, {5, 2, 8, 1, 4, 7, 3, \
6}, 
 
   {5, 3, 1, 6, 8, 2, 4, 7}, {5, 3, 1, 7, 2, 8, 6, 4}, {5, 3, 8, 4, 7, 1, 6, \
2}, 
 
   {5, 7, 1, 3, 8, 6, 4, 2}, {5, 7, 1, 4, 2, 8, 6, 3}, {5, 7, 2, 4, 8, 1, 3, \
6}, 
 
   {5, 7, 2, 6, 3, 1, 4, 8}, {5, 7, 2, 6, 3, 1, 8, 4}, {5, 7, 4, 1, 3, 8, 6, \
2}, 
 
   {5, 8, 4, 1, 3, 6, 2, 7}, {5, 8, 4, 1, 7, 2, 6, 3}, {6, 1, 5, 2, 8, 3, 7, \
4}, 
 
   {6, 2, 7, 1, 3, 5, 8, 4}, {6, 2, 7, 1, 4, 8, 5, 3}, {6, 3, 1, 7, 5, 8, 2, \
4}, 
 
   {6, 3, 1, 8, 4, 2, 7, 5}, {6, 3, 1, 8, 5, 2, 4, 7}, {6, 3, 5, 7, 1, 4, 2, \
8}, 
 
   {6, 3, 5, 8, 1, 4, 2, 7}, {6, 3, 7, 2, 4, 8, 1, 5}, {6, 3, 7, 2, 8, 5, 1, \
4}, 
 
   {6, 3, 7, 4, 1, 8, 2, 5}, {6, 4, 1, 5, 8, 2, 7, 3}, {6, 4, 2, 8, 5, 7, 1, \
3}, 
 
   {6, 4, 7, 1, 3, 5, 2, 8}, {6, 4, 7, 1, 8, 2, 5, 3}, {6, 8, 2, 4, 1, 7, 5, \
3}, 
 
   {7, 1, 3, 8, 6, 4, 2, 5}, {7, 2, 4, 1, 8, 5, 3, 6}, {7, 2, 6, 3, 1, 4, 8, \
5}, 
 
   {7, 3, 1, 6, 8, 5, 2, 4}, {7, 3, 8, 2, 5, 1, 6, 4}, {7, 4, 2, 5, 8, 1, 3, \
6}, 
 
   {7, 4, 2, 8, 6, 1, 3, 5}, {7, 5, 3, 1, 6, 8, 2, 4}, {8, 2, 4, 1, 7, 5, 3, \
6}, 
 
   {8, 2, 5, 3, 1, 7, 4, 6}, {8, 3, 1, 6, 2, 5, 7, 4}, {8, 4, 1, 3, 6, 2, 7, \
5}}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["t8 = qs[[1]]", "Input"],

Cell[OutputFormData["\<\
14.38999999999998*Second\
\>", "\<\
14.39 Second\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[qs[[2]]]", "Input"],

Cell[OutputFormData["\<\
92\
\>", "\<\
92\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsg = QueensPlot[#]& /@ qs[[2]]", "Input"],

Cell[OutputFormData["\<\
{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{8.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{8.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
     {Circle[{8.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{8.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{1.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
    {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{6.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
     {Circle[{8.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
     {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
     {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
     {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
     {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
     {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
    {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
     {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
     {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
    {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
     {Circle[{2.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
  Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
        Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
        Rectangle[{1, 7}, {2, 8}]}, 
       {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
        Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
       {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
        Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
       {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
        Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, 5}], \

        Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
       {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
        Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
       {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
        Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
       {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
        Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
     {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
        Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
       {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
        Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
       {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
        Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
       {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
        Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
     {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, 4}], \

        Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
       {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
        Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
       {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
        Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
       {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
        Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
    {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
     {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
    {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
     {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
     {Circle[{6.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
     {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
    {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
     {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, {GrayLevel[0], {Disk[{5.5, \
8.5}, 0.1]}}}
}, AspectRatio -> 1]}\
\>", "\<\
{-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
  -Graphics-}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["qsga = Partition[qsg,9]", "Input"],

Cell[OutputFormData["\<\
{{Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{8.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{8.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
      {Circle[{8.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{8.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{1.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
     {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
  {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{6.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
      {Circle[{8.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
      {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
      {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
      {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
      {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
      {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
     {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
      {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
      {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}}\
\>", "\<\
{{-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
   -Graphics-, -Graphics-}, {-Graphics-, -Graphics-, -Graphics-, -Graphics-, 
 
   -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
   -Graphics-, -Graphics-}, {-Graphics-, -Graphics-, -Graphics-, -Graphics-, 
 
   -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
   -Graphics-, -Graphics-}, {-Graphics-, -Graphics-, -Graphics-, -Graphics-, 
 
   -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
   -Graphics-, -Graphics-}, {-Graphics-, -Graphics-, -Graphics-, -Graphics-, 
 
   -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}, 
 
  {-Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-, \
-Graphics-, 
 
   -Graphics-, -Graphics-}, {-Graphics-, -Graphics-, -Graphics-, -Graphics-, 
 
   -Graphics-, -Graphics-, -Graphics-, -Graphics-, -Graphics-}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[GraphicsArray[qsga]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11224 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.026482 0.10582 [
[ 0 0 0 0 ]
[ 1 1.11224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11224 L
0 1.11224 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.026482 0.120991 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.81746 .18254 m
.81746 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.81746 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.81746 .18254 m
.81746 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.026482 0.227891 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.81746 .18254 m
.81746 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.71164 .39418 m
.71164 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.81746 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.71164 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.92328 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.81746 .18254 m
.81746 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.71164 .39418 m
.71164 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.026482 0.334791 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.81746 .18254 m
.81746 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.81746 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.81746 .18254 m
.81746 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.026482 0.441691 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.81746 .18254 m
.81746 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.28836 .5 m
.28836 .5 .04233 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.81746 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.28836 .5 .04233 0 365.73 arc
s
newpath
.60582 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.81746 .18254 m
.81746 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.28836 .5 m
.28836 .5 .01058 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.026482 0.548591 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.81746 .18254 m
.81746 .18254 .04233 0 365.73 arc
F
.5 .28836 m
.5 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.60582 .5 m
.60582 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.81746 .18254 .04233 0 365.73 arc
s
newpath
.5 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.60582 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.81746 .18254 m
.81746 .18254 .01058 0 365.73 arc
F
.5 .28836 m
.5 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.60582 .5 m
.60582 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.026482 0.655491 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.81746 .18254 m
.81746 .18254 .04233 0 365.73 arc
F
.5 .28836 m
.5 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.81746 .18254 .04233 0 365.73 arc
s
newpath
.5 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.81746 .18254 m
.81746 .18254 .01058 0 365.73 arc
F
.5 .28836 m
.5 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.026482 0.762391 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.81746 .18254 m
.81746 .18254 .04233 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .04233 0 365.73 arc
F
.39418 .39418 m
.39418 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.81746 .18254 .04233 0 365.73 arc
s
newpath
.60582 .28836 .04233 0 365.73 arc
s
newpath
.39418 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.81746 .18254 m
.81746 .18254 .01058 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .01058 0 365.73 arc
F
.39418 .39418 m
.39418 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.026482 0.869291 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.92328 .18254 m
.92328 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.92328 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.81746 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.92328 .18254 m
.92328 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.026482 0.97619 0.123664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.92328 .18254 m
.92328 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.5 .81746 m
.5 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.92328 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.5 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.92328 .18254 m
.92328 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.5 .81746 m
.5 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.133382 0.120991 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.28836 .5 m
.28836 .5 .04233 0 365.73 arc
F
.5 .60582 m
.5 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.28836 .5 .04233 0 365.73 arc
s
newpath
.5 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.18254 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.28836 .5 m
.28836 .5 .01058 0 365.73 arc
F
.5 .60582 m
.5 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.133382 0.227891 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.28836 .5 m
.28836 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.28836 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.18254 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.28836 .5 m
.28836 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.133382 0.334791 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.5 .5 m
.5 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.5 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.5 .5 m
.5 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.133382 0.441691 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.5 .28836 m
.5 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.60582 .5 m
.60582 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.5 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.60582 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.5 .28836 m
.5 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.60582 .5 m
.60582 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.133382 0.548591 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.5 .28836 m
.5 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.5 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.60582 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.18254 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.5 .28836 m
.5 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.133382 0.655491 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.5 .28836 m
.5 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.92328 .92328 m
.92328 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.5 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.92328 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.5 .28836 m
.5 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.92328 .92328 m
.92328 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.133382 0.762391 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.5 .28836 m
.5 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.5 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.60582 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.5 .28836 m
.5 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.133382 0.869291 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.5 .5 m
.5 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.92328 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.5 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.60582 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.5 .5 m
.5 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.133382 0.97619 0.230564 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.81746 .18254 m
.81746 .18254 .04233 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .04233 0 365.73 arc
F
.39418 .39418 m
.39418 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.81746 .18254 .04233 0 365.73 arc
s
newpath
.18254 .28836 .04233 0 365.73 arc
s
newpath
.39418 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.81746 .18254 m
.81746 .18254 .01058 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .01058 0 365.73 arc
F
.39418 .39418 m
.39418 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.240282 0.120991 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.92328 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.81746 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.240282 0.227891 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.28836 .5 m
.28836 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.39418 .71164 m
.39418 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.18254 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.28836 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.39418 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.28836 .5 m
.28836 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.39418 .71164 m
.39418 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.240282 0.334791 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.92328 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.240282 0.441691 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.5 .60582 m
.5 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.5 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.60582 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.5 .60582 m
.5 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.240282 0.548591 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.81746 .5 m
.81746 .5 .04233 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.81746 .5 .04233 0 365.73 arc
s
newpath
.60582 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.81746 .5 m
.81746 .5 .01058 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.240282 0.655491 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.5 .60582 m
.5 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.5 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.5 .60582 m
.5 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.240282 0.762391 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.5 .81746 m
.5 .81746 .04233 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.60582 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.5 .81746 .04233 0 365.73 arc
s
newpath
.81746 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.5 .81746 m
.5 .81746 .01058 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.240282 0.869291 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.81746 .5 m
.81746 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.92328 .92328 m
.92328 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.81746 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.92328 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.81746 .5 m
.81746 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.92328 .92328 m
.92328 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.240282 0.97619 0.337464 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.71164 .18254 m
.71164 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.71164 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.81746 .92328 .04233 0 365.73 arc
s
.71164 .18254 m
.71164 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.347182 0.120991 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.81746 .5 m
.81746 .5 .04233 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.81746 .5 .04233 0 365.73 arc
s
newpath
.28836 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.81746 .5 m
.81746 .5 .01058 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.347182 0.227891 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.5 .5 m
.5 .5 .04233 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.5 .5 .04233 0 365.73 arc
s
newpath
.81746 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.28836 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.5 .5 m
.5 .5 .01058 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.347182 0.334791 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.71164 .71164 m
.71164 .71164 .04233 0 365.73 arc
F
.5 .81746 m
.5 .81746 .04233 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.71164 .71164 .04233 0 365.73 arc
s
newpath
.5 .81746 .04233 0 365.73 arc
s
newpath
.28836 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.71164 .71164 m
.71164 .71164 .01058 0 365.73 arc
F
.5 .81746 m
.5 .81746 .01058 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.347182 0.441691 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.5 .5 m
.5 .5 .04233 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.5 .5 .04233 0 365.73 arc
s
newpath
.28836 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.5 .5 m
.5 .5 .01058 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.347182 0.548591 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.5 .5 m
.5 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.5 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.5 .5 m
.5 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.347182 0.655491 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.5 .81746 m
.5 .81746 .04233 0 365.73 arc
F
.92328 .92328 m
.92328 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.5 .81746 .04233 0 365.73 arc
s
newpath
.92328 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.5 .81746 m
.5 .81746 .01058 0 365.73 arc
F
.92328 .92328 m
.92328 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.347182 0.762391 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.92328 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.347182 0.869291 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.28836 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.347182 0.97619 0.444363 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.71164 .71164 m
.71164 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.92328 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.71164 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.81746 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.71164 .71164 m
.71164 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.454082 0.120991 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.92328 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.454082 0.227891 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.18254 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.454082 0.334791 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.5 .5 m
.5 .5 .04233 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.18254 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.5 .5 .04233 0 365.73 arc
s
newpath
.28836 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.5 .5 m
.5 .5 .01058 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.454082 0.441691 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.18254 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.454082 0.548591 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.39418 .71164 m
.39418 .71164 .04233 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .04233 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.39418 .71164 .04233 0 365.73 arc
s
newpath
.18254 .81746 .04233 0 365.73 arc
s
newpath
.81746 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.39418 .71164 m
.39418 .71164 .01058 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .01058 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.454082 0.655491 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.81746 .5 m
.81746 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.18254 .92328 m
.18254 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.81746 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.18254 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.81746 .5 m
.81746 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.18254 .92328 m
.18254 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.454082 0.762391 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.71164 .39418 m
.71164 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.71164 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.81746 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.92328 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.71164 .39418 m
.71164 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.454082 0.869291 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.5 .60582 m
.5 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.5 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.5 .60582 m
.5 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.454082 0.97619 0.551263 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.60582 .18254 m
.60582 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.5 .81746 m
.5 .81746 .04233 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.60582 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.5 .81746 .04233 0 365.73 arc
s
newpath
.81746 .92328 .04233 0 365.73 arc
s
.60582 .18254 m
.60582 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.5 .81746 m
.5 .81746 .01058 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.560982 0.120991 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.60582 .5 m
.60582 .5 .04233 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.60582 .5 .04233 0 365.73 arc
s
newpath
.28836 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.81746 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.60582 .5 m
.60582 .5 .01058 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.560982 0.227891 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.28836 .5 m
.28836 .5 .04233 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.28836 .5 .04233 0 365.73 arc
s
newpath
.81746 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.28836 .5 m
.28836 .5 .01058 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.560982 0.334791 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .04233 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.60582 .81746 .04233 0 365.73 arc
s
newpath
.28836 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .01058 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.560982 0.441691 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.60582 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.560982 0.548591 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.39418 .39418 m
.39418 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.39418 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.28836 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.18254 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.39418 .39418 m
.39418 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.560982 0.655491 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.28836 .5 m
.28836 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.92328 .92328 m
.92328 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.28836 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.92328 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.28836 .5 m
.28836 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.92328 .92328 m
.92328 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.560982 0.762391 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.71164 .71164 m
.71164 .71164 .04233 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .04233 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.71164 .71164 .04233 0 365.73 arc
s
newpath
.92328 .81746 .04233 0 365.73 arc
s
newpath
.28836 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.71164 .71164 m
.71164 .71164 .01058 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .01058 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.560982 0.869291 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.92328 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.560982 0.97619 0.658163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.60582 .5 m
.60582 .5 .04233 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.92328 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.60582 .5 .04233 0 365.73 arc
s
newpath
.81746 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.60582 .5 m
.60582 .5 .01058 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.667881 0.120991 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.81746 .5 m
.81746 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.71164 .71164 m
.71164 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.92328 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.81746 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.71164 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.81746 .5 m
.81746 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.71164 .71164 m
.71164 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.667881 0.227891 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.18254 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.28836 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.667881 0.334791 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.39418 .71164 m
.39418 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.18254 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.39418 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.28836 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.39418 .71164 m
.39418 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.667881 0.441691 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.81746 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.667881 0.548591 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.18254 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.667881 0.655491 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .04233 0 365.73 arc
F
.18254 .92328 m
.18254 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.60582 .81746 .04233 0 365.73 arc
s
newpath
.18254 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .01058 0 365.73 arc
F
.18254 .92328 m
.18254 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.667881 0.762391 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.60582 .5 m
.60582 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.60582 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.60582 .5 m
.60582 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.667881 0.869291 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.60582 .5 m
.60582 .5 .04233 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.60582 .5 .04233 0 365.73 arc
s
newpath
.81746 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.60582 .5 m
.60582 .5 .01058 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.667881 0.97619 0.765063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.5 .18254 m
.5 .18254 .04233 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.39418 .71164 m
.39418 .71164 .04233 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .04233 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.5 .18254 .04233 0 365.73 arc
s
newpath
.28836 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.39418 .71164 .04233 0 365.73 arc
s
newpath
.60582 .81746 .04233 0 365.73 arc
s
newpath
.81746 .92328 .04233 0 365.73 arc
s
.5 .18254 m
.5 .18254 .01058 0 365.73 arc
F
.28836 .28836 m
.28836 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.39418 .71164 m
.39418 .71164 .01058 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .01058 0 365.73 arc
F
.81746 .92328 m
.81746 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.774781 0.120991 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.81746 .5 m
.81746 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.81746 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.92328 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.81746 .5 m
.81746 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.774781 0.227891 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.81746 .5 m
.81746 .5 .04233 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.81746 .5 .04233 0 365.73 arc
s
newpath
.60582 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.92328 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.81746 .5 m
.81746 .5 .01058 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.774781 0.334791 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.28836 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.774781 0.441691 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.28836 .5 m
.28836 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.18254 .92328 m
.18254 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.28836 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.18254 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.28836 .5 m
.28836 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.18254 .92328 m
.18254 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.774781 0.548591 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.5 .60582 m
.5 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .04233 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.5 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.60582 .81746 .04233 0 365.73 arc
s
newpath
.28836 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.5 .60582 m
.5 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .01058 0 365.73 arc
F
.28836 .92328 m
.28836 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.774781 0.655491 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.60582 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.774781 0.762391 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.28836 .5 m
.28836 .5 .04233 0 365.73 arc
F
.5 .60582 m
.5 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.28836 .5 .04233 0 365.73 arc
s
newpath
.5 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.28836 .5 m
.28836 .5 .01058 0 365.73 arc
F
.5 .60582 m
.5 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.774781 0.869291 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.5 .81746 m
.5 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.60582 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.5 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.60582 .60582 m
.60582 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.5 .81746 m
.5 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.774781 0.97619 0.871963 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.18254 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.881681 0.120991 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.28836 .18254 m
.28836 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.39418 .39418 m
.39418 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.28836 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.39418 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.18254 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.28836 .18254 m
.28836 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.39418 .39418 m
.39418 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.18254 .81746 m
.18254 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.881681 0.227891 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.28836 .18254 m
.28836 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.28836 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.28836 .18254 m
.28836 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.881681 0.334791 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.28836 .18254 m
.28836 .18254 .04233 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .04233 0 365.73 arc
F
.71164 .39418 m
.71164 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.28836 .18254 .04233 0 365.73 arc
s
newpath
.92328 .28836 .04233 0 365.73 arc
s
newpath
.71164 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.28836 .18254 m
.28836 .18254 .01058 0 365.73 arc
F
.92328 .28836 m
.92328 .28836 .01058 0 365.73 arc
F
.71164 .39418 m
.71164 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.881681 0.441691 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.60582 .5 m
.60582 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.5 .81746 m
.5 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.18254 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.60582 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.5 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.18254 .28836 m
.18254 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.60582 .5 m
.60582 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.5 .81746 m
.5 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.881681 0.548591 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.5 .81746 m
.5 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.60582 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.5 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.5 .81746 m
.5 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.881681 0.655491 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.18254 .92328 m
.18254 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.60582 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.18254 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.18254 .92328 m
.18254 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.881681 0.762391 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.5 .60582 m
.5 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.60582 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.5 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.92328 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.5 .60582 m
.5 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.92328 .81746 m
.92328 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.881681 0.869291 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.5 .5 m
.5 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.60582 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.5 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.71164 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.5 .5 m
.5 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.71164 .92328 m
.71164 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.881681 0.97619 0.978863 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.39418 .18254 m
.39418 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .04233 0 365.73 arc
F
.60582 .5 m
.60582 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.39418 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.28836 .39418 .04233 0 365.73 arc
s
newpath
.60582 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.39418 .18254 m
.39418 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.28836 .39418 m
.28836 .39418 .01058 0 365.73 arc
F
.60582 .5 m
.60582 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.988581 0.120991 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.18254 .18254 m
.18254 .18254 .04233 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.18254 .18254 .04233 0 365.73 arc
s
newpath
.60582 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.81746 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.18254 .18254 m
.18254 .18254 .01058 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.81746 .71164 m
.81746 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.130709 0.988581 0.227891 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.18254 .18254 m
.18254 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.18254 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.81746 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.28836 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.18254 .18254 m
.18254 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.81746 .60582 m
.81746 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.28836 .81746 m
.28836 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.237609 0.988581 0.334791 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.18254 .18254 m
.18254 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.5 .39418 m
.5 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.18254 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.5 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.92328 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.60582 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.18254 .18254 m
.18254 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.5 .39418 m
.5 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.92328 .60582 m
.92328 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.60582 .81746 m
.60582 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.344509 0.988581 0.441691 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.18254 .18254 m
.18254 .18254 .04233 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .04233 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.18254 .18254 .04233 0 365.73 arc
s
newpath
.81746 .28836 .04233 0 365.73 arc
s
newpath
.60582 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.28836 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.18254 .18254 m
.18254 .18254 .01058 0 365.73 arc
F
.81746 .28836 m
.81746 .28836 .01058 0 365.73 arc
F
.60582 .39418 m
.60582 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.451409 0.988581 0.548591 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.28836 .18254 m
.28836 .18254 .04233 0 365.73 arc
F
.5 .28836 m
.5 .28836 .04233 0 365.73 arc
F
.71164 .39418 m
.71164 .39418 .04233 0 365.73 arc
F
.92328 .5 m
.92328 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.28836 .18254 .04233 0 365.73 arc
s
newpath
.5 .28836 .04233 0 365.73 arc
s
newpath
.71164 .39418 .04233 0 365.73 arc
s
newpath
.92328 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.18254 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.28836 .18254 m
.28836 .18254 .01058 0 365.73 arc
F
.5 .28836 m
.5 .28836 .01058 0 365.73 arc
F
.71164 .39418 m
.71164 .39418 .01058 0 365.73 arc
F
.92328 .5 m
.92328 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.18254 .71164 m
.18254 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.558309 0.988581 0.655491 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.28836 .18254 m
.28836 .18254 .04233 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.18254 .5 m
.18254 .5 .04233 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.28836 .18254 .04233 0 365.73 arc
s
newpath
.60582 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.18254 .5 .04233 0 365.73 arc
s
newpath
.39418 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.28836 .18254 m
.28836 .18254 .01058 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.18254 .5 m
.18254 .5 .01058 0 365.73 arc
F
.39418 .60582 m
.39418 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.665209 0.988581 0.762391 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.28836 .18254 m
.28836 .18254 .04233 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .04233 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .04233 0 365.73 arc
F
.5 .5 m
.5 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .04233 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.28836 .18254 .04233 0 365.73 arc
s
newpath
.60582 .28836 .04233 0 365.73 arc
s
newpath
.81746 .39418 .04233 0 365.73 arc
s
newpath
.5 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.71164 .81746 .04233 0 365.73 arc
s
newpath
.39418 .92328 .04233 0 365.73 arc
s
.28836 .18254 m
.28836 .18254 .01058 0 365.73 arc
F
.60582 .28836 m
.60582 .28836 .01058 0 365.73 arc
F
.81746 .39418 m
.81746 .39418 .01058 0 365.73 arc
F
.5 .5 m
.5 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.71164 .81746 m
.71164 .81746 .01058 0 365.73 arc
F
.39418 .92328 m
.39418 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.772109 0.988581 0.869291 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.28836 .18254 m
.28836 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.81746 .5 m
.81746 .5 .04233 0 365.73 arc
F
.5 .60582 m
.5 .60582 .04233 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .04233 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.28836 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.81746 .5 .04233 0 365.73 arc
s
newpath
.5 .60582 .04233 0 365.73 arc
s
newpath
.92328 .71164 .04233 0 365.73 arc
s
newpath
.39418 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.28836 .18254 m
.28836 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.81746 .5 m
.81746 .5 .01058 0 365.73 arc
F
.5 .60582 m
.5 .60582 .01058 0 365.73 arc
F
.92328 .71164 m
.92328 .71164 .01058 0 365.73 arc
F
.39418 .81746 m
.39418 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.879009 0.988581 0.97619 1.08576 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.28836 .18254 m
.28836 .18254 .04233 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .04233 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .04233 0 365.73 arc
F
.5 .71164 m
.5 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.28836 .18254 .04233 0 365.73 arc
s
newpath
.71164 .28836 .04233 0 365.73 arc
s
newpath
.92328 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.18254 .60582 .04233 0 365.73 arc
s
newpath
.5 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.28836 .18254 m
.28836 .18254 .01058 0 365.73 arc
F
.71164 .28836 m
.71164 .28836 .01058 0 365.73 arc
F
.92328 .39418 m
.92328 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.18254 .60582 m
.18254 .60582 .01058 0 365.73 arc
F
.5 .71164 m
.5 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{537.875, 598.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008I0002EQ000`40O003h00Oogooogoo6goo003o
OoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo
6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00
ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomo
oa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo000COol60005Li`6
0005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=Ool50006Li`50006Li`5
0006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006Li`5
0006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60005Li`60006Li`=
Ool50006Li`50006Li`50006Li`50003Li`00`00LiacW00=Ool60005Li`60005Li`60005Li`60003
Li`00`00Liaoo`0>Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P0000IcW6mkLia_Ng>LKg/200002Goo000006mkLia_Ng>LKg]cW00=Ool500001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_Ng>LKg/=
Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo0000
07>LKg]cW6mkLi`>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Uoo`00001cW6mkLia_Ng>LKg/03Goo1@00
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001o
o`00Li`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
1Fmk000007oo00003goo000COol60005Li`60005Li`60005Li`400000goo001cW004Li`=Ool60005
Li`60005Li`60006Li`00`00Ool000020006Li`=Ool50006Li`50006Li`50006Li`01P00Ool00000
Ool000EcW0eoo`H000EcW0H000EcW0H000EcW0800004Ool000000005Li`>Ool50006Li`50006Li`5
0006Li`01P00Ool00000Ool000EcW0eoo`D000IcW0H000EcW0H000EcW0@00003Ool007>L00AcW0eo
o`H000EcW0H000EcW0H000EcW0800004Ool000000006Li`=Ool50006Li`50006Li`50006Li`50000
0g>L001oo`03000=Ool60005Li`60005Li`60005Li`700001Goo000007oo00003Woo000COol60000
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]c
W6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk0P00
00Uoo`00001_Ng>LKg]cW6mkLi`03Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L3Woo1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0P0000Uoo`00001_Ng>LKg]c
W6mkLi`03Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<0
0008Ool00000Kg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00<00009Ool00000Lia_Ng>LKg]cW6mk00eoo`D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L3Goo1P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_N`00001oo`0000moo`004goo
1P001G>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001W>L1@001W>L3Goo1@001W>L
1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P001G>L3Woo1@001W>L1@001W>L
1@001W>L1@001W>L3Goo1@001W>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001G>L
1P001W>L3Goo1@001W>L1@001W>L1@001W>L1@000g>L00<007>LLi`03Goo1P001G>L1P001G>L1P00
1G>L1P000g>L00<007>LOol03Woo000COol600001FmkLi`007>LKg/01P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLi`007>L00H00005Kg]cW6mk
Lia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo
1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW000Lia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW000Li`01P0000E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol6Li`200000goo
00000006Li`50006Li`50006Li`5000=Ool6Li`300000goo001cW005Li`50006Li`60005Li`6000=
Ool5Li`6000017>L000007oo1`001G>L1P001G>L1P003Goo1W>L1@000W>L00@007oo001cW0D000Ic
W0D000IcW0D000ioo`EcW0H000EcW0<00003Ool0000000EcW0H000EcW0H000eoo`EcW0H000IcW080
0003Ool0000000IcW0D000IcW0D000eoo`IcW0D000IcW0D0009cW004001oo`00Li`50006Li`6000=
Ool5Li`300000goo00000005Li`60005Li`60005Li`6000=Ool6Li`300000goo001cW005Li`50006
Li`50006Li`5000?Ool001=oo`07Kg]cW6mkLia_Ng>L00000Woo0P0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00McW6mkLia_Ng>LKg/00003Ool01`00
Kg]cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>L
Kg]cW0070003Ool700001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_
Ng>L1@0000IcW000Oomoo`00Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0020002Ool200001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001fmkLia_Ng>LKg]cW000009oo`800006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@0000I_N`00Oomoo`00Li`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`020002Ool2
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01g>LKg]c
W6mkLia_N`0000=oo`07001_Ng>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D000moo`004goo1W>L1P001G>L1@001W>L1@001W>L1@003Goo1W>L100000=oo`00Li`017>L
1@001W>L1P001G>L1P003Goo1G>L1P0000EcW000000007oo00H000EcW0H000EcW0H000eoo`IcW0D0
009cW0T000IcW0D000IcW0D000ioo`EcW0H000EcW0@00003Ool007>L00AcW0H000EcW0H000eoo`Ec
W0H000IcW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D0009cW0T000IcW0H000eoo`EcW0H000Ec
W0H000EcW0H000EcW0H000eoo`IcW0@00003Ool007>L00AcW0D000IcW0D000IcW0D000moo`004goo
00I_Ng>LKg]cW6mkLi`200002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000A_Ng>L001oo`L0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg/0
07oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool0
1G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`200002Goo000007>LKg]cW6mkLia_N`0500001Vmk
Lia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo
001cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]c
W0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/200002Goo
000006mkLia_Ng>LKg]cW00500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo000C
Ool6Li`50006Li`50006Li`50006Li`5000=Ool6Li`50006Li`50006Li`60005Li`6000=Ool5Li`6
0003Li`00`00Li`000050005Li`60005Li`6000=Ool6Li`50003Li`00`00LiacW0050006Li`50006
Li`5000>Ool5Li`60005Li`60005Li`60005Li`6000=Ool5Li`60006Li`50006Li`50006Li`5000=
Ool6Li`50006Li`50003Li`00`00LiacW0050006Li`6000=Ool5Li`60005Li`60005Li`60005Li`6
000=Ool6Li`50006Li`50006Li`50006Li`5000?Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW000Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_
Ng>L001cW00>Ool500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mk001_Ng>L1P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=o
o`H000EcW0H00004Li`00000Ool70005Li`60005Li`=Ool60005Li`60005Li`60002Li`01000Ool0
07>L1@001W>L3Goo0`0000=oo`00Li`01G>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L
1P001G>L1P0000EcW000001oo`0000ioo`D0009cW004001oo`00Li`50006Li`50006Li`50006Li`=
Ool50002Li`01000Ool007>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L0`0000=oo`0000001G>L
1P001G>L1P001W>L3Goo1@001W>L1@000W>L00@007oo001cW0D000IcW0D000IcW0eoo`H000EcW0H0
00EcW0<00003Ool0000000EcW0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00L00004Ool00000
Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01P0000EcW000000007oo00H00006Kg]cW6mkLia_Ng>L3Goo00/007oo000007oo001c
W6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00L00005Ool0
0000Ool0000=Ool500001G>L00000000Ool01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000=_N`00Ool02@0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00800009Ool00000001cW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@00
00=_N`00Ool0200000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H0
00EcW0H00003Li`007oo00P000EcW0H000EcW0eoo`H000EcW0H000EcW0H0009cW004001oo`00Li`5
0006Li`=Ool300000goo001cW005Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005
Li`600001G>L000007oo00003Woo1@000W>L00@007oo001cW0D000IcW0D000IcW0D000IcW0eoo`D0
009cW004001oo`00Li`60005Li`60005Li`60005Li`=Ool60005Li`300000goo00000005Li`60005
Li`60006Li`=Ool50006Li`50002Li`01000Ool007>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L
0`0000=oo`0000001G>L1P001G>L3goo000COol600001FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L
00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool60000
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW000Li`0
3Woo1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`=Ool500001VmkLia_N`00Kg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol60005Li`6
0005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=Ool50006Li`50006Li`5
0003Li`00`00LiacW0050006Li`=Ool60003Li`00`00Li`000050005Li`60005Li`60005Li`>Ool5
0006Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005Li`60003Li`00`00Liaoo`0<
Ool60005Li`60005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005
Li`60005Li`60005Li`60005Li`?Ool001=oo`06Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001Vmk
Li`007oo001cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H000eo
o`06Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000A_N`00001oo`L0
0005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000=oo`00Ool037oo00I_Ng>L001oo`00Li`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool016mk000007oo
1`0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mk
Lia_Ng>LKg/500001VmkLi`007oo001cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
000?Ool001=oo`06Li`007ooOol007>L1@001W>L1@001W>L1@001W>L1@003Goo1W>L1@0000IcW000
Oomoo`00Li`50006Li`60005Li`6000=Ool5Li`60005Li`60005Li`20002Ool20005Li`6000=Ool6
Li`01@00Oomoogoo00001W>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1`000goo1`001G>L1P00
3Goo1G>L1P001W>L1@001W>L1@001W>L00D007ooOomoo`0000eoo`06Li`007ooOol007>L1@001W>L
1@001W>L1@001W>L1P003Goo00@007ooOomoo`L000EcW0H000EcW0H000EcW0H000eoo`IcW0D00006
Li`007ooOol007>L1@001W>L1@001W>L1@003goo000COol01FmkLi`00000Ool01P0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/5
00000fmkLi`0000800001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_
Ng>LKg]cW6mkLi`400001goo001_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg/00000001oo`060000
1G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0@00003Ool007oo00]oo`03Kg]cW00000P00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05Kg/00000001oo`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mk
Lia_N`D00003Kg]cW00000P00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=o
o`9cW004001oo`00Li`50006Li`50006Li`50006Li`5000=Ool6Li`50002Li`01000Ool007>L1@00
1W>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L0`0000=oo`0000001G>L1P003Goo1W>L0P0000=o
o`0000001W>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P0000=cW000Ool020001G>L1P003Goo
1G>L1P001W>L1@001W>L1@001W>L0P0000=oo`0000003Goo0W>L00@007oo001cW0D000IcW0D000Ic
W0D000IcW0H000eoo`03Li`007oo00P000EcW0H000EcW0H000EcW0H000eoo`IcW0D0009cW004001o
o`00Li`50006Li`50006Li`5000?Ool001=oo`06Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001Vmk
Lia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool01Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L001cW6mk00H00005Lia_
Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLi`007>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/50000
1VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`H0
00EcW0H000EcW0H000EcW0H000=cW003001cW7oo00aoo`H000EcW0H000EcW0H000IcW0D000IcW0eo
o`D000IcW0D000IcW0D000IcW0D000=cW003001cW7>L00eoo`H000EcW0H000EcW0H000EcW0H000Ec
W0ioo`D000IcW0D000IcW0D000IcW0D000=cW003001cW7>L00eoo`D000IcW0H000EcW0H0009cW003
001cW7>L00H000EcW0eoo`H000EcW0H000EcW0H000=cW003001cW00000D000IcW0eoo`D000IcW0D0
00IcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0moo`004goo1P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW000001oo`0000eoo`<0
0008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@0000IcW6mk001oo`00Kg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008
Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001cW0eoo`D00006Kg]cW6mkLia_
Ng>L1P0000E_Ng>LKg]cW6mk00H00003Li`007oo00P00005Kg]cW6mkLia_N`0=Ool600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H00004Kg]cW000Ool700001W>LKg]cW6mkLia_N`eoo`D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`<00008Ool006mkLia_
Ng>LKg]cW0eoo`<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P001G>L1P001G>L1`0000Eoo`00001oo`00
00aoo`800004Ool000000005Li`60005Li`60006Li`50006Li`=Ool50006Li`50006Li`50006Li`5
00000g>L001oo`03000=Ool60005Li`60005Li`2000017oo000000001G>L1P001G>L3Woo1@001W>L
1@001W>L1@001W>L1@0000=cW00000000`003Goo1@001W>L1P001G>L1`0000Aoo`00001oo`H000Ec
W0eoo`H000EcW0H000EcW0H00005Li`00000001oo`060006Li`=Ool50006Li`50006Li`50006Li`0
1P00Ool00000Ool000EcW0eoo`@00003Ool007>L00AcW0H000EcW0H000EcW0H000EcW0moo`004goo
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000=cW000Ool0
0P003Goo0`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`00`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L3Goo1@0000I_
Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000=cW000Ool0200000E_Ng>LKg]cW6mk00eoo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000A_Ng>L001oo`L00006Lia_Ng>LKg]cW6mk
3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`0000Qo
o`00Kg]cW6mkLia_Ng>L3Goo0`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol60005Li`60005Li`60005Li`60002Li`0
0`00LiacW00=Ool60005Li`60005Li`60006Li`50006Li`=Ool50006Li`50006Li`50006Li`50003
Li`00`00LiacW00=Ool60005Li`60005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006Li`5
0003Li`00`00LiacW00=Ool50006Li`60005Li`60002Li`00`00LiacW0060005Li`=Ool60005Li`6
0005Li`60003Li`00`00Li`000050006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005
Li`60005Li`60005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg/006mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>
Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01P0000IcW6mkLi`007>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`IcW0D000Ic
W0D0009cW004001oo`00Li`50006Li`5000=Ool6Li`50006Li`300000goo001cW005Li`60005Li`6
000=Ool5Li`60005Li`60002Li`00`00Ool000060005Li`6000=Ool2Li`01000Ool007>L1@001W>L
1@001W>L1@001W>L1@003Woo0W>L00<007oo00001P001G>L1P001G>L1P001G>L1P003Goo0W>L00<0
07oo00001P001W>L1@001W>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L1@001W>L0`0000=oo`00
00003Goo1G>L1P001G>L1P000W>L00<007oo00001P001G>L1P003Goo1W>L1@001W>L1@001W>L1@00
0W>L00@007oo001cW0D000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000AcW000Oomoo`L00005Kg]cW6mkLia_N`06000=Ool01VmkLi`0
07oo001cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
00ioo`04Kg/007ooOol700001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W006000=Ool017>LKg/007oo1`0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/300000goo0000000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00004Kg/007ooOol700001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`5000?Ool001=oo`IcW0D0
00IcW0D00005Li`00000001oo`060006Li`5000=Ool6Li`50006Li`400000goo001cW004Li`60005
Li`6000=Ool5Li`60005Li`7000017oo000007oo1P001G>L1P003Goo00=cW000000020001W>L1@00
1W>L1@001W>L1@003Woo00D007oo000007oo00H000EcW0H000EcW0H000EcW0H000eoo`05Li`00000
001oo`060006Li`50006Li`50006Li`5000=Ool6Li`50006Li`50006Li`50006Li`400000goo001o
o`0<Ool5Li`60005Li`7000017oo000007oo1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@0000=c
W000000020003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001o
o`00Li`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`3
000027oo001cW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`06000017>L000007oo1`0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW000Ool007>L
1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00=_
N`00Ool0200000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo
00AcW6mk001oo`L00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk0`0000=oo`0000003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
16mk000007oo1`0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@003goo000COol6Li`50006Li`50003
Li`00`00LiacW0050006Li`5000=Ool6Li`50006Li`50006Li`60005Li`6000=Ool5Li`60005Li`6
0003Li`00`00Li`000050005Li`6000=Ool3Li`00`00LiacW0050006Li`50006Li`50006Li`5000>
Ool2Li`00`00LiacW0060005Li`60005Li`60005Li`6000=Ool3Li`00`00Li`000050006Li`50006
Li`50006Li`5000=Ool6Li`50006Li`50006Li`50006Li`6000=Ool5Li`60005Li`60003Li`00`00
Li`000050005Li`6000=Ool6Li`50006Li`50006Li`50003Li`00`00LiacW005000?Ool001=oo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg/006mkLi`=Ool500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg/006mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>L
Kg/006mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0<00003Ool0000000EcW0H000EcW0H000EcW0eoo`H0
00EcW0H000EcW0H000IcW0D0009cW004001oo`00Li`=Ool50002Li`01000Ool007>L1@001W>L1@00
1W>L1@001W>L3Goo1P001G>L1P001G>L1P0000AcW000001oo`L000EcW0ioo`D000IcW0<00003Ool0
07>L00EcW0D000IcW0D000IcW0eoo`D000IcW0<00003Ool0000000EcW0H000EcW0H000EcW0eoo`H0
0004Li`00000Ool70005Li`60005Li`60006Li`=Ool50006Li`300000goo001cW005Li`50006Li`5
0006Li`=Ool60005Li`6000017>L000007oo1`001G>L1P001G>L3goo000COol600001FmkLia_Ng>L
Kg/0100000Moo`00Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001Vmk00000000
Ool000eoo`D00003Kg/007oo00P00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01`0000Aoo`00001oo`H0
0005Lia_Ng>LKg]cW00>Ool5000027>LKg]cW6mkLia_N`00Ool200001goo001cW6mkLia_Ng>L00D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0@00007Ool0
06mkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool7000017oo000007oo
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00008Lia_
Ng>LKg]cW6mk001oo`800007Ool007>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW007000017oo000007oo1P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0<00003Ool0000000EcW0H000EcW0H000EcW0eoo`H000Ec
W0H000EcW0H000IcW0D0009cW004001oo`00Li`=Ool50002Li`01000Ool007>L1@001W>L1@001W>L
1@001W>L3Goo1P001G>L1P001G>L1P0000AcW000001oo`L000EcW0ioo`D000IcW0800003Ool00000
00IcW0D000IcW0D000IcW0eoo`D000IcW0<00003Ool0000000EcW0H000EcW0H000EcW0eoo`H00004
Li`00000Ool70005Li`60005Li`60006Li`=Ool50006Li`300000goo001cW005Li`50006Li`50006
Li`=Ool60005Li`600000g>L001oo`080005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`=Ool5
00001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00H0
0005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg/006mk00H00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005
Lia_Ng>LKg]cW00600001FmkLi`007>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?
Ool001=oo`H000EcW0H000EcW0H000=cW003001cW00000D000EcW0eoo`H000EcW0H000EcW0H000Ic
W0D000IcW0eoo`D000IcW0D000=cW003001cW7>L00D000IcW0D000IcW0eoo`H000EcW0H000=cW003
001cW00000D000EcW0H000EcW0ioo`D000IcW0D000IcW0D000=cW003001cW7>L00D000IcW0eoo`D0
00IcW0H000EcW0H000EcW0H000EcW0eoo`H000EcW0H000=cW003001cW00000D000EcW0H000IcW0eo
o`D000IcW0D000IcW0D000=cW003001cW7>L00D000IcW0eoo`H000EcW0H000EcW0H000=cW003001c
W00000D000EcW0moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D00006Lia_N`00Ool006mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008
Ool00000Lia_Ng>LKg]cW0H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_
N`00Ool006mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`6000=Ool0
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/3000027oo001_Ng>L
Kg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000IcW080009oo`03001cW7>L00AcW0D000eoo`Ic
W0D000IcW0D0009cW004001oo`00Li`60005Li`6000=Ool5Li`60005Li`300000goo00000005Li`6
0005Li`6000=Ool6Li`50006Li`20002Ool00`00LiacW004Li`50006Li`5000>Ool5Li`60005Li`6
0005Li`300000goo00000005Li`6000=Ool5Li`60006Li`50002Li`01000Ool007>L1@001W>L1@00
3Goo1W>L1@001W>L0P000Woo00<007>LLi`017>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L0`00
00=oo`0000001G>L1P003Goo1W>L1@001W>L1@001W>L0P000Woo00<007>LLi`017>L1@003goo000C
Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000Q_Ng>LKg]cW6mkLi`007oo0P0000Mo
o`00Kg]cW6mkLia_N`05000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000=cW000
Ool02@0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00P0000Uo
o`00000007>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000Qc
W6mkLia_Ng>LKg/007oo0P0000Moo`00Lia_Ng>LKg]cW00500001W>LKg]cW6mkLia_N`D000ioo`05
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001G>L00000000Ool01P0000I_Ng>L
Kg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00008Lia_Ng>LKg]cW6mk001oo`800007Ool007>L
Kg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00H00005Kg]cW6mkLia_N`0200002Goo00000000Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L1@0000QcW6mkLia_Ng>LKg/007oo0P0000Moo`00Lia_Ng>LKg]cW005
000?Ool001=oo`IcW0D000IcW0D000IcW0800003Ool0000000IcW0D000eoo`IcW0D000IcW0D0009c
W004001oo`00Li`60005Li`6000=Ool5Li`60005Li`300000goo00000005Li`60005Li`6000=Ool6
Li`50006Li`200000goo00000006Li`50006Li`5000>Ool5Li`60005Li`60005Li`300000goo0000
0005Li`6000=Ool5Li`60006Li`50002Li`01000Ool007>L1@001W>L1@003Goo1W>L1@001W>L0`00
00=oo`00Li`01G>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L0`0000=oo`0000001G>L1P003Goo
1W>L1@001W>L1@001W>L0P0000=oo`0000001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`H00005Lia_Ng>LKg]cW006000=
Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
1@003goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]o
o`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mo
oomooa]oo`00ogooogoo6goo003oOoooOolKOol0039oo`03001oogoo03Ioo`03001oogoo03Ioo`03
001oogoo03Moo`03001oogoo03Ioo`03001oogoo03Ioo`03001oogoo03Moo`03001oogoo03Ioo`03
001oogoo03aoo`03001oogoo01Aoo`004goo1P001G>L1P001G>L1P0000AcW000001oo`L000EcW0eo
o`H000EcW0H000EcW0H0009cW004001oo`00Li`50006Li`=Ool50006Li`50006Li`50002Li`01000
Ool007>L1@001W>L3Goo1P001G>L1P001G>L1P0000AcW000001oo`L000EcW0ioo`D000IcW0D000Ic
W0D0009cW004001oo`00Li`50006Li`=Ool50006Li`60005Li`600001G>L001oo`00Li`01P001G>L
3Goo1P001G>L1P001G>L1P000W>L00<007oo00001P001W>L3Goo1@001W>L1@001W>L1@000W>L00@0
07oo001cW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0<00003Ool0000000EcW0moo`004goo1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00700000goo0000000700001G>LKg]cW6mkLi`03Goo
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600000g>L0000000800001VmkLia_Ng>LKg]c
W0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500000fmk001oo`0800001W>LKg]c
W6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01`0000=oo`0000001`0000Ec
W6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500000g>L00000008
00001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00L00003Ool0
000000L00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00003
Kg/0000000P00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D00003Li`007oo00P00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P001G>L1P00
00AcW000Oomoo`L000EcW0eoo`H000EcW0H000EcW0H0009cW003001oo`0000H000IcW0eoo`D000Ic
W0D000IcW0D0009cW003001oo`0000H000IcW0eoo`H000EcW0H000EcW0H00004Li`007ooOol70005
Li`>Ool50006Li`50006Li`50002Li`00`00Ool000060006Li`=Ool50006Li`60005Li`6000017>L
001oogoo1`001G>L3Goo1P001G>L1P001G>L1P000W>L00<007oo00001P001W>L3Goo1@001W>L1@00
1W>L1@000W>L00<007oo00001P001W>L3Goo1P001G>L1P001G>L1P001G>L0`0000=oo`0000001G>L
3goo000COol600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg/007oo001_N`060000
1G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg/007oo
001_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00004Kg]cW000Ool700001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_
Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>L001oo`00Li`01P0000E_Ng>LKg]cW6mk00eoo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000A_Ng>L001oo`L00006Lia_Ng>LKg]cW6mk
3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@0000I_
Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W003000027oo000006mkLia_Ng>LKg/?Ool001=oo`H000EcW0H000EcW0H0009cW003001cW7>L00H0
00EcW0eoo`H000EcW0H000EcW0H000=cW003001cW7>L00D000IcW0eoo`D000IcW0D000IcW0D000=c
W003001cW7>L00D000IcW0eoo`H000EcW0H000EcW0H000=cW003001cW00000D000EcW0ioo`D000Ic
W0D000IcW0D000=cW003001cW7>L00D000IcW0eoo`D000IcW0H000EcW0H0009cW003001cW7>L00H0
00EcW0eoo`H000EcW0H000EcW0H000=cW003001cW00000D000IcW0eoo`D000IcW0D000IcW0D000=c
W003001cW7>L00D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0moo`004goo00I_Ng>LKg]c
W6mkLi`500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000=
Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]c
W6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
000=Ool01W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D000moo`004goo1W>L1@000W>L00@007oo001cW0D000IcW0D000IcW0D000eoo`Ic
W0D0009cW004001oo`00Li`50006Li`60005Li`6000=Ool5Li`6000017>L000007oo1`001G>L1P00
1G>L1P003Goo1W>L1@001W>L0`0000=oo`00Li`01G>L1@001W>L1@003Woo1G>L1P001G>L0`0000=o
o`0000001G>L1P001G>L1P003Goo1G>L1P001W>L0P0000=oo`0000001W>L1@001W>L1@003Goo1W>L
1@001W>L0`0000=oo`00Li`01G>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L0`0000=o
o`0000003Goo0W>L00@007oo001cW0D000IcW0D000IcW0D000IcW0D000moo`004goo00I_Ng>LKg]c
W6mkLi`500001G>L00000000Ool01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000eo
o`06Lia_Ng>LKg]cW6mk1@0000=_N`00Ool0200000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`0
1P003Goo00EcW6mkLia_Ng>L00L00004Ool00000Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000QcW6mkLia_Ng>LKg/007oo0P0000Moo`00Lia_Ng>L
Kg]cW00500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01000
00Moo`00Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00008Kg]c
W6mkLia_Ng>L001oo`<00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_
Ng>LKg]cW0D00008Lia_Ng>LKg]cW6mk001oo`800007Ool007>LKg]cW6mkLi`01@0000IcW6mkLia_
Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`00P0000Aoo`00000000eoo`05Li`00000001oo`0600001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D0009cW004001oo`00
Li`50006Li`50006Li`5000=Ool6Li`50002Li`01000Ool007>L1@001W>L1P001G>L1P003Goo1G>L
1P0000AcW000001oo`L000EcW0H000EcW0H000eoo`IcW0D000IcW0800003Ool0000000IcW0D000Ic
W0D000ioo`EcW0H000EcW0<00003Ool0000000EcW0H000EcW0H000eoo`EcW0H000IcW0800003Ool0
000000IcW0D000IcW0D000eoo`IcW0D000IcW0<00003Ool007>L00EcW0D000IcW0H000eoo`EcW0H0
00EcW0H000EcW0H000EcW0<00003Ool0000000eoo`9cW004001oo`00Li`50006Li`50006Li`50006
Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D00006
Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_N`00
Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool0
1G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000IcW0D0
00=cW003001cW7>L00D000eoo`IcW0D000IcW0D000IcW0H0009cW003001cW7>L00H000eoo`EcW0H0
00EcW0H000EcW0H000=cW003001cW00000D000eoo`=cW003001cW7>L00D000IcW0D000IcW0D000Ic
W0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H000IcW0D000IcW0D000=cW003001c
W7>L00D000eoo`IcW0D000IcW0D000IcW0D000=cW003001cW7>L00H000eoo`EcW0H000EcW0H000Ec
W0H000EcW0H000eoo`IcW0D000=cW003001cW7>L00D000IcW0D000IcW0D000moo`004goo1P0000E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_
Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`800009
Ool00000Kg]cW6mkLia_Ng>L00eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`eoo`<00008Ool00000Kg]cW6mkLia_N`H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00006Lia_N`00
Ool006mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo
1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000
Kg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00<00009Ool00000Lia_Ng>LKg]cW6mk00eoo`D00006Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00<00008
Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol60005
Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`00`00Ool000020006Li`=Ool5
0006Li`50006Li`50006Li`00`00Ool000030005Li`=Ool60005Li`60005Li`60005Li`60005Li`>
Ool500000g>L000000080006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=
Ool60005Li`60005Li`60005Li`2000017oo000000001W>L3Goo1@0000=cW000000020001W>L1@00
1W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P001G>L3goo000COol600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`=Ool60000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk0P0000Uoo`00001_Ng>L
Kg]cW6mkLi`03Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L0P000Woo0P0000E_Ng>LKg]cW6mk00eoo`<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00004Lia_N`00Ool700001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>L
Kg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk3Goo
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Uoo`00001c
W6mkLia_Ng>LKg/03Goo1@0000AcW6mk001oo`L00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/6
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P001G>L1P001G>L0`00
00=oo`0000001G>L3Goo1P001G>L1P001G>L1P001W>L0P0000=oo`0000001W>L3Goo1@001W>L1@00
1W>L1@001W>L0`0000=oo`00Li`01G>L3Goo0`0000=oo`0000001G>L1P001G>L1P001G>L1P001G>L
3Woo1@000W>L00@007oo001cW0D000IcW0D000IcW0D000IcW0eoo`D000IcW0H000EcW0H000EcW0<0
0003Ool0000000EcW0eoo`H000EcW0H000EcW0H000EcW0<00003Ool0000000IcW0eoo`D0009cW004
001oo`00Li`50006Li`50006Li`50006Li`=Ool60005Li`300000goo00000005Li`60005Li`60005
Li`?Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW000Lia_
N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006
Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mk
Lia_Ng>LKg/=Ool500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`IcW0D000IcW0D000IcW0D000IcW0D000eo
o`IcW0D000IcW0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW0D0
00IcW0D000=cW003001cW7>L00D000IcW0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`=c
W003001cW00000D000IcW0D000IcW0D000IcW0D000eoo`=cW003001cW7>L00D000IcW0D000IcW0D0
00IcW0H000eoo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D0
00moo`004goo00I_Ng>LKg]cW6mkLi`200002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D0
00ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00300000goo0000000=Ool017>LKg/007oo1`0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0<00003
Ool007oo00ioo`004goo1W>L00<007oo00000`001G>L1@001W>L1@001W>L1@003Goo1W>L00H007oo
000007oo0005Li`50006Li`60005Li`6000=Ool5Li`60005Li`2000017oo000000001G>L1P001G>L
1P003Goo1W>L1@001W>L1@0000=cW000Ool020001W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L
1P003Goo00EcW000000007oo00H000IcW0D000IcW0D000IcW0D000eoo`03Li`007oo00P000IcW0D0
00IcW0D000IcW0H000eoo`EcW0H000EcW0800004Ool000000005Li`60005Li`6000=Ool6Li`50006
Li`50006Li`50006Li`01P00Ool00000Ool000ioo`004goo00I_Ng>LKg]cW6mkLi`200002Goo0000
07>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mk
Lia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]c
W006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H0
0005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
001oo`00Li`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00300000goo0000000=Ool017>LKg/007oo1`00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>L
001oo`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6
000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005
Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0<00003Ool007oo00ioo`004goo1W>L1@001W>L1@001W>L1@00
1W>L1@003Goo1W>L1@001W>L1@001W>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P00
3Goo1W>L1@001W>L1@000g>L00<007>LLi`01@001W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L
1P003Goo0g>L00<007>L00001@001W>L1@001W>L1@001W>L1@003Goo0g>L00<007>LLi`01@001W>L
1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L
1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW000Li`01P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`01P00
3Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg/006mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo000COol60005Li`6000017>L
000007oo1`001G>L1P001G>L3Goo1P001G>L1P001G>L1P001W>L1@000W>L00@007oo001cW0eoo`<0
0003Ool007>L00EcW0D000IcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H00005Li`0
0000Ool0000>Ool50006Li`50006Li`300000goo001cW005Li`50006Li`=Ool50006Li`300000goo
00000005Li`60005Li`60005Li`=Ool60005Li`60005Li`60005Li`60002Li`01000Ool007>L3Goo
0`0000=oo`00Li`01G>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P0000AcW000001o
o`L000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00L00003Ool0000000L00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]c
W6mkLia_N`D00003Kg/0000000<000eoo`03001oo`0000<00005Lia_Ng>LKg]cW00500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0700000goo00000002000=Ool500001W>LKg]c
W6mkLia_N`D00008Kg]cW6mkLia_Ng>L001oo`@00005Kg]cW6mkLia_N`0500001VmkLia_Ng>LKg]c
W0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
1P0000=cW00000000`003Goo00<007oo00000`0000E_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01`0000=oo`0000001`0000E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P0000AcW000
Oomoo`L000EcW0H000EcW0eoo`H000EcW0H000EcW0H000IcW0D0009cW004001oo`00000=Ool20002
Ool20005Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`6000017>L001oogoo
0P003Goo1@001W>L1@001W>L0P000Woo0P001G>L1@001W>L3Goo1@001W>L0`0000=oo`0000001G>L
1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001G>L1P000W>L00@007oo000000eoo`80009oo`80
00EcW0D000IcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H00004Li`007ooOol70005Li`?Ool0
01=oo`H00005Kg]cW6mkLia_N`0600001G>L001oo`00Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>L001oo`00Li`=Ool3000027oo001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg/007oo00003Woo1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0800009Ool00000Lia_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L3Goo
1@0000I_Ng>LKg]cW6mkLi`3000027oo000006mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00006Lia_N`00Ool006mk3Goo0P0000Uoo`00001cW6mkLia_Ng>LKg/01@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0600001G>L001oo`00Li`01P0000E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P00
0W>L00<007>LLi`01P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001W>L1@000g>L00<007>LLi`0
3Goo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P000g>L00<007>L
Ool03Goo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1@001W>L1P001G>L1P001G>L1P001G>L3Goo
1P001G>L1P001G>L1P001G>L1P000g>L00<007>LLi`03Goo1@001W>L1@001W>L1@001W>L1@001W>L
3Goo1P001G>L1P001G>L1P000W>L00<007>LLi`01P001G>L3goo000COol01VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`H00005Lia_Ng>LKg]cW006
000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001G>LKg]cW000Li`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLi`007>L00H000eoo`06
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@003goo000COol6Li`50006Li`50006Li`50006Li`300000goo001oo`0<Ool6Li`50006Li`5
0002Li`01000Ool007>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L0`0000=oo`000000
3Goo1W>L0`0000=oo`00Li`01G>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P0000Ac
W000001oo`L000eoo`EcW0H000IcW0D0009cW004001oo`00Li`50006Li`5000=Ool6Li`300000goo
001cW005Li`50006Li`50006Li`6000=Ool5Li`60005Li`60005Li`6000017>L000007oo1`003Goo
1W>L1@001W>L0`0000=oo`00Li`01G>L1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000027>LKg]cW6mkLia_N`00Ool200000goo001o
o`0;Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000=cW000Ool02@0000EcW6mkLia_
Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`02000017oo000000003Goo00Q_Ng>LKg]cW6mkLi`007oo0P0000Moo`00Kg]cW6mk
Lia_N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01`0000Aoo`00001oo`H000eoo`05Lia_Ng>LKg]c
W00600001VmkLia_Ng>LKg]cW0D00005Li`00000001oo`0600001VmkLia_Ng>LKg]cW0D000eoo`08
Kg]cW6mkLia_Ng>L001oo`800007Ool006mkLia_Ng>LKg/01@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00L00004Ool00000Ool6000=Ool01W>LKg]cW6mkLia_N`D00008Kg]cW6mkLia_Ng>L001oo`800007
Ool006mkLia_Ng>LKg/01@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000IcW0D0
00IcW0800003Ool0000000eoo`IcW0D000IcW0D0009cW004001oo`00Li`60005Li`6000=Ool5Li`6
0005Li`60005Li`60005Li`300000goo0000000=Ool6Li`200000goo00000006Li`50006Li`50006
Li`5000>Ool5Li`60005Li`60005Li`600000g>L001oo`08000=Ool5Li`60006Li`50002Li`01000
Ool007>L1@001W>L1@003Goo1W>L0`0000=oo`00Li`01G>L1@001W>L1@001W>L1P003Goo1G>L1P00
1G>L1P001G>L1P0000AcW000001oo`L000eoo`IcW0D000IcW0800003Ool0000000IcW0D000IcW0D0
00moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Li`007>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L00H000eoo`05Lia_
Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`5
000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00005Lia_Ng>L001cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000moo`004goo0g>L00<007>LLi`01@001W>L1@00
1W>L1@001W>L1@003Goo0g>L00<007>LLi`01@001W>L1@001W>L1P001G>L1P003Goo1G>L1P001G>L
1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@000g>L00<007>LLi`01@003Woo0g>L00<0
07>L00001@001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L1@001W>L1@003Goo1W>L
1@001W>L1@000g>L00<007>LLi`01@001W>L1P003Goo1G>L1P001G>L1P000g>L00<007>L00001@00
1G>L1P003Goo1W>L1@001W>L1@001W>L1@001W>L1@003goo000COol3000027oo000006mkLia_Ng>L
Kg/600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool3000027oo
000007>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L3Woo0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>L001oo`00
Li`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00006Lia_Ng>LKg]c
W6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000AcW000001oo`L00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00moo`004goo0P000Woo0P001G>L1P001G>L1P001G>L1P001G>L
3Goo0P000Woo0P001G>L1P001G>L1P001W>L1@001W>L3Goo1@0000IcW000Oomoo`00Li`50006Li`5
0006Li`50006Li`=Ool60005Li`60005Li`60005Li`20002Ool20005Li`>Ool01@00Oomoogoo0000
1W>L1@001W>L1@001W>L1@001W>L3Goo1@0000IcW000Oomoo`00Li`60005Li`60005Li`60005Li`=
Ool60005Li`60005Li`20002Ool20005Li`60006Li`=Ool50006Li`50006Li`01@00Oomoogoo0000
1W>L1@001W>L3Goo1`000goo1`001G>L1P001G>L1P001G>L3goo000COol400001goo001_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0eoo`D00005Kg]cW000001oo`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`03Woo100000Moo`00Kg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500000fmkLi`0000900001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00@00007Ool006mkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L100000Moo`00Kg]cW6mkLia_N`0500001VmkLia_Ng>LKg]c
W0eoo`H00005Li`00000001oo`0600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0?Ool001=oo`<00003Ool0000000EcW0H000EcW0H000EcW0H000EcW0eoo`<00003Ool0
000000EcW0H000EcW0H000IcW0D000IcW0eoo`D0009cW004001oo`00Li`50006Li`50006Li`50006
Li`=Ool60005Li`60005Li`60005Li`300000goo00000005Li`>Ool200000goo00000006Li`50006
Li`50006Li`50006Li`=Ool50002Li`01000Ool007>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L
1P001G>L0`0000=oo`0000001G>L1P001W>L3Goo1@001W>L1@001W>L0`0000=oo`00Li`01G>L1@00
1W>L3Goo1P0000=cW000Ool020001G>L1P001G>L1P001G>L3goo000COol600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo
1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_N`00Kg]cW0H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool60000
1G>LKg/006mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
3goo000COol6Li`50006Li`50003Li`00`00LiacW0050006Li`5000=Ool6Li`50006Li`50006Li`6
0005Li`6000=Ool5Li`60005Li`60003Li`00`00Li`000050005Li`6000=Ool6Li`50003Li`00`00
LiacW0050006Li`50006Li`5000>Ool5Li`60003Li`00`00Li`000050005Li`60005Li`6000=Ool5
Li`60006Li`50006Li`50006Li`5000=Ool6Li`50003Li`00`00LiacW0050006Li`50006Li`6000=
Ool5Li`60003Li`00`00Li`000050005Li`60005Li`6000=Ool6Li`50006Li`50003Li`00`00Liac
W0050006Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`0
07oo001cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0<00008Ool007>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H00004Li`00000Ool700001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mk
Li`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool0
1FmkLia_Ng>LKg/01P0000AcW000001oo`L00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
3Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0<00003Ool007oo00aoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mk001oo`00Kg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00004Li`00000Ool7
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@003goo000COol6Li`50006
Li`500001G>L00000000Ool01P001W>L1@003Goo1W>L1@001W>L100000=oo`00Li`017>L1P001G>L
1P003Goo1G>L1P001G>L1`0000Aoo`00001oo`H000EcW0H000eoo`IcW0D00003Li`0000000P000Ic
W0D000IcW0D000ioo`EcW0L00004Ool00000Ool60005Li`60005Li`6000=Ool5Li`60006Li`50006
Li`50006Li`01P00Ool00000Ool000aoo`IcW0D00003Li`007oo00P000IcW0D000IcW0H000eoo`Ec
W0L00004Ool00000Ool60005Li`60005Li`6000=Ool6Li`50006Li`500000g>L000000080006Li`5
000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001cW0D0
0006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0<00008Ool0
07>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00H00004Li`00000Ool700001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>L
Kg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>L
Kg/01P0000=cW000Ool0200000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]c
W6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0P00
00=oo`0000003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000AcW000001oo`L00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D0
0006Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000=cW003
001cW7>L00D000IcW0D000eoo`IcW0D000IcW0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000=c
W003001cW00000D000EcW0H000eoo`IcW0D000=cW003001cW7>L00D000IcW0D000IcW0D000ioo`Ec
W0H0009cW003001cW7>L00H000EcW0H000EcW0H000eoo`EcW0H000IcW0D000IcW0D000IcW0D000eo
o`IcW0D000=cW003001cW7>L00D000IcW0D000IcW0H000eoo`EcW0H000=cW003001cW00000D000Ec
W0H000EcW0H000eoo`IcW0D000IcW0D000=cW003001cW7>L00D000IcW0D000moo`004goo00I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>L
Kg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eo
o`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D000moo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo
6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00
ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo000COol600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L
3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@0000Ic
W6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk001_
N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW6mk
Lia_N`0600001G>LKg/006mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool6
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW00600001FmkLia_Ng>L
Kg/03goo000COol60005Li`60005Li`300000goo00000005Li`60005Li`=Ool60005Li`60005Li`6
0002Li`01000Ool007>L1@001W>L3Goo1@001W>L1@001W>L1@000W>L00@007oo001cW0D000IcW0eo
o`H000EcW0H000EcW0H00004Li`00000Ool70005Li`>Ool50006Li`50006Li`50002Li`01000Ool0
07>L1@001W>L3Goo1@001W>L1P001G>L1P0000=cW000Ool020001G>L3Goo1P001G>L1P001G>L1P00
0W>L00<007oo00001P001W>L3Goo1@001W>L1@001W>L1@000W>L00@007oo001cW0D000IcW0eoo`H0
00EcW0H000EcW0H00004Li`00000Ool70005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`0100000Moo`00Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>L00000000Ool01P0000I_Ng>LKg]cW6mkLi`=Ool50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000=_N`00Ool0200000IcW6mkLia_Ng>LKg/=
Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00L00004Ool00000Ool600001G>LKg]cW6mk
Li`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00003Li`0000000P00006Kg]c
W6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01`0000Aoo`00001oo`H0
0005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg/00000
001oo`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00000g>L001oo`0800001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01`0000Aoo`00001oo`H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0H000EcW0<00003Ool0
000000EcW0H000EcW0eoo`H000EcW0H000EcW0H0009cW004001oo`00Li`50006Li`=Ool50006Li`5
0006Li`50002Li`01000Ool007>L1@001W>L3Goo1P001G>L1P001G>L1P0000AcW000001oo`L000Ec
W0ioo`D000IcW0D000IcW0D0009cW004001oo`00Li`50006Li`=Ool50006Li`60005Li`600000g>L
001oo`080005Li`=Ool60005Li`60005Li`60002Li`00`00Ool000060006Li`=Ool50006Li`50006
Li`50002Li`01000Ool007>L1@001W>L3Goo1P001G>L1P001G>L1P0000=cW000Ool020001G>L3goo
000COol600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW000Lia_
N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_
Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg/006mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00H00006Lia_Ng>LKg]c
W6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@00
00I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_N`00
Kg]cW00600001FmkLia_Ng>LKg/03goo000COol60005Li`60005Li`60005Li`60003Li`00`00Liao
o`0<Ool60005Li`60005Li`60006Li`50006Li`=Ool50003Li`00`00LiacW0050006Li`50006Li`5
0006Li`=Ool60003Li`00`00Li`000050005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006
Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60005Li`60006
Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`?Ool0
01=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk0`0000=oo`00Ool037oo00IcW6mk001oo`00Kg/500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW003000027oo000006mk
Lia_Ng>LKg/600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L
0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000io
o`05Kg]cW6mkLia_N`06000017>L000007oo1`0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000AcW000001oo`L00005Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLi`007oo001c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000Ic
W0D000IcW003001oo`0000<000aoo`03Li`007oo00P000IcW0D000IcW0H000EcW0H000eoo`EcW080
0004Ool000000005Li`60005Li`60005Li`6000=Ool6Li`00`00Ool000030005Li`50006Li`50006
Li`5000>Ool5Li`700000goo000000070005Li`60005Li`6000=Ool5Li`600000g>L000000080006
Li`50006Li`5000=Ool6Li`500000g>L001oo`080006Li`50006Li`6000=Ool5Li`700000goo0000
00070005Li`60005Li`6000=Ool6Li`500000g>L000000080006Li`50006Li`5000?Ool001=oo`06
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk0P000Woo0P0037oo00AcW6mk001oo`L00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6
00001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`20002Ool200001Fmk
Lia_Ng>LKg/01@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_
N`06000017>L001oogoo1`0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]c
W6mkLi`01P0000A_Ng>L001oo`L00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool0
1VmkLia_Ng>LKg]cW0D00004Lia_N`00Ool700001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1P003Goo00E_Ng>LKg]cW6mk00H00004Li`007ooOol700001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000A_Ng>L001oo`L00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000IcW0D000IcW0800003Ool0000000eoo`9c
W004001oo`00Li`50006Li`50006Li`60005Li`6000=Ool5Li`300000goo00000005Li`60005Li`6
0005Li`6000=Ool6Li`200000goo00000006Li`50006Li`50006Li`5000>Ool5Li`600001G>L001o
o`00Li`01P001G>L1P001G>L1P003Goo1G>L1P000W>L00@007oo001cW0D000IcW0D000IcW0D000eo
o`IcW0D0009cW004001oo`00Li`50006Li`50006Li`6000=Ool5Li`60002Li`00`00Ool000060005
Li`60005Li`6000=Ool6Li`50002Li`01000Ool007>L1@001W>L1@001W>L1@003goo000COol01Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D000eoo`06Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H00005
Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mk001_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006
Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P00
3Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L1@003goo000COol60005Li`60003Li`00`00Li`000050005Li`60005Li`=
Ool60005Li`60005Li`60006Li`50006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005
Li`60005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006Li`50006Li`=Ool50006Li`60005
Li`60005Li`60005Li`=Ool60005Li`60005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006
Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`06
000017>L000007oo1`0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00<00009Ool00000Lia_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L
3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000Qo
o`00Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L3Woo0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo0`0000Qoo`00Kg]cW6mk
Lia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo0`00
00Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]c
W6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`00
00Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00moo`004goo1P001G>L1`0000Aoo`00001o
o`H000EcW0H000EcW0eoo`H000EcW0H000EcW0800004Ool000000006Li`50006Li`=Ool50006Li`5
0006Li`50006Li`01P00Ool00000Ool000EcW0eoo`H000EcW0H000EcW0H000EcW0800004Ool00000
0005Li`>Ool01P00Ool00000Ool000EcW0D000IcW0D000IcW0D000IcW0eoo`@00003Ool007>L00Ac
W0H000EcW0H000EcW0H000EcW0eoo`800004Ool000000005Li`60005Li`60005Li`60006Li`=Ool5
0006Li`50006Li`01P00Ool00000Ool000EcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000Ec
W0moo`004goo1P0000E_Ng>LKg]cW6mk00H00003Li`007oo00P00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0300002Goo000007>LKg]c
W6mkLia_N`0500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0ioo`800009
Ool00000Lia_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0eoo`<00008Ool006mkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_
N`0?Ool001=oo`H000EcW0H0009cW003001cW7>L00H000EcW0H000EcW0eoo`H000EcW0H000EcW0H0
00IcW0D000IcW0eoo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H0
00EcW0ioo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`D000IcW0H000EcW0H000EcW0H000EcW0eo
o`H000EcW0H000EcW0H000EcW0H000IcW0eoo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`H000Ec
W0H000EcW0H000EcW0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>L001cW00600001FmkLia_
Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00io
o`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00H00005Kg]cW6mk001_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001W>LKg]cW000Lia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00moo`004goo0W>L00@007oo
001cW0D000IcW0D000IcW0D000IcW0D000eoo`IcW0<00003Ool007>L00EcW0D000IcW0H000EcW0H0
00eoo`04Li`00000Ool70005Li`60005Li`60005Li`6000=Ool2Li`01000Ool007>L1@001W>L1@00
1W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P0000AcW000001oo`L000eoo`EcW0H000IcW0D0
00IcW0D000IcW0<00003Ool007oo00aoo`IcW0D000IcW0D000IcW0D000IcW0<00003Ool0000000eo
o`EcW0H000EcW0H000EcW0H00004Li`00000Ool7000=Ool6Li`50006Li`50006Li`50006Li`30000
0goo001oo`0>Ool001=oo`03Kg/0000000P00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D000eoo`08Lia_Ng>LKg]cW6mk001oo`@00005Lia_Ng>LKg]cW0050000
1W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool00`00Ool0000800001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool00fmk0000000800001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P00
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0700000goo00000007000=Ool01G>LKg]cW6mkLi`0
1P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00008Kg]cW6mkLia_Ng>L001oo`@000ao
o`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01`00
00=oo`0000001`003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000Q_Ng>LKg]cW6mkLi`007oo10003Woo000COol2Li`00`00Ool000060006Li`50006Li`5
0006Li`5000=Ool6Li`20002Ool20005Li`50006Li`60005Li`6000=Ool017>L001oogoo1`001G>L
1P001G>L1P001G>L1P003Goo0W>L00<007oo00001P001W>L1@001W>L1@001W>L1@003Woo1G>L1P00
1G>L1P001G>L1P0000AcW000Oomoo`L000eoo`EcW0H000IcW0D000IcW0D000IcW080009oo`8000ao
o`IcW0D000IcW0D000IcW0D000IcW0<00003Ool0000000eoo`EcW0H000EcW0H000EcW0H00004Li`0
07ooOol7000=Ool6Li`50006Li`50006Li`50006Li`20002Ool2000>Ool001=oo`06Kg]cW000Ool0
07>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo
00IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H00005Lia_
Ng>LKg]cW006000=Ool017>LKg/007oo1`0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/01P003Goo00I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0600001G>L001oo`00Li`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0800003Ool0000000eoo`06Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
0`0000=oo`0000003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
1P0000AcW6mk001oo`L000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000=oo`00Ool03Woo000COol3Li`00`00LiacW0050006
Li`50006Li`50006Li`5000=Ool6Li`50006Li`50006Li`60005Li`6000=Ool3Li`00`00Li`00005
0005Li`60005Li`60005Li`6000=Ool3Li`00`00LiacW0050006Li`50006Li`50006Li`5000>Ool5
Li`60005Li`60005Li`60002Li`00`00LiacW006000=Ool5Li`60006Li`50006Li`50006Li`5000=
Ool6Li`50006Li`50006Li`50006Li`6000=Ool5Li`60005Li`60005Li`60003Li`00`00Li`00005
000=Ool6Li`50006Li`50006Li`50006Li`5000?Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`=Ool500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>L001cW6mk00H00005
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=o
o`H000EcW0H000EcW0H000EcW0<00003Ool0000000EcW0eoo`H000EcW0H000EcW0H000IcW0D0009c
W004001oo`00Li`=Ool50006Li`300000goo001cW005Li`50006Li`50006Li`=Ool60005Li`60000
17>L000007oo1`001G>L1P001G>L3Woo1@001W>L1@001W>L0`0000=oo`00Li`01G>L1@001W>L3Goo
1@001W>L1P0000EcW000Ool007>L00H000EcW0H000EcW0eoo`H000EcW0H000EcW0<00003Ool00000
00EcW0H000IcW0eoo`<00003Ool007>L00EcW0D000IcW0D000IcW0D000IcW0eoo`<00003Ool00000
00EcW0H000EcW0H000EcW0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/0100000Moo`00Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_N`00000007oo000=Ool5000026mkLia_
Ng>LKg]cW000Ool200001goo001_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/=Ool600001FmkLia_Ng>LKg/01`0000Aoo`00001oo`H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/5000026mkLia_Ng>LKg]cW000Ool200001goo001_
Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`700000goo00000007
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`00P0000Uoo`00000006mkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool02`00Ool00000
Ool006mkLia_Ng>LKg/01@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L3Goo100000Moo`00Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0H000EcW0H000EcW0<00003Ool0000000EcW0eo
o`H000EcW0H000EcW0H000IcW0D0009cW004001oo`00Li`=Ool50006Li`300000goo001cW005Li`5
0006Li`50006Li`=Ool60005Li`600000g>L001oo`080005Li`60005Li`>Ool50006Li`50006Li`2
00000goo00000006Li`50006Li`=Ool50006Li`600001G>L001oo`00Li`01P001G>L1P001G>L3Goo
1P001G>L1P001G>L0`0000=oo`0000001G>L1P001W>L3Goo0P0000=oo`0000001W>L1@001W>L1@00
1W>L1@001W>L3Goo0`0000=oo`0000001G>L1P001G>L1P001G>L1P001G>L3goo000COol600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
001_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L00H00005Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0H00005
Kg]cW000Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/03goo000COol60002Li`00`00LiacW0060005Li`60005Li`60005Li`=Ool60005Li`6
0005Li`60006Li`50006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`6
0005Li`60003Li`00`00Liaoo`0=Ool50006Li`50006Li`50006Li`50003Li`00`00LiacW00=Ool5
0003Li`00`00LiacW0060005Li`60005Li`60005Li`=Ool60003Li`00`00Li`000050005Li`60005
Li`60006Li`=Ool50006Li`50003Li`00`00LiacW0050006Li`50006Li`=Ool60005Li`60003Li`0
0`00Li`000050005Li`60005Li`?Ool001=oo`06Kg]cW6mkLia_Ng>L0P0000Uoo`00001cW6mkLia_
Ng>LKg/01@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk
1@0000I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00004Li`00000Ool700001FmkLia_Ng>LKg/01P003Goo
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/300000goo001oo`0=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`00`0000=oo`0000003Goo00EcW6mkLia_Ng>L00<00009Ool00000
Kg]cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_
Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H0
0005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW003001oo`0000<000EcW0D0
00IcW0D000IcW0D000eoo`IcW0D00003Li`007oo00P000IcW0H000EcW0H000eoo`EcW0H000EcW0L0
0003Ool0000000L000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW003001oo`0000<000eoo`Ec
W0H000EcW0H000EcW0H000EcW0H000eoo`EcW0800004Ool000000006Li`50006Li`50006Li`5000=
Ool6Li`00`00Ool000030005Li`50006Li`50006Li`6000=Ool5Li`60005Li`2000017oo00000000
1G>L1P001G>L1P003Goo1W>L1@001W>L00<007oo00000`001G>L1@001W>L1@003goo000COol01Vmk
Lia_Ng>LKg]cW080009oo`07001cW6mkLia_Ng>LKg/01@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000A_Ng>L001oo`L00006Lia_Ng>LKg]cW6mk1P00
00EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000AcW000Oomo
o`L00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`80009oo`8000eoo`05Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00300000goo0000000=Ool01G>L
Kg]cW6mkLi`00`0000Uoo`00001_Ng>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L0P000Woo0P0000E_Ng>LKg]cW6mk00D00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<0
0008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L0P000Woo0P0000E_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L1@003goo000C
Ool6Li`200000goo00000006Li`50006Li`50006Li`5000=Ool6Li`50002Li`01000Ool007>L1@00
1W>L1P001G>L1P003Goo1G>L1P001G>L1P000W>L00<007oo00001P001G>L1P003Goo1W>L1@001W>L
1@001W>L1@001W>L0`0000=oo`00Ool03Goo1G>L1P001G>L1P001G>L1P001G>L0`0000=oo`000000
3Goo1G>L0`0000=oo`0000001W>L1@001W>L1@001W>L1@003Goo1W>L0`0000=oo`00Li`01G>L1@00
1W>L1@001W>L1P003Goo1G>L1P001G>L0`0000=oo`0000001G>L1P001G>L1P003Goo1W>L1@001W>L
0P0000=oo`0000001W>L1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW00600001FmkLia_Ng>LKg/01P003Goo
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo000C
Ool60005Li`60005Li`60003Li`00`00Li`000050005Li`=Ool60005Li`60005Li`60006Li`50006
Li`=Ool50006Li`50006Li`50006Li`50003Li`00`00LiacW00=Ool60005Li`60005Li`60005Li`6
0005Li`>Ool50003Li`00`00LiacW0050006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005
Li`60005Li`=Ool60005Li`60003Li`00`00Li`000050005Li`60006Li`=Ool50003Li`00`00Liac
W0050006Li`50006Li`50006Li`=Ool60003Li`00`00Li`000050005Li`60005Li`60005Li`?Ool0
01=oo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000A_N`00001oo`L00005Lia_Ng>L
Kg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk0P00
00Uoo`00001_Ng>LKg]cW6mkLi`03Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mk001oo`00Kg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00>Ool500001W>LKg/007oo
001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D0
0006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW003000027oo000006mk
Lia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000AcW000001oo`L00005Kg]cW6mkLia_N`060000
1W>LKg]cW6mkLia_N`eoo`D00006Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000AcW000001oo`L00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P001G>L1`0000Aoo`00001o
o`H000EcW0eoo`H000EcW0H000EcW0H000IcW003001oo`00008000IcW0eoo`D000IcW0D000IcW0D0
00IcW0D00003Li`007oo00<000eoo`H000EcW0H000EcW0800004Ool000000005Li`60005Li`>Ool5
00001G>L00000000Ool01P001W>L1@001W>L1@001W>L3Goo1@001W>L1P001G>L1P001G>L100000=o
o`00Li`017>L3Goo1P001G>L1`0000Aoo`00001oo`H000EcW0H000IcW0eoo`D00003Li`0000000P0
00IcW0D000IcW0D000IcW0eoo`L00004Ool00000Ool60005Li`60005Li`60005Li`?Ool001=oo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000=_N`00Ool0200000EcW6mkLia_Ng>L00eo
o`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/200002Goo0000
06mkLia_Ng>LKg]cW00=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg/007oo001_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00ioo`D00006Lia_N`00Ool006mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>L
Kg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_
N`eoo`H00005Kg]cW6mkLia_N`06000017>L000007oo1`0000E_Ng>LKg]cW6mk00H00006Lia_Ng>L
Kg]cW6mk3Goo1@0000IcW6mk001oo`00Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`=Ool600000g>L001oo`0800001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0H000EcW0H0009cW003001cW7>L00H000Ec
W0eoo`H000EcW0H000EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW0D000IcW0D000=cW003001c
W7>L00eoo`H000EcW0H000EcW0H000EcW0H000EcW0ioo`D000=cW003001cW7>L00D000IcW0D000Ic
W0D000IcW0eoo`D000IcW0H000EcW0H000EcW0H000EcW0eoo`H000EcW0H000=cW003001cW00000D0
00EcW0H000IcW0eoo`D000=cW003001cW7>L00D000IcW0D000IcW0D000IcW0eoo`H0009cW003001c
W7>L00H000EcW0H000EcW0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>LKg]cW00600001Fmk
Lia_N`00Kg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`004goo1W>L1@00
0W>L00@007oo001cW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0<00003Ool007>L00EcW0H000Ec
W0H000eoo`EcW0H000EcW0<00003Ool0000000EcW0H000EcW0H000eoo`IcW0D0009cW004001oo`00
Li`50006Li`50006Li`5000>Ool5Li`60005Li`300000goo00000005Li`60005Li`6000=Ool5Li`6
0006Li`50002Li`01000Ool007>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L1@000W>L00@007oo
001cW0H000eoo`EcW0H000EcW0H000EcW0H000EcW0<00003Ool0000000eoo`IcW0D000IcW0D000Ic
W0D0009cW004001oo`00Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000=cW0000000200000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/00P0000Uoo`00000007>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06
Kg]cW6mkLia_Ng>L1@0000=cW0000000200000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
00ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500000g>L0000000800001Vmk
Lia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D00003Li`007oo00T000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW002000017oo000000003Goo00IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000=_N`00000020003goo000COol6Li`50002Li`0
0`00Ool000060006Li`50006Li`5000=Ool6Li`50006Li`300000goo00000005Li`60005Li`6000=
Ool5Li`60005Li`300000goo00000005Li`60005Li`6000=Ool6Li`50002Li`00`00Ool000060006
Li`50006Li`5000>Ool5Li`60005Li`300000goo00000005Li`60005Li`6000=Ool5Li`60006Li`5
0002Li`00`00Ool000060006Li`5000=Ool6Li`50006Li`50006Li`50002Li`00`00Ool00007000=
Ool5Li`60005Li`60005Li`60005Li`300000goo0000000=Ool6Li`50006Li`50006Li`50002Li`0
0`00Ool00006000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mk001oo`00Kg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0<00008Ool007>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`06000=Ool01Vmk
Lia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P00
00EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_N`00
Ool006mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`H000eoo`05Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00300000goo0000000=Ool01W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001c
W0D000moo`004goo1W>L1@000g>L00<007>LLi`01@001W>L1@001W>L1@003Goo1W>L1@001W>L1@00
1W>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@000g>L00<007>LLi`0
1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@000g>L
00<007>LLi`01@001W>L1@003Goo1W>L1@001W>L1@001W>L1@000g>L00<007>LLi`01P003Goo1G>L
1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@000g>L00<007>LLi`01@003goo
003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogoo
ogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]o
o`00ogooogoo6goo003oOoooOolKOol001=oo`H000EcW0H000EcW0H000EcW0H000EcW0eoo`H000Ec
W0H000EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`H000EcW0H000Ec
W0H000EcW0H000EcW0ioo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`D000IcW0H000EcW0H000Ec
W0H000EcW0eoo`H000EcW0H000EcW0H000EcW0H000IcW0eoo`D000IcW0D000IcW0D000IcW0D000Ic
W0eoo`H000EcW0H000EcW0H000EcW0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0300002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]c
W0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qoo`00
001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`3000027oo001cW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_
Ng>L1P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0=Ool6
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00006Lia_
Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0<00008Ool007>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03
000027oo000007>LKg]cW6mkLi`600001FmkLia_Ng>LKg/03goo000COol60005Li`60005Li`40000
0goo001cW004Li`60005Li`=Ool60005Li`60005Li`2000017oo000000001W>L1@001W>L3Goo1@00
1W>L1@001W>L00H007oo000007oo0005Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`>
Ool50006Li`50006Li`01P00Ool00000Ool000EcW0D000IcW0eoo`D000IcW0H000EcW0@00003Ool0
07>L00AcW0H000EcW0eoo`H000EcW0H000EcW0800004Ool000000005Li`60006Li`=Ool50006Li`5
0006Li`01P00Ool00000Ool000EcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0moo`00
4goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/60000
1G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0300002Goo000007>L
Kg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00ioo`D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`200002Goo000007>LKg]cW6mkLia_N`050000
1VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00<00008Ool00000
Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00<00008Ool00000Kg]cW6mkLia_N`H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P00
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`600001FmkLia_
Ng>LKg/03goo000COol60005Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`5
0006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`>
Ool50006Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005
Li`60005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005
Li`60005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool50000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`IcW0D000=cW003001c
W7>L00D000IcW0D000IcW0D000eoo`IcW0D000=cW003001cW7>L00D000IcW0H000EcW0H000eoo`Ec
W0H000EcW0H000EcW0H000=cW003001cW00000D000eoo`IcW0D000IcW0D000IcW0D000=cW003001c
W7>L00D000ioo`EcW0H000EcW0H000EcW0H000=cW003001cW00000D000eoo`EcW0H000IcW0D000Ic
W0D000=cW003001cW7>L00D000eoo`IcW0D000IcW0D000IcW0D000=cW003001cW7>L00H000eoo`Ec
W0H000EcW0H000EcW0H000=cW003001cW00000D000eoo`IcW0D000IcW0D000IcW0D000IcW0D000mo
o`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_
Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000A_N`00001oo`L000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@003Woo00E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000AcW000001oo`L000eoo`05Lia_Ng>LKg]cW006
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`5000=Ool01Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_
N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00004Li`0
0000Ool7000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0<00003Ool007oo00ioo`004goo1W>L1@0000EcW000000007oo00H000Ic
W0D000IcW0D000eoo`IcW0D00003Li`007oo00P000IcW0H000EcW0H000eoo`EcW0H000EcW0H000Ec
W0L00004Ool00000Ool6000=Ool6Li`50006Li`50006Li`500000g>L001oo`08000>Ool5Li`60005
Li`60005Li`7000017oo000007oo1P003Goo1G>L1P001W>L1@001W>L1@0000EcW000000007oo00H0
00eoo`IcW0D000IcW0D000IcW0D00003Li`007oo00T000eoo`EcW0H000EcW0H000EcW0L00004Ool0
0000Ool6000=Ool6Li`50006Li`50006Li`50006Li`01P00Ool00000Ool000ioo`004goo00I_Ng>L
Kg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/600001G>L
Kg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000A_N`00001oo`L000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_N`00Ool006mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000=cW000Ool020003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001cW0D000eoo`06Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1P003Goo00E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000AcW000001oo`L000eoo`06
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L0P0000=oo`0000003goo000COol6Li`50003Li`00`00LiacW0050006Li`50006Li`5000=Ool6
Li`50003Li`00`00LiacW0050006Li`60005Li`6000=Ool5Li`60005Li`60005Li`60003Li`00`00
Li`00005000=Ool6Li`50006Li`50006Li`50003Li`00`00LiacW005000>Ool5Li`60005Li`60005
Li`60002Li`00`00LiacW006000=Ool5Li`60006Li`50006Li`50003Li`00`00LiacW005000=Ool6
Li`50006Li`50006Li`50003Li`00`00LiacW006000=Ool5Li`60005Li`60005Li`60003Li`00`00
Li`00005000=Ool6Li`50006Li`50006Li`50006Li`5000?Ool001=oo`H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`=Ool5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mk001_Ng>L1P0000E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg/006mk00H00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_
N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005
Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?
Ool001=oo`<00003Ool0000000EcW0H000EcW0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H000Ic
W0D0009cW004001oo`00Li`=Ool300000goo001cW005Li`50006Li`50006Li`50006Li`=Ool30000
0goo00000005Li`60005Li`60005Li`60005Li`>Ool50002Li`01000Ool007>L1@001W>L1@001W>L
1@001W>L3Goo1@000W>L00@007oo001cW0H000EcW0H000EcW0H000EcW0eoo`H00004Li`00000Ool7
0005Li`60005Li`60006Li`=Ool50006Li`50002Li`01000Ool007>L1@001W>L1@001W>L3Goo1P00
1G>L1P0000AcW000001oo`L000EcW0H000EcW0moo`004goo100000Moo`00Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_N`00000007oo000=Ool02`00
Ool00000Ool007>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00ioo`D00005Li`00000001oo`0600001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500000fmk001oo`0900001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool7000017oo000007oo1P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@00
00=_N`00Ool0200000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]c
W007000017oo000007oo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`<00003
Ool0000000EcW0H000EcW0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H000IcW0D0009cW004001o
o`00Li`=Ool300000goo001cW005Li`50006Li`50006Li`50006Li`=Ool300000goo00000005Li`6
0005Li`60005Li`60005Li`>Ool50002Li`01000Ool007>L1@001W>L1@001W>L1@001W>L3Goo1@00
0W>L00@007oo001cW0H000EcW0H000EcW0H000EcW0eoo`H00004Li`00000Ool70005Li`60005Li`6
0006Li`=Ool50006Li`50002Li`01000Ool007>L1@001W>L1@001W>L3Goo1P001G>L1P0000=cW000
Ool020001G>L1P001G>L3goo000COol600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_
N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@00
00IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`=Ool500001VmkLia_N`00Kg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>L
001cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol60005Li`60005Li`6
0005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=Ool50006Li`50006Li`50006Li`5
0006Li`=Ool60005Li`60005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006Li`50006Li`=
Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60005Li`60006Li`=Ool50006
Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`?Ool001=oo`06Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk
1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000Ec
W6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000EcW6mkLia_Ng>L
00H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=
Ool01FmkLia_N`00Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P003Goo00IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000IcW0D0009cW004001oo`00Li`5000=
Ool6Li`50006Li`300000goo001cW005Li`60005Li`6000=Ool5Li`6000017>L000007oo1`001G>L
1P001G>L1P003Goo1W>L1@001W>L0`0000=oo`00Li`01G>L1@001W>L1@003Woo1G>L1P001G>L0`00
00=oo`0000001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L0P0000=oo`0000001W>L1@003Goo
1W>L1@001W>L1@001W>L0`0000=oo`00Li`01G>L1P003Goo00AcW000001oo`L000EcW0H000EcW0H0
00EcW0H000eoo`9cW004001oo`00Li`50006Li`50006Li`50006Li`5000?Ool001=oo`06Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00005Li`00000001oo`06000=
Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L100000Moo`00Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00L00004Ool00000Ool600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000QcW6mkLia_Ng>LKg/007oo0P0000Mo
o`00Lia_Ng>LKg]cW00500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`0100000Moo`00Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L
00H00006Kg]cW6mkLia_Ng>L1@0000QcW6mkLia_Ng>LKg/007oo0P0000Moo`00Lia_Ng>LKg]cW005
000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`400001goo
001_Ng>LKg]cW6mk00H000eoo`05001oo`00001oo`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>L00000000Ool01P0000I_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo000COol6Li`50006Li`50006Li`50002
Li`01000Ool007>L1@003Goo1W>L1@001W>L0`0000=oo`00Li`01G>L1P001G>L1P003Goo1G>L1P00
00AcW000001oo`L000EcW0H000EcW0H000eoo`IcW0D000IcW0800003Ool0000000IcW0D000IcW0D0
00ioo`EcW0H000EcW0<00003Ool0000000EcW0H000EcW0H000eoo`EcW0H000IcW0D000IcW0800003
Ool0000000IcW0D000eoo`IcW0D000IcW0D000IcW0<00003Ool007>L00EcW0H000eoo`03Li`007oo
00P000EcW0H000EcW0H000EcW0H000eoo`9cW004001oo`00Li`50006Li`50006Li`50006Li`5000?
Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>L001cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P00
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]c
W6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
3Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/6000=Ool01FmkLi`007>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`01P003Goo00IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000IcW0D000IcW0D0
00eoo`IcW0D000IcW0D000IcW0H0009cW003001cW7>L00H000eoo`EcW0H000EcW0H000EcW0H000Ec
W0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eo
o`EcW0H000=cW003001cW7>L00D000IcW0D000IcW0D000eoo`IcW0D000=cW003001cW7>L00D000Ic
W0D000IcW0H000eoo`EcW0H000=cW003001cW00000D000EcW0H000EcW0H000eoo`IcW0D000=cW003
001cW7>L00D000IcW0D000IcW0D000moo`004goo1P0000=_N`00Ool0200000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001W>LKg]cW6mkLia_N`800009Ool00000Kg]cW6mkLia_Ng>L00eoo`D00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk3Goo
1P0000A_N`00001oo`L00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW000Ool007>L3Goo1@0000I_Ng>LKg]cW6mkLi`3000027oo000006mkLia_Ng>LKg/600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`03000027oo000007>LKg]c
W6mkLi`600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`<0
0008Ool006mkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool60000
1G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0?Ool001=oo`L00004Ool00000Ool60005Li`60005Li`60005Li`=Ool60005Li`60005Li`6
0006Li`00`00Ool000020006Li`=Ool50006Li`50006Li`50006Li`500000g>L001oo`03000=Ool7
000017oo000007oo1P001G>L1P001G>L1P001G>L3Woo1@001W>L1@001W>L1@001W>L1@0000=cW000
00000`003Goo1@001W>L100000=oo`00Li`017>L1P001G>L1P001G>L3Goo1P001G>L0P0000Aoo`00
000000EcW0H000EcW0H000IcW0eoo`D000IcW006001oo`00001oo`001G>L1@001W>L1@001W>L3Goo
1P001G>L1P001G>L1P001G>L1P001G>L3goo000COol600000fmk001oo`0800001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H00006Lia_Ng>LKg]cW6mk0P0000Uoo`00001_Ng>LKg]cW6mkLi`03Goo1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk001oo`00Kg/=
Ool600000fmk001oo`0800001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLi`007oo001cW0eoo`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00001_Ng>LKg]cW6mk1P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mk
Lia_Ng>L1P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/3
000027oo001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P00
00EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/03goo000COol60002Li`00`00LiacW0060005Li`60005Li`60005Li`=Ool60005Li`60005
Li`60006Li`50006Li`=Ool50006Li`50006Li`50006Li`50003Li`00`00LiacW00=Ool60002Li`0
0`00LiacW0060005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006Li`50003Li`00`00Liac
W00=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60005Li`60006Li`=Ool5
0006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`?Ool001=oo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0?Ool001=oo`IcW0D000IcW0D000IcW0D000IcW0D000eoo`=cW003001cW7>L
00D000IcW0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW0D000Ic
W0D000IcW0D000IcW0D000ioo`=cW003001cW00000D000EcW0H000EcW0H000EcW0H000eoo`=cW003
001cW00000D000IcW0D000IcW0D000IcW0D000eoo`=cW003001cW7>L00D000IcW0D000IcW0D000Ic
W0H000eoo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000mo
o`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/300000goo001oo`0<Ool01W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P003Goo00I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/300000goo
001oo`0=Ool016mk000007oo1`0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P003Goo00AcW6mk001oo`L00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00003Ool0000000eoo`06Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`<00008Ool006mkLia_Ng>LKg]cW0D000mo
o`004goo1W>L1@001W>L1@001W>L1@001W>L00H007oo000007oo000<Ool00g>L001oo`080006Li`5
0006Li`60005Li`6000=Ool5Li`60005Li`60005Li`2000017oo000000001G>L1P003Goo1W>L1@00
1W>L1@001W>L1@001W>L00H007oo000007oo000=Ool01@00Ool00000Ool01P001G>L1P001G>L1P00
1G>L1P003Goo00EcW000000007oo00H000IcW0D000IcW0D000IcW0D000eoo`03Li`007oo00P000Ic
W0D000IcW0D000IcW0H000eoo`EcW0H000EcW0H000EcW0H000EcW0800004Ool00000000=Ool6Li`5
0006Li`50006Li`01P00Ool00000Ool000EcW0D000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/200000goo0000000=Ool0
1W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mk
Li`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qo
o`00001_Ng>LKg]cW6mk1P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/300000goo001oo`0=Ool00fmk001oo`0800001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool017>LKg/007oo1`0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>L001o
o`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=
Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`00`0000=oo`0000003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk0P0000Uoo`00001_Ng>LKg]cW6mkLi`01@003goo000COol6Li`50006Li`50006Li`50006
Li`5000=Ool3Li`00`00LiacW0050006Li`50006Li`60005Li`6000=Ool5Li`60005Li`60005Li`6
0005Li`6000=Ool6Li`50006Li`50006Li`50006Li`5000>Ool2Li`00`00LiacW0060005Li`60005
Li`60005Li`6000=Ool3Li`00`00Li`000050006Li`50006Li`50006Li`5000=Ool3Li`00`00Liac
W0050006Li`50006Li`50006Li`6000=Ool5Li`60005Li`60005Li`60005Li`6000=Ool6Li`50006
Li`50006Li`50006Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
00ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`H000Ec
W0H000EcW0H00004Li`00000Ool70005Li`=Ool60005Li`60005Li`60002Li`01000Ool007>L1@00
1W>L3Goo1@001W>L1@000W>L00@007oo001cW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H00004
Li`00000Ool70005Li`>Ool50006Li`300000goo001cW005Li`50006Li`50006Li`=Ool50006Li`6
00001G>L001oo`00Li`01P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001G>L1P000W>L00@007oo
001cW0eoo`D000IcW0D000IcW0D0009cW004001oo`00Li`50006Li`=Ool6000017>L000007oo1`00
1G>L1P001G>L1P001G>L3goo000COol600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00L00003
Ool0000000L00005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H0
0003Li`0000000P00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500000g>L001oo`08
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00700000goo0000000700001G>LKg]cW6mkLi`03Woo1@0000QcW6mkLia_Ng>LKg/007oo
100000EcW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001Vmk
Lia_Ng>LKg]cW0L00003Ool0000000L00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000=cW00000000`00
3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00003Li`007oo00P00006Kg]cW6mk
Lia_Ng>L3Goo1`0000=oo`0000001`0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/03goo000COol60005Li`60005Li`6000017>L001oogoo1`001G>L3Goo1P001G>L1P00
1G>L1P000W>L00<007oo00001P001W>L3Goo1@001W>L1@000W>L00<007oo00001P001W>L1@001W>L
3Goo1P001G>L1P001G>L1P0000AcW000Oomoo`L000EcW0ioo`D000IcW080009oo`8000EcW0D000Ic
W0D000IcW0eoo`D000IcW0H00003Li`007oo00P000EcW0H000EcW0eoo`H000EcW0H000EcW0H000Ec
W0H0009cW004001oo`00000=Ool50006Li`50006Li`50002Li`00`00Ool000060006Li`=Ool60000
17>L001oogoo1`001G>L1P001G>L1P001G>L3goo000COol600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg/007oo001_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0600001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=
Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00004Kg]cW000Ool700001G>LKg]cW6mk
Li`03Woo1@0000IcW6mkLia_Ng>LKg/200002Goo000006mkLia_Ng>LKg]cW00500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001Fmk001oo`00Kg/01P00
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg/007oo001_N`eoo`D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW000
Ool007>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`00
4goo1P001G>L1P001G>L1P000W>L00<007>LLi`01P001G>L3Goo1P001G>L1P001G>L1P000g>L00<0
07>LLi`01@001W>L3Goo1@001W>L1@000g>L00<007>LLi`01@001W>L1@001W>L3Goo1P001G>L1P00
1G>L1P000g>L00<007>L00001@001G>L3Woo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1@001W>L
1P000W>L00<007>LLi`01P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001G>L1P000g>L00<007>L
Li`03Goo1@001W>L1@001W>L1@000g>L00<007>LLi`01@001W>L3Goo1P000W>L00<007>LLi`01P00
1G>L1P001G>L1P001G>L3goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]c
W6mkLi`500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>
Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@003goo000COol6Li`50006
Li`300000goo001cW005Li`50006Li`5000=Ool6Li`300000goo001cW005Li`50006Li`60005Li`6
000=Ool5Li`300000goo00000005Li`60005Li`60005Li`6000=Ool6Li`50002Li`01000Ool007>L
1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L0`0000=oo`0000001G>L1P003Goo1G>L1P00
1W>L1@001W>L1@001W>L0`0000=oo`00Ool037oo1W>L1@001W>L0`0000=oo`00Li`01G>L1@001W>L
1P003Goo1G>L0`0000=oo`0000001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@00
0W>L00@007oo001cW0D000moo`004goo00I_Ng>LKg]cW6mkLi`5000027>LKg]cW6mkLia_N`00Ool2
00001goo001cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@003Goo00QcW6mkLia_Ng>LKg/007oo
0P0000Moo`00Lia_Ng>LKg]cW00500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool0
1G>LKg]cW6mkLi`00P0000Uoo`00000006mkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00003Li`0000000P00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0400001goo001cW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000Q_Ng>LKg]cW6mkLi`007oo0P0000=oo`00Ool02goo00I_Ng>L
Kg]cW6mkLi`5000027>LKg]cW6mkLia_N`00Ool200001goo001cW6mkLia_Ng>L00D00006Lia_Ng>L
Kg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00800009Ool00000001cW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000=_N`00000020003goo000COol6Li`50006Li`200000goo00000006
Li`50006Li`5000=Ool6Li`300000goo001cW005Li`50006Li`60005Li`6000=Ool5Li`300000goo
00000005Li`60005Li`60005Li`6000=Ool6Li`50002Li`01000Ool007>L1@001W>L1@001W>L1@00
3Woo1G>L1P001G>L1P001G>L0`0000=oo`0000001G>L1P003Goo1G>L1P001W>L1@001W>L1@001W>L
0P0000=oo`0000003Goo1W>L1@001W>L0`0000=oo`00Li`01G>L1@001W>L1P003Goo1G>L0`0000=o
o`0000001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@000W>L00@007oo001cW0D0
00moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mk
Li`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_
Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D000moo`004goo1W>L1@001W>L1@001W>L1@001W>L
1@003Goo1W>L1@001W>L1@001W>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo
1W>L1@001W>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P00
1W>L1@001W>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P00
1G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@001W>L1@003goo003oOoooOolKOol00?mooomo
oa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol0
0?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo000WOol0
0`00Oomoo`0kOol00`00Oomoo`0gOol00`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0fOol0
0`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0fOol00`00Oomoo`0OOol001=oo`H000EcW0H0
0004Li`00000Ool70005Li`60005Li`=Ool60005Li`60005Li`300000goo00000006Li`50006Li`=
Ool50006Li`50006Li`300000goo001cW005Li`50006Li`=Ool60005Li`60005Li`300000goo0000
0005Li`60005Li`>Ool50006Li`50006Li`300000goo001cW005Li`50006Li`=Ool50006Li`60005
Li`300000goo00000005Li`60005Li`=Ool60005Li`60005Li`300000goo00000005Li`60006Li`=
Ool50006Li`50006Li`300000goo001cW005Li`50006Li`=Ool60005Li`60005Li`300000goo0000
0005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`070003Ool700001FmkLia_Ng>LKg/01P00
00EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00P000Woo0P0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000McW6mkLia_
Ng>LKg/00003Ool01`00Kg]cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW0020002Ool200001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00io
o`D00006Lia_Ng>LKg]cW6mk1@0000M_Ng>LKg]cW6mkLi`00003Ool01`00Lia_Ng>LKg]cW6mk00D0
0006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/00P000Woo0P00
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L0080009oo`800005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]c
W6mk1@0000M_Ng>LKg]cW6mkLi`00003Ool01`00Lia_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L
3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`020002Ool200001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P0000EcW000000007oo00H000EcW0H000EcW0eoo`H0
00EcW0H000EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW0@00003Ool007>L00AcW0D000IcW0eo
o`H000EcW0H000EcW0H000EcW0H000EcW0ioo`D000IcW0D000IcW0@00003Ool007>L00AcW0D000Ic
W0eoo`D000IcW0H000EcW0@00003Ool007>L00AcW0H000EcW0eoo`H000EcW0H000EcW0H000EcW0H0
00IcW0eoo`D000IcW0D000IcW0@00003Ool007>L00AcW0D000IcW0eoo`H000EcW0H000EcW0H000Ec
W0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00H00003Li`007oo00P00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0300002Goo0000
07>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00io
o`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`200002Goo000007>LKg]cW6mkLia_N`05
00001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00<00008Ool0
0000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`600001Fmk
Lia_Ng>LKg/03goo000COol60005Li`60002Li`00`00LiacW0060005Li`60005Li`=Ool60005Li`6
0005Li`60006Li`50006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`6
0005Li`60005Li`>Ool50006Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005Li`6
0005Li`=Ool60005Li`60005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006Li`50006Li`=
Ool60005Li`60005Li`60005Li`60005Li`?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLi`007>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_
Ng>L001cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=
Ool01VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>L
Kg/500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool0
01=oo`IcW0D000IcW0D000IcW0D000IcW0<00003Ool007oo00aoo`9cW004001oo`00Li`50006Li`5
0006Li`60005Li`6000=Ool017>L000007oo1`001G>L1P001G>L1P001G>L1P003Goo0W>L00@007oo
001cW0D000IcW0D000IcW0D000IcW0D000ioo`EcW0<00003Ool0000000EcW0H000EcW0H000EcW0H0
00eoo`EcW0<00003Ool0000000IcW0D000IcW0D000IcW0D000eoo`IcW0<00003Ool007>L00EcW0D0
00IcW0D000IcW0H000eoo`EcW0<00003Ool0000000EcW0H000EcW0H000EcW0H000eoo`IcW0D0009c
W004001oo`00Li`50006Li`50006Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0D00008Lia_Ng>LKg]cW6mk001oo`800003Ool007oo00]oo`03
Li`007oo00P00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P00
3Goo00D007oo000007oo00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00H000eoo`03Kg/0000000P00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0400001goo001cW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L0080000:Ool00000001_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00Q_Ng>LKg]cW6mkLi`0
07oo0P0000Moo`00Kg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P00
3Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000=_N`000000200000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D000moo`004goo1W>L1@001W>L1@001W>L1@001W>L0P0000=oo`0000003Goo0W>L
00@007oo001cW0D000IcW0D000IcW0H000EcW0H000eoo`04Li`00000Ool70005Li`60005Li`60005
Li`6000=Ool2Li`01000Ool007>L1@001W>L1@001W>L1@001W>L1@003Woo1G>L0`0000=oo`000000
1G>L1P001G>L1P001G>L1P003Goo1G>L0`0000=oo`0000001W>L1@001W>L1@001W>L1@003Goo1W>L
0`0000=oo`00Li`01G>L1@001W>L1@001W>L1P003Goo1G>L0`0000=oo`0000001G>L1P001G>L1P00
1G>L1P003Goo1W>L1@000W>L00@007oo001cW0D000IcW0D000IcW0D000moo`004goo00I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000=
Ool01W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]c
W6mkLi`01P003Goo00EcW6mkLi`007>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D000moo`004goo1W>L1@001W>L1@000g>L00<007>LLi`01@001W>L1@003Goo1W>L
1@001W>L1@001W>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L
1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L
1@001W>L1@003Goo1W>L1@001W>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L
1P003Goo0g>L00<007>LLi`01@001W>L1@001W>L1@001W>L1@003goo000COol600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00=Ool6
00001G>LKg]cW6mkLi`01P0000A_Ng>L001oo`L00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`50000
1W>LKg/007oo001_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00H00005Lia_N`00Ool0000>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@00
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_N`00
Ool006mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW006000016mkLi`007oo1`0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001cW0eoo`<0
0008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00moo`004goo1P001G>L1P001G>L0`0000=oo`0000001G>L1P001G>L3Goo1P001G>L1P00
0W>L00<007oo00001P001W>L1@001W>L3Goo1@001W>L1@001W>L1@001W>L1@000W>L00@007oo001c
W0eoo`H000EcW0H000EcW0H000EcW0H00005Li`007ooOol0000>Ool50006Li`50002Li`01000Ool0
07>L1@001W>L1@001W>L3Goo1@001W>L1P0000EcW000Ool007>L00H000EcW0H000EcW0eoo`H000Ec
W0H000EcW0H0009cW003001oo`0000H000IcW0eoo`D000IcW0D000IcW0D000IcW0D0009cW004001o
o`00Li`=Ool300000goo00000005Li`60005Li`60005Li`60005Li`?Ool001=oo`H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`0100000Moo`00Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo
1P0000EcW6mkLia_Ng>L00H00005Kg/00000001oo`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
1@0000=cW000Ool00`003Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01`0000Eoo`00001oo`0000eoo`D00006Lia_Ng>LKg]cW6mk1@0000E_N`00000007oo00H0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0L00003Ool0
000000L00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00600001Fmk00000000Ool01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500000fmk001oo`03000=Ool40000
1goo001cW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00moo`004goo1P001G>L1P001G>L0`0000=oo`0000001G>L1P001G>L3Goo1P001G>L1P000W>L
00<007oo00001P001W>L1@001W>L3Goo1@001W>L1@001W>L1@001W>L1@000W>L00@007oo001cW0eo
o`H000EcW0H000EcW0H000EcW0H00005Li`00000Ool0000>Ool50006Li`50002Li`01000Ool007>L
1@001W>L1@001W>L3Goo1@001W>L1P0000EcW000Ool007>L00H000EcW0H000EcW0eoo`H000EcW0H0
00EcW0H0009cW003001oo`0000H000IcW0eoo`D000IcW0D000IcW0D000IcW0D0009cW004001oo`00
Li`=Ool300000goo00000005Li`60005Li`60005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg/006mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=
Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW000Lia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00005Lia_Ng>L001cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>L001c
W6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0eoo`H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_
N`0?Ool001=oo`IcW0D000=cW003001cW7>L00D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000Ic
W0H000EcW0H000eoo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000Ic
W0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H000IcW0D000IcW0D000=cW003001c
W7>L00D000eoo`=cW003001cW7>L00D000IcW0D000IcW0D000IcW0H000eoo`=cW003001cW00000D0
00EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000moo`004goo00I_Ng>L
Kg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/3000027oo
000007>LKg]cW6mkLi`6000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool00000
Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`6000=Ool0
1G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool0
07>L1@003Goo00I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/6000=Ool016mk000007oo1`0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L1@003goo000COol6Li`500001G>L00000000
Ool01P001W>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L100000=oo`00Li`017>L1P003Goo1G>L
1P001G>L0P0000Aoo`00000000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW006001oo`00001o
o`001G>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L1@0000Ec
W000000007oo00H000eoo`03Li`007oo00P000IcW0D000IcW0D000IcW0H000eoo`05001oo`00001o
o`060005Li`60005Li`60005Li`6000=Ool6Li`50006Li`50006Li`01P00Ool00000Ool000EcW0D0
00moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/3000027oo000007>LKg]cW6mkLi`6000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_Ng>LKg/5000>
Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>L
Kg]cW6mkLi`6000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D00006Kg]cW000Ool007>L1@003Goo00I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool00fmk001oo`0800001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/200002Goo000006mkLia_Ng>LKg]cW005000?Ool001=o
o`IcW0D000=cW003001cW7>L00D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000IcW0H000EcW0H0
00eoo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000ioo`Ec
W0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H000IcW0D000IcW0D000=cW003001cW7>L00D000eo
o`=cW003001cW7>L00D000IcW0D000IcW0D000IcW0H000eoo`9cW003001cW7>L00H000EcW0H000Ec
W0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000moo`004goo00I_Ng>LKg/006mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000=Ool01W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`0
1P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_N`00Kg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`H000eoo`05Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool0
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D000moo`004goo0`0000=oo`0000001G>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L1P00
1G>L1P001W>L1@000W>L00@007oo001cW0eoo`D0009cW004001oo`00Li`50006Li`50006Li`50006
Li`=Ool60005Li`300000goo00000005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006Li`5
0002Li`01000Ool007>L3Goo1@001W>L0`0000=oo`0000001G>L1P001G>L1P001G>L3Goo1P001G>L
1P001G>L1P001G>L0`0000=oo`0000001W>L3Goo1@001W>L1@000W>L00@007oo001cW0D000IcW0D0
00IcW0eoo`H000EcW0H000EcW0H000EcW0H0009cW003001oo`0000moo`004goo0`0000Qoo`00001_
Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW000
Ool007>L3Goo1@0000I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001cW0eoo`D00006Kg]cW6mkLia_Ng>L
0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool60000
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0300002Goo000007>LKg]c
W6mkLia_N`0=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg/007ooOol0000?Ool001=oo`@00003Ool007>L00AcW0H000EcW0H000Ec
W0H000EcW0eoo`H000EcW0H000EcW0H000IcW0D00006Li`00000001oo`003Goo1@0000=cW000Ool0
20001W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P001G>L3Woo1@001W>L1@001W>L
1@001W>L1@0000=cW00000000`003Goo1@001W>L100000=oo`00Li`017>L1P001G>L1P001G>L3Goo
1P001G>L1P001G>L1P001G>L0P0000Aoo`00000000IcW0eoo`D000IcW0D00003Li`007oo00P000Ic
W0D000IcW0eoo`H000EcW0H000EcW0H000EcW0L00005Ool00000Ool0000>Ool001=oo`<00008Ool0
0000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001Vmk
Li`007oo001cW0eoo`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]c
W0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`=Ool500001VmkLia_Ng>L
Kg]cW0<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Uoo`00001c
W6mkLia_Ng>LKg/03Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001cW0D00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00600001Fmk000007oo00003goo000COol60005Li`60005Li`60005Li`60005
Li`=Ool60005Li`60005Li`60006Li`50003Li`00`00LiacW00=Ool50003Li`00`00LiacW0050006
Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006
Li`50003Li`00`00LiacW00=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`6
0005Li`60006Li`=Ool50006Li`50003Li`00`00LiacW0050006Li`50006Li`=Ool60005Li`60005
Li`60005Li`60003Li`00`00Liaoo`0>Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@003Goo00IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`06000=Ool0
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000
Lia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P003Goo00IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=o
o`IcW0D000IcW0D000IcW0D0009cW004001oo`00Li`5000=Ool6Li`300000goo001cW005Li`50006
Li`60005Li`6000=Ool5Li`60005Li`60005Li`6000017>L000007oo1`003Goo1W>L1@001W>L1@00
1W>L1@000W>L00@007oo001cW0D000ioo`EcW0H00004Li`00000Ool70005Li`60005Li`6000=Ool5
Li`60006Li`50006Li`50006Li`300000goo001oo`0<Ool6Li`50006Li`300000goo001cW005Li`5
0006Li`6000=Ool5Li`60005Li`60005Li`6000017>L000007oo1`003Goo1W>L0`0000=oo`00Li`0
1G>L1@001W>L1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`500001G>L00000000Ool01P003Goo00QcW6mkLia_Ng>LKg/007oo0P0000Mo
o`00Lia_Ng>LKg]cW00500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW007000017oo000007oo1P003Goo00I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000=cW000Ool02000
3Woo00E_Ng>LKg]cW6mk00L00004Ool00000Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000Q_
Ng>LKg]cW6mkLi`007oo0P0000=oo`00Ool02goo00I_Ng>LKg]cW6mkLi`5000027>LKg]cW6mkLia_
N`00Ool200001goo001cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01`0000Aoo`00001oo`H000eoo`08Lia_Ng>L
Kg]cW6mk001oo`800007Ool007>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D000moo`004goo1W>L1@001W>L1@001W>L1@000W>L00@007oo001cW0D000eoo`IcW0<00003
Ool007>L00EcW0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000EcW0H00004Li`00000Ool7000=
Ool6Li`50006Li`50006Li`50002Li`01000Ool007>L1@003Woo1G>L1P0000=cW000Ool020001G>L
1P001G>L1P003Goo1G>L1P001W>L1@001W>L1@001W>L0P0000=oo`0000003Goo1W>L1@001W>L0`00
00=oo`00Li`01G>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P0000AcW000001oo`L000eoo`Ic
W0800003Ool0000000IcW0D000IcW0D000IcW0D000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/5000=Ool01W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk
00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>L001cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_N`00Kg]cW00600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW006000=Ool01W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D0
00moo`004goo1W>L1@001W>L1@001W>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L1P001G>L1P00
3Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@001W>L1@003Woo1G>L
1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L1@001W>L1@003Goo1W>L1@001W>L
1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L
1@001W>L1@003goo000COol600001FmkLi`007>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`060000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_N`00Kg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=
Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg/006mkLi`01P0000E_Ng>L
Kg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H0
0006Lia_Ng>L001cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol600001G>L001oo`00Li`01P00
1G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001W>L0P0000=oo`0000001W>L3Goo1@001W>L
0`0000=oo`00Li`01G>L1@001W>L1@001W>L3Goo1P0000AcW000001oo`L000EcW0H000EcW0H000Ec
W0ioo`<00003Ool007>L00EcW0D000IcW0D000IcW0D000IcW0eoo`D000IcW0H000EcW0H00003Li`0
07oo00P000EcW0eoo`H000EcW0H000EcW0H000EcW0H0009cW004001oo`00Li`=Ool50006Li`30000
0goo001cW005Li`50006Li`50006Li`=Ool60005Li`6000017>L000007oo1`001G>L1P001G>L3goo
000COol700000goo0000000700001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00008Lia_Ng>LKg]cW6mk001o
o`<00006Kg]cW6mkLia_Ng>L3Goo1@0000Q_Ng>LKg]cW6mkLi`007oo0P0000Moo`00Kg]cW6mkLia_
N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1`0000Aoo`00001oo`H00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`0;001oo`00001oo`00Kg]c
W6mkLia_N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=
Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`07000017oo000007oo1P0000E_Ng>LKg]c
W6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006
Li`00000001oo`003Goo1@0000QcW6mkLia_Ng>LKg/007oo0P0000Moo`00Lia_Ng>LKg]cW0050000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00L00004Ool00000
Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`004goo1P0000=cW000Ool020001G>L
1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001W>L0P0000=oo`0000001W>L3Goo1@001W>L0`00
00=oo`00Li`01G>L1@001W>L1@001W>L3Goo1P0000=cW000Ool020001G>L1P001G>L1P001G>L3Woo
0P0000=oo`0000001W>L1@001W>L1@001W>L1@001W>L3Goo1@001W>L1P001G>L1P0000=cW000Ool0
20001G>L3Goo1P001G>L1P001G>L1P001G>L1P000W>L00@007oo001cW0eoo`D000IcW0<00003Ool0
07>L00EcW0D000IcW0D000IcW0eoo`H000EcW0H00003Li`007oo00P000EcW0H000EcW0moo`004goo
1P0000E_Ng>L001cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>L001cW6mk00H00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mk
Li`600001FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW000Lia_N`eo
o`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW000Lia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00moo`004goo1W>L1@001W>L1@001W>L1@001W>L1@003Goo1W>L1@000g>L
00<007>LLi`01@001W>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@00
1W>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P000g>L00<007>L00001@003Goo0g>L
00<007>L00001@001W>L1@001W>L1@001W>L1@003Goo1W>L1@000g>L00<007>LLi`01@001W>L1@00
1W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@000g>L00<0
07>LLi`01@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`3000027oo001cW6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW000Ool0
07>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P003Goo00I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`<00008Ool006mkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000Ac
W000001oo`L000eoo`04Lia_N`00Ool700001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H000eoo`06Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@003goo000COol6
Li`50006Li`50006Li`01P00Ool00000Ool000EcW0D000eoo`IcW0D00003Li`007oo00P000IcW0H0
00EcW0H000eoo`EcW0H000EcW0H000EcW0800004Ool000000005Li`6000=Ool6Li`50006Li`01P00
Ool00000Ool000EcW0D000IcW0D000ioo`EcW0H000EcW0H000EcW0L00004Ool00000Ool6000=Ool0
1G>L00000000Ool01P001W>L1@001W>L1@001W>L1@003Goo1W>L1@0000=cW000Ool020001W>L1@00
1W>L1P003Goo1G>L1P001G>L1P001G>L0P0000Aoo`00000000EcW0H000eoo`IcW0D000IcW0D000Ic
W0D00003Li`0000000P000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L0P0000Uoo`00001cW6mkLia_Ng>LKg/01@003Goo00IcW6mkLia_Ng>LKg/50000
1VmkLi`007oo001cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H0
00eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/200002Goo000006mkLia_Ng>LKg]cW005
00001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H00003Li`007oo00P000eoo`04Lia_N`00Ool700001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool0
06mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H000eoo`06Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L
1@003goo000COol6Li`50006Li`50006Li`50006Li`5000=Ool6Li`50003Li`00`00LiacW0050006
Li`60005Li`6000=Ool5Li`60005Li`60005Li`60005Li`6000=Ool6Li`50006Li`50006Li`50006
Li`5000>Ool5Li`60005Li`60005Li`60002Li`00`00LiacW006000=Ool3Li`00`00Li`000050006
Li`50006Li`50006Li`5000=Ool6Li`50003Li`00`00LiacW0050006Li`50006Li`6000=Ool5Li`6
0005Li`60005Li`60005Li`6000=Ool6Li`50006Li`50006Li`50003Li`00`00LiacW005000?Ool0
01=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mk
Li`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool00?mooomooa]oo`00ogooogoo6goo003oOoooOolK
Ool00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003o
OoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`004goo1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW0060000
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/0
06mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`6
00001FmkLi`007>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_
Ng>LKg/01P0000EcW6mkLi`007>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P0000AcW000001oo`L000EcW0H000EcW0eoo`H000Ec
W0H0009cW003001oo`0000H000IcW0D000IcW0eoo`D000IcW0D0009cW004001oo`00Li`50006Li`5
0006Li`=Ool60005Li`6000017>L000007oo1`001G>L1P001G>L3Woo1@001W>L1@000W>L00@007oo
001cW0D000IcW0D000IcW0eoo`D000IcW0H00005Li`007oo001cW0060005Li`60005Li`=Ool60005
Li`6000017>L000007oo1`001G>L1P001W>L3Goo1@001W>L1@000W>L00@007oo001cW0D000IcW0D0
00IcW0eoo`H000EcW0H00004Li`00000Ool70005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_
N`07000017oo000007oo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]c
W6mkLi`01P0000E_N`00000007oo00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool5
00001VmkLia_Ng>LKg]cW0D00003Li`007oo00P00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/=Ool600001FmkLia_Ng>LKg/01`0000Aoo`00001oo`H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001Fmk00000000Ool01P0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1`0000=oo`0000001`0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01`0000Aoo`00001oo`H00005Kg]c
W6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000=_N`00Ool02000
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW007000017oo0000
07oo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0H00003Li`007oo
00P000EcW0H000EcW0eoo`H000EcW0H0009cW003001oo`0000H000IcW0D000IcW0eoo`D000IcW0D0
009cW004001oo`00Li`50006Li`50006Li`=Ool60005Li`600000g>L001oo`080005Li`60005Li`>
Ool50006Li`50002Li`01000Ool007>L1@001W>L1@001W>L3Goo1@001W>L1P0000EcW000Ool007>L
00H000EcW0H000EcW0eoo`H000EcW0H00004Li`00000Ool70005Li`60006Li`=Ool50006Li`50002
Li`01000Ool007>L1@001W>L1@001W>L3Goo1P001G>L1P0000=cW000Ool020001G>L1P001G>L3goo
000COol600001FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`0600001W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk001_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_
Ng>LKg]cW0H00005Kg]cW000Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]c
W6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>L001cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/03goo000COol60005Li`60005Li`60003Li`00`00Li`000050005
Li`=Ool60005Li`60005Li`60003Li`00`00LiacW0050006Li`=Ool50006Li`50006Li`50003Li`0
0`00LiacW0050006Li`=Ool60005Li`60005Li`60005Li`60005Li`>Ool50006Li`50006Li`50006
Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60005Li`60006
Li`=Ool50006Li`50006Li`50006Li`50003Li`00`00LiacW00=Ool60005Li`60005Li`60005Li`6
0003Li`00`00Liaoo`0>Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`<00008Ool00000Lia_Ng>LKg]cW0H000eoo`05Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H0
00eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
N`00Ool006mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
1P0000AcW000001oo`L000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>L001oo`00Li`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`H000eoo`05Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00300000goo0000000=Ool01W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0<00003Ool007oo00ioo`004goo1W>L1@001W>L1@001W>L00<007oo00000`001G>L1@003Goo1W>L
1@001W>L1@001W>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L0P0000Aoo`00000000EcW0H000eo
o`IcW0D000IcW0D000IcW0D00003Li`007oo00P000ioo`EcW0H000EcW0H000EcW0L00003Ool00000
00L000eoo`EcW0H000IcW0D000IcW0D00003Li`0000000P000eoo`IcW0D000IcW0D000IcW0D00003
Li`007oo00T000eoo`EcW0H000EcW0H000EcW0H000EcW0800004Ool00000000=Ool6Li`50006Li`5
0006Li`50006Li`00`00Ool00003000>Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW080009oo`800005Kg]cW6mkLia_N`05000=Ool01W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/3000027oo000007>LKg]cW6mkLi`6000=
Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW003000027oo000006mk
Lia_Ng>LKg/6000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`5000017>LKg/007oo1`003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P0000AcW000Oomoo`L000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000A_Ng>L001oo`L000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00004Lia_N`00Ool8000=Ool01FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000=oo`0000003Goo00IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`2
0002Ool2000>Ool001=oo`IcW0D000IcW0D000IcW0800003Ool0000000IcW0D000eoo`IcW0D000Ic
W0D000IcW0<00003Ool0000000EcW0H000eoo`EcW0H000EcW0H000EcW0<00003Ool0000000EcW0H0
00eoo`IcW0D000IcW0D000IcW0D0009cW004001oo`00Li`5000>Ool5Li`60005Li`60005Li`60000
1G>L001oo`00Li`01P003Goo1G>L1P001W>L1@001W>L1@000W>L00@007oo001cW0D000eoo`IcW0D0
00IcW0D000IcW0D0009cW004001oo`00Li`6000=Ool5Li`60005Li`60005Li`60005Li`300000goo
0000000=Ool6Li`50006Li`50006Li`50006Li`300000goo001oo`0>Ool001=oo`06Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_
Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW000Lia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H00005Lia_N`00Kg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/6000=Ool01Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
3Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`5000?Ool001=oo`H000EcW0H000EcW0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H0
00IcW0D000=cW003001cW7>L00eoo`D000IcW0D000IcW0D000IcW0D000=cW003001cW7>L00eoo`H0
00EcW0H000EcW0H000EcW0H000EcW0ioo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`D000IcW0H0
00EcW0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H000EcW0H000IcW0eoo`D000IcW0D000IcW0D0
00IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0moo`004goo0`0000Qoo`00001_Ng>L
Kg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P00
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool0
07>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mk001oo`00Kg/=Ool3000027oo000006mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`<00008Ool006mkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]c
W0H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`600001FmkLia_Ng>LKg/03Goo1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/600001W>LKg]c
W6mkLia_N`eoo`<00008Ool007>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`004goo100000=oo`00Li`017>L1P00
1G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001W>L1@0000IcW000000007oo000=Ool50006
Li`50006Li`50006Li`500000g>L001oo`03000=Ool60005Li`60005Li`60005Li`60005Li`>Ool5
0006Li`01P00Ool00000Ool000EcW0D000IcW0D000IcW0eoo`D000IcW0H000EcW0@00003Ool007>L
00AcW0H000EcW0eoo`H000EcW0H000EcW0800004Ool000000005Li`60006Li`=Ool01P00Ool00000
Ool000EcW0D000IcW0D000IcW0D000IcW0eoo`@00003Ool007>L00AcW0H000EcW0H000EcW0H000Ec
W0moo`004goo0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>L
Kg]cW6mkLia_N`D00006Kg]cW000Ool007>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk001oo`00Kg/=Ool3000027oo000006mkLia_Ng>L
Kg/600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>L
Kg]cW6mkLia_N`800009Ool00000Kg]cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`03000027oo000007>LKg]c
W6mkLi`600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0030000
27oo000006mkLia_Ng>LKg/600001W>LKg]cW6mkLia_N`eoo`800009Ool00000Lia_Ng>LKg]cW6mk
00D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`<00008
Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00moo`004goo1P001G>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001W>L1@00
0g>L00<007>LLi`03Goo1@001W>L1@001W>L1@001W>L1@000g>L00<007>LLi`03Goo1P001G>L1P00
1G>L1P001G>L1P001G>L3Woo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1@001W>L1P001G>L1P00
1G>L1P001G>L3Goo1P001G>L1P001G>L1P001G>L1P001W>L3Goo1@001W>L1@001W>L1@001W>L1@00
1W>L3Goo1P001G>L1P001G>L1P001G>L1P001G>L3goo000COol600001FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLi`007>L
00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW000Li`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg/006mkLi`=Ool500001VmkLia_N`00Kg]cW0H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000C
Ool6Li`50006Li`50002Li`01000Ool007>L1@001W>L1@003Goo1W>L0`0000=oo`00Li`01G>L1@00
1W>L1P001G>L1P003Goo1G>L1P0000AcW000001oo`L000EcW0H000EcW0H000eoo`IcW0D000IcW0D0
00IcW0D000IcW0<00003Ool007oo00eoo`EcW0H000EcW0H000EcW0H000EcW0<00003Ool0000000eo
o`EcW0<00003Ool0000000IcW0D000IcW0D000IcW0D000eoo`IcW0D0009cW004001oo`00Li`50006
Li`50006Li`6000=Ool5Li`6000017>L000007oo1`001G>L1P001G>L1P003Goo1W>L1@001W>L1@00
0W>L00@007oo001cW0D000IcW0D000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D00006Kg/007ooOol007>L1@0000IcW6mkLia_Ng>LKg/5000=Ool01g>LKg]cW6mkLia_N`0000=o
o`07001_Ng>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00Ec
W6mkLia_Ng>L00L000=oo`L00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000McW6mkLia_Ng>LKg/0
0003Ool00`00Oomoo`0<Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`00P000Woo0P003Goo00EcW6mkLia_Ng>L0080009oo`800006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L
1@0000IcW000Oomoo`00Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_
Ng>LKg]cW6mk00L000=oo`L00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Li`007ooOol006mk1@0000I_Ng>LKg]cW6mkLi`5
000?Ool001=oo`IcW0D000IcW0D0009cW0800003Ool0000000@000IcW0D000eoo`IcW0@00003Ool0
07>L00AcW0D000IcW0H000EcW0H000eoo`EcW0H00005Li`00000001oo`060005Li`60005Li`6000=
Ool6Li`50006Li`50006Li`50006Li`400000goo001oo`0<Ool5Li`60005Li`60005Li`60005Li`6
000=Ool5Li`60006Li`50006Li`50006Li`5000=Ool6Li`50002Li`90006Li`50006Li`6000=Ool5
Li`600001G>L00000000Ool01P001G>L1P001G>L1P003Goo1W>L1@001W>L1@000W>L2@001W>L1@00
3goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`50000
1W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00004Kg]cW000Ool7
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`0000=oo`00Ool03Goo00E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<0
0003Ool0000000eoo`05Lia_Ng>LKg]cW00300002Goo000006mkLia_Ng>LKg]cW00500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_
N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000Ac
W6mk001oo`L00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=o
o`IcW0D000IcW0D000=cW003001cW7>L00D000IcW0D000eoo`IcW0D000IcW0D000IcW0H000EcW0H0
00eoo`EcW0H000=cW003001cW00000D000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000Ic
W0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H000IcW0D000IcW0D000IcW0D000eo
o`IcW0D000=cW003001cW7>L00D000IcW0D000IcW0H000eoo`EcW0H000=cW003001cW00000D000Ec
W0H000EcW0H000eoo`IcW0D000IcW0D000=cW003001cW7>L00D000IcW0D000moo`004goo1P0000E_
Ng>L001cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eo
o`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`60000
1FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_
Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00moo`004goo1P0000EcW000Ool007>L00H000EcW0H000EcW0H000EcW0eoo`H000Ec
W0H000EcW0H000IcW0800003Ool0000000IcW0eoo`<00003Ool007>L00EcW0D000IcW0D000IcW0D0
00IcW0eoo`H000EcW0H000EcW0<00003Ool0000000EcW0H000EcW0ioo`D0009cW004001oo`00Li`5
0006Li`50006Li`50006Li`=Ool50006Li`60005Li`600000g>L001oo`080005Li`=Ool300000goo
00000005Li`60005Li`60005Li`60006Li`=Ool50006Li`50006Li`50002Li`01000Ool007>L1@00
1W>L3Goo1P001G>L1P001G>L1P001G>L0`0000=oo`0000001G>L3goo000COol700000goo00000007
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00008Lia_Ng>LKg]cW6mk001oo`<00006Kg]cW6mkLia_Ng>L
3Goo00/007oo000007oo001cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00P0000Uo
o`00000006mkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00005Li`00000001oo`0600001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>L
Kg]cW0H00005Kg]cW6mkLia_N`07000017oo000007oo1P0000E_Ng>LKg]cW6mk00eoo`800009Ool0
0000001_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_
Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000=cW000Ool0200000I_
Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/03goo000COol600000g>L001oo`080005Li`60005Li`60005Li`=Ool6
0005Li`60005Li`60006Li`200000goo00000006Li`=Ool300000goo001cW005Li`50006Li`50006
Li`50006Li`=Ool60005Li`60005Li`300000goo00000005Li`60005Li`>Ool50002Li`01000Ool0
07>L1@001W>L1@001W>L1@001W>L3Goo1@001W>L1P001G>L1P0000=cW000Ool020001G>L3Goo0`00
00=oo`0000001G>L1P001G>L1P001G>L1P001W>L3Goo1@001W>L1@001W>L1@000W>L00@007oo001c
W0D000IcW0eoo`H000EcW0H000EcW0H000EcW0<00003Ool0000000EcW0moo`004goo1P0000E_Ng>L
001cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001Fmk
Lia_Ng>LKg/01P0000EcW6mk001_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L
3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00moo`004goo1P001G>L1P001G>L1P001G>L1P000g>L00<007>LOol037oo1P001G>L1P00
1G>L1P001W>L1@001W>L3Goo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1P000g>L00<007>L0000
1@001G>L1P001G>L1P001G>L3Woo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1@001W>L1P001G>L
1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P000g>L00<007>L00001@001W>L3Goo1@000g>L00<0
07>LLi`01@001W>L1@001W>L1@001W>L3Goo1P000g>L00<007>L00001@001G>L1P001G>L1P001G>L
3goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`<00003Ool007oo00aoo`06Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW006000016mk000007oo1`003Goo00I_Ng>LKg]cW6mkLi`30000
27oo001cW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000016mk000007oo1`0000EcW6mkLia_Ng>L00H000eo
o`04Lia_N`00Ool700001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`30000
27oo001cW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`<00008Ool006mk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D0
00IcW0D000IcW0D000IcW005001oogooOol0000=Ool01W>L001oogoo001cW0D000IcW0D000IcW0H0
00EcW0H000eoo`EcW0H000EcW0H000EcW0L000=oo`L000eoo`IcW005001oogooOol00006Li`50006
Li`50006Li`5000>Ool5Li`60005Li`70003Ool70005Li`6000=Ool017>L001oogoo1`001W>L1@00
1W>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L0P000Woo00<007>LLi`017>L1P003Goo1G>L0P00
0Woo0P001G>L1P001G>L1P001G>L1P003Goo1W>L00D007ooOomoo`0000IcW0D000IcW0D000IcW0D0
00moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/400000goo001oo`0;Ool00g>LKg/0000800001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H00005Kg/00000001oo`06000=Ool01VmkLia_Ng>LKg]cW0@00007
Ool006mkLia_Ng>LKg/01@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_N`00000007oo00H00005Lia_Ng>LKg]cW006000=
Ool01G>LKg/00000Ool01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
100000Moo`00Kg]cW6mkLia_N`06000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/400001goo001cW6mk
Lia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000Ic
W0D000IcW0D000IcW0800003Ool0000000eoo`9cW004001oo`00Li`50006Li`50006Li`60005Li`6
000=Ool5Li`60005Li`60005Li`60002Li`00`00Ool00006000=Ool6Li`200000goo00000006Li`5
0006Li`50006Li`5000>Ool5Li`60005Li`600000g>L001oo`080005Li`6000=Ool2Li`00`00Ool0
00060006Li`50006Li`50006Li`5000=Ool6Li`50006Li`50006Li`300000goo001cW005Li`6000=
Ool5Li`300000goo00000005Li`60005Li`60005Li`6000=Ool6Li`200000goo00000006Li`50006
Li`50006Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`06000=Ool01VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L001cW6mk00H00005Lia_Ng>LKg]cW006
000=Ool01G>LKg]cW000Li`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`H000EcW0H000Ec
W0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW0D000Ic
W0D000IcW0eoo`H000EcW0H000EcW0H000=cW003001cW00000D000EcW0ioo`D000IcW0D000IcW0D0
00IcW0D000IcW0eoo`D000IcW0H000EcW0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H000EcW0H0
00=cW003001cW7>L00eoo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000=c
W003001cW00000D000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]c
W0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00<00008Ool0
0000Kg]cW6mkLia_N`H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00004Kg/00000Ool700001G>LKg]c
W6mkLi`03Woo0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`3000027oo000006mkLia_Ng>L
Kg/600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_N`00Ool006mk3Goo1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L3Goo
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000017>L000007oo1`0000E_Ng>LKg]cW6mk
00moo`004goo1P001G>L100000=oo`00Li`017>L1P001G>L1P001G>L3Goo1P001G>L0P0000Aoo`00
000000EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW006001oo`00001oo`001G>L1@001W>L3Goo
1P001G>L1P001G>L1`0000Aoo`00001oo`H000EcW0ioo`06001oo`00001oo`001G>L1@001W>L1@00
1W>L1@001W>L3Goo1@001W>L100000=oo`00Li`017>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L
1P001G>L1P0000IcW000000007oo000=Ool50006Li`50006Li`50006Li`01P00Ool00000Ool000Ec
W0eoo`H000EcW0H000EcW0L00004Ool00000Ool60005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`03
000027oo000007>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005
Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/600001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`<00008Ool006mkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
16mk000007oo1`0000EcW6mkLia_Ng>L00ioo`800009Ool00000Lia_Ng>LKg]cW6mk00D00006Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_
Ng>L0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool6
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg/007oo
001_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`<0
0008Ool006mkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000=c
W000Ool0200000E_Ng>LKg]cW6mk00moo`004goo1P001G>L1P001G>L1P001G>L1P001G>L3Goo1P00
1G>L1P001G>L1P001W>L1@001W>L3Goo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P00
1G>L1P000g>L00<007>L00001@001G>L3Woo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1@001W>L
1P001G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001G>L1P000g>L00<007>LLi`03Goo1@00
1W>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P000W>L00<007>LLi`01P001G>L3goo
000COol600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_
Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00eoo`H0
0005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]c
W6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/03goo000COol6Li`50006Li`50006Li`50002Li`01000Ool007>L
1@003Goo1W>L1@001W>L1@000W>L00@007oo001cW0H000EcW0H000eoo`EcW0<00003Ool0000000Ec
W0H000EcW0H000EcW0H000eoo`IcW0D0009cW004001oo`00Li`50006Li`50006Li`5000>Ool5Li`6
0005Li`60005Li`300000goo00000005Li`6000=Ool5Li`60006Li`50006Li`50006Li`300000goo
001oo`0<Ool6Li`300000goo001cW005Li`50006Li`50006Li`6000=Ool5Li`60005Li`60002Li`0
0`00Ool000060005Li`6000=Ool6Li`50002Li`01000Ool007>L1@001W>L1@001W>L1@003goo000C
Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/0
07oo001_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_
N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`00P000Woo0P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg/0
07oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`6000=Ool0
1G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L0P000Woo00<007ooOol02goo00M_Ng>LKg]cW6mkLi`00003Ool01`00Lia_Ng>LKg]cW6mk00D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00004Kg/007ooOol700001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/50000
1VmkLi`007oo001cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`Ic
W0D000IcW0D000IcW0D00005Li`00000001oo`06000=Ool6Li`50006Li`500000g>L001oo`090005
Li`6000=Ool5Li`60005Li`60005Li`60005Li`6000=Ool6Li`500000g>L000000080006Li`50006
Li`5000>Ool5Li`60005Li`60005Li`60005Li`6000=Ool5Li`60006Li`50006Li`50006Li`01P00
Ool00000Ool000aoo`IcW0@00003Ool007>L00AcW0D000IcW0D000IcW0H000eoo`EcW0H000EcW0L0
0004Ool00000Ool60005Li`6000=Ool6Li`500000g>L000000080006Li`50006Li`5000?Ool001=o
o`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00
Ool006mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk
1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/60000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mk001o
o`00Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P003Goo00Ec
W6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0800003Ool0000000eoo`06Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000A_N`00001oo`L00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW000
Ool007>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000moo`004goo1W>L1@001W>L
1@001W>L1@000g>L00<007>LLi`01@003Goo1W>L1@001W>L1@000g>L00<007>LLi`01P001G>L1P00
3Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@000g>L00<007>LLi`01@001W>L1@001W>L
1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L1@001W>L1@003Goo
1W>L1@001W>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P000g>L00<007>L00001@001G>L1P00
3Goo1W>L1@000g>L00<007>LLi`01@001W>L1@001W>L1@003goo003oOoooOolKOol00?mooomooa]o
o`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mo
oomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolK
Ool0025oo`03001oogoo03aoo`03001oogoo03Ioo`03001oogoo03Moo`03001oogoo03Ioo`03001o
ogoo03Ioo`03001oogoo03Moo`03001oogoo03Ioo`03001oogoo03Moo`03001oogoo02Aoo`004goo
1P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00004Kg]cW000Ool700001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000AcW000001oo`L0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLi`0
07oo001cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]c
W0H00005Kg/007oo001_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]c
W6mkLia_N`06000017>L000007oo1`0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@00
00IcW6mkLia_Ng>LKg/500001VmkLi`007oo001cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000A_N`00001oo`L00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/03goo000COol60005Li`60005Li`60005Li`60005Li`=Ool60005Li`600000g>L0000
00080006Li`50006Li`=Ool50006Li`500000g>L001oo`080006Li`50006Li`=Ool60005Li`70000
0goo000000070005Li`60005Li`>Ool50006Li`500000g>L000000080006Li`50006Li`=Ool50006
Li`700000goo000000070005Li`60005Li`=Ool60005Li`700000goo000000070005Li`60006Li`=
Ool50006Li`500000g>L001oo`080006Li`50006Li`=Ool60005Li`700000goo000000070005Li`6
0005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>LKg]cW006000016mkLi`007oo1`0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000AcW6mk001o
o`L00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000Ac
W000Oomoo`L00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/5
000016mkLi`007oo1`0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mk
Lia_Ng>L1P0000=_N`00Ool0200000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001Fmk
Lia_Ng>LKg/01P0000AcW000Oomoo`L00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D0
0006Lia_Ng>LKg]cW6mk1@0000A_Ng>L001oo`L00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`=Ool600001G>LKg]cW6mkLi`01P0000A_N`00Oomoo`L00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/03goo000COol60005Li`300000goo00000005Li`60005Li`60005Li`=Ool60005Li`60002
Li`00`00Ool000060006Li`50006Li`=Ool50006Li`50002Li`01000Ool007>L1@001W>L1@001W>L
3Goo1P001G>L1P0000EcW000Ool007>L00H000EcW0H000EcW0ioo`D000IcW0D0009cW004001oo`00
Li`50006Li`50006Li`=Ool50006Li`600001G>L001oo`00Li`01P001G>L1P001G>L3Goo1P001G>L
1P000W>L00<007oo00001P001G>L1P001W>L3Goo1@001W>L1@000W>L00@007oo001cW0D000IcW0D0
00IcW0eoo`H000EcW0H00005Li`007oo001cW0060005Li`60005Li`?Ool001=oo`H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool60000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg/006mkLi`01P0000E_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@00
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>L
001cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>L001cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eo
o`H00005Lia_Ng>LKg]cW00600001FmkLi`007>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0?Ool001=oo`IcW0D000IcW0D000IcW0D000IcW0D000eoo`=cW003001cW7>L00D000IcW0D0
00IcW0H000EcW0H000eoo`=cW003001cW00000D000EcW0H000EcW0H000EcW0H000eoo`IcW0D000Ic
W0D000IcW0D000IcW0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H000IcW0D000Ic
W0D000IcW0D000eoo`IcW0D000IcW0D000IcW0D000IcW0H000eoo`EcW0H000EcW0H000EcW0H000Ec
W0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/300000goo001oo`0<Ool0
1W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mk
Li`01P003Goo00AcW000001oo`L00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mk
Li`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00300002Goo
000006mkLia_Ng>LKg]cW00500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_
Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_
N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo000COol6Li`50006Li`50006Li`5
0006Li`01P00Ool00000Ool000aoo`03Li`007oo00P000IcW0D000IcW0H000EcW0H000eoo`05001o
o`00001oo`060005Li`60005Li`60005Li`6000=Ool6Li`01P00Ool00000Ool000EcW0D000IcW0D0
00IcW0D000ioo`EcW0@00003Ool007>L00AcW0H000EcW0H000EcW0H000eoo`EcW0800004Ool00000
0006Li`50006Li`50006Li`5000=Ool6Li`01P00Ool00000Ool000EcW0D000IcW0D000IcW0H000eo
o`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW006001oo`00001oo`001G>L1@001W>L1@001W>L
1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`800003Ool0000000eoo`06Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool017>L000007oo1`0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`2
00002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@00
3Woo00E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00<00009Ool00000Kg]cW6mkLia_Ng>L00D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0<00008Ool007>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/0
0`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool0
1W>LKg]cW6mkLia_N`800009Ool00000Kg]cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0D000IcW0D000IcW0D000eoo`=cW003001cW7>L
00D000IcW0D000IcW0H000EcW0H000eoo`=cW003001cW00000D000EcW0H000EcW0H000EcW0H000eo
o`IcW0D000IcW0D000IcW0D000IcW0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H0
00IcW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000IcW0D000IcW0H000eoo`EcW0H000EcW0H0
00EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000moo`004goo00I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000=Ool0
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/600001G>LKg]cW6mk
Li`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P0000E_
Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/01P0000EcW6mkLi`007>L00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`H000eoo`05Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=
Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D000moo`004goo1P001G>L1P0000AcW000001oo`L000EcW0H000EcW0eoo`H000EcW0H0
00EcW0<00003Ool0000000IcW0D000IcW0eoo`D000IcW0D000IcW0<00003Ool007>L00EcW0D000Ic
W0eoo`H000EcW0H000EcW0<00003Ool0000000EcW0H000EcW0ioo`D000IcW0D000IcW0D000IcW0<0
0003Ool007>L00EcW0eoo`D000IcW0H000EcW0H000EcW0<00003Ool0000000EcW0eoo`H000EcW0H0
00EcW0H000EcW0<00003Ool0000000IcW0eoo`D000IcW0D000IcW0D000IcW0D0009cW004001oo`00
Li`=Ool60005Li`60005Li`60005Li`600001G>L000007oo00003goo000COol600001FmkLia_Ng>L
Kg/01`0000=oo`0000001`0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk0080000:Ool00000001cW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000QcW6mkLia_Ng>LKg/007oo100000EcW6mkLia_Ng>L
00D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00200002Goo
00000000Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00008Lia_Ng>LKg]cW6mk001oo`@00005Lia_Ng>LKg]cW00=Ool500001VmkLia_
Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk0080000:Ool00000001c
W6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500000fmk001oo`03000=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00700000goo00000002000>Ool001=oo`H000EcW0H00004Li`007ooOol70005Li`6
0005Li`=Ool60005Li`60005Li`300000goo00000006Li`50006Li`=Ool50006Li`50006Li`20002
Ool20005Li`50006Li`=Ool60005Li`60005Li`300000goo00000005Li`60005Li`>Ool50006Li`5
0006Li`50006Li`20002Ool20005Li`=Ool50006Li`60005Li`60005Li`300000goo00000005Li`=
Ool60005Li`60005Li`60005Li`300000goo00000006Li`=Ool50006Li`50006Li`50006Li`50002
Li`01000Ool000003Goo1P001G>L1P001G>L1P001G>L1P0000AcW000Oomoo`8000ioo`004goo1P00
00E_Ng>LKg]cW6mk00H00005Li`007oo001cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Uoo`00001cW6mkLia_Ng>LKg/0
1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`0000Qo
o`00Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/200002Goo000006mkLia_Ng>LKg]c
W00=Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qo
o`00001_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/00`0000Uoo`00001cW6mkLia_Ng>LKg/03Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`=Ool600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLi`007oo00003goo000COol60005
Li`60002Li`00`00LiacW0060005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=Ool5
0006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`>Ool50006Li`5
0006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`6
0005Li`60006Li`=Ool50006Li`50006Li`50006Li`50003Li`00`00LiacW00=Ool60005Li`60005
Li`60005Li`60003Li`00`00Liaoo`0>Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@003Goo00IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool0
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=o
o`IcW0D000IcW0D000IcW0D0009cW004001oo`00Li`5000=Ool6Li`50006Li`50006Li`60005Li`3
00000goo0000000=Ool5Li`60005Li`60005Li`60005Li`300000goo0000000=Ool6Li`50006Li`5
0006Li`50006Li`300000goo001oo`0=Ool5Li`6000017>L000007oo1`001G>L1P001G>L1P003Goo
1G>L1P000W>L00@007oo001cW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D0009cW004001oo`00
Li`50006Li`6000=Ool5Li`60005Li`6000017>L000007oo1`001G>L1P003Goo1W>L1@001W>L1@00
1W>L0`0000=oo`00Li`01G>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001G>L00000000Ool01P003Goo00IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00@00003Ool007oo00aoo`05
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`02
000017oo000000003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@0000QcW6mkLia_Ng>LKg/007oo0P0000=oo`00Ool037oo00E_Ng>LKg]cW6mk00L00004Ool0
0000Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW0060000
1Fmk00000000Ool01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500000fmk001oo`0800001W>LKg]cW6mkLia_N`H000eoo`05
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01`0000Aoo`00001oo`H00005Lia_Ng>LKg]cW006000=
Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000QcW6mkLia_Ng>LKg/007oo0P0000Mo
o`00Lia_Ng>LKg]cW005000?Ool001=oo`IcW0D000IcW0D000IcW0D0009cW004001oo`00Li`5000=
Ool6Li`50006Li`50006Li`60005Li`300000goo0000000=Ool5Li`60005Li`60005Li`60005Li`3
00000goo0000000=Ool6Li`50006Li`50006Li`50006Li`300000goo001oo`0=Ool5Li`600000g>L
001oo`080005Li`60005Li`6000=Ool5Li`60002Li`01000Ool007>L1@001W>L1@001W>L1@003Goo
1W>L1@001W>L1@000W>L00@007oo001cW0D000IcW0H000eoo`EcW0H000EcW0H00004Li`00000Ool7
0005Li`6000=Ool6Li`50006Li`50006Li`200000goo00000006Li`5000?Ool001=oo`06Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@00
3Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mk
Lia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg/006mkLi`0
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>L
Kg/006mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool0
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`0
1P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`5000?Ool001=oo`=cW003001cW7>L00D000IcW0D000IcW0D000IcW0D000eoo`Ic
W0D000IcW0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW0D000Ic
W0D000IcW0D000IcW0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H000IcW0D000Ic
W0D000IcW0D000eoo`=cW003001cW7>L00D000IcW0D000IcW0D000IcW0H000eoo`EcW0H000EcW0H0
00EcW0H000=cW003001cW00000D000eoo`=cW003001cW7>L00D000IcW0D000IcW0D000IcW0D000mo
o`004goo0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`03Goo1P0000AcW000001oo`L00005Kg]cW6mkLia_N`0600001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00004Kg/00000Ool700001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_
Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>L001oo`00Li`01P0000E_Ng>LKg]cW6mk00eoo`<0
0008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mk
Lia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/3000027oo001_Ng>LKg]cW6mkLi`=Ool3000027oo000007>LKg]cW6mkLi`600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0H000EcW0H000Ec
W0H000EcW0eoo`L00003Ool0000000L000EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW0D00003
Li`007oo00P000IcW0eoo`H000EcW0H000EcW0L00003Ool0000000L000EcW0ioo`D000IcW0D000Ic
W0D00003Li`0000000P000IcW0eoo`D000IcW0H000EcW0L00003Ool0000000L000EcW0eoo`800004
Ool000000005Li`60005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006Li`00`00Ool00003
0005Li`=Ool60005Li`60005Li`60005Li`60005Li`?Ool001=oo`<00008Ool00000Kg]cW6mkLia_
N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00004Li`0
07ooOol700001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000016mkLi`007oo1`0000IcW6mkLia_Ng>L
Kg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00004Kg/007ooOol700001G>LKg]c
W6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00004Lia_N`00Ool70000
1VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00004Li`007oo
Ool700001FmkLia_Ng>LKg/03Goo0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`80009oo`800005Lia_Ng>LKg]cW00=Ool3000027oo0000
07>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?
Ool001=oo`<00003Ool0000000EcW0H000EcW0H000EcW0H000EcW0eoo`H0009cW003001oo`0000H0
00EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW0D0009cW004001oo`00Li`50006Li`=Ool60005
Li`60005Li`60002Li`00`00Ool000060005Li`>Ool50006Li`50006Li`50002Li`01000Ool007>L
1@001W>L3Goo1@001W>L1P001G>L1P0000EcW000Ool007>L00H000EcW0eoo`<00003Ool0000000Ec
W0H000EcW0H000EcW0H000IcW0eoo`D000IcW0D000IcW0D000IcW0<00003Ool007>L00EcW0eoo`<0
0003Ool0000000EcW0H000EcW0H000EcW0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>L001c
W00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]c
W6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000Ec
W6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000
Lia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P00
00EcW6mk001_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`00
4goo1W>L1@001W>L1@001W>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L1P000W>L00<007>LLi`0
1P003Goo1G>L1P000g>L00<007>L00001@001G>L1P001G>L1P003Goo0g>L00<007>LLi`01@001W>L
1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L
1@001W>L1@003Goo1W>L1@001W>L1@001W>L1@001W>L1P003Goo0g>L00<007>L00001@001G>L1P00
1G>L1P001G>L1P003Goo1W>L1@000g>L00<007>LLi`01@001W>L1@001W>L1@003goo000COol01Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_
Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6
00001G>L001oo`00Li`01P003Goo00EcW6mkLia_Ng>L00H00004Kg/00000Ool700001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00003Ool0000000eoo`05Lia_Ng>L
Kg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`30000
0goo001oo`0<Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`<00003Ool0000000eoo`04Kg/00000Ool700001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW000
Ool007>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000moo`004goo1W>L1@001W>L
1@001W>L00H007oo000007oo0005Li`5000=Ool6Li`50006Li`50006Li`700000goo00000007000=
Ool5Li`7000017oo000007oo1P001G>L1P001G>L1P003Goo00=cW000000020001W>L1@001W>L1@00
1W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L1@001W>L00H0
07oo000007oo000<Ool6Li`50006Li`50006Li`50006Li`400000goo001oo`0<Ool01@00Ool00000
Ool01P001G>L1P001G>L1P001G>L1P003Goo1W>L1@0000=cW000000020001W>L1@001W>L1@003goo
000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`200002Goo
000007>LKg]cW6mkLia_N`05000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/600001G>L001oo`00Li`01P003Goo00EcW6mkLia_Ng>L00H00004Kg/00000Ool7
00001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW000Ool007>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00003Ool00000
00eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`200000goo0000000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`<00003Ool0000000eoo`03Kg/007oo00P00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk
1@0000I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo000C
Ool6Li`50006Li`50006Li`50006Li`5000=Ool6Li`50006Li`50006Li`60002Li`00`00LiacW006
000=Ool5Li`60003Li`00`00Li`000050005Li`60005Li`6000=Ool3Li`00`00LiacW0050006Li`5
0006Li`50006Li`5000>Ool5Li`60005Li`60005Li`60005Li`6000=Ool5Li`60006Li`50006Li`5
0006Li`5000=Ool6Li`50006Li`50006Li`50006Li`6000=Ool2Li`00`00LiacW0060005Li`60005
Li`60005Li`6000=Ool6Li`50003Li`00`00LiacW0050006Li`50006Li`5000?Ool001=oo`06Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1P0000Ec
W6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L
00H00005Kg]cW6mk001_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mk001_N`0600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=
Ool01FmkLia_Ng>LKg/01P0000EcW6mkLi`007>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@00
00I_Ng>LKg]cW6mkLi`5000?Ool001=oo`H00005Li`007oo001cW0060005Li`60005Li`60005Li`=
Ool60005Li`300000goo00000005Li`60006Li`50006Li`=Ool50006Li`50006Li`50006Li`30000
0goo001cW005Li`=Ool60005Li`300000goo00000005Li`60005Li`60005Li`>Ool300000goo001c
W005Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`300000goo00000005Li`60005Li`=
Ool60005Li`60005Li`60002Li`00`00Ool000060006Li`=Ool50006Li`300000goo001cW005Li`5
0006Li`50006Li`=Ool60005Li`60005Li`300000goo00000005Li`60005Li`?Ool001=oo`L00004
Ool00000Kg/600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool6
00001G>LKg]cW6mkLi`00P0000Uoo`00000006mkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000026mkLia_
Ng>LKg]cW000Ool400001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`03001oo`0000<00005Kg]cW6mkLia_
N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool50000
1VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000=_N`000000200000IcW6mkLia_
Ng>LKg/=Ool5000027>LKg]cW6mkLia_N`00Ool400001G>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H00004Li`007ooOol70005Li`60005Li`6
0005Li`=Ool60005Li`300000goo00000005Li`60006Li`50006Li`=Ool50006Li`50006Li`50006
Li`20002Ool20005Li`=Ool60005Li`300000goo00000005Li`60005Li`60005Li`>Ool20002Ool2
0005Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`300000goo00000005Li`60005Li`=
Ool60005Li`60005Li`60002Li`00`00Ool000060006Li`=Ool50006Li`20002Ool20005Li`50006
Li`50006Li`=Ool60005Li`60005Li`300000goo00000005Li`60005Li`?Ool001=oo`H00005Kg/0
07oo001_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool6
00001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0<00008Ool007>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`03000027oo000007>LKg]c
W6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`800009Ool00000Lia_Ng>LKg]c
W6mk00D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D0
0006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]c
W6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00004Kg]cW000Ool70000
1W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/00`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00moo`004goo1P000W>L00<007>L
Li`01P001G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001W>L1@001W>L3Goo1@001W>L1@00
1W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P001G>L3Woo1@001W>L1@001W>L1@00
1W>L1@001W>L3Goo1@001W>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P000g>L00<0
07>L00001@001W>L3Goo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L
1P001G>L3goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mk
Li`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/5000>Ool01FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`01P003Goo
00EcW6mkLi`007>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@003goo000COol6Li`50006Li`50002Li`0
1000Ool007>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L0`0000=oo`0000001G>L1P003Goo1G>L
0`0000=oo`0000001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@000W>L00@007oo
001cW0D000ioo`EcW0H000EcW0H00004Li`00000Ool70005Li`6000=Ool2Li`00`00Ool000060006
Li`50006Li`50006Li`5000=Ool6Li`50002Li`01000Ool007>L1@001W>L1@001W>L1P003Goo1G>L
1P001G>L1P001G>L0`0000=oo`0000001G>L1P003Goo1W>L1@001W>L1@001W>L1@000W>L00@007oo
001cW0D000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00005Kg/00000001o
o`0600001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`@00007Ool007>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00800009Ool0
0000001_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000=cW000Ool020003Woo
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW007000017oo000007oo1P0000EcW6mkLia_Ng>L00H0
00eoo`05Li`00000001oo`0600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00003Li`007oo00P00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0200002Goo00000000Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500000fmk00000008000?Ool001=oo`IcW0D000IcW0D0009c
W004001oo`00Li`50006Li`5000=Ool6Li`50006Li`50006Li`300000goo00000005Li`6000=Ool5
Li`300000goo00000005Li`60005Li`60005Li`6000=Ool6Li`50006Li`50006Li`50002Li`01000
Ool007>L1@003Woo1G>L1P001G>L1P0000=cW000Ool020001G>L1P003Goo0W>L00<007oo00001P00
1W>L1@001W>L1@001W>L1@003Goo1W>L1@000W>L00@007oo001cW0D000IcW0D000IcW0H000eoo`Ec
W0H000EcW0H000EcW0<00003Ool0000000EcW0H000eoo`IcW0D000IcW0D000IcW0D0009cW004001o
o`00Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D000ioo`05Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L001cW6mk00H00005Lia_Ng>LKg]cW006000=
Ool01G>LKg]cW000Li`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`5000?Ool001=oo`IcW0D000IcW0D000Ic
W0D000IcW0D000eoo`IcW0D000IcW0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000EcW0H000Ec
W0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eo
o`EcW0H000IcW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000IcW0D000IcW0H000eoo`EcW0H0
00EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000moo`00ogooogoo6goo
003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogoo
ogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]o
o`00ogooogoo6goo000COol60005Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006
Li`50006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005
Li`>Ool50006Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool6
0005Li`60005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`6
0005Li`60005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mk
Li`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>LKg]cW003000027oo
000006mkLia_Ng>LKg/600001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>L
Kg]cW6mkLi`3000027oo001cW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk3Goo1P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`06
00001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`3000027oo0000
06mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_
N`03000027oo000007>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool5
00001W>LKg]cW6mkLia_N`<00008Ool006mkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0@00003Ool007>L00AcW0H000EcW0H0
00EcW0eoo`H000EcW0800004Ool000000005Li`60006Li`50006Li`=Ool50006Li`01P00Ool00000
Ool000EcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0ioo`D000IcW006001o
o`00001oo`001G>L1@001W>L1@001W>L3Goo1@001W>L100000=oo`00Li`017>L1P001G>L1P001G>L
3Goo1P001G>L0P0000Aoo`00000000EcW0H000EcW0H000IcW0eoo`D000IcW006001oo`00001oo`00
1G>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P001G>L3goo000COol600001FmkLia_
Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=
Ool600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`03000027oo000007>L
Kg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk
0P0000Uoo`00001_Ng>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eo
o`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>L
Kg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00<0
0008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol6
0005Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=Ool50006Li`5
0006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`>Ool50006Li`50006Li`5
0006Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60005Li`6
0006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`60005Li`?
Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00H00005
Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>L001c
W6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg/006mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]c
W6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_N`00Kg]cW00600001FmkLia_Ng>LKg/03Goo
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000IcW6mkLia_
Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`IcW0D000IcW0D000IcW0<00003Ool007>L00Ec
W0D000eoo`IcW0D000IcW0D000IcW0<00003Ool0000000EcW0H000eoo`EcW0H000EcW0H000EcW0<0
0003Ool0000000EcW0H000eoo`IcW0D000IcW0D000IcW0<00003Ool007>L00EcW0D000ioo`EcW0H0
00EcW0H000EcW0<00003Ool0000000EcW0H000eoo`EcW0H000IcW0D000IcW0800003Ool0000000Ic
W0D000eoo`IcW0D000IcW0D000IcW0<00003Ool007>L00EcW0H000eoo`EcW0H000EcW0H000EcW0H0
0004Li`00000Ool7000=Ool6Li`50006Li`50006Li`50002Li`01000Ool007>L1@003goo000COol0
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000Q_Ng>LKg]cW6mkLi`007oo100000E_Ng>L
Kg]cW6mk00D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00200002Goo00000000Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000Q_Ng>LKg]cW6mkLi`007oo100000E_Ng>LKg]cW6mk00D000ioo`05Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool0
1G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`5000027>LKg]cW6mkLia_N`00Ool400001G>LKg]c
W6mkLi`01@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
1P0000E_Ng>LKg]cW6mk00H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00L00003Ool0000000L000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`50000
1W>LKg]cW6mkLia_N`D00003Kg/0000000P000moo`004goo1W>L1@001W>L1@001W>L0P000Woo0P00
1G>L1@003Goo1W>L1@001W>L1@001W>L0`0000=oo`0000001G>L1P003Goo1G>L1P001G>L1P001G>L
0`0000=oo`0000001G>L1P003Goo1W>L1@001W>L1@001W>L0P000Woo0P001G>L1@003Woo1G>L1P00
1G>L1P001G>L0`0000=oo`0000001G>L1P003Goo1G>L1P001W>L1@001W>L0P000Woo0P001G>L1@00
3Goo1W>L1@001W>L1@001W>L0`0000=oo`0000001G>L1P003Goo1G>L1P001G>L1P001G>L1P0000Ac
W000Oomoo`L000eoo`IcW0D000IcW0D000IcW0D0009cW003001oo`0000H000moo`004goo00I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0P0000Uoo`00001cW6mkLia_
Ng>LKg/01@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
0`0000Qoo`00001cW6mkLia_Ng>L1P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk1P003Goo00I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L
1P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/200002Goo
000006mkLia_Ng>LKg]cW005000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`06000017>LKg/007oo1`003Goo00IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`5000?Ool001=oo`Ic
W0D000IcW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000IcW0H000EcW0H000eoo`EcW0H000Ec
W0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000ioo`EcW0H000EcW0H000Ec
W0H000EcW0H000eoo`EcW0H000IcW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000IcW0D000Ic
W0H000eoo`EcW0H000EcW0H000EcW0H000=cW003001cW00000D000eoo`IcW0D000IcW0D000IcW0D0
00=cW003001cW7>L00D000moo`004goo1P0000E_Ng>L001cW6mk00H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>L001cW00600001FmkLia_Ng>L
Kg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>L001cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
001_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mk001_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001W>LKg]cW000Lia_N`eoo`D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLi`007>L00H00005Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00moo`004goo1P0000EcW000Ool0
07>L00H000EcW0H000EcW0H000EcW0eoo`H00004Li`00000Ool70005Li`60006Li`50006Li`=Ool5
0006Li`50002Li`01000Ool007>L1@001W>L1@001W>L3Goo1P001G>L1P0000AcW000001oo`L000Ec
W0H000EcW0ioo`D000IcW0D000IcW0D000IcW0D0009cW004001oo`00Li`=Ool50006Li`60005Li`6
0005Li`600001G>L000007oo00003Goo1P001G>L1P001G>L1P001G>L1P000W>L00@007oo001cW0eo
o`D0009cW004001oo`00Li`50006Li`50006Li`50006Li`=Ool6000017>L000007oo1`001G>L1P00
1G>L1P001G>L3goo000COol700000goo0000000700001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00=Ool7000017oo000007oo1P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00003Li`007oo00P00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01`0000Aoo`00001o
o`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000=_N`0000000`003Goo1@0000I_Ng>LKg]cW6mk
Li`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00L00005Ool00000Ool0000<Ool600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>L00000000Ool000eo
o`D00003Li`0000000P00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`L00004Ool00000Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0?Ool001=oo`H00003Li`007oo00P000EcW0H000EcW0H000EcW0eoo`H00004Li`00000
Ool70005Li`60006Li`50006Li`=Ool50006Li`50002Li`01000Ool007>L1@001W>L1@001W>L3Goo
1P001G>L1P0000=cW000Ool020001G>L1P001G>L3Woo1@001W>L1@001W>L1@001W>L1@000W>L00@0
07oo001cW0eoo`D000IcW0H000EcW0H000EcW0H00003Li`007oo008000eoo`H000EcW0H000EcW0H0
00EcW0H0009cW004001oo`00Li`=Ool50002Li`01000Ool007>L1@001W>L1@001W>L1@001W>L3Goo
1P0000=cW000Ool020001G>L1P001G>L1P001G>L3goo000COol600001FmkLi`007>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLi`007>L
00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg/006mkLi`=Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>L001cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>L001cW6mk3Goo1@0000IcW6mkLi`007>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg/0
06mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000C
Ool60005Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=Ool50006
Li`50006Li`50006Li`50006Li`=Ool60003Li`00`00Li`000050005Li`60005Li`60005Li`>Ool5
0006Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool60003Li`0
0`00Li`000050005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006Li`50003Li`00`00Liac
W00=Ool60005Li`60005Li`60005Li`60003Li`00`00Liaoo`0>Ool001=oo`06Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@003Goo00Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW000Ool007>L
00H000eoo`04Li`00000Ool700001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`06000=Ool01VmkLia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool016mk000007oo1`0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00AcW6mk001oo`L00006Kg]cW6mkLia_Ng>L1@00
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L0`0000Qoo`00
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00300000goo
0000000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0<00003Ool007oo00ioo`004goo1W>L1@001W>L1@001W>L1@0000=cW0000000
20003Goo1W>L1@001W>L1@001W>L1`0000=oo`0000001`003Goo00<007oo000020001G>L1P001G>L
1P001G>L1P003Goo1W>L00<007oo00000`001G>L1@001W>L1@001W>L1@003Woo00<007oo00002000
1G>L1P001G>L1P001G>L1P003Goo00=cW000000020001W>L1@001W>L1@001W>L1@003Goo1W>L00<0
07oo00000`001G>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L0P0000Aoo`00
000000eoo`IcW0D000IcW0D000IcW0D000IcW003001oo`0000<000ioo`004goo00I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000AcW6mk001oo`L000eoo`06Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H00003Li`007oo00P000eo
o`04Li`007ooOol700001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06
000=Ool01VmkLia_Ng>LKg]cW080009oo`800005Kg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@003Woo00A_N`00Oomoo`L00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H000eoo`04Lia_N`00Ool700001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW080009oo`800005Kg]c
W6mkLia_N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00003Ool00000
00eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L0P000Woo0P003Woo000COol6Li`50006Li`50006Li`50002Li`01000Ool007>L1@00
3Goo1W>L1@001W>L1@001W>L1P0000EcW000Ool007>L00H000eoo`9cW003001oo`0000H000EcW0H0
00EcW0H000EcW0H000eoo`IcW0800003Ool0000000IcW0D000IcW0D000IcW0D000ioo`05Li`007oo
001cW0060005Li`60005Li`60005Li`6000=Ool2Li`00`00Ool000060006Li`50006Li`50006Li`5
000=Ool6Li`300000goo001cW005Li`50006Li`50006Li`6000=Ool5Li`60005Li`60005Li`60005
Li`300000goo0000000=Ool6Li`50006Li`50006Li`50006Li`300000goo001oo`0>Ool001=oo`06
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001c
W6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P00
00EcW6mk001_Ng>L00H000eoo`05Lia_Ng>L001cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW000Lia_N`0600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW000Li`01P00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6
000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`H000EcW0H000EcW0H000EcW0H000EcW0eoo`H000Ec
W0H000EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW0D000IcW0D000=cW003001cW7>L00eoo`H0
00EcW0H000EcW0H000EcW0H000=cW003001cW7oo00eoo`D000IcW0D000=cW003001cW7>L00D000Ic
W0D000IcW0eoo`D000IcW0H000EcW0H000EcW0H000EcW0eoo`H000EcW0H000=cW003001cW00000D0
00EcW0H000IcW0eoo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000=cW003
001cW00000D000EcW0moo`004goo0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0300002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk3Goo
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW000001o
o`0000ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/00`0000Qoo`00
001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`06000017>L000007oo
1`0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`06000017>L000007oo1`0000E_Ng>LKg]cW6mk00moo`004goo
100000=oo`00Li`017>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L0P0000Aoo`000000
00IcW0D000IcW0eoo`D000IcW0D000IcW0D000IcW0D00003Li`007oo00<000eoo`H000EcW0H000Ec
W0H000EcW0L00005Ool00000Ool0000=Ool50006Li`500001G>L00000000Ool01P001W>L1@001W>L
3Goo1@001W>L1P001G>L100000=oo`00Li`017>L1P001G>L3Goo1P001G>L1`0000Aoo`00001oo`H0
00EcW0H000IcW0eoo`D000IcW0D000IcW006001oo`00001oo`001G>L1@001W>L3Goo1P001G>L1P00
1G>L1`0000Aoo`00001oo`H000EcW0moo`004goo0`0000Qoo`00001_Ng>LKg]cW6mk1P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLia_Ng>L00H0
0005Kg]cW6mkLia_N`0300002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0eoo`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00
Ool006mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P00
00EcW000001oo`0000ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/0
0`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`060000
17>L000007oo1`0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600000g>L001oo`0800001FmkLia_Ng>LKg/0
3goo000COol60005Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=
Ool50006Li`50006Li`50006Li`50003Li`00`00LiacW00=Ool60005Li`60005Li`60005Li`60003
Li`00`00Liaoo`0=Ool50006Li`50003Li`00`00LiacW0050006Li`50006Li`=Ool50006Li`60005
Li`60005Li`60005Li`=Ool60005Li`60003Li`00`00Li`000050005Li`60006Li`=Ool50006Li`5
0006Li`50006Li`50006Li`=Ool60005Li`60005Li`60002Li`00`00LiacW0060005Li`?Ool001=o
o`H00005Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_
Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=
Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000EcW6mkLia_Ng>L
00H00005Kg]cW6mkLia_N`0?Ool001=oo`IcW0D000IcW0<00003Ool007>L00EcW0D000IcW0D000eo
o`9cW004001oo`00Li`50006Li`50006Li`60005Li`6000=Ool5Li`60005Li`6000017>L000007oo
1`001G>L1P003Goo1W>L1@001W>L1@000W>L00@007oo001cW0D000IcW0D000ioo`EcW0H000EcW0H0
00EcW0H00004Li`00000Ool7000=Ool5Li`60006Li`50006Li`50002Li`01000Ool007>L1@003Goo
0W>L00@007oo001cW0D000IcW0D000IcW0D000IcW0H000eoo`04Li`00000Ool70005Li`60005Li`6
0005Li`6000=Ool6Li`50006Li`300000goo001cW005Li`50006Li`5000?Ool001=oo`06Kg]cW6mk
Lia_Ng>L1@0000QcW6mkLia_Ng>LKg/007oo100000EcW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk
1@003Goo00=cW000Ool0200000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>L
Kg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00L00003Ool0000000L00005Kg]c
W6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000=_N`00Ool02000
00IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0700000goo00000007000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00003Kg/0000000P000eoo`03Kg/007oo00P00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`03001oo`0000P00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000Q_Ng>L
Kg]cW6mkLi`007oo100000E_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L1@003goo000COol6Li`5
0006Li`20002Ool20005Li`50006Li`5000=Ool2Li`00`00Ool000060006Li`50006Li`60005Li`6
000=Ool5Li`60005Li`6000017>L001oogoo1`001G>L1P003Goo1W>L1@001W>L1@000W>L00<007oo
00001P001W>L1@003Woo1G>L1P001G>L1P001G>L1P0000AcW000Oomoo`L000eoo`EcW0H000IcW0D0
00IcW0D0009cW003001oo`0000H000eoo`9cW003001oo`0000H000IcW0D000IcW0D000IcW0H000eo
o`04Li`007ooOol70005Li`60005Li`60005Li`6000=Ool6Li`50006Li`20002Ool20005Li`50006
Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/200002Goo000006mkLia_
Ng>LKg]cW00500001W>LKg]cW6mkLia_N`D000eoo`06Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00H00004Lia_N`00Ool700001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L001oo`00Li`01P00
3Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`0
07oo001cW0D000eoo`06Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_N`00Ool006mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`200002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D000moo`004goo1W>L1@00
1W>L1@001W>L1@001W>L1@003Goo0g>L00<007>LLi`01@001W>L1@001W>L1P001G>L1P003Goo1G>L
1P001G>L1P000g>L00<007>L00001@001G>L1P003Goo1W>L1@001W>L1@000g>L00<007>LLi`01@00
1W>L1@003Woo1G>L1P001G>L1P001G>L1P000W>L00<007>LLi`01P003Goo1G>L1P001W>L1@001W>L
1@000g>L00<007>LLi`01@003Goo0g>L00<007>LLi`01@001W>L1@001W>L1@001W>L1P003Goo0W>L
00<007>LLi`01P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@001W>L1@003goo
000COol600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW000Li`03Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_
N`D00006Kg]cW6mk001_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_
N`00Kg]cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]c
W6mk3Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/03goo000COol60005Li`60005Li`60005Li`600001G>L000007oo
00003Goo1P001G>L1P001G>L1P001W>L1@000W>L00@007oo001cW0eoo`D000IcW0D000IcW0D000Ic
W0<00003Ool007>L00EcW0eoo`H000EcW0H000EcW0H000EcW0<00003Ool0000000EcW0ioo`D000Ic
W0D000IcW0<00003Ool007>L00EcW0D000IcW0eoo`D0009cW004001oo`00Li`60005Li`60005Li`6
0005Li`=Ool60005Li`60005Li`60005Li`300000goo00000006Li`=Ool50006Li`50002Li`01000
Ool007>L1@001W>L1@001W>L3Goo0`0000=oo`0000001G>L1P001G>L1P001G>L1P001G>L3goo000C
Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0700001Goo0000
07oo000037oo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D0
0006Kg/00000001oo`003Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00008Kg]c
W6mkLia_Ng>L001oo`800007Ool006mkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/00P0000Uoo`00000007>LKg]cW6mkLi`03Woo1@0000IcW6mk
Lia_Ng>LKg/5000026mkLia_Ng>LKg]cW000Ool200001goo001_Ng>LKg]cW6mk00D00006Kg]cW6mk
Lia_Ng>L3Goo1@0000=_N`00Ool02@0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
0P0000Yoo`00000007>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000=_N`00Ool02000
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`@00007Ool007>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol60005Li`60005
Li`60005Li`600000g>L001oo`02000=Ool60005Li`60005Li`60006Li`50002Li`01000Ool007>L
3Goo1@001W>L1@001W>L1@001W>L0`0000=oo`00Li`01G>L3Goo1P001G>L1P001G>L1P001G>L0`00
00=oo`0000001G>L3Woo1@001W>L1@001W>L0P0000=oo`0000001W>L1@001W>L3Goo1@000W>L00@0
07oo001cW0H000EcW0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H000EcW0<00003Ool0000000Ic
W0eoo`D000IcW0D0009cW004001oo`00Li`50006Li`50006Li`=Ool300000goo00000005Li`60005
Li`60005Li`60005Li`?Ool001=oo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00H00005Lia_N`00Kg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool50000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`D00006Kg]cW6mk001_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P0000IcW6mkLia_Ng>LKg/=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@00
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0H000EcW0H0
00EcW0H000EcW0eoo`H000EcW0H000=cW003001cW00000D000IcW0D000IcW0eoo`D000=cW003001c
W7>L00D000IcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0ioo`D000=cW003
001cW7>L00D000IcW0D000IcW0D000IcW0eoo`D000IcW0H0009cW003001cW7>L00H000EcW0H000Ec
W0eoo`H000EcW0H000EcW0H000EcW0H000IcW0eoo`D000IcW0D000IcW0D000=cW003001cW7>L00D0
00IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0moo`004goo00I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H0
00eoo`05Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00H000eoo`06Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]c
W0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]c
W6mkLia_Ng>L0P0000Uoo`00001cW6mkLia_Ng>LKg/01@0000I_Ng>LKg]cW6mkLi`5000=Ool01Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_
N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool0
0000Lia_Ng>LKg]cW0H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/0
07oo001_N`D00006Kg]cW6mkLia_Ng>L1@003goo000COol6Li`50006Li`500000g>L000000080006
Li`5000=Ool6Li`50006Li`60005Li`60005Li`6000=Ool5Li`2000017oo000000001G>L1P001G>L
1P001G>L1P003Goo00=cW000000020001W>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L
1P001G>L1P003Goo1G>L1P001W>L00<007oo00000P001W>L1@001W>L1@003Goo1W>L1@001W>L1@00
00=cW000Ool020001W>L1P003Goo1G>L1P001G>L1P001G>L0P0000Aoo`00000000EcW0H000eoo`Ic
W0D000IcW0D00003Li`0000000P000IcW0D000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00004Kg]cW000Ool700001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`3000027oo000006mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00Ec
W6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P003Goo00A_Ng>L001oo`L00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001VmkLia_Ng>LKg]cW080
0009Ool00000Lia_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00004Kg]cW000Ool700001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H0
00eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000017>LKg/007oo1`0000I_Ng>LKg]c
W6mkLi`5000?Ool001=oo`IcW0D000IcW0D0009cW004001oo`00Li`50006Li`5000=Ool6Li`50006
Li`300000goo001cW005Li`60005Li`6000=Ool5Li`300000goo00000005Li`60005Li`60005Li`6
000=Ool2Li`01000Ool007>L1@001W>L1@001W>L1@001W>L1@003Woo1G>L0`0000=oo`0000001G>L
1P001G>L1P001G>L1P003Goo1G>L1P001W>L0P0000=oo`0000001W>L1@001W>L1@003Goo1W>L1@00
1W>L1@000W>L00@007oo001cW0D000IcW0H000eoo`EcW0H000EcW0H000EcW0<00003Ool0000000Ec
W0H000eoo`IcW0D000IcW0D0009cW004001oo`00Li`50006Li`5000?Ool001=oo`06Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_
Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`06000=Ool01VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
3Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>L
Kg]cW6mkLi`5000?Ool00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00
ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomo
oa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`004goo1P0000E_Ng>L001cW6mk00H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>L
001cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D0
0006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P00
00EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00mo
o`004goo1P0000EcW000Ool007>L00H000EcW0H000EcW0H000EcW0eoo`H00004Li`00000Ool70005
Li`60006Li`50006Li`=Ool50002Li`01000Ool007>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L
0`0000=oo`0000001G>L1P001G>L1P001G>L3Woo1@001W>L0`0000=oo`00Li`01G>L1@001W>L1@00
1W>L3Goo1@001W>L0`0000=oo`0000001G>L1P001G>L1P001G>L3Goo1P001G>L0`0000=oo`000000
1G>L1P001G>L1P001W>L3Goo1@001W>L0`0000=oo`00Li`01G>L1@001W>L1@001W>L3Goo1P001G>L
0`0000=oo`0000001G>L1P001G>L1P001G>L3goo000COol700000goo0000000700001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=Ool7000017oo000007oo1P0000E_Ng>L
Kg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500000fmk001oo`080000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@00
00QcW6mkLia_Ng>LKg/007oo0P0000Moo`00Lia_Ng>LKg]cW00500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`400001goo001_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00800009Ool00000001cW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00008Lia_Ng>LKg]cW6mk
001oo`800007Ool007>LKg]cW6mkLi`01@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eo
o`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0?Ool001=oo`H00003Li`007oo00P000EcW0H000EcW0H000EcW0eoo`H00004Li`00000Ool7
0005Li`60006Li`50006Li`=Ool50002Li`01000Ool007>L1@001W>L1@001W>L1@001W>L3Goo1P00
1G>L0`0000=oo`0000001G>L1P001G>L1P001G>L3Woo1@001W>L0P0000=oo`0000001W>L1@001W>L
1@001W>L3Goo1@001W>L0`0000=oo`0000001G>L1P001G>L1P001G>L3Goo1P001G>L0`0000=oo`00
00001G>L1P001G>L1P001W>L3Goo1@001W>L0`0000=oo`00Li`01G>L1@001W>L1@001W>L3Goo1P00
1G>L0`0000=oo`0000001G>L1P001G>L1P001G>L3goo000COol600001FmkLi`007>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo1P0000EcW6mkLi`007>L
00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_
Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000C
Ool60005Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=Ool50006
Li`50006Li`50006Li`50003Li`00`00LiacW00=Ool60005Li`60005Li`60005Li`60005Li`>Ool5
0006Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`60005Li`60005Li`=Ool60005Li`6
0005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`6
0003Li`00`00Li`000050005Li`?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@003Goo00IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW000Ool007>L00H000eoo`05Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0300000goo0000
000=Ool01VmkLi`007oo001cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000A_Ng>L001oo`L0
0005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg/0
07oo001_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00004Kg]cW000Ool700001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L1@003goo
000COol6Li`50006Li`50006Li`50002Li`01000Ool007>L1@003Goo1W>L1@001W>L1@001W>L1P00
00EcW000Ool007>L00H000eoo`EcW0H000EcW0H000EcW0H000EcW0<00003Ool0000000eoo`9cW004
001oo`00Li`50006Li`50006Li`50006Li`5000>Ool5Li`60005Li`6000017>L001oogoo1`001G>L
1P003Goo1G>L1P001W>L1@000W>L00@007oo001cW0D000IcW0D000eoo`IcW0D000IcW0D0009cW004
001oo`00Li`50006Li`6000=Ool5Li`60005Li`6000017>L001oogoo1`001G>L1P003Goo1W>L1@00
1W>L1@001W>L0P000Woo00<007>LLi`017>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001G>L00000000Ool01P003Goo00IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1`0000=oo`0000001`003Goo00EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00800004
Ool00000000=Ool00fmk0000000800001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00L00004Ool00000Ool6
00001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000EcW000
000007oo00H00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D00003Kg/007oo00P00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW007000017oo000007oo1P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`5000027>LKg]cW6mkLia_N`00Ool200001goo001cW6mkLia_Ng>L00D000moo`00
4goo1W>L1@001W>L1@001W>L1@000W>L00@007oo001cW0D000eoo`IcW0D000IcW0D000IcW0H00005
Li`007oo001cW006000=Ool5Li`60005Li`60005Li`60005Li`300000goo0000000=Ool2Li`01000
Ool007>L1@001W>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P0000=cW000Ool020001G>L1P00
3Goo1G>L1P001W>L1@000W>L00@007oo001cW0D000IcW0D000eoo`IcW0D000IcW0D0009cW004001o
o`00Li`50006Li`6000=Ool5Li`60005Li`6000017>L000007oo1`001G>L1P003Goo1W>L1@001W>L
1@001W>L0P0000=oo`0000001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H00005Lia_N`00Kg]cW006000=Ool01G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo
00I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW000Lia_N`060000
1G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`0
07>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
00001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00600001FmkLia_N`00Kg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo000C
Ool60005Li`60005Li`60005Li`60005Li`=Ool60005Li`60005Li`60006Li`50006Li`=Ool50006
Li`50006Li`50003Li`00`00LiacW0050006Li`=Ool60005Li`60005Li`60005Li`60005Li`>Ool5
0003Li`00`00LiacW0050006Li`50006Li`50006Li`=Ool50003Li`00`00LiacW0060005Li`60005
Li`60005Li`=Ool60005Li`60005Li`60005Li`60006Li`=Ool50006Li`50006Li`50006Li`50003
Li`00`00LiacW00=Ool60003Li`00`00Li`000050005Li`60005Li`60005Li`?Ool001=oo`H00005
Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Uoo`00001cW6mkLia_Ng>L
Kg/01@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0ioo`D00006Lia_N`00Ool0
06mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@00
00I_Ng>L001oo`00Li`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_
N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0300002Goo
000007>LKg]cW6mkLia_N`0=Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLi`007oo001cW0eoo`H00004Li`00000Ool700001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0@00003Ool007>L00Ac
W0H000EcW0H000EcW0eoo`H000EcW0H000EcW0800004Ool000000006Li`50006Li`=Ool50006Li`5
0006Li`500000g>L001oo`080006Li`=Ool60005Li`60005Li`60005Li`2000017oo000000001G>L
3Woo1@0000EcW000000007oo00H000IcW0D000IcW0D000IcW0eoo`D00003Li`007oo00T000EcW0H0
00EcW0H000EcW0eoo`H000EcW0H000EcW0H000EcW0800004Ool000000006Li`=Ool50006Li`50006
Li`50006Li`500000g>L001oo`03000=Ool7000017oo000007oo1P001G>L1P001G>L1P001G>L3goo
000COol600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00009Ool00000
Lia_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`>Ool50000
1W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`D00006Kg]cW000Ool007>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/00`0000Uoo`00001cW6mkLia_Ng>LKg/03Goo1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`=Ool600000g>L001oo`0800001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0?Ool001=oo`H000EcW0H000Ec
W0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H000IcW0D000IcW0eoo`D000IcW0D000IcW0D000=c
W003001cW7>L00D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0ioo`D000=cW003001cW7>L
00D000IcW0D000IcW0D000IcW0eoo`D000=cW003001cW7>L00H000EcW0H000EcW0H000EcW0eoo`H0
00EcW0H000EcW0H000EcW0H000IcW0eoo`D000IcW0D000IcW0D000IcW0D000=cW003001cW7>L00eo
o`H0009cW003001cW7>L00H000EcW0H000EcW0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P00
00EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00mo
o`004goo1W>L1@001W>L1@001W>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L1P001G>L1P003Goo
0g>L00<007>L00001@001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@000g>L00<007>LLi`0
1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L1@001W>L
1@003Goo0g>L00<007>LLi`01@001W>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P00
1G>L1P003Goo1W>L1@001W>L1@000g>L00<007>LLi`01@001W>L1@003goo000COol01VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_Ng>LKg/5
000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>L
Kg]cW6mkLi`00`0000=oo`0000003Goo00AcW000001oo`L00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5
00001VmkLi`007oo001cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00003Ool0000000eoo`05Lia_
Ng>LKg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`3
00000goo001oo`0<Ool01VmkLi`007oo001cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qo
o`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L1@003goo000COol6Li`50006
Li`50006Li`01P00Ool00000Ool000EcW0D000eoo`IcW0D000IcW0D000IcW0H000EcW0@00003Ool0
07oo00aoo`05001oo`00001oo`060005Li`60005Li`60005Li`6000=Ool6Li`50006Li`500000g>L
001oo`080006Li`5000>Ool5Li`60005Li`60005Li`60005Li`6000=Ool5Li`60006Li`50006Li`5
0006Li`01P00Ool00000Ool000aoo`03Li`007oo00P000IcW0D000IcW0D000IcW0H000eoo`EcW0H0
00EcW0800004Ool000000005Li`60005Li`6000=Ool6Li`50006Li`500000g>L000000080006Li`5
000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW080
0009Ool00000Lia_Ng>LKg]cW6mk00D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00300000goo0000000=Ool017>L000007oo1`00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/5000>
Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`00`0000=oo`0000003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0800003Ool0000000eoo`06Kg]cW000Ool007>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo
00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@0000I_Ng>LKg]c
W6mkLi`5000?Ool001=oo`IcW0D000IcW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000IcW0H0
00EcW0H000eoo`=cW003001cW00000D000EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000=c
W003001cW7>L00D000IcW0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H000IcW0D0
00IcW0D000IcW0D000eoo`=cW003001cW7>L00D000IcW0D000IcW0D000IcW0H000eoo`EcW0H000Ec
W0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D000=cW003001cW7>L00D000IcW0D000moo`004goo
1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLi`0
07>L00eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006
00001FmkLia_Ng>LKg/01P0000EcW6mkLi`007>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mk
Li`600001FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLi`007>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eo
o`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]c
W6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg/006mk00moo`004goo1P001G>L1P001G>L1P001G>L1P0000EcW000001oo`0000eo
o`<00003Ool0000000EcW0H000EcW0H000IcW0D000IcW0eoo`D000IcW0<00003Ool007>L00EcW0D0
00IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H00005Li`00000Ool0000>Ool300000goo001c
W005Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`600000g>L001oo`080005Li`=Ool6
0005Li`6000017>L000007oo1`001G>L1P001W>L3Goo0`0000=oo`00Li`01G>L1@001W>L1@001W>L
1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P0000EcW000001oo`0000moo`004goo1P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01`0000Eoo`00001oo`0000aoo`80
0009Ool00000001cW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L3Goo1@0000Q_Ng>LKg]cW6mkLi`007oo0P0000Moo`00Kg]cW6mkLia_N`050000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01`0000Eoo`00001oo`0000eoo`0;001oo`00001oo`00Kg]cW6mk
Lia_N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool5
00001VmkLia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`07000017oo000007oo1P0000E_Ng>LKg]cW6mk
00eoo`H00005Kg]cW6mkLia_N`07000017oo000007oo1P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>L
Kg]cW6mk3Goo00/007oo000007oo001_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00L00005Ool00000Ool0000>Ool001=oo`H000EcW0H000EcW0H000EcW0H0
0003Li`007oo008000eoo`<00003Ool0000000EcW0H000EcW0H000IcW0D000IcW0eoo`D000IcW0<0
0003Ool007>L00EcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H00005Li`00000Ool0
000>Ool200000goo00000006Li`50006Li`50006Li`50006Li`=Ool50006Li`60005Li`600000g>L
001oo`080005Li`=Ool60005Li`6000017>L000007oo1`001G>L1P001W>L3Goo0P0000=oo`000000
1W>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P0000EcW000001oo`0000mo
o`004goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000Ec
W6mk001_Ng>L00eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLi`007>L00ioo`D00006Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>L
Kg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mk001_Ng>L00H00005Kg]cW6mkLia_N`0=Ool6
00001FmkLia_Ng>LKg/01P0000EcW6mkLi`007>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mk
Lia_N`eoo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg/006mk00moo`004goo1P001G>L1P001G>L1P001G>L1P001G>L3Goo1P00
1G>L1P001G>L1P001W>L1@001W>L3Goo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1P001G>L1P00
1G>L1P001G>L1P001G>L3Woo1@001W>L1@001W>L1@001W>L1@001W>L3Goo1@001W>L1P001G>L1P00
1G>L1P001G>L3Goo1P001G>L1P001G>L1P001G>L1P001W>L3Goo1@001W>L1@001W>L1@001W>L1@00
1W>L3Goo1P001G>L1P001G>L1P001G>L1P001G>L3goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool0
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW00600001FmkLia_Ng>LKg/0
1P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_
N`0600001G>LKg]cW000Li`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLi`007>L00H000eoo`06Lia_Ng>L
001cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@00
3goo000COol6Li`50006Li`50002Li`01000Ool007>L1@001W>L1@003Goo1W>L1@001W>L0`0000=o
o`00Li`01G>L1P001G>L1P003Goo1G>L1P001G>L1P0000AcW000001oo`L000EcW0H000eoo`IcW0<0
0003Ool007>L00EcW0D000IcW0D000IcW0D000ioo`EcW0H000EcW0H000EcW0H00004Li`00000Ool7
000=Ool5Li`60006Li`200000goo00000006Li`50006Li`5000=Ool6Li`300000goo001cW005Li`5
0006Li`50006Li`6000=Ool5Li`60005Li`60005Li`6000017>L000007oo1`003Goo0W>L00@007oo
001cW0D000IcW0D000IcW0D000IcW0D000moo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D00005Kg/00000001oo`0600001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`400001goo001_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>L
Kg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00L00004Ool00000Ool600001FmkLia_Ng>LKg/01P003Goo
00Q_Ng>LKg]cW6mkLi`007oo0P0000Moo`00Kg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01`0000Aoo`00001oo`H000eoo`05Lia_Ng>LKg]cW006000026mkLia_Ng>LKg]cW000Ool30000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00Q_Ng>LKg]cW6mkLi`007oo0P0000Mo
o`00Kg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01`0000Aoo`00001oo`H000eoo`05
Li`00000001oo`0600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`5000?Ool001=oo`IcW0D000IcW0D0009cW004001oo`00Li`50006Li`5000=Ool6Li`50006Li`3
00000goo001cW005Li`60005Li`6000=Ool5Li`60005Li`6000017>L000007oo1`001G>L1P003Goo
1W>L0P0000=oo`0000001W>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P0000=cW000
Ool020003Goo1G>L1P001W>L0P0000=oo`0000001W>L1@001W>L1@003Goo1W>L0`0000=oo`00Li`0
1G>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P0000AcW000001oo`L000eoo`9cW004
001oo`00Li`50006Li`50006Li`50006Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_N`00Kg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLi`007>L00H00005Kg]cW6mkLia_N`06
000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00005Lia_N`00Kg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P00
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P003Goo00IcW6mkLi`0
07>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?
Ool001=oo`=cW003001cW7>L00D000IcW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000IcW0H0
00EcW0H000eoo`EcW0H000EcW0H000EcW0H000=cW003001cW00000D000eoo`IcW0D000IcW0D000Ic
W0D000IcW0D000ioo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`EcW0H000IcW0D000IcW0D000=c
W003001cW7>L00D000eoo`IcW0D000IcW0D000IcW0D000IcW0H000eoo`EcW0H000EcW0H000EcW0H0
00EcW0H000eoo`IcW0D000IcW0D000IcW0D000=cW003001cW7>L00D000moo`004goo0`0000Qoo`00
001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg/007oo001_N`D00006Kg]c
W6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00004Li`00000Ool70000
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L001o
o`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`6
00001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`eoo`H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_N`00Ool006mk
3Goo1@0000IcW6mk001oo`00Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W003000027oo000006mkLia_Ng>LKg/?Ool001=oo`H000EcW0H000EcW0H000EcW0H000EcW0eoo`H0
00EcW0H000EcW0H00003Li`0000000P000IcW0eoo`D000IcW0D000IcW0D000IcW006001oo`00001o
o`001G>L3Goo1P001G>L1`0000=oo`0000001`001G>L1P001G>L3Woo1@001W>L1@0000=cW0000000
20001W>L1@001W>L3Goo1@001W>L1P001G>L1P001G>L1P001G>L3Goo1P001G>L1P001G>L1P001G>L
1P0000IcW000000007oo000=Ool500000g>L000000080006Li`50006Li`50006Li`=Ool60005Li`6
0005Li`60005Li`60005Li`?Ool001=oo`<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/01P0000AcW6mk001oo`L00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk3Goo1P00
00E_Ng>LKg]cW6mk00H00003Li`007oo00P00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo
1@0000IcW6mkLia_Ng>LKg/5000016mkLi`007oo1`0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0030000
27oo000006mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001W>LKg/007oo001_N`eoo`D00004Lia_N`00Ool700001VmkLia_Ng>LKg]cW0D0
0006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool600001G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/?Ool001=oo`H000EcW0H0
00EcW0H000EcW0H000EcW0eoo`H000EcW0H000EcW0H000=cW003001cW7>L00D000IcW0eoo`D000Ic
W0D000IcW0D000IcW0D000IcW0eoo`H000EcW0H0009cW003001cW7>L00H000EcW0H000EcW0ioo`D0
00IcW0D000=cW003001cW7>L00D000IcW0D000IcW0eoo`D000IcW0H000EcW0H000EcW0H000EcW0eo
o`H000EcW0H000EcW0H000EcW0H000=cW003001cW7>L00eoo`D000=cW003001cW7>L00D000IcW0D0
00IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0moo`004goo1P0000E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_
Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eo
o`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P00
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00moo`004goo1W>L1@001W>L1@001W>L1@001W>L1@003Goo1W>L1@000g>L00<007>LLi`01@001W>L
1P001G>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@001W>L
1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo0g>L00<007>L00001@001W>L1@001W>L1@00
1W>L1@003Goo1W>L1@001W>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P00
3Goo1W>L1@001W>L1@001W>L1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mk
Lia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo
00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`03000027oo000007>LKg]cW6mkLi`600001FmkLia_
Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
0`0000Qoo`00Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P003Goo00AcW6mk001oo`L00006Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`H000eo
o`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00008Ool00000Lia_
Ng>LKg]cW0H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_
Ng>LKg/500001VmkLia_Ng>LKg]cW0D000moo`004goo1W>L1@001W>L00H007oo000007oo0005Li`5
0006Li`5000=Ool6Li`500000g>L001oo`080006Li`60005Li`6000=Ool5Li`60005Li`2000017oo
000000001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L00H007oo000007oo0005Li`5000>Ool5
Li`60005Li`60005Li`60005Li`6000=Ool01G>L00000000Ool01P001W>L1@001W>L1@001W>L1@00
3Goo1W>L1@001W>L1@001W>L100000=oo`00Li`017>L1P003Goo1G>L1P001G>L1P001G>L0P0000Ao
o`00000000EcW0H000eoo`IcW0D000IcW006001oo`00001oo`001G>L1@001W>L1@003goo000COol0
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0P0000Uoo`00001_Ng>LKg]cW6mkLi`01@0000Ic
W6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW000Ool007>L1@0000IcW6mkLia_
Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`030000
27oo000007>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>L
Kg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L
1P003Goo00AcW6mk001oo`L00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0<00008Ool007>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00<00008Ool00000Lia_Ng>LKg]cW0H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`200002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D000moo`00
4goo1W>L1@001W>L1@001W>L1@001W>L1@003Goo1W>L1@000g>L00<007>LLi`01@001W>L1P001G>L
1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@001W>L1@003Woo
1G>L1P001G>L1P001G>L1P001G>L1P003Goo0g>L00<007>L00001@001W>L1@001W>L1@001W>L1@00
3Goo1W>L1@001W>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L
1@001W>L1@001W>L1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P003Goo00I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo003oOooo
OolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo
003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogoo
ogoo6goo000FOol00`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0fOol00`00Oomoo`0lOol0
0`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0_Ool0
01=oo`<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P00
00EcW6mkLia_Ng>L00eoo`<00008Ool00000Lia_Ng>LKg]cW0H00005Kg]cW6mkLia_N`0600001W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo0`0000Qoo`00Kg]cW6mkLia_Ng>L1@0000IcW6mk
Lia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk3Goo0`0000Qoo`00001_Ng>L
Kg]cW6mk1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@00
00IcW6mk001oo`00Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`=Ool500001VmkLi`007oo001cW0H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P00
00E_Ng>LKg]cW6mk00eoo`H00004Kg/00000Ool700001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk
00H00006Lia_Ng>LKg]cW6mk3Goo1@0000IcW6mk001oo`00Kg/500001VmkLia_Ng>LKg]cW0D00006
Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool6000017>L000007oo1`0000E_Ng>LKg]cW6mk
00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03goo000COol20002Ool20005Li`60005Li`6
0005Li`60005Li`=Ool20002Ool20005Li`60005Li`60006Li`50006Li`=Ool01@00Oomoogoo0000
1W>L1@001W>L1@001W>L1@001W>L3Goo0P000Woo0P001G>L1P001G>L1P001G>L1P001G>L3Woo1@00
00IcW000Oomoo`00Li`50006Li`50006Li`50006Li`=Ool500001W>L001oogoo001cW0H000EcW0H0
00EcW0H000EcW0eoo`L000=oo`L000EcW0H000EcW0H000IcW0eoo`D00006Li`007ooOol007>L1@00
1W>L1@001W>L1@001W>L3Goo1`000goo1`001G>L1P001G>L1P001G>L3goo000COol30002Ool01P00
Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eo
o`@00007Ool007>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_
Ng>LKg]cW6mkLi`=Ool400001goo001cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`@00007Ool006mkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000=cW6mk00000Woo1P0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000E_Ng>L0000
07oo00L00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005
Kg/00000001oo`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk
3Goo1@0000EcW6mk000007oo00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Lia_Ng>LKg]cW0eoo`H00003Li`00000009oo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00moo`004goo0`0000=oo`0000001G>L1P001G>L1P001G>L1P001G>L3Goo
0`0000=oo`0000001G>L1P001G>L1P001W>L1@001W>L3Goo0`0000=oo`00Li`01G>L1@001W>L1@00
1W>L1@001W>L3Goo0`0000=oo`0000001G>L1P001G>L1P001G>L1P001G>L3Woo1@000W>L00@007oo
001cW0D000IcW0D000IcW0D000IcW0eoo`D0009cW004001oo`00Li`60005Li`60005Li`60005Li`=
Ool60002Li`00`00Ool000060005Li`60005Li`60006Li`=Ool50002Li`01000Ool007>L1@001W>L
1@001W>L1@001W>L3Goo1P0000=cW000Ool020001G>L1P001G>L1P001G>L3goo000COol600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`03Goo
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`D00006Kg]cW6mk
Lia_Ng>L3Goo1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLi`007>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_N`00Kg]cW0H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00eoo`H00005Kg]cW6mk001_
N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk3Goo1@0000Ic
W6mkLi`007>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`=Ool600001G>LKg/006mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/03goo000COol6Li`50006Li`50003Li`00`00LiacW0050006Li`5000=Ool6Li`50006
Li`50006Li`60005Li`6000=Ool5Li`60005Li`60005Li`60003Li`00`00Li`00005000=Ool6Li`5
0006Li`50006Li`50003Li`00`00LiacW005000>Ool5Li`60005Li`60005Li`60005Li`6000=Ool5
Li`60006Li`50003Li`00`00LiacW0050006Li`5000=Ool6Li`50006Li`50003Li`00`00LiacW005
0006Li`6000=Ool5Li`60005Li`60005Li`60005Li`6000=Ool6Li`50006Li`50006Li`50006Li`5
000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001cW0D0
0006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk0`0000Qoo`00001cW6mkLia_Ng>L1P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`01P0000A_N`00001oo`L000eoo`06Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@003Woo00E_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P00
3Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mk001oo`00Kg/500001VmkLia_
Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLi`007oo001c
W0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001Fmk
Lia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`0000Qoo`00Kg]cW6mkLia_Ng>L1@003goo000COol6Li`5
0006Li`500001G>L00000000Ool01P001W>L1@003Goo1W>L1@001W>L1@001W>L100000=oo`00Li`0
17>L1P003Goo1G>L1P001G>L1P001G>L1`0000Aoo`00001oo`H000eoo`IcW0D000IcW0D000IcW0D0
0003Li`007oo00P000ioo`EcW0H000EcW0@00003Ool007>L00AcW0H000EcW0H000eoo`EcW0H000Ic
W0D00005Li`00000001oo`060006Li`5000=Ool6Li`50006Li`500000g>L001oo`080006Li`6000=
Ool5Li`60005Li`60005Li`2000017oo000000001G>L1P003Goo1W>L1@001W>L1@001W>L00H007oo
000007oo0005Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001Vmk
Li`007oo001cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0D00006Lia_Ng>LKg]cW6mk0`0000Qoo`00001cW6mkLia_Ng>L1P003Goo00EcW6mkLia_Ng>L
00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000A_N`00001oo`L000eoo`06Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@00
3Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/600001G>L
Kg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mk001oo`00
Kg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/50000
1VmkLi`007oo001cW0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>L
Kg]cW00600001FmkLia_Ng>LKg/00`0000Qoo`00001cW6mkLia_Ng>L1P003Goo00IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0P0000Uoo`00001_Ng>LKg]cW6mkLi`0
1@003goo000COol6Li`50006Li`50003Li`00`00LiacW0050006Li`5000=Ool6Li`50006Li`50006
Li`60005Li`6000=Ool5Li`60005Li`60005Li`60003Li`00`00Li`00005000=Ool6Li`50006Li`5
0006Li`50003Li`00`00LiacW005000>Ool5Li`60005Li`60005Li`60005Li`6000=Ool5Li`60006
Li`50003Li`00`00LiacW0050006Li`5000=Ool6Li`50006Li`50003Li`00`00LiacW0050006Li`6
000=Ool5Li`60005Li`60005Li`60005Li`6000=Ool6Li`50006Li`50006Li`50006Li`5000?Ool0
01=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D000ioo`05Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mk
Li`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@003Goo
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`0
07>LKg/6000=Ool01FmkLia_N`00Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`H000EcW0H000EcW0H000EcW0H00005Li`0
0000Ool0000=Ool60005Li`60005Li`60006Li`50002Li`01000Ool007>L3Goo1@001W>L1@000W>L
00@007oo001cW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0<00003Ool0000000EcW0H000EcW0io
o`D000IcW0D000IcW0D0009cW004001oo`00Li`50006Li`=Ool50006Li`60005Li`60005Li`30000
0goo00000005Li`=Ool60005Li`60005Li`60005Li`300000goo00000006Li`=Ool300000goo001c
W005Li`50006Li`50006Li`50006Li`=Ool60005Li`60005Li`60005Li`600001G>L000007oo0000
3goo000COol600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`070003
Ool00`00Oomoo`0;Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]c
W6mk1@0000I_N`00Oomoo`00Li`=Ool500001VmkLia_Ng>LKg]cW0D00006Li`007ooOol006mk1@00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`00P000Woo0P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW000Oomoo`00Kg/500001VmkLia_Ng>LKg]cW0eoo`D0
0006Kg]cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0020002Ool200001Fmk
Lia_Ng>LKg/03Goo1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
0P000Woo0P0000IcW6mkLia_Ng>LKg/=Ool02`00Oomoogoo001cW6mkLia_Ng>LKg/01@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L
00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01`000goo00<007ooOol03Goo000COol60005
Li`60005Li`60005Li`600001W>L00000000Ool000aoo`H000EcW0H000EcW0H000IcW0D0009cW080
0003Ool007oo00aoo`D000IcW0D0009cW0T000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H0
00EcW0ioo`D000IcW0D000IcW0D0009cW0T000IcW0eoo`D000IcW0H000EcW0H000EcW0@00003Ool0
07>L00AcW0eoo`H000EcW0H000EcW0H000EcW0H000IcW0eoo`@00003Ool007>L00AcW0D000IcW0D0
00IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H00006Li`00000001oo`003Woo000COol60000
1FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600000g>L001oo`02000=
Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
001oo`00Li`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_N`00Ool006mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`eoo`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qo
o`00001_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00ioo`D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`500001W>LKg/007oo001_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mk
Li`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`eoo`H0
0005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00<00009Ool00000Lia_
Ng>LKg]cW6mk00eoo`800009Ool00000Lia_Ng>LKg]cW6mk00D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>L
Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW000Ool0000?Ool001=oo`H000EcW0H000EcW0H000Ec
W0H0009cW003001cW7>L00eoo`H000EcW0H000EcW0H000IcW0D000=cW003001cW7>L00eoo`D000Ic
W0D000=cW003001cW7>L00D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0H000EcW0ioo`D0
00IcW0D000IcW0D000=cW003001cW7>L00D000IcW0eoo`D000IcW0H000EcW0H000EcW0H000EcW0eo
o`H000EcW0H000EcW0H000EcW0H000IcW0eoo`D000IcW0D000IcW0D000IcW0D000IcW0eoo`H000Ec
W0H000EcW0H000EcW0H000=cW003001cW7oo00ioo`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_
N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo00Ec
W6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H0
00eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/0
1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>L001cW00600001VmkLia_Ng>LKg]cW0D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]c
W6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW006000=Ool01W>LKg]cW6mk
Lia_N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000mo
o`004goo1W>L1@001W>L1@001W>L0`0000=oo`00Li`01G>L1@003Goo1W>L1@000W>L00@007oo001c
W0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000EcW0<00003Ool0000000EcW0H000eoo`IcW0D0
00IcW0D000IcW0D000IcW0<00003Ool007oo00eoo`EcW0H000EcW0H000EcW0H000EcW0<00003Ool0
000000eoo`9cW003001oo`0000H000IcW0D000IcW0D000IcW0D000eoo`IcW0D000IcW0<00003Ool0
07>L00EcW0D000IcW0H000eoo`EcW0H000EcW0H000EcW0H00004Li`00000Ool7000=Ool6Li`50002
Li`01000Ool007>L1@001W>L1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1@0000Q_Ng>LKg]cW6mkLi`007oo0P0000Moo`00Kg]cW6mkLia_N`05000=Ool01W>LKg]c
W6mkLia_N`D00003Kg/007oo00P00006Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05
Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00800009Ool00000001_Ng>L
Kg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D00008Lia_Ng>LKg]cW6mk001oo`800003Ool007oo00aoo`05Kg]cW6mkLia_N`0600001G>LKg]c
W6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>L00000000Ool01P00
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>L
Kg]cW6mkLi`5000027>LKg]cW6mkLia_N`00Ool200001goo001cW6mkLia_Ng>L00D00006Lia_Ng>L
Kg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01`00
00Aoo`00001oo`H000eoo`06Lia_Ng>LKg]cW6mk1@0000=_N`000000200000IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D000moo`004goo1W>L1@001W>L1@001W>L0P0000=oo`0000001W>L1@00
3Goo1W>L1@000W>L00@007oo001cW0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000EcW0<00003
Ool0000000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0<00003Ool007oo00eoo`EcW0H000Ec
W0H000EcW0H000EcW0<00003Ool0000000eoo`9cW003001oo`0000H000IcW0D000IcW0D000IcW0D0
00eoo`IcW0D000IcW0<00003Ool007>L00EcW0D000IcW0H000eoo`EcW0H000EcW0H000EcW0H00004
Li`00000Ool7000=Ool6Li`50002Li`01000Ool007>L1@001W>L1@001W>L1@003goo000COol01Vmk
Lia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`H00005
Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]c
W00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_
Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLi`007>L00H00006
Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1P00
3Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLi`0
07>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg/006mkLi`500001W>LKg]cW6mkLia_N`D0
0006Kg]cW6mkLia_Ng>L1@003goo000COol6Li`50003Li`00`00LiacW0050006Li`50006Li`5000=
Ool6Li`50006Li`50006Li`60002Li`00`00LiacW006000=Ool5Li`60005Li`60005Li`60005Li`6
000=Ool6Li`50006Li`50006Li`50006Li`5000>Ool5Li`60003Li`00`00Li`000050005Li`60005
Li`6000=Ool5Li`60003Li`00`00LiacW0050006Li`50006Li`5000=Ool3Li`00`00LiacW0050006
Li`50006Li`50006Li`6000=Ool5Li`60005Li`60005Li`60005Li`6000=Ool3Li`00`00LiacW005
0006Li`50006Li`50006Li`5000?Ool001=oo`H00005Kg]cW6mkLia_N`03000027oo000007>LKg]c
W6mkLi`600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/200002Goo000006mkLia_Ng>LKg]cW00=Ool50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/007oo
001_N`eoo`H00004Kg]cW000Ool700001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_
Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`<00008Ool006mkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0<00008Ool00000Kg]cW6mk
Lia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo0`0000Qoo`00001_Ng>LKg]cW6mk
1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001W>LKg]cW6mkLia_N`eoo`D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>L001oo`00Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
3Goo0`0000Qoo`00001cW6mkLia_Ng>L1P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW0060000
1FmkLia_Ng>LKg/03goo000COol60005Li`300000goo00000005Li`60005Li`60005Li`=Ool60005
Li`60005Li`60006Li`200000goo00000006Li`=Ool50006Li`50006Li`50006Li`500001W>L001o
ogoo001cW0eoo`H00004Li`007ooOol70005Li`60005Li`60005Li`>Ool50006Li`20002Ool00`00
LiacW004Li`50006Li`50006Li`=Ool50006Li`300000goo00000005Li`60005Li`60005Li`=Ool2
0002Ool20005Li`60005Li`60005Li`60006Li`=Ool50006Li`50002Li`01000Ool007>L1@001W>L
1@001W>L3Goo0`0000=oo`0000001G>L1P001G>L1P001G>L1P001G>L3goo000COol600001FmkLia_
Ng>LKg/0100000Moo`00Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00eo
o`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000QcW6mkLia_Ng>LKg/007oo0`0000I_
Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500000g>LKg/00003000=Ool7000017oo000007oo1P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`03Woo1@0000QcW6mkLia_Ng>LKg/007oo0P0000Moo`00Lia_
Ng>LKg]cW00500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1@0000I_Ng>LKg]cW6mk
Li`400001goo001_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>L
Kg/=Ool500001W>LKg]cW6mkLia_N`D00003Kg/007oo00P00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`=Ool400001goo001cW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00moo`004goo1P001G>L0`0000=oo`0000001G>L1P001G>L1P001G>L
3Goo1P001G>L1P001G>L1P001W>L0P0000=oo`0000001W>L3Goo1@001W>L1@001W>L1@001W>L1@00
0W>L00@007oo001cW0eoo`H00003Li`007oo00P000EcW0H000EcW0H000EcW0ioo`D000IcW0800003
Ool0000000IcW0D000IcW0D000IcW0eoo`D000IcW0<00003Ool0000000EcW0H000EcW0H000EcW0eo
o`<00003Ool0000000EcW0H000EcW0H000EcW0H000IcW0eoo`D000IcW0D0009cW004001oo`00Li`5
0006Li`50006Li`=Ool300000goo00000005Li`60005Li`60005Li`60005Li`?Ool001=oo`H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00=
Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk1@0000I_Ng>L
Kg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW000Lia_N`eoo`H00005Kg]cW000Lia_N`0600001G>LKg]cW6mkLi`01P0000E_
Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00>Ool500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1P00
00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/03Goo1P0000E_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000IcW6mkLia_Ng>LKg/=Ool50000
1W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>L
Kg]cW0eoo`H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0?Ool001=oo`IcW0D000IcW0D000IcW0D000=cW003001cW7>L00D000eoo`IcW0D0
00IcW0D000IcW0H000EcW0H000eoo`EcW0H000EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW0D0
00IcW0D000IcW0D000ioo`=cW003001cW00000D000EcW0H000EcW0H000EcW0H000eoo`EcW0H000Ic
W0D000IcW0D000IcW0D000eoo`IcW0D000IcW0D000IcW0D000IcW0H000eoo`EcW0H000EcW0H000Ec
W0H000EcW0H000eoo`IcW0D000IcW0D000IcW0D000IcW0D000moo`004goo00I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk001oo`00Kg/5000=Ool01W>L
Kg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000Qoo`00Lia_Ng>LKg]cW6mk1P0000EcW6mkLia_
Ng>L00H000eoo`05Lia_Ng>LKg]cW003000027oo000006mkLia_Ng>LKg/600001G>LKg]cW6mkLi`0
1P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/3000027oo
001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000ioo`04Kg/00000Ool700001G>LKg]cW6mk
Li`01P0000E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_
Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L0`0000=oo`00Ool037oo
00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/300000goo0000000=Ool01FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mk
Lia_N`0600001G>LKg]cW6mkLi`00`0000=oo`0000003Goo00IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0<00008Ool007>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@003goo000COol6Li`5
0006Li`50006Li`500001G>L00000000Ool01P003Goo1W>L1@001W>L100000=oo`00Li`017>L1P00
1G>L1P003Goo1G>L0P0000Aoo`00000000EcW0H000EcW0H000EcW0H000eoo`IcW0D000IcW006001o
o`00001oo`001G>L1@001W>L1@003Woo00D007oo000007oo00H000EcW0H000EcW0H000EcW0H000eo
o`EcW0H000IcW0D000IcW0D000IcW006001oo`00001oo`0037oo1W>L1@001W>L1@001W>L1@001W>L
100000=oo`00Ool037oo1G>L1P001G>L1P001G>L1P001G>L0P0000Aoo`00000000eoo`IcW0D000Ic
W006001oo`00001oo`001G>L1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>L
Kg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg/007oo001_N`D000eoo`06Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`3000027oo001cW6mkLia_Ng>LKg/600001G>LKg]cW6mkLi`01P003Goo
00EcW6mkLia_Ng>L00<00008Ool00000Kg]cW6mkLia_N`H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`800009Ool00000Kg]cW6mk
Lia_Ng>L00D00006Lia_Ng>LKg]cW6mk1@003Woo00=_N`00Ool0200000EcW6mkLia_Ng>L00H00005
Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_
Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0800003Ool0000000eoo`06Kg]cW6mk
Lia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`00
00=oo`0000003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>LKg]cW00600001FmkLia_Ng>LKg/01P00
00EcW6mkLia_Ng>L00<00003Ool0000000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`2
00002Goo000007>LKg]cW6mkLia_N`0500001VmkLia_Ng>LKg]cW0D000moo`004goo1W>L1@001W>L
1@001W>L1@000g>L00<007>LLi`01@003Goo1W>L1@001W>L1@001W>L1P001G>L1P003Goo1G>L1P00
1G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@001W>L1@003Woo0W>L00<007>LLi`0
1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L1@001W>L1@001W>L1@003Goo1W>L1@001W>L
1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L1@001W>L1@001W>L
1@001W>L1@003goo000COol01VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]c
W6mkLi`500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`H00005Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000E_Ng>L
Kg]cW6mk00H00005Lia_Ng>L001cW00600001FmkLia_Ng>LKg/01P003Goo00I_Ng>LKg]cW6mkLi`5
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/5000>Ool01Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>LKg]cW000Li`01P00
3Goo00EcW6mkLia_Ng>L00H00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_
Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]c
W0D00006Lia_Ng>LKg]cW6mk1P003Goo00E_Ng>LKg]cW6mk00H00005Lia_Ng>L001cW00600001Fmk
Lia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`06Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mk001_Ng>L1@003goo000COol600001G>L001oo`00
Li`01P001G>L1P001G>L1P001G>L3Goo1P000W>L00<007oo00001P001G>L1P001W>L1@001W>L3Goo
1@001W>L1@001W>L0`0000=oo`00Li`01G>L1@001W>L3Goo1P001G>L1P001G>L1P000W>L00<007oo
00001P001G>L3Woo1@001W>L1@001W>L1@001W>L0`0000=oo`00Li`01G>L3Goo1@001W>L1P001G>L
1P0000EcW000Ool007>L00H000EcW0eoo`H000EcW0H000EcW0H0009cW003001oo`0000H000IcW0eo
o`D000IcW0<00003Ool007>L00EcW0D000IcW0D000IcW0eoo`H000EcW0H000EcW0H000EcW0<00003
Ool0000000EcW0moo`004goo1P0000E_N`00Ool006mk00H00005Lia_Ng>LKg]cW00600001FmkLia_
Ng>LKg/01P0000EcW6mkLia_Ng>L00eoo`H00004Li`007ooOol700001FmkLia_Ng>LKg/01P0000Ic
W6mkLia_Ng>LKg/500001VmkLia_Ng>LKg]cW0eoo`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_
Ng>LKg/20002Ool01`00Kg]cW6mkLia_Ng>L00D00006Lia_Ng>LKg]cW6mk3Goo1P0000E_Ng>LKg]c
W6mk00H00005Lia_Ng>LKg]cW006000016mk001oogoo1`0000EcW6mkLia_Ng>L00ioo`D00006Lia_
Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`80009oo`07001_Ng>LKg]c
W6mkLi`03Goo1@0000I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000AcW000Oomoo`L00005
Kg]cW6mkLia_N`0=Ool600001FmkLia_Ng>LKg/01P0000EcW6mkLia_Ng>L00H00004Kg]cW000Ool7
00001W>LKg]cW6mkLia_N`eoo`D00006Lia_Ng>LKg]cW6mk0P000Woo00L006mkLia_Ng>LKg]cW005
00001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]c
W6mkLia_N`0600001G>LKg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk3goo000COol700000goo
000000070005Li`60005Li`60005Li`=Ool7000017oo000007oo1P001G>L1P001W>L1@001W>L3Goo
1@001W>L1@001W>L00H007oo000007oo0005Li`50006Li`=Ool60005Li`60005Li`7000017oo0000
07oo1P001G>L3Woo1@001W>L1@001W>L1@001W>L00H007oo000007oo0005Li`=Ool50006Li`60005
Li`7000017oo000007oo1P001G>L3Goo1P001G>L1P001G>L1P0000EcW000000007oo00H000IcW0eo
o`D000IcW006001oo`00001oo`001G>L1@001W>L1@001W>L3Goo1P001G>L1P001G>L1P001G>L1P00
1G>L3goo000COol600000fmk001oo`0800001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H00005
Lia_Ng>LKg]cW00=Ool6000017>L000007oo1`0000E_Ng>LKg]cW6mk00H00006Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`=Ool500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0`0000Qo
o`00Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/=Ool600001FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00004Kg/00000Ool700001G>LKg]cW6mkLi`03Woo1@0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk0P0000Uoo`00001_Ng>LKg]cW6mkLi`03Goo1@00
00I_Ng>LKg]cW6mkLi`600001FmkLia_Ng>LKg/01P0000=cW000Ool0200000E_Ng>LKg]cW6mk00eo
o`H00005Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000A_Ng>L001oo`L00006Lia_Ng>LKg]c
W6mk3Goo1@0000IcW6mkLia_Ng>LKg/3000027oo001_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_
N`D00006Kg]cW6mkLia_Ng>L3Goo1P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`0600001G>L
Kg]cW6mkLi`00`0000Qoo`00001_Ng>LKg]cW6mk3goo000COol60002Li`00`00LiacW0060005Li`6
0005Li`60005Li`=Ool60003Li`00`00Li`000050005Li`60006Li`50006Li`=Ool50006Li`50006
Li`50006Li`50006Li`=Ool60005Li`60005Li`60003Li`00`00Li`000050005Li`>Ool50006Li`5
0006Li`50006Li`50006Li`=Ool50006Li`60005Li`60002Li`00`00LiacW0060005Li`=Ool60005
Li`60005Li`60003Li`00`00Li`000050006Li`=Ool50006Li`50006Li`50006Li`50006Li`=Ool6
0005Li`60005Li`60005Li`60005Li`?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>L
Kg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Goo00IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>L
Kg]cW00600001FmkLia_N`00Kg/01P0000EcW6mkLia_Ng>L00H00005Kg]cW6mkLia_N`06000=Ool0
1VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D000ioo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00H00005
Lia_Ng>LKg]cW006000=Ool01G>LKg]cW6mkLi`01P0000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mk
Lia_N`D00006Kg]cW6mkLia_Ng>L1@003Goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW000Lia_N`D0
0006Kg]cW6mkLia_Ng>L1@0000IcW6mkLia_Ng>LKg/6000=Ool01FmkLia_Ng>LKg/01P0000EcW6mk
Lia_Ng>L00H00005Kg]cW6mk001_N`0600001G>LKg]cW6mkLi`01P003Goo00IcW6mkLia_Ng>LKg/5
00001VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`5000?Ool001=o
o`IcW0D000IcW0<00003Ool007>L00EcW0D000IcW0D000eoo`IcW0D000IcW0D0009cW004001oo`00
Li`60005Li`6000=Ool5Li`6000017>L000007oo1`001G>L1P001G>L1P003Goo1W>L1@000W>L00@0
07oo001cW0D000IcW0D000IcW0D000ioo`EcW0H000EcW0H00004Li`00000Ool70005Li`6000=Ool5
Li`60006Li`200000goo00000006Li`50006Li`5000=Ool6Li`50002Li`01000Ool007>L1@001W>L
1@001W>L1P003Goo1G>L1P001G>L1P0000AcW000001oo`L000EcW0H000eoo`IcW0D000IcW0D0009c
W004001oo`00Li`50006Li`5000?Ool001=oo`06Kg]cW6mkLia_Ng>L1@0000QcW6mkLia_Ng>LKg/0
07oo0P0000Moo`00Lia_Ng>LKg]cW00500001W>LKg]cW6mkLia_N`D000eoo`06Lia_Ng>LKg]cW6mk
1@0000I_Ng>LKg]cW6mkLi`500000g>L001oo`0900001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_
Ng>L00L00004Ool00000Ool600001G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]c
W6mkLia_Ng>L1@0000=cW0000000200000I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D000io
o`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01`0000Aoo`00001oo`H00005Lia_Ng>LKg]cW006
000=Ool01G>LKg]cW6mkLi`01P0000Q_Ng>LKg]cW6mkLi`007oo0`0000IcW6mkLia_Ng>LKg/50000
1VmkLia_Ng>LKg]cW0D000eoo`06Kg]cW6mkLia_Ng>L1@0000=cW000Ool0200000I_Ng>LKg]cW6mk
Li`500001W>LKg]cW6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01`0000Ao
o`00001oo`H00005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L
1@0000=cW0000000200000I_Ng>LKg]cW6mkLi`5000?Ool001=oo`IcW0D000IcW0800003Ool00000
00IcW0D000IcW0D000eoo`IcW0D000IcW0D0009cW004001oo`00Li`60005Li`6000=Ool5Li`60000
17>L000007oo1`001G>L1P001G>L1P003Goo1W>L1@000W>L00@007oo001cW0D000IcW0D000IcW0D0
00ioo`EcW0H000EcW0H00003Li`007oo00P000EcW0H000eoo`EcW0H000IcW0800003Ool0000000Ic
W0D000IcW0D000eoo`IcW0D0009cW004001oo`00Li`50006Li`50006Li`6000=Ool5Li`60005Li`6
000017>L000007oo1`001G>L1P003Goo1W>L1@001W>L1@000W>L00@007oo001cW0D000IcW0D000mo
o`004goo00I_Ng>LKg]cW6mkLi`500001W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000Ic
W6mkLia_Ng>LKg/5000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`0
07>LKg/600001G>LKg]cW6mkLi`01P003Goo00EcW6mkLia_Ng>L00H00005Kg]cW6mk001_N`060000
1G>LKg]cW6mkLi`01P0000E_Ng>LKg]cW6mk00H000eoo`06Kg]cW6mkLia_Ng>L1@0000IcW6mkLi`0
07>LKg/500001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@003Woo00E_Ng>LKg]cW6mk00H0
0005Lia_Ng>LKg]cW00600001FmkLi`007>LKg/01P0000EcW6mkLia_Ng>L00H000eoo`05Lia_Ng>L
Kg]cW00600001VmkLia_Ng>LKg]cW0D00006Lia_Ng>LKg]cW6mk1@0000I_Ng>LKg]cW6mkLi`5000=
Ool01VmkLia_Ng>LKg]cW0D00006Lia_Ng>L001cW6mk1@0000I_Ng>LKg]cW6mkLi`500001W>LKg]c
W6mkLia_N`H000eoo`05Kg]cW6mkLia_N`0600001G>LKg]cW6mkLi`01P0000E_Ng>LKg/006mk00H0
0005Lia_Ng>LKg]cW006000=Ool01W>LKg]cW6mkLia_N`D00006Kg]cW6mkLia_Ng>L1@0000IcW6mk
Li`007>LKg/500001VmkLia_Ng>LKg]cW0D000moo`004goo1W>L1@001W>L1@001W>L1@001W>L1@00
3Goo1W>L1@001W>L1@001W>L1P001G>L1P003Goo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1W>L
1@001W>L1@001W>L1@001W>L1@003Woo1G>L1P001G>L1P001G>L1P001G>L1P003Goo1G>L1P001W>L
1@001W>L1@001W>L1@003Goo1W>L1@001W>L1@001W>L1@001W>L1P003Goo1G>L1P001G>L1P001G>L
1P001G>L1P003Goo1W>L1@001W>L1@001W>L1@001W>L1@003goo003oOoooOolKOol00?mooomooa]o
o`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mo
oomooa]oo`00ogooogoo6goo003oOoooOolKOol00?mooomooa]oo`00ogooogoo6goo003oOoooOolK
Ool00?mooomooa]oo`00ogooogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 536.875}, {597.375, 0}} -> {-0.225047, -0.25243, 
  0.0176021, 0.0176021}, {{12.75, 64.9375}, {583, 
  530.813}} -> {-2.53382, -2.82807, 0.18108, 0.18108}, {{70.125, 122.313}, {
  583, 530.813}} -> {-12.9233, -2.82807, 0.18108, 0.18108}, {{127.563, 
  179.688}, {583, 530.813}} -> {-23.3517, -2.83686, 0.181297, 0.181297}, {{
  184.938, 237.125}, {583, 530.813}} -> {-33.7135, -2.82807, 0.18108, 
  0.18108}, {{242.313, 294.5}, {583, 530.813}} -> {-44.103, -2.82807, 
  0.18108, 0.18108}, {{299.688, 351.875}, {583, 
  530.813}} -> {-54.4924, -2.82807, 0.18108, 0.18108}, {{357.125, 409.25}, {
  583, 530.813}} -> {-64.9707, -2.83686, 0.181297, 0.181297}, {{414.5, 
  466.688}, {583, 530.813}} -> {-75.2826, -2.82807, 0.18108, 0.18108}, {{
  471.875, 524.063}, {583, 530.813}} -> {-85.6721, -2.82807, 0.18108, 
  0.18108}, {{12.75, 64.9375}, {525.625, 473.438}} -> {-2.53382, -13.2175, 
  0.18108, 0.18108}, {{70.125, 122.313}, {525.625, 
  473.438}} -> {-12.9233, -13.2175, 0.18108, 0.18108}, {{127.563, 179.688}, {
  525.625, 473.438}} -> {-23.3517, -13.2388, 0.181297, 0.181297}, {{184.938, 
  237.125}, {525.625, 473.438}} -> {-33.7135, -13.2175, 0.18108, 0.18108}, {{
  242.313, 294.5}, {525.625, 473.438}} -> {-44.103, -13.2175, 0.18108, 
  0.18108}, {{299.688, 351.875}, {525.625, 473.438}} -> {-54.4924, -13.2175, 
  0.18108, 0.18108}, {{357.125, 409.25}, {525.625, 
  473.438}} -> {-64.9707, -13.2388, 0.181297, 0.181297}, {{414.5, 466.688}, {
  525.625, 473.438}} -> {-75.2826, -13.2175, 0.18108, 0.18108}, {{471.875, 
  524.063}, {525.625, 473.438}} -> {-85.6721, -13.2175, 0.18108, 0.18108}, {{
  12.75, 64.9375}, {468.25, 416.063}} -> {-2.53382, -23.607, 0.18108, 
  0.18108}, {{70.125, 122.313}, {468.25, 416.063}} -> {-12.9233, -23.607, 
  0.18108, 0.18108}, {{127.563, 179.688}, {468.25, 
  416.063}} -> {-23.3517, -23.6407, 0.181297, 0.181297}, {{184.938, 
  237.125}, {468.25, 416.063}} -> {-33.7135, -23.607, 0.18108, 0.18108}, {{
  242.313, 294.5}, {468.25, 416.063}} -> {-44.103, -23.607, 0.18108, 
  0.18108}, {{299.688, 351.875}, {468.25, 416.063}} -> {-54.4924, -23.607, 
  0.18108, 0.18108}, {{357.125, 409.25}, {468.25, 
  416.063}} -> {-64.9707, -23.6407, 0.181297, 0.181297}, {{414.5, 466.688}, {
  468.25, 416.063}} -> {-75.2826, -23.607, 0.18108, 0.18108}, {{471.875, 
  524.063}, {468.25, 416.063}} -> {-85.6721, -23.607, 0.18108, 0.18108}, {{
  12.75, 64.9375}, {410.813, 358.688}} -> {-2.54225, -34.0483, 0.181297, 
  0.181297}, {{70.125, 122.313}, {410.813, 358.688}} -> {-12.9442, -34.0483, 
  0.181297, 0.181297}, {{127.563, 179.688}, {410.813, 
  358.688}} -> {-23.3517, -34.0483, 0.181297, 0.181297}, {{184.938, 
  237.125}, {410.813, 358.688}} -> {-33.7593, -34.0483, 0.181297, 
  0.181297}, {{242.313, 294.5}, {410.813, 358.688}} -> {-44.1612, -34.0483, 
  0.181297, 0.181297}, {{299.688, 351.875}, {410.813, 
  358.688}} -> {-54.5631, -34.0483, 0.181297, 0.181297}, {{357.125, 409.25}, {
  410.813, 358.688}} -> {-64.9707, -34.0483, 0.181297, 0.181297}, {{414.5, 
  466.688}, {410.813, 358.688}} -> {-75.3783, -34.0483, 0.181297, 
  0.181297}, {{471.875, 524.063}, {410.813, 358.688}} -> {-85.7802, -34.0483, 
  0.181297, 0.181297}, {{12.75, 64.9375}, {353.438, 
  301.25}} -> {-2.53382, -44.3972, 0.18108, 0.18108}, {{70.125, 122.313}, {
  353.438, 301.25}} -> {-12.9233, -44.3972, 0.18108, 0.18108}, {{127.563, 
  179.688}, {353.438, 301.25}} -> {-23.3517, -44.4558, 0.181297, 0.181297}, {{
  184.938, 237.125}, {353.438, 301.25}} -> {-33.7135, -44.3972, 0.18108, 
  0.18108}, {{242.313, 294.5}, {353.438, 301.25}} -> {-44.103, -44.3972, 
  0.18108, 0.18108}, {{299.688, 351.875}, {353.438, 
  301.25}} -> {-54.4924, -44.3972, 0.18108, 0.18108}, {{357.125, 409.25}, {
  353.438, 301.25}} -> {-64.9707, -44.4558, 0.181297, 0.181297}, {{414.5, 
  466.688}, {353.438, 301.25}} -> {-75.2826, -44.3972, 0.18108, 0.18108}, {{
  471.875, 524.063}, {353.438, 301.25}} -> {-85.6721, -44.3972, 0.18108, 
  0.18108}, {{12.75, 64.9375}, {296.063, 243.875}} -> {-2.53382, -54.7867, 
  0.18108, 0.18108}, {{70.125, 122.313}, {296.063, 
  243.875}} -> {-12.9233, -54.7867, 0.18108, 0.18108}, {{127.563, 179.688}, {
  296.063, 243.875}} -> {-23.3517, -54.8578, 0.181297, 0.181297}, {{184.938, 
  237.125}, {296.063, 243.875}} -> {-33.7135, -54.7867, 0.18108, 0.18108}, {{
  242.313, 294.5}, {296.063, 243.875}} -> {-44.103, -54.7867, 0.18108, 
  0.18108}, {{299.688, 351.875}, {296.063, 243.875}} -> {-54.4924, -54.7867, 
  0.18108, 0.18108}, {{357.125, 409.25}, {296.063, 
  243.875}} -> {-64.9707, -54.8578, 0.181297, 0.181297}, {{414.5, 466.688}, {
  296.063, 243.875}} -> {-75.2826, -54.7867, 0.18108, 0.18108}, {{471.875, 
  524.063}, {296.063, 243.875}} -> {-85.6721, -54.7867, 0.18108, 0.18108}, {{
  12.75, 64.9375}, {238.688, 186.5}} -> {-2.53382, -65.1761, 0.18108, 
  0.18108}, {{70.125, 122.313}, {238.688, 186.5}} -> {-12.9233, -65.1761, 
  0.18108, 0.18108}, {{127.563, 179.688}, {238.688, 
  186.5}} -> {-23.3517, -65.2597, 0.181297, 0.181297}, {{184.938, 237.125}, {
  238.688, 186.5}} -> {-33.7135, -65.1761, 0.18108, 0.18108}, {{242.313, 
  294.5}, {238.688, 186.5}} -> {-44.103, -65.1761, 0.18108, 0.18108}, {{
  299.688, 351.875}, {238.688, 186.5}} -> {-54.4924, -65.1761, 0.18108, 
  0.18108}, {{357.125, 409.25}, {238.688, 186.5}} -> {-64.9707, -65.2597, 
  0.181297, 0.181297}, {{414.5, 466.688}, {238.688, 
  186.5}} -> {-75.2826, -65.1761, 0.18108, 0.18108}, {{471.875, 524.063}, {
  238.688, 186.5}} -> {-85.6721, -65.1761, 0.18108, 0.18108}, {{12.75, 
  64.9375}, {181.25, 129.063}} -> {-2.53382, -75.5769, 0.18108, 0.18108}, {{
  70.125, 122.313}, {181.25, 129.063}} -> {-12.9233, -75.5769, 0.18108, 
  0.18108}, {{127.563, 179.688}, {181.25, 129.063}} -> {-23.3517, -75.6729, 
  0.181297, 0.181297}, {{184.938, 237.125}, {181.25, 
  129.063}} -> {-33.7135, -75.5769, 0.18108, 0.18108}, {{242.313, 294.5}, {
  181.25, 129.063}} -> {-44.103, -75.5769, 0.18108, 0.18108}, {{299.688, 
  351.875}, {181.25, 129.063}} -> {-54.4924, -75.5769, 0.18108, 0.18108}, {{
  357.125, 409.25}, {181.25, 129.063}} -> {-64.9707, -75.6729, 0.181297, 
  0.181297}, {{414.5, 466.688}, {181.25, 129.063}} -> {-75.2826, -75.5769, 
  0.18108, 0.18108}, {{471.875, 524.063}, {181.25, 
  129.063}} -> {-85.6721, -75.5769, 0.18108, 0.18108}, {{12.75, 64.9375}, {
  123.875, 71.6875}} -> {-2.53382, -85.9663, 0.18108, 0.18108}, {{70.125, 
  122.313}, {123.875, 71.6875}} -> {-12.9233, -85.9663, 0.18108, 0.18108}, {{
  127.563, 179.688}, {123.875, 71.6875}} -> {-23.3517, -86.0748, 0.181297, 
  0.181297}, {{184.938, 237.125}, {123.875, 71.6875}} -> {-33.7135, -85.9663, 
  0.18108, 0.18108}, {{242.313, 294.5}, {123.875, 
  71.6875}} -> {-44.103, -85.9663, 0.18108, 0.18108}, {{299.688, 351.875}, {
  123.875, 71.6875}} -> {-54.4924, -85.9663, 0.18108, 0.18108}, {{357.125, 
  409.25}, {123.875, 71.6875}} -> {-64.9707, -86.0748, 0.181297, 0.181297}, {{
  414.5, 466.688}, {123.875, 71.6875}} -> {-75.2826, -85.9663, 0.18108, 
  0.18108}, {{471.875, 524.063}, {123.875, 71.6875}} -> {-85.6721, -85.9663, 
  0.18108, 0.18108}, {{12.75, 64.9375}, {66.5, 
  14.3125}} -> {-2.53382, -96.3558, 0.18108, 0.18108}, {{70.125, 122.313}, {
  66.5, 14.3125}} -> {-12.9233, -96.3558, 0.18108, 0.18108}, {{127.563, 
  179.688}, {66.5, 14.3125}} -> {-23.3517, -96.4767, 0.181297, 0.181297}, {{
  184.938, 237.125}, {66.5, 14.3125}} -> {-33.7135, -96.3558, 0.18108, 
  0.18108}, {{242.313, 294.5}, {66.5, 14.3125}} -> {-44.103, -96.3558, 
  0.18108, 0.18108}, {{299.688, 351.875}, {66.5, 
  14.3125}} -> {-54.4924, -96.3558, 0.18108, 0.18108}, {{357.125, 409.25}, {
  66.5, 14.3125}} -> {-64.9707, -96.4767, 0.181297, 0.181297}, {{414.5, 
  466.688}, {66.5, 14.3125}} -> {-75.2826, -96.3558, 0.18108, 0.18108}, {{
  471.875, 524.063}, {66.5, 14.3125}} -> {-85.6721, -96.3558, 0.18108, 
  0.18108}}],

Cell[OutputFormData["\<\
GraphicsArray[{{Graphics[{{{GrayLevel[0], 
        {{Rectangle[{1, 1}, {2, 2}], Rectangle[{1, 3}, {2, 4}], 
          Rectangle[{1, 5}, {2, 6}], Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{1.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{1.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{1.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{2.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{2.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{2.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{8.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{8.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{3.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{3.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{3.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{6.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
       {Circle[{8.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{4.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{4.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{4.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{1.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{8.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{2.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{7.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{2.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{6.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{5.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{5.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{5.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{3.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{8.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{7.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{7.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{4.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{7.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{1.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{3.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{8.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{7.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{6.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 8.5}, 0.4]}}}, 
      {{Circle[{6.5, 1.5}, 0.4]}, {Circle[{8.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{4.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{5.5, 7.5}, 0.4]}, {Circle[{3.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{6.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{1.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}, 
   {Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{6.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{4.5, 6.5}, 0.4]}, 
       {Circle[{8.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
       {Circle[{8.5, 3.5}, 0.4]}, {Circle[{2.5, 4.5}, 0.4]}, 
       {Circle[{5.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{6.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{5.5, 4.5}, 0.4]}, 
       {Circle[{8.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
       {Circle[{2.5, 3.5}, 0.4]}, {Circle[{8.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{1.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{7.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{8.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
      {{Circle[{7.5, 1.5}, 0.4]}, {Circle[{5.5, 2.5}, 0.4]}, 
       {Circle[{3.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{6.5, 5.5}, 0.4]}, {Circle[{8.5, 6.5}, 0.4]}, 
       {Circle[{2.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{7.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{8.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{4.5, 3.5}, 0.4]}, {Circle[{1.5, 4.5}, 0.4]}, 
       {Circle[{7.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
       {Circle[{3.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
    Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
          Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
          Rectangle[{1, 7}, {2, 8}]}, 
         {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
          Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
         {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
          Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
         {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
          Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
          Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
         {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
          Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
         {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
          Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
         {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
          Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
       {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], \

          Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
         {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
          Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
         {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
          Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
         {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
          Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
       {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
          Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
         {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
          Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
         {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
          Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
         {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
          Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
      {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{2.5, 2.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{5.5, 3.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{1.5, 5.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{7.5, 6.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{4.5, 7.5}, 0.4]}}, 
       {GrayLevel[1], {Disk[{6.5, 8.5}, 0.4]}}}, 
      {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{2.5, 2.5}, 0.4]}, 
       {Circle[{5.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
       {Circle[{1.5, 5.5}, 0.4]}, {Circle[{7.5, 6.5}, 0.4]}, 
       {Circle[{4.5, 7.5}, 0.4]}, {Circle[{6.5, 8.5}, 0.4]}}, 
      {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{2.5, 2.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{5.5, 3.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{1.5, 5.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{7.5, 6.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{4.5, 7.5}, 0.1]}}, 
       {GrayLevel[0], {Disk[{6.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}}]\
\>", "\<\
-GraphicsArray-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[GraphicsArray[{qsg[[91]],qsg[[92]]}]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.92328 .18254 m
.92328 .18254 .04233 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.71164 .5 m
.71164 .5 .04233 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .04233 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.5 .92328 m
.5 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.92328 .18254 .04233 0 365.73 arc
s
newpath
.39418 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.71164 .5 .04233 0 365.73 arc
s
newpath
.28836 .60582 .04233 0 365.73 arc
s
newpath
.60582 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.5 .92328 .04233 0 365.73 arc
s
.92328 .18254 m
.92328 .18254 .01058 0 365.73 arc
F
.39418 .28836 m
.39418 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.71164 .5 m
.71164 .5 .01058 0 365.73 arc
F
.28836 .60582 m
.28836 .60582 .01058 0 365.73 arc
F
.60582 .71164 m
.60582 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.5 .92328 m
.5 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.0238095 0.10582 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.12963 .12963 m
.12963 .23545 L
.23545 .23545 L
.23545 .12963 L
F
.12963 .34127 m
.12963 .44709 L
.23545 .44709 L
.23545 .34127 L
F
.12963 .55291 m
.12963 .65873 L
.23545 .65873 L
.23545 .55291 L
F
.12963 .76455 m
.12963 .87037 L
.23545 .87037 L
.23545 .76455 L
F
.34127 .12963 m
.34127 .23545 L
.44709 .23545 L
.44709 .12963 L
F
.34127 .34127 m
.34127 .44709 L
.44709 .44709 L
.44709 .34127 L
F
.34127 .55291 m
.34127 .65873 L
.44709 .65873 L
.44709 .55291 L
F
.34127 .76455 m
.34127 .87037 L
.44709 .87037 L
.44709 .76455 L
F
.55291 .12963 m
.55291 .23545 L
.65873 .23545 L
.65873 .12963 L
F
.55291 .34127 m
.55291 .44709 L
.65873 .44709 L
.65873 .34127 L
F
.55291 .55291 m
.55291 .65873 L
.65873 .65873 L
.65873 .55291 L
F
.55291 .76455 m
.55291 .87037 L
.65873 .87037 L
.65873 .76455 L
F
.76455 .12963 m
.76455 .23545 L
.87037 .23545 L
.87037 .12963 L
F
.76455 .34127 m
.76455 .44709 L
.87037 .44709 L
.87037 .34127 L
F
.76455 .55291 m
.76455 .65873 L
.87037 .65873 L
.87037 .55291 L
F
.76455 .76455 m
.76455 .87037 L
.87037 .87037 L
.87037 .76455 L
F
.9 g
.12963 .23545 m
.12963 .34127 L
.23545 .34127 L
.23545 .23545 L
F
.12963 .44709 m
.12963 .55291 L
.23545 .55291 L
.23545 .44709 L
F
.12963 .65873 m
.12963 .76455 L
.23545 .76455 L
.23545 .65873 L
F
.12963 .87037 m
.12963 .97619 L
.23545 .97619 L
.23545 .87037 L
F
.34127 .23545 m
.34127 .34127 L
.44709 .34127 L
.44709 .23545 L
F
.34127 .44709 m
.34127 .55291 L
.44709 .55291 L
.44709 .44709 L
F
.34127 .65873 m
.34127 .76455 L
.44709 .76455 L
.44709 .65873 L
F
.34127 .87037 m
.34127 .97619 L
.44709 .97619 L
.44709 .87037 L
F
.55291 .23545 m
.55291 .34127 L
.65873 .34127 L
.65873 .23545 L
F
.55291 .44709 m
.55291 .55291 L
.65873 .55291 L
.65873 .44709 L
F
.55291 .65873 m
.55291 .76455 L
.65873 .76455 L
.65873 .65873 L
F
.55291 .87037 m
.55291 .97619 L
.65873 .97619 L
.65873 .87037 L
F
.76455 .23545 m
.76455 .34127 L
.87037 .34127 L
.87037 .23545 L
F
.76455 .44709 m
.76455 .55291 L
.87037 .55291 L
.87037 .44709 L
F
.76455 .65873 m
.76455 .76455 L
.87037 .76455 L
.87037 .65873 L
F
.76455 .87037 m
.76455 .97619 L
.87037 .97619 L
.87037 .87037 L
F
0 g
.23545 .23545 m
.23545 .34127 L
.34127 .34127 L
.34127 .23545 L
F
.23545 .44709 m
.23545 .55291 L
.34127 .55291 L
.34127 .44709 L
F
.23545 .65873 m
.23545 .76455 L
.34127 .76455 L
.34127 .65873 L
F
.23545 .87037 m
.23545 .97619 L
.34127 .97619 L
.34127 .87037 L
F
.44709 .23545 m
.44709 .34127 L
.55291 .34127 L
.55291 .23545 L
F
.44709 .44709 m
.44709 .55291 L
.55291 .55291 L
.55291 .44709 L
F
.44709 .65873 m
.44709 .76455 L
.55291 .76455 L
.55291 .65873 L
F
.44709 .87037 m
.44709 .97619 L
.55291 .97619 L
.55291 .87037 L
F
.65873 .23545 m
.65873 .34127 L
.76455 .34127 L
.76455 .23545 L
F
.65873 .44709 m
.65873 .55291 L
.76455 .55291 L
.76455 .44709 L
F
.65873 .65873 m
.65873 .76455 L
.76455 .76455 L
.76455 .65873 L
F
.65873 .87037 m
.65873 .97619 L
.76455 .97619 L
.76455 .87037 L
F
.87037 .23545 m
.87037 .34127 L
.97619 .34127 L
.97619 .23545 L
F
.87037 .44709 m
.87037 .55291 L
.97619 .55291 L
.97619 .44709 L
F
.87037 .65873 m
.87037 .76455 L
.97619 .76455 L
.97619 .65873 L
F
.87037 .87037 m
.87037 .97619 L
.97619 .97619 L
.97619 .87037 L
F
.9 g
.23545 .12963 m
.23545 .23545 L
.34127 .23545 L
.34127 .12963 L
F
.23545 .34127 m
.23545 .44709 L
.34127 .44709 L
.34127 .34127 L
F
.23545 .55291 m
.23545 .65873 L
.34127 .65873 L
.34127 .55291 L
F
.23545 .76455 m
.23545 .87037 L
.34127 .87037 L
.34127 .76455 L
F
.44709 .12963 m
.44709 .23545 L
.55291 .23545 L
.55291 .12963 L
F
.44709 .34127 m
.44709 .44709 L
.55291 .44709 L
.55291 .34127 L
F
.44709 .55291 m
.44709 .65873 L
.55291 .65873 L
.55291 .55291 L
F
.44709 .76455 m
.44709 .87037 L
.55291 .87037 L
.55291 .76455 L
F
.65873 .12963 m
.65873 .23545 L
.76455 .23545 L
.76455 .12963 L
F
.65873 .34127 m
.65873 .44709 L
.76455 .44709 L
.76455 .34127 L
F
.65873 .55291 m
.65873 .65873 L
.76455 .65873 L
.76455 .55291 L
F
.65873 .76455 m
.65873 .87037 L
.76455 .87037 L
.76455 .76455 L
F
.87037 .12963 m
.87037 .23545 L
.97619 .23545 L
.97619 .12963 L
F
.87037 .34127 m
.87037 .44709 L
.97619 .44709 L
.97619 .34127 L
F
.87037 .55291 m
.87037 .65873 L
.97619 .65873 L
.97619 .55291 L
F
.87037 .76455 m
.87037 .87037 L
.97619 .87037 L
.97619 .76455 L
F
1 g
.92328 .18254 m
.92328 .18254 .04233 0 365.73 arc
F
.5 .28836 m
.5 .28836 .04233 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .04233 0 365.73 arc
F
.39418 .5 m
.39418 .5 .04233 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .04233 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .04233 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .04233 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .04233 0 365.73 arc
F
0 g
.5 Mabswid
newpath
.92328 .18254 .04233 0 365.73 arc
s
newpath
.5 .28836 .04233 0 365.73 arc
s
newpath
.18254 .39418 .04233 0 365.73 arc
s
newpath
.39418 .5 .04233 0 365.73 arc
s
newpath
.71164 .60582 .04233 0 365.73 arc
s
newpath
.28836 .71164 .04233 0 365.73 arc
s
newpath
.81746 .81746 .04233 0 365.73 arc
s
newpath
.60582 .92328 .04233 0 365.73 arc
s
.92328 .18254 m
.92328 .18254 .01058 0 365.73 arc
F
.5 .28836 m
.5 .28836 .01058 0 365.73 arc
F
.18254 .39418 m
.18254 .39418 .01058 0 365.73 arc
F
.39418 .5 m
.39418 .5 .01058 0 365.73 arc
F
.71164 .60582 m
.71164 .60582 .01058 0 365.73 arc
F
.28836 .71164 m
.28836 .71164 .01058 0 365.73 arc
F
.81746 .81746 m
.81746 .81746 .01058 0 365.73 arc
F
.60582 .92328 m
.60582 .92328 .01058 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 137.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000RA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`0067oo3@003W>L3P003W>L3@003W>L3P00
3G>L8Goo3P003W>L3@003W>L3P003W>L3@003W>L37oo000HOol=00003VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/>000017>LKg]cW6mk1P0000=cW6mkLi`08Goo3P0000icW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000i_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3@0000EcW6mkLia_Ng>L00H00003Kg]cW6mk00aoo`0067oo
3@003W>L3P003W>L3@003W>L3P000g>L00<007ooOol017oo00<007>LLi`08Goo3P003W>L3@003W>L
3P003W>L3@0017>L00<007ooOol017oo00<007>LLi`037oo000HOol=00003VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/>000017>LKg]cW0001goo00<007>LOol087oo3P0000icW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000i_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3@0000AcW6mkLi`000Moo`03001cW6mk00aoo`0067oo
3@003W>L3P003W>L3@003W>L3P000W>L00<007ooOol01goo00<007ooOol07goo3P003W>L3@003W>L
3P003W>L3@000W>L00<007ooOol01goo00<007>LOol02goo000HOol=00003VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/>00000g>LKg/00009Ool00`00Oomoo`0OOol>00003W>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/=00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00000g>LKg/00009Ool00`00Kg]oo`0;Ool001Qoo`d0
00icW0h000icW0d000icW0h00003Li`007oo009oo`@000=oo`03001oogoo01moo`h000icW0d000ic
W0h000icW0d0009cW004001oogooOol40003Ool00`00Oomoo`0:Ool001Qoo`d0000>Kg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`h00003Li`007oo00Uoo`03001oogoo01moo`h0000>Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0
000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d00003Lia_N`0000Uoo`8000aoo`0067oo3@00
3W>L3P003W>L3@003W>L3P0000=cW000Ool02Goo00<007ooOol07goo3P003W>L3@003W>L3P003W>L
3@000W>L00<007ooOol01goo00<007>LOol02goo000HOol=00003VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/>00000g>LKg/00008Ool00`00Liaoo`0POol>00003W>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/=00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`=00000g>LKg/00008Ool00`00Lia_N`0<Ool001Qoo`d000icW0h0
00icW0d000icW0h000=cW003001oogoo00Aoo`03001cW7>L025oo`h000icW0d000icW0h000icW0d0
00=cW08000Ioo`03001cW7>L00aoo`0067oo3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
3P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3@0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mk3P0000AcW6mkLia_N`80009oo`800003Lia_Ng>L025oo`h0000>Lia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0d00005Lia_Ng>LKg]cW0020002Ool200000fmkLia_N`0<Ool001Qo
o`d000icW0h000icW0d000icW0h000IcW08000EcW25oo`h000icW0d000icW0h000icW0d000McW080
00EcW0aoo`0067oo3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000i_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L3@0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3P0000ecW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW00QOol>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=
00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`=00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/<Ool001Qoo`ecW0h000icW0h000ec
W0h000icW0d0025oo`icW0h000ecW0h000icW0h000ecW0h000aoo`0067oo00ecW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00>000016mkLia_Ng>L1P0000A_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/03P0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@008Goo00icW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3P0000ecW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>00003Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h0
00aoo`0067oo3G>L3P000g>L00<007ooOol017oo00@007>LLiacW0h000ecW0h000icW0d0025oo`ic
W0h000ecW0D000Ioo`<000icW0h000ecW0h000aoo`0067oo00ecW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW00>000016mkLia_N`001goo00<006mkLi`03P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00@000Qoo`80000>Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0037oo
000HOol=Li`>0002Li`00`00Oomoo`07Ool00`00Li`0000=000=Li`>000>Li`=000QOol>Li`>000=
Li`3000:Ool00`00LiacW00<Li`>000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`03P0000=_Ng>L00002Goo00<007>L00003@0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`0>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Yoo`0?001_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0037oo
000HOol=Li`>00000g>L001oo`03Ool30003Ool00`00Li`0000=000=Li`>000>Li`=000QOol>Li`>
000=Li`30003Ool40003Ool00`00LiacW00<Li`>000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`03P0000=_N`00Ool02Goo00<007>L00003@0000e_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`0>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Uoo`80
000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/03P0037oo000HOol=Li`>0002Li`00`00Oomoo`07Ool00`00Li`0000=000=Li`>000>Li`=000Q
Ool>Li`>000=Li`30009Ool2000>Li`>000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`03P0000=_Ng>L000027oo00<006mkLi`03P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00<000Qoo`<0000>Kg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P00
37oo000HOol=Li`>0003Li`20006Ool00`00LiacW00>000=Li`>000>Li`=000QOol>Li`>000=Li`5
0006Ool3000>Li`>000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03P00
00E_Ng>LKg]cW6mk0080009oo`800003Lia_Ng>L00h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/03P0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@008Goo00icW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk3P0000ecW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0070002Ool500003VmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h000ao
o`0067oo3G>L3P001g>L0P001G>L3P003G>L3P003W>L3@008Goo3W>L3P003G>L3P003W>L3P003G>L
3P0037oo000HOol03G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0000icW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk3@008Goo00icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3P0000ec
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>
00003FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h000aoo`0067oo3@003W>L3P003W>L3@003W>L
3P003G>L8Goo3P003W>L3@003W>L3P003W>L3@003W>L37oo000HOol60002Ool500003VmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLi`>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L025o
o`L0009oo`D0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0000>Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_N`aoo`0067oo10001Woo0`003W>L3P003W>L3@003W>L3P003G>L8Goo
10001goo0`003W>L3@003W>L3P003W>L3@003W>L37oo000HOol30009Ool03`00Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L025oo`<0
00Uoo`80000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0000>Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`aoo`0067oo0`002Goo00<007>LLi`037>L3P003W>L3@003W>L3P003G>L
8Goo0`002Goo0P003W>L3@003W>L3P003W>L3@003W>L37oo000HOol2000:Ool03`00Kg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L025o
o`<000Yoo`0?001cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00d0000>Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_N`aoo`0067oo0P000goo10000goo00<007>LLi`037>L3P003W>L3@00
3W>L3P003G>L8Goo0`000goo0`0017oo00<007>LLi`037>L3@003W>L3P003W>L3@003W>L37oo000H
Ool2000:Ool03`00Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`=00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L025oo`<000Uoo`80000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`aoo`0067oo0`002Goo00<007>L
Li`037>L3P003W>L3@003W>L3P003G>L8Goo0`002Goo0P003W>L3@003W>L3P003W>L3@003W>L37oo
000HOol40007Ool200003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003VmkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`=00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L025oo`@000Moo`<0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`aoo`0067oo10001Woo0`00
3W>L3P003W>L3@003W>L3P003G>L8Goo1@001Woo0`003W>L3@003W>L3P003W>L3@003W>L37oo000H
Ool=00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`=00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L025oo`h0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0000>Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`aoo`0067oo3@003W>L3P003W>L3@003W>L3P003G>L
8Goo3P003W>L3@003W>L3P003W>L3@003W>L37oo000HOol=00003VmkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L025oo`h0000>Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000>
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`aoo`0067oo3G>L3P003W>L3P003G>L3P003W>L3@008Goo3W>L3P0017>L10001G>L3P003W>L3P00
3G>L3P0037oo000HOol03G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00h0000>Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/010001Goo1@0000ic
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@008Goo00icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk3P0000AcW6mkLi`000Aoo`800003Lia_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0037oo000HOol=Li`>000>Li`>000=
Li`40007Ool3000>Li`=000QOol>Li`>0003Li`00`00Oomoo`04Ool200000g>L0000000<000>Li`>
000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03P0000i_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L3P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`030009Ool20000
3W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/>00000g>LKg/00009Ool?00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003Fmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h000aoo`0067oo3G>L3P003W>L3P003G>L0`002Goo0P00
3W>L3@008Goo3W>L3P000W>L00<007ooOol01goo3`003W>L3P003G>L3P0037oo000HOol03G>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000=
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/00`000goo0`0017oo00l007>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/03@008Goo00icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3P0000=cW000Ool0
0Woo10000goo3`0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000e_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_N`0>000<Ool001Qoo`ecW0h000icW0h000ecW0<000Yoo`03001cW7>L00acW0d0
025oo`icW0h00003Li`007oo00Uoo`l000icW0h000ecW0h000aoo`0067oo00ecW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003FmkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk00<000Uoo`80000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0
025oo`0>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`h00003Li`007oo00Uoo`l0000>Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0037oo
000HOol=Li`>000>Li`>000=Li`30009Ool2000>Li`=000QOol>Li`>0002Li`00`00Oomoo`07Ool?
000>Li`>000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03P0000i_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`050006
Ool300003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg/>000017>LKg]cW0001Woo0P0000=cW0000000300000i_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L3P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0>000<Ool001Qoo`ecW0h0
00icW0h000ecW0L000=oo`@000icW0d0025oo`icW0h000AcW08000=oo`04001cW7>LLi`>000>Li`>
000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03P0000i_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L3P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0>00003W>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>
00001W>LKg]cW6mkLia_N`@00003Lia_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0037oo000HOol=Li`>000>Li`>000=Li`>
000>Li`=000QOol>Li`>000=Li`>000>Li`>000=Li`>000<Ool001Qoo`d0000>Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`h0000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo3P00
00icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>L3P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3@0000icW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk37oo000HOol=0005Li`60003Li`>000>Li`=000>Li`>000=Li`QOol>000>Li`=000>
Li`>0004Li`60004Li`=000>Li`<Ool001Qoo`d00005Kg]cW6mkLi`00006Ool00`00Kg]cW00>0000
3VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`=00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L025oo`h0000>Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_N`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h00004Kg]cW6mk0006Ool0
1000Lia_Ng>L3@0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk37oo000HOol=0003Li`00`00
Oomoo`05Ool00`00LiacW00>000>Li`=000>Li`>000=Li`QOol>000>Li`=000>Li`>0003Li`00`00
Oomoo`05Ool00`00LiacW00=000>Li`<Ool001Qoo`d00003Kg]cW00000Uoo`03001cW00000d0000>
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`h0000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000icW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000=_Ng>L00002Goo00<0
07>L0000300000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk37oo000HOol=0002Li`00`00Oomo
o`07Ool00`00Li`0000=000>Li`=000>Li`>000=Li`QOol>000>Li`=000>Li`>0002Li`00`00Oomo
o`07Ool00`00Li`0000<000>Li`<Ool001Qoo`d00003Kg]cW00000=oo`@000=oo`l0000>Kg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`h0000=
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000=_N`00Ool00Woo10000goo00<0
07>L0000300000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk37oo000HOol=0002Li`00`00Oomo
o`07Ool@000>Li`=000>Li`>000=Li`QOol>000>Li`=000>Li`>00000g>L001oo`09Ool00`00Li`0
000<000>Li`<Ool001Qoo`d00003Kg]cW00000Uoo`03001cW00000d0000>Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`h0000=Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@0000i_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000=_Ng>L00002Goo00<007>L0000300000icW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk37oo000HOol=0002Li`00`00Oomoo`06Ool00`00LiacW00>
000>Li`=000>Li`>000=Li`QOol>000>Li`=000>Li`>0002Li`00`00Oomoo`06Ool00`00LiacW00=
000>Li`<Ool001Qoo`d00003Kg]cW6mk008000Ioo`03001_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`h0000=Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@0000i_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000A_Ng>LKg/000Moo`03001_Ng>L00d0000>Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`aoo`0067oo3@001G>L0P000Woo0P000g>L3P003W>L3@00
3W>L3P003G>L8Goo3P003W>L3@003W>L3P0017>L0P000goo0P000g>L3@003W>L37oo000HOol=0000
1fmkLia_Ng>LKg]cW6mk00800005Lia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLi`=00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L025oo`h0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0000>Kg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0h00006Kg]cW6mkLia_Ng>L0`0000EcW6mkLia_Ng>L00d0000>Lia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`aoo`0067oo3@003W>L3P003W>L3@003W>L3P003G>L8Goo
3P003W>L3@003W>L3P003W>L3@003W>L37oo000HOol03G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h00006Kg]cW6mkLia_Ng>L0P0000E_Ng>L
Kg]cW6mk00h0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0025oo`0>Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`h0000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03P0000i_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0>000<Ool0
01Qoo`ecW0h000icW0h000AcW080009oo`8000=cW0h000icW0d0025oo`icW0H0009oo`H000ecW0h0
00icW0h000ecW0h000aoo`0067oo00ecW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>00003VmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>000016mkLia_N`001Woo0P0000=_N`000000300000icW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@008Goo00icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
10001Woo100000ecW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mkLi`>00003FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h000aoo`0067oo3G>L3P00
3W>L3P000W>L00<007ooOol01goo3`003W>L3@008Goo3W>L100027oo0P003G>L3P003W>L3P003G>L
3P0037oo000HOol03G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0h00003Kg/007oo00Uoo`l0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`d0025oo`0>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`<000Uoo`80000=Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`03P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000e_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0>000<Ool001Qoo`ecW0h000icW0h00003Li`007oo00Uoo`l000ic
W0d0025oo`icW0<000Uoo`8000ecW0h000icW0h000ecW0h000aoo`0067oo00ecW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00000fmk001oo`02
Ool40003Ool?00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/20003Ool40003Ool200003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/03P0037oo000HOol=Li`>000>Li`>00000g>L001oo`08Ool00`00Li`0000=000>Li`=000Q
Ool>Li`2000:Ool2000=Li`>000>Li`>000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`03P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000=_N`00Ool027oo00<0
06mk00003@0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@008Goo00icW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk0`002Goo0P0000ecW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>00003Vmk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>00003FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h0
00aoo`0067oo3G>L3P003W>L3P0000=cW000Ool01goo00<007>LLi`03P003W>L3@008Goo3W>L0`00
27oo0`003G>L3P003W>L3P003G>L3P0037oo000HOol03G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h00004Kg]cW0000006Ool00`00Lia_N`0>
00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg/50006Ool300003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00h0000>Kg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0037oo000H
Ool=Li`>000>Li`>0004Li`60003Li`>000>Li`=000QOol>Li`>000=Li`>000>Li`>000=Li`>000<
Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03P0000i_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L3P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0>00003W>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000=
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0037oo000HOol=Li`>000>Li`>000=Li`>000>Li`=
000QOol>Li`>000=Li`>000>Li`>000=Li`>000<Ool001Qoo`d0000>Kg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_N`h0000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000icW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P00
00i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3@0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mk37oo000HOol=000>Li`>000>Li`=000>Li`50003Ool6000=Li`QOol>000>Li`=000>Li`>000>
Li`50003Ool5000>Li`<Ool001Qoo`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0000>
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
N`@000Ioo`@0000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000icW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000i_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_Ng>L10001Woo0`0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
37oo000HOol=000>Li`>000>Li`=000>Li`30009Ool2000=Li`QOol>000>Li`=000>Li`>000>Li`3
0009Ool00`00LiacW00<Li`<Ool001Qoo`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0
000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`<000Uoo`80000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000icW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000i_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0`002Goo00l007>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/037oo000HOol=000>Li`>000>Li`=000>Li`2000:Ool2000=Li`QOol>000>Li`=000>Li`>000>
Li`2000:Ool00`00LiacW00<Li`<Ool001Qoo`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]c
W0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`8000=oo`@000=oo`80000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000ic
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
3P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0P000goo10000goo00l007>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/037oo000HOol=000>Li`>000>Li`=000>Li`30009Ool2000=Li`QOol>
000>Li`=000>Li`>000>Li`2000:Ool00`00LiacW00<Li`<Ool001Qoo`d0000>Kg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mkLia_N`<000Uoo`80000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`0
8Goo3P0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>L3P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0P002Woo00l007>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>LKg/037oo000HOol=000>Li`>000>Li`=000>Li`40007Ool3000=Li`Q
Ool>000>Li`=000>Li`>000>Li`30008Ool2000>Li`<Ool001Qoo`d0000>Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_N`D000Ioo`<0000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo
3P0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L3P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L10001Woo0`0000icW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk37oo000HOol=000>Li`>000>Li`=000>Li`>000=Li`QOol>000>Li`=
000>Li`>000>Li`=000>Li`<Ool001Qoo`d0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0h0
000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0d0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`h0000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`08Goo3P0000icW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mk3@0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L3P0000i_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLia_Ng>L3@0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk37oo000HOol=
Li`>000>Li`>000=Li`>000>Li`=000QOol>Li`>000=Li`>000>Li`>000=Li`>000<Ool001Qoo`0=
Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
3P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg/=000QOol03W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>L
Kg]cW6mkLia_Ng>L00h00004Kg]cW6mkLi`700000g>LKg]cW00>00003FmkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW6mk00h000aoo`0067oo3G>L3P003W>L10001Woo10003G>L3P003W>L3@008Goo3W>L3P00
3G>L3P000g>L00<007ooOol01Goo00<007>LLi`03P003G>L3P0037oo000HOol03G>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW0@000Moo`<0000=
Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0000icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
3@008Goo00icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3P0000ecW6mkLia_Ng>LKg]cW6mkLia_
Ng>LKg]cW00>000016mkLia_N`001goo00<006mkLi`03P0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_N`0>000<Ool001Qoo`ecW0h000icW0<000Uoo`8000ecW0h000icW0d0025oo`icW0h000ecW0h0
009cW003001oogoo00Moo`03001cW00000d000ecW0h000aoo`0067oo00ecW6mkLia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`30009Ool200003FmkLia_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h0000>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`d0025o
o`0>Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`h0000=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk
Li`03P0000=_Ng>L00002Goo00<007>L00003@0000e_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0>
000<Ool001Qoo`ecW0h000icW08000=oo`@000=oo`8000ecW0h000icW0d0025oo`icW0h000ecW0h0
009cW004001oogooOol30003Ool00`00Li`0000=000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mk
Lia_Ng>LKg]cW6mkLi`03P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0P002Woo0P0000e_
Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_N`0>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=
000QOol03W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mk
Lia_Ng>L00h00003Kg]cW00000Uoo`03001cW00000d0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
Kg/03P0037oo000HOol=Li`>000>Li`30009Ool2000=Li`>000>Li`=000QOol>Li`>000=Li`>0002
Li`00`00Oomoo`07Ool00`00Li`0000=000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>L
Kg]cW6mkLi`03P0000i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L0`0027oo0`0000e_Ng>LKg]c
W6mkLia_Ng>LKg]cW6mkLia_N`0>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol0
3W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L
00h00003Kg]cW00000Qoo`03001_Ng>L00h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P00
37oo000HOol=Li`>000>Li`40007Ool3000=Li`>000>Li`=000QOol>Li`>000=Li`>0003Li`20006
Ool00`00LiacW00>000=Li`>000<Ool001Qoo`0=Lia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`03P00
00i_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L1P000goo1@0000e_Ng>LKg]cW6mkLia_Ng>LKg]c
W6mkLia_N`0>00003W>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/=000QOol03W>LKg]cW6mkLia_
Ng>LKg]cW6mkLia_Ng>LKg/>00003G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00h00005Kg]cW6mk
Lia_N`020002Ool200000g>LKg]cW00>00003FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h000ao
o`0067oo3G>L3P003W>L3P003G>L3P003W>L3@008Goo3W>L3P003G>L3P001g>L0P001G>L3P003G>L
3P0037oo000HOol03G>LKg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>L00h0000>Kg]cW6mkLia_Ng>LKg]c
W6mkLia_Ng>LKg]cW0h0000=Kg]cW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg/03P0000icW6mkLia_Ng>L
Kg]cW6mkLia_Ng>LKg]cW6mk3@008Goo00icW6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk3P0000ec
W6mkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW00>00003VmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mkLi`>
00003FmkLia_Ng>LKg]cW6mkLia_Ng>LKg]cW6mk00h000aoo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {136.125, 0}} -> {-0.0541876, -0.0238146, 
  0.00734626, 0.00734626}, {{7.375, 137}, {132.875, 
  3.1875}} -> {-0.76271, -0.464262, 0.0729034, 0.0729034}, {{149.938, 
  279.625}, {132.875, 3.1875}} -> {-11.1507, -0.461869, 0.0728683, 
  0.0728683}}],

Cell[OutputFormData["\<\
GraphicsArray[{Graphics[{{{GrayLevel[0], 
       {{Rectangle[{1, 1}, {2, 2}], Rectangle[{1, 3}, {2, 4}], 
         Rectangle[{1, 5}, {2, 6}], Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 8.5}, 0.4]}}}, 
     {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{3.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{6.5, 4.5}, 0.4]}, 
      {Circle[{2.5, 5.5}, 0.4]}, {Circle[{5.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{4.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 8.5}, 0.1]}}}}, AspectRatio -> 1], 
   Graphics[{{{GrayLevel[0], {{Rectangle[{1, 1}, {2, 2}], 
         Rectangle[{1, 3}, {2, 4}], Rectangle[{1, 5}, {2, 6}], 
         Rectangle[{1, 7}, {2, 8}]}, 
        {Rectangle[{3, 1}, {4, 2}], Rectangle[{3, 3}, {4, 4}], 
         Rectangle[{3, 5}, {4, 6}], Rectangle[{3, 7}, {4, 8}]}, 
        {Rectangle[{5, 1}, {6, 2}], Rectangle[{5, 3}, {6, 4}], 
         Rectangle[{5, 5}, {6, 6}], Rectangle[{5, 7}, {6, 8}]}, 
        {Rectangle[{7, 1}, {8, 2}], Rectangle[{7, 3}, {8, 4}], 
         Rectangle[{7, 5}, {8, 6}], Rectangle[{7, 7}, {8, 8}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{1, 2}, {2, 3}], Rectangle[{1, 4}, {2, \
5}], 
         Rectangle[{1, 6}, {2, 7}], Rectangle[{1, 8}, {2, 9}]}, 
        {Rectangle[{3, 2}, {4, 3}], Rectangle[{3, 4}, {4, 5}], 
         Rectangle[{3, 6}, {4, 7}], Rectangle[{3, 8}, {4, 9}]}, 
        {Rectangle[{5, 2}, {6, 3}], Rectangle[{5, 4}, {6, 5}], 
         Rectangle[{5, 6}, {6, 7}], Rectangle[{5, 8}, {6, 9}]}, 
        {Rectangle[{7, 2}, {8, 3}], Rectangle[{7, 4}, {8, 5}], 
         Rectangle[{7, 6}, {8, 7}], Rectangle[{7, 8}, {8, 9}]}}}, 
      {GrayLevel[0], {{Rectangle[{2, 2}, {3, 3}], Rectangle[{2, 4}, {3, 5}], 
         Rectangle[{2, 6}, {3, 7}], Rectangle[{2, 8}, {3, 9}]}, 
        {Rectangle[{4, 2}, {5, 3}], Rectangle[{4, 4}, {5, 5}], 
         Rectangle[{4, 6}, {5, 7}], Rectangle[{4, 8}, {5, 9}]}, 
        {Rectangle[{6, 2}, {7, 3}], Rectangle[{6, 4}, {7, 5}], 
         Rectangle[{6, 6}, {7, 7}], Rectangle[{6, 8}, {7, 9}]}, 
        {Rectangle[{8, 2}, {9, 3}], Rectangle[{8, 4}, {9, 5}], 
         Rectangle[{8, 6}, {9, 7}], Rectangle[{8, 8}, {9, 9}]}}}, 
      {GrayLevel[0.9], {{Rectangle[{2, 1}, {3, 2}], Rectangle[{2, 3}, {3, \
4}], 
         Rectangle[{2, 5}, {3, 6}], Rectangle[{2, 7}, {3, 8}]}, 
        {Rectangle[{4, 1}, {5, 2}], Rectangle[{4, 3}, {5, 4}], 
         Rectangle[{4, 5}, {5, 6}], Rectangle[{4, 7}, {5, 8}]}, 
        {Rectangle[{6, 1}, {7, 2}], Rectangle[{6, 3}, {7, 4}], 
         Rectangle[{6, 5}, {7, 6}], Rectangle[{6, 7}, {7, 8}]}, 
        {Rectangle[{8, 1}, {9, 2}], Rectangle[{8, 3}, {9, 4}], 
         Rectangle[{8, 5}, {9, 6}], Rectangle[{8, 7}, {9, 8}]}}}}, 
     {{GrayLevel[1], {Disk[{8.5, 1.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{4.5, 2.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{1.5, 3.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{3.5, 4.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{6.5, 5.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{2.5, 6.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{7.5, 7.5}, 0.4]}}, 
      {GrayLevel[1], {Disk[{5.5, 8.5}, 0.4]}}}, 
     {{Circle[{8.5, 1.5}, 0.4]}, {Circle[{4.5, 2.5}, 0.4]}, 
      {Circle[{1.5, 3.5}, 0.4]}, {Circle[{3.5, 4.5}, 0.4]}, 
      {Circle[{6.5, 5.5}, 0.4]}, {Circle[{2.5, 6.5}, 0.4]}, 
      {Circle[{7.5, 7.5}, 0.4]}, {Circle[{5.5, 8.5}, 0.4]}}, 
     {{GrayLevel[0], {Disk[{8.5, 1.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{4.5, 2.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{1.5, 3.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{3.5, 4.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{6.5, 5.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{2.5, 6.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{7.5, 7.5}, 0.1]}}, 
      {GrayLevel[0], {Disk[{5.5, 8.5}, 0.1]}}}}, AspectRatio -> 1]}]\
\>", "\<\
-GraphicsArray-\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The (9 \[Times] 9)-board", "Subsection"],

Cell[CellGroupData[{

Cell["t9 = Timing[qs = QueensSolution[9];][[1]]", "Input"],

Cell[OutputFormData["\<\
142.32*Second\
\>", "\<\
142.32 Second\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[qs]", "Input"],

Cell[OutputFormData["\<\
352\
\>", "\<\
352\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculation time and memory", "Subsection"],

Cell[CellGroupData[{

Cell["{t4, t5, t6, t7, t8, t9}", "Input"],

Cell[OutputFormData["\<\
{0.*Second, 0.04999999999999715*Second, 0.2199999999999988*Second, 
  1.650000000000034*Second, 14.38999999999998*Second, 142.32*Second}\
\>", "\<\
{0. Second, 0.05 Second, 0.22 Second, 1.65 Second, 14.39 Second, 142.32 \
Second}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MemoryInUse[]", "Input"],

Cell[OutputFormData["\<\
2070384\
\>", "\<\
2070384\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaxMemoryUsed[]", "Input"],

Cell[OutputFormData["\<\
25317376\
\>", "\<\
25317376\
\>"], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculation of Permanents", "Section"],

Cell[CellGroupData[{

Cell["The procedure Permanent1", "Subsection"],

Cell["\<\
This is the implementation of the procedure Permanent1 of  I. Vardi [1].\
\>", "Text"],

Cell[CellGroupData[{

Cell["x /: x[_]^_ := 0", "Input"],

Cell["\<\

Permanent1[a_List] :=
With[{vars = Array[x,Length[a]]},
    Expand[
          Apply[Times,
               Map[vars.# &,
                  a
                  ]
               ]
          ] /. x[_] -> 1
    ]\
\>", "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples using Permanent1", "Subsection"],

Cell["\<\
Before you carry out the following examples, you have to evaluate the \
definitions of the subsections \"The procedure \"Permanent1\".\
\>", "Text"],

Cell[CellGroupData[{

Cell["A = Array[u,{2,2}]", "Input"],

Cell[OutputFormData["\<\
{{u[1, 1], u[1, 2]}, {u[2, 1], u[2, 2]}}\
\>", "\<\
{{u[1, 1], u[1, 2]}, {u[2, 1], u[2, 2]}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent1[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{0.*Second, u[1, 2]*u[2, 1] + u[1, 1]*u[2, 2]}\
\>", "\<\
{0. Second, u[1, 2] u[2, 1] + u[1, 1] u[2, 2]}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Array[u,{3,3}]", "Input"],

Cell[OutputFormData["\<\
{{u[1, 1], u[1, 2], u[1, 3]}, {u[2, 1], u[2, 2], u[2, 3]}, 
  {u[3, 1], u[3, 2], u[3, 3]}}\
\>", "\<\
{{u[1, 1], u[1, 2], u[1, 3]}, {u[2, 1], u[2, 2], u[2, 3]}, 
 
  {u[3, 1], u[3, 2], u[3, 3]}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent1[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{0.*Second, u[1, 3]*u[2, 2]*u[3, 1] + u[1, 2]*u[2, 3]*u[3, 1] + 
   u[1, 3]*u[2, 1]*u[3, 2] + u[1, 1]*u[2, 3]*u[3, 2] + 
   u[1, 2]*u[2, 1]*u[3, 3] + u[1, 1]*u[2, 2]*u[3, 3]}\
\>", "\<\
{0. Second, u[1, 3] u[2, 2] u[3, 1] + u[1, 2] u[2, 3] u[3, 1] + 
 
   u[1, 3] u[2, 1] u[3, 2] + u[1, 1] u[2, 3] u[3, 2] + 
 
   u[1, 2] u[2, 1] u[3, 3] + u[1, 1] u[2, 2] u[3, 3]}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Array[u,{4,4}]", "Input"],

Cell[OutputFormData["\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4]}, {u[2, 1], u[2, 2], u[2, 3], u[2, 4]}, 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4]}, {u[4, 1], u[4, 2], u[4, 3], u[4, 4]}}\
\
\>", "\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4]}, {u[2, 1], u[2, 2], u[2, 3], u[2, 4]}, 
 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4]}, {u[4, 1], u[4, 2], u[4, 3], u[4, 4]}}\
\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent1[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{0.05000000000001136*Second, u[1, 4]*u[2, 3]*u[3, 2]*u[4, 1] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 1] + u[1, 4]*u[2, 2]*u[3, 3]*u[4, 1] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 1] + u[1, 3]*u[2, 2]*u[3, 4]*u[4, 1] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 1] + u[1, 4]*u[2, 3]*u[3, 1]*u[4, 2] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 2] + u[1, 4]*u[2, 1]*u[3, 3]*u[4, 2] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 2] + u[1, 3]*u[2, 1]*u[3, 4]*u[4, 2] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 2] + u[1, 4]*u[2, 2]*u[3, 1]*u[4, 3] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 3] + u[1, 4]*u[2, 1]*u[3, 2]*u[4, 3] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 3] + u[1, 2]*u[2, 1]*u[3, 4]*u[4, 3] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 3] + u[1, 3]*u[2, 2]*u[3, 1]*u[4, 4] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 4] + u[1, 3]*u[2, 1]*u[3, 2]*u[4, 4] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 4] + u[1, 2]*u[2, 1]*u[3, 3]*u[4, 4] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 4]}\
\>", "\<\
{0.05 Second, u[1, 4] u[2, 3] u[3, 2] u[4, 1] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 1] + u[1, 4] u[2, 2] u[3, 3] u[4, 1] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 1] + u[1, 3] u[2, 2] u[3, 4] u[4, 1] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 1] + u[1, 4] u[2, 3] u[3, 1] u[4, 2] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 2] + u[1, 4] u[2, 1] u[3, 3] u[4, 2] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 2] + u[1, 3] u[2, 1] u[3, 4] u[4, 2] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 2] + u[1, 4] u[2, 2] u[3, 1] u[4, 3] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 3] + u[1, 4] u[2, 1] u[3, 2] u[4, 3] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 3] + u[1, 2] u[2, 1] u[3, 4] u[4, 3] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 3] + u[1, 3] u[2, 2] u[3, 1] u[4, 4] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 4] + u[1, 3] u[2, 1] u[3, 2] u[4, 4] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 4] + u[1, 2] u[2, 1] u[3, 3] u[4, 4] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 4]}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Array[u,{5,5}]", "Input"],

Cell[OutputFormData["\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5]}, 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5]}, 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5]}, 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5]}, 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5]}}\
\>", "\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5]}, 
 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5]}, 
 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5]}, 
 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5]}, 
 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5]}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent1[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{0.5999999999999943*Second, u[1, 5]*u[2, 4]*u[3, 3]*u[4, 2]*u[5, 1] + 
   u[1, 4]*u[2, 5]*u[3, 3]*u[4, 2]*u[5, 1] + 
   u[1, 5]*u[2, 3]*u[3, 4]*u[4, 2]*u[5, 1] + 
   u[1, 3]*u[2, 5]*u[3, 4]*u[4, 2]*u[5, 1] + 
   u[1, 4]*u[2, 3]*u[3, 5]*u[4, 2]*u[5, 1] + 
   u[1, 3]*u[2, 4]*u[3, 5]*u[4, 2]*u[5, 1] + 
   u[1, 5]*u[2, 4]*u[3, 2]*u[4, 3]*u[5, 1] + 
   u[1, 4]*u[2, 5]*u[3, 2]*u[4, 3]*u[5, 1] + 
   u[1, 5]*u[2, 2]*u[3, 4]*u[4, 3]*u[5, 1] + 
   u[1, 2]*u[2, 5]*u[3, 4]*u[4, 3]*u[5, 1] + 
   u[1, 4]*u[2, 2]*u[3, 5]*u[4, 3]*u[5, 1] + 
   u[1, 2]*u[2, 4]*u[3, 5]*u[4, 3]*u[5, 1] + 
   u[1, 5]*u[2, 3]*u[3, 2]*u[4, 4]*u[5, 1] + 
   u[1, 3]*u[2, 5]*u[3, 2]*u[4, 4]*u[5, 1] + 
   u[1, 5]*u[2, 2]*u[3, 3]*u[4, 4]*u[5, 1] + 
   u[1, 2]*u[2, 5]*u[3, 3]*u[4, 4]*u[5, 1] + 
   u[1, 3]*u[2, 2]*u[3, 5]*u[4, 4]*u[5, 1] + 
   u[1, 2]*u[2, 3]*u[3, 5]*u[4, 4]*u[5, 1] + 
   u[1, 4]*u[2, 3]*u[3, 2]*u[4, 5]*u[5, 1] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 5]*u[5, 1] + 
   u[1, 4]*u[2, 2]*u[3, 3]*u[4, 5]*u[5, 1] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 5]*u[5, 1] + 
   u[1, 3]*u[2, 2]*u[3, 4]*u[4, 5]*u[5, 1] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 5]*u[5, 1] + 
   u[1, 5]*u[2, 4]*u[3, 3]*u[4, 1]*u[5, 2] + 
   u[1, 4]*u[2, 5]*u[3, 3]*u[4, 1]*u[5, 2] + 
   u[1, 5]*u[2, 3]*u[3, 4]*u[4, 1]*u[5, 2] + 
   u[1, 3]*u[2, 5]*u[3, 4]*u[4, 1]*u[5, 2] + 
   u[1, 4]*u[2, 3]*u[3, 5]*u[4, 1]*u[5, 2] + 
   u[1, 3]*u[2, 4]*u[3, 5]*u[4, 1]*u[5, 2] + 
   u[1, 5]*u[2, 4]*u[3, 1]*u[4, 3]*u[5, 2] + 
   u[1, 4]*u[2, 5]*u[3, 1]*u[4, 3]*u[5, 2] + 
   u[1, 5]*u[2, 1]*u[3, 4]*u[4, 3]*u[5, 2] + 
   u[1, 1]*u[2, 5]*u[3, 4]*u[4, 3]*u[5, 2] + 
   u[1, 4]*u[2, 1]*u[3, 5]*u[4, 3]*u[5, 2] + 
   u[1, 1]*u[2, 4]*u[3, 5]*u[4, 3]*u[5, 2] + 
   u[1, 5]*u[2, 3]*u[3, 1]*u[4, 4]*u[5, 2] + 
   u[1, 3]*u[2, 5]*u[3, 1]*u[4, 4]*u[5, 2] + 
   u[1, 5]*u[2, 1]*u[3, 3]*u[4, 4]*u[5, 2] + 
   u[1, 1]*u[2, 5]*u[3, 3]*u[4, 4]*u[5, 2] + 
   u[1, 3]*u[2, 1]*u[3, 5]*u[4, 4]*u[5, 2] + 
   u[1, 1]*u[2, 3]*u[3, 5]*u[4, 4]*u[5, 2] + 
   u[1, 4]*u[2, 3]*u[3, 1]*u[4, 5]*u[5, 2] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 5]*u[5, 2] + 
   u[1, 4]*u[2, 1]*u[3, 3]*u[4, 5]*u[5, 2] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 5]*u[5, 2] + 
   u[1, 3]*u[2, 1]*u[3, 4]*u[4, 5]*u[5, 2] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 5]*u[5, 2] + 
   u[1, 5]*u[2, 4]*u[3, 2]*u[4, 1]*u[5, 3] + 
   u[1, 4]*u[2, 5]*u[3, 2]*u[4, 1]*u[5, 3] + 
   u[1, 5]*u[2, 2]*u[3, 4]*u[4, 1]*u[5, 3] + 
   u[1, 2]*u[2, 5]*u[3, 4]*u[4, 1]*u[5, 3] + 
   u[1, 4]*u[2, 2]*u[3, 5]*u[4, 1]*u[5, 3] + 
   u[1, 2]*u[2, 4]*u[3, 5]*u[4, 1]*u[5, 3] + 
   u[1, 5]*u[2, 4]*u[3, 1]*u[4, 2]*u[5, 3] + 
   u[1, 4]*u[2, 5]*u[3, 1]*u[4, 2]*u[5, 3] + 
   u[1, 5]*u[2, 1]*u[3, 4]*u[4, 2]*u[5, 3] + 
   u[1, 1]*u[2, 5]*u[3, 4]*u[4, 2]*u[5, 3] + 
   u[1, 4]*u[2, 1]*u[3, 5]*u[4, 2]*u[5, 3] + 
   u[1, 1]*u[2, 4]*u[3, 5]*u[4, 2]*u[5, 3] + 
   u[1, 5]*u[2, 2]*u[3, 1]*u[4, 4]*u[5, 3] + 
   u[1, 2]*u[2, 5]*u[3, 1]*u[4, 4]*u[5, 3] + 
   u[1, 5]*u[2, 1]*u[3, 2]*u[4, 4]*u[5, 3] + 
   u[1, 1]*u[2, 5]*u[3, 2]*u[4, 4]*u[5, 3] + 
   u[1, 2]*u[2, 1]*u[3, 5]*u[4, 4]*u[5, 3] + 
   u[1, 1]*u[2, 2]*u[3, 5]*u[4, 4]*u[5, 3] + 
   u[1, 4]*u[2, 2]*u[3, 1]*u[4, 5]*u[5, 3] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 5]*u[5, 3] + 
   u[1, 4]*u[2, 1]*u[3, 2]*u[4, 5]*u[5, 3] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 5]*u[5, 3] + 
   u[1, 2]*u[2, 1]*u[3, 4]*u[4, 5]*u[5, 3] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 5]*u[5, 3] + 
   u[1, 5]*u[2, 3]*u[3, 2]*u[4, 1]*u[5, 4] + 
   u[1, 3]*u[2, 5]*u[3, 2]*u[4, 1]*u[5, 4] + 
   u[1, 5]*u[2, 2]*u[3, 3]*u[4, 1]*u[5, 4] + 
   u[1, 2]*u[2, 5]*u[3, 3]*u[4, 1]*u[5, 4] + 
   u[1, 3]*u[2, 2]*u[3, 5]*u[4, 1]*u[5, 4] + 
   u[1, 2]*u[2, 3]*u[3, 5]*u[4, 1]*u[5, 4] + 
   u[1, 5]*u[2, 3]*u[3, 1]*u[4, 2]*u[5, 4] + 
   u[1, 3]*u[2, 5]*u[3, 1]*u[4, 2]*u[5, 4] + 
   u[1, 5]*u[2, 1]*u[3, 3]*u[4, 2]*u[5, 4] + 
   u[1, 1]*u[2, 5]*u[3, 3]*u[4, 2]*u[5, 4] + 
   u[1, 3]*u[2, 1]*u[3, 5]*u[4, 2]*u[5, 4] + 
   u[1, 1]*u[2, 3]*u[3, 5]*u[4, 2]*u[5, 4] + 
   u[1, 5]*u[2, 2]*u[3, 1]*u[4, 3]*u[5, 4] + 
   u[1, 2]*u[2, 5]*u[3, 1]*u[4, 3]*u[5, 4] + 
   u[1, 5]*u[2, 1]*u[3, 2]*u[4, 3]*u[5, 4] + 
   u[1, 1]*u[2, 5]*u[3, 2]*u[4, 3]*u[5, 4] + 
   u[1, 2]*u[2, 1]*u[3, 5]*u[4, 3]*u[5, 4] + 
   u[1, 1]*u[2, 2]*u[3, 5]*u[4, 3]*u[5, 4] + 
   u[1, 3]*u[2, 2]*u[3, 1]*u[4, 5]*u[5, 4] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 5]*u[5, 4] + 
   u[1, 3]*u[2, 1]*u[3, 2]*u[4, 5]*u[5, 4] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 5]*u[5, 4] + 
   u[1, 2]*u[2, 1]*u[3, 3]*u[4, 5]*u[5, 4] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 5]*u[5, 4] + 
   u[1, 4]*u[2, 3]*u[3, 2]*u[4, 1]*u[5, 5] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 1]*u[5, 5] + 
   u[1, 4]*u[2, 2]*u[3, 3]*u[4, 1]*u[5, 5] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 1]*u[5, 5] + 
   u[1, 3]*u[2, 2]*u[3, 4]*u[4, 1]*u[5, 5] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 1]*u[5, 5] + 
   u[1, 4]*u[2, 3]*u[3, 1]*u[4, 2]*u[5, 5] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 2]*u[5, 5] + 
   u[1, 4]*u[2, 1]*u[3, 3]*u[4, 2]*u[5, 5] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 2]*u[5, 5] + 
   u[1, 3]*u[2, 1]*u[3, 4]*u[4, 2]*u[5, 5] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 2]*u[5, 5] + 
   u[1, 4]*u[2, 2]*u[3, 1]*u[4, 3]*u[5, 5] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 3]*u[5, 5] + 
   u[1, 4]*u[2, 1]*u[3, 2]*u[4, 3]*u[5, 5] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 3]*u[5, 5] + 
   u[1, 2]*u[2, 1]*u[3, 4]*u[4, 3]*u[5, 5] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 3]*u[5, 5] + 
   u[1, 3]*u[2, 2]*u[3, 1]*u[4, 4]*u[5, 5] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 4]*u[5, 5] + 
   u[1, 3]*u[2, 1]*u[3, 2]*u[4, 4]*u[5, 5] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 4]*u[5, 5] + 
   u[1, 2]*u[2, 1]*u[3, 3]*u[4, 4]*u[5, 5] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 4]*u[5, 5]}\
\>", "\<\
{0.6 Second, u[1, 5] u[2, 4] u[3, 3] u[4, 2] u[5, 1] + 
 
   u[1, 4] u[2, 5] u[3, 3] u[4, 2] u[5, 1] + 
 
   u[1, 5] u[2, 3] u[3, 4] u[4, 2] u[5, 1] + 
 
   u[1, 3] u[2, 5] u[3, 4] u[4, 2] u[5, 1] + 
 
   u[1, 4] u[2, 3] u[3, 5] u[4, 2] u[5, 1] + 
 
   u[1, 3] u[2, 4] u[3, 5] u[4, 2] u[5, 1] + 
 
   u[1, 5] u[2, 4] u[3, 2] u[4, 3] u[5, 1] + 
 
   u[1, 4] u[2, 5] u[3, 2] u[4, 3] u[5, 1] + 
 
   u[1, 5] u[2, 2] u[3, 4] u[4, 3] u[5, 1] + 
 
   u[1, 2] u[2, 5] u[3, 4] u[4, 3] u[5, 1] + 
 
   u[1, 4] u[2, 2] u[3, 5] u[4, 3] u[5, 1] + 
 
   u[1, 2] u[2, 4] u[3, 5] u[4, 3] u[5, 1] + 
 
   u[1, 5] u[2, 3] u[3, 2] u[4, 4] u[5, 1] + 
 
   u[1, 3] u[2, 5] u[3, 2] u[4, 4] u[5, 1] + 
 
   u[1, 5] u[2, 2] u[3, 3] u[4, 4] u[5, 1] + 
 
   u[1, 2] u[2, 5] u[3, 3] u[4, 4] u[5, 1] + 
 
   u[1, 3] u[2, 2] u[3, 5] u[4, 4] u[5, 1] + 
 
   u[1, 2] u[2, 3] u[3, 5] u[4, 4] u[5, 1] + 
 
   u[1, 4] u[2, 3] u[3, 2] u[4, 5] u[5, 1] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 5] u[5, 1] + 
 
   u[1, 4] u[2, 2] u[3, 3] u[4, 5] u[5, 1] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 5] u[5, 1] + 
 
   u[1, 3] u[2, 2] u[3, 4] u[4, 5] u[5, 1] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 5] u[5, 1] + 
 
   u[1, 5] u[2, 4] u[3, 3] u[4, 1] u[5, 2] + 
 
   u[1, 4] u[2, 5] u[3, 3] u[4, 1] u[5, 2] + 
 
   u[1, 5] u[2, 3] u[3, 4] u[4, 1] u[5, 2] + 
 
   u[1, 3] u[2, 5] u[3, 4] u[4, 1] u[5, 2] + 
 
   u[1, 4] u[2, 3] u[3, 5] u[4, 1] u[5, 2] + 
 
   u[1, 3] u[2, 4] u[3, 5] u[4, 1] u[5, 2] + 
 
   u[1, 5] u[2, 4] u[3, 1] u[4, 3] u[5, 2] + 
 
   u[1, 4] u[2, 5] u[3, 1] u[4, 3] u[5, 2] + 
 
   u[1, 5] u[2, 1] u[3, 4] u[4, 3] u[5, 2] + 
 
   u[1, 1] u[2, 5] u[3, 4] u[4, 3] u[5, 2] + 
 
   u[1, 4] u[2, 1] u[3, 5] u[4, 3] u[5, 2] + 
 
   u[1, 1] u[2, 4] u[3, 5] u[4, 3] u[5, 2] + 
 
   u[1, 5] u[2, 3] u[3, 1] u[4, 4] u[5, 2] + 
 
   u[1, 3] u[2, 5] u[3, 1] u[4, 4] u[5, 2] + 
 
   u[1, 5] u[2, 1] u[3, 3] u[4, 4] u[5, 2] + 
 
   u[1, 1] u[2, 5] u[3, 3] u[4, 4] u[5, 2] + 
 
   u[1, 3] u[2, 1] u[3, 5] u[4, 4] u[5, 2] + 
 
   u[1, 1] u[2, 3] u[3, 5] u[4, 4] u[5, 2] + 
 
   u[1, 4] u[2, 3] u[3, 1] u[4, 5] u[5, 2] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 5] u[5, 2] + 
 
   u[1, 4] u[2, 1] u[3, 3] u[4, 5] u[5, 2] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 5] u[5, 2] + 
 
   u[1, 3] u[2, 1] u[3, 4] u[4, 5] u[5, 2] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 5] u[5, 2] + 
 
   u[1, 5] u[2, 4] u[3, 2] u[4, 1] u[5, 3] + 
 
   u[1, 4] u[2, 5] u[3, 2] u[4, 1] u[5, 3] + 
 
   u[1, 5] u[2, 2] u[3, 4] u[4, 1] u[5, 3] + 
 
   u[1, 2] u[2, 5] u[3, 4] u[4, 1] u[5, 3] + 
 
   u[1, 4] u[2, 2] u[3, 5] u[4, 1] u[5, 3] + 
 
   u[1, 2] u[2, 4] u[3, 5] u[4, 1] u[5, 3] + 
 
   u[1, 5] u[2, 4] u[3, 1] u[4, 2] u[5, 3] + 
 
   u[1, 4] u[2, 5] u[3, 1] u[4, 2] u[5, 3] + 
 
   u[1, 5] u[2, 1] u[3, 4] u[4, 2] u[5, 3] + 
 
   u[1, 1] u[2, 5] u[3, 4] u[4, 2] u[5, 3] + 
 
   u[1, 4] u[2, 1] u[3, 5] u[4, 2] u[5, 3] + 
 
   u[1, 1] u[2, 4] u[3, 5] u[4, 2] u[5, 3] + 
 
   u[1, 5] u[2, 2] u[3, 1] u[4, 4] u[5, 3] + 
 
   u[1, 2] u[2, 5] u[3, 1] u[4, 4] u[5, 3] + 
 
   u[1, 5] u[2, 1] u[3, 2] u[4, 4] u[5, 3] + 
 
   u[1, 1] u[2, 5] u[3, 2] u[4, 4] u[5, 3] + 
 
   u[1, 2] u[2, 1] u[3, 5] u[4, 4] u[5, 3] + 
 
   u[1, 1] u[2, 2] u[3, 5] u[4, 4] u[5, 3] + 
 
   u[1, 4] u[2, 2] u[3, 1] u[4, 5] u[5, 3] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 5] u[5, 3] + 
 
   u[1, 4] u[2, 1] u[3, 2] u[4, 5] u[5, 3] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 5] u[5, 3] + 
 
   u[1, 2] u[2, 1] u[3, 4] u[4, 5] u[5, 3] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 5] u[5, 3] + 
 
   u[1, 5] u[2, 3] u[3, 2] u[4, 1] u[5, 4] + 
 
   u[1, 3] u[2, 5] u[3, 2] u[4, 1] u[5, 4] + 
 
   u[1, 5] u[2, 2] u[3, 3] u[4, 1] u[5, 4] + 
 
   u[1, 2] u[2, 5] u[3, 3] u[4, 1] u[5, 4] + 
 
   u[1, 3] u[2, 2] u[3, 5] u[4, 1] u[5, 4] + 
 
   u[1, 2] u[2, 3] u[3, 5] u[4, 1] u[5, 4] + 
 
   u[1, 5] u[2, 3] u[3, 1] u[4, 2] u[5, 4] + 
 
   u[1, 3] u[2, 5] u[3, 1] u[4, 2] u[5, 4] + 
 
   u[1, 5] u[2, 1] u[3, 3] u[4, 2] u[5, 4] + 
 
   u[1, 1] u[2, 5] u[3, 3] u[4, 2] u[5, 4] + 
 
   u[1, 3] u[2, 1] u[3, 5] u[4, 2] u[5, 4] + 
 
   u[1, 1] u[2, 3] u[3, 5] u[4, 2] u[5, 4] + 
 
   u[1, 5] u[2, 2] u[3, 1] u[4, 3] u[5, 4] + 
 
   u[1, 2] u[2, 5] u[3, 1] u[4, 3] u[5, 4] + 
 
   u[1, 5] u[2, 1] u[3, 2] u[4, 3] u[5, 4] + 
 
   u[1, 1] u[2, 5] u[3, 2] u[4, 3] u[5, 4] + 
 
   u[1, 2] u[2, 1] u[3, 5] u[4, 3] u[5, 4] + 
 
   u[1, 1] u[2, 2] u[3, 5] u[4, 3] u[5, 4] + 
 
   u[1, 3] u[2, 2] u[3, 1] u[4, 5] u[5, 4] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 5] u[5, 4] + 
 
   u[1, 3] u[2, 1] u[3, 2] u[4, 5] u[5, 4] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 5] u[5, 4] + 
 
   u[1, 2] u[2, 1] u[3, 3] u[4, 5] u[5, 4] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 5] u[5, 4] + 
 
   u[1, 4] u[2, 3] u[3, 2] u[4, 1] u[5, 5] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 1] u[5, 5] + 
 
   u[1, 4] u[2, 2] u[3, 3] u[4, 1] u[5, 5] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 1] u[5, 5] + 
 
   u[1, 3] u[2, 2] u[3, 4] u[4, 1] u[5, 5] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 1] u[5, 5] + 
 
   u[1, 4] u[2, 3] u[3, 1] u[4, 2] u[5, 5] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 2] u[5, 5] + 
 
   u[1, 4] u[2, 1] u[3, 3] u[4, 2] u[5, 5] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 2] u[5, 5] + 
 
   u[1, 3] u[2, 1] u[3, 4] u[4, 2] u[5, 5] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 2] u[5, 5] + 
 
   u[1, 4] u[2, 2] u[3, 1] u[4, 3] u[5, 5] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 3] u[5, 5] + 
 
   u[1, 4] u[2, 1] u[3, 2] u[4, 3] u[5, 5] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 3] u[5, 5] + 
 
   u[1, 2] u[2, 1] u[3, 4] u[4, 3] u[5, 5] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 3] u[5, 5] + 
 
   u[1, 3] u[2, 2] u[3, 1] u[4, 4] u[5, 5] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 4] u[5, 5] + 
 
   u[1, 3] u[2, 1] u[3, 2] u[4, 4] u[5, 5] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 4] u[5, 5] + 
 
   u[1, 2] u[2, 1] u[3, 3] u[4, 4] u[5, 5] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 4] u[5, 5]}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Array[u,{6,6}]", "Input"],

Cell[OutputFormData["\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5], u[1, 6]}, 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5], u[2, 6]}, 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5], u[3, 6]}, 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5], u[4, 6]}, 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5], u[5, 6]}, 
  {u[6, 1], u[6, 2], u[6, 3], u[6, 4], u[6, 5], u[6, 6]}}\
\>", "\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5], u[1, 6]}, 
 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5], u[2, 6]}, 
 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5], u[3, 6]}, 
 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5], u[4, 6]}, 
 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5], u[5, 6]}, 
 
  {u[6, 1], u[6, 2], u[6, 3], u[6, 4], u[6, 5], u[6, 6]}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent1[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{9.400000000000005*Second, u[1, 6]*u[2, 5]*u[3, 4]*u[4, 3]*u[5, 2]*u[6, 1] + 
   u[1, 5]*u[2, 6]*u[3, 4]*u[4, 3]*u[5, 2]*u[6, 1] + 
   u[1, 6]*u[2, 4]*u[3, 5]*u[4, 3]*u[5, 2]*u[6, 1] + 
   u[1, 4]*u[2, 6]*u[3, 5]*u[4, 3]*u[5, 2]*u[6, 1] + 
   u[1, 5]*u[2, 4]*u[3, 6]*u[4, 3]*u[5, 2]*u[6, 1] + 
   u[1, 4]*u[2, 5]*u[3, 6]*u[4, 3]*u[5, 2]*u[6, 1] + 
   u[1, 6]*u[2, 5]*u[3, 3]*u[4, 4]*u[5, 2]*u[6, 1] + 
   u[1, 5]*u[2, 6]*u[3, 3]*u[4, 4]*u[5, 2]*u[6, 1] + 
   u[1, 6]*u[2, 3]*u[3, 5]*u[4, 4]*u[5, 2]*u[6, 1] + 
   u[1, 3]*u[2, 6]*u[3, 5]*u[4, 4]*u[5, 2]*u[6, 1] + 
   u[1, 5]*u[2, 3]*u[3, 6]*u[4, 4]*u[5, 2]*u[6, 1] + 
   u[1, 3]*u[2, 5]*u[3, 6]*u[4, 4]*u[5, 2]*u[6, 1] + 
   u[1, 6]*u[2, 4]*u[3, 3]*u[4, 5]*u[5, 2]*u[6, 1] + 
   u[1, 4]*u[2, 6]*u[3, 3]*u[4, 5]*u[5, 2]*u[6, 1] + 
   u[1, 6]*u[2, 3]*u[3, 4]*u[4, 5]*u[5, 2]*u[6, 1] + 
   u[1, 3]*u[2, 6]*u[3, 4]*u[4, 5]*u[5, 2]*u[6, 1] + 
   u[1, 4]*u[2, 3]*u[3, 6]*u[4, 5]*u[5, 2]*u[6, 1] + 
   u[1, 3]*u[2, 4]*u[3, 6]*u[4, 5]*u[5, 2]*u[6, 1] + 
   u[1, 5]*u[2, 4]*u[3, 3]*u[4, 6]*u[5, 2]*u[6, 1] + 
   u[1, 4]*u[2, 5]*u[3, 3]*u[4, 6]*u[5, 2]*u[6, 1] + 
   u[1, 5]*u[2, 3]*u[3, 4]*u[4, 6]*u[5, 2]*u[6, 1] + 
   u[1, 3]*u[2, 5]*u[3, 4]*u[4, 6]*u[5, 2]*u[6, 1] + 
   u[1, 4]*u[2, 3]*u[3, 5]*u[4, 6]*u[5, 2]*u[6, 1] + 
   u[1, 3]*u[2, 4]*u[3, 5]*u[4, 6]*u[5, 2]*u[6, 1] + 
   u[1, 6]*u[2, 5]*u[3, 4]*u[4, 2]*u[5, 3]*u[6, 1] + 
   u[1, 5]*u[2, 6]*u[3, 4]*u[4, 2]*u[5, 3]*u[6, 1] + 
   u[1, 6]*u[2, 4]*u[3, 5]*u[4, 2]*u[5, 3]*u[6, 1] + 
   u[1, 4]*u[2, 6]*u[3, 5]*u[4, 2]*u[5, 3]*u[6, 1] + 
   u[1, 5]*u[2, 4]*u[3, 6]*u[4, 2]*u[5, 3]*u[6, 1] + 
   u[1, 4]*u[2, 5]*u[3, 6]*u[4, 2]*u[5, 3]*u[6, 1] + 
   u[1, 6]*u[2, 5]*u[3, 2]*u[4, 4]*u[5, 3]*u[6, 1] + 
   u[1, 5]*u[2, 6]*u[3, 2]*u[4, 4]*u[5, 3]*u[6, 1] + 
   u[1, 6]*u[2, 2]*u[3, 5]*u[4, 4]*u[5, 3]*u[6, 1] + 
   u[1, 2]*u[2, 6]*u[3, 5]*u[4, 4]*u[5, 3]*u[6, 1] + 
   u[1, 5]*u[2, 2]*u[3, 6]*u[4, 4]*u[5, 3]*u[6, 1] + 
   u[1, 2]*u[2, 5]*u[3, 6]*u[4, 4]*u[5, 3]*u[6, 1] + 
   u[1, 6]*u[2, 4]*u[3, 2]*u[4, 5]*u[5, 3]*u[6, 1] + 
   u[1, 4]*u[2, 6]*u[3, 2]*u[4, 5]*u[5, 3]*u[6, 1] + 
   u[1, 6]*u[2, 2]*u[3, 4]*u[4, 5]*u[5, 3]*u[6, 1] + 
   u[1, 2]*u[2, 6]*u[3, 4]*u[4, 5]*u[5, 3]*u[6, 1] + 
   u[1, 4]*u[2, 2]*u[3, 6]*u[4, 5]*u[5, 3]*u[6, 1] + 
   u[1, 2]*u[2, 4]*u[3, 6]*u[4, 5]*u[5, 3]*u[6, 1] + 
   u[1, 5]*u[2, 4]*u[3, 2]*u[4, 6]*u[5, 3]*u[6, 1] + 
   u[1, 4]*u[2, 5]*u[3, 2]*u[4, 6]*u[5, 3]*u[6, 1] + 
   u[1, 5]*u[2, 2]*u[3, 4]*u[4, 6]*u[5, 3]*u[6, 1] + 
   u[1, 2]*u[2, 5]*u[3, 4]*u[4, 6]*u[5, 3]*u[6, 1] + 
   u[1, 4]*u[2, 2]*u[3, 5]*u[4, 6]*u[5, 3]*u[6, 1] + 
   u[1, 2]*u[2, 4]*u[3, 5]*u[4, 6]*u[5, 3]*u[6, 1] + 
   u[1, 6]*u[2, 5]*u[3, 3]*u[4, 2]*u[5, 4]*u[6, 1] + 
   u[1, 5]*u[2, 6]*u[3, 3]*u[4, 2]*u[5, 4]*u[6, 1] + 
   u[1, 6]*u[2, 3]*u[3, 5]*u[4, 2]*u[5, 4]*u[6, 1] + 
   u[1, 3]*u[2, 6]*u[3, 5]*u[4, 2]*u[5, 4]*u[6, 1] + 
   u[1, 5]*u[2, 3]*u[3, 6]*u[4, 2]*u[5, 4]*u[6, 1] + 
   u[1, 3]*u[2, 5]*u[3, 6]*u[4, 2]*u[5, 4]*u[6, 1] + 
   u[1, 6]*u[2, 5]*u[3, 2]*u[4, 3]*u[5, 4]*u[6, 1] + 
   u[1, 5]*u[2, 6]*u[3, 2]*u[4, 3]*u[5, 4]*u[6, 1] + 
   u[1, 6]*u[2, 2]*u[3, 5]*u[4, 3]*u[5, 4]*u[6, 1] + 
   u[1, 2]*u[2, 6]*u[3, 5]*u[4, 3]*u[5, 4]*u[6, 1] + 
   u[1, 5]*u[2, 2]*u[3, 6]*u[4, 3]*u[5, 4]*u[6, 1] + 
   u[1, 2]*u[2, 5]*u[3, 6]*u[4, 3]*u[5, 4]*u[6, 1] + 
   u[1, 6]*u[2, 3]*u[3, 2]*u[4, 5]*u[5, 4]*u[6, 1] + 
   u[1, 3]*u[2, 6]*u[3, 2]*u[4, 5]*u[5, 4]*u[6, 1] + 
   u[1, 6]*u[2, 2]*u[3, 3]*u[4, 5]*u[5, 4]*u[6, 1] + 
   u[1, 2]*u[2, 6]*u[3, 3]*u[4, 5]*u[5, 4]*u[6, 1] + 
   u[1, 3]*u[2, 2]*u[3, 6]*u[4, 5]*u[5, 4]*u[6, 1] + 
   u[1, 2]*u[2, 3]*u[3, 6]*u[4, 5]*u[5, 4]*u[6, 1] + 
   u[1, 5]*u[2, 3]*u[3, 2]*u[4, 6]*u[5, 4]*u[6, 1] + 
   u[1, 3]*u[2, 5]*u[3, 2]*u[4, 6]*u[5, 4]*u[6, 1] + 
   u[1, 5]*u[2, 2]*u[3, 3]*u[4, 6]*u[5, 4]*u[6, 1] + 
   u[1, 2]*u[2, 5]*u[3, 3]*u[4, 6]*u[5, 4]*u[6, 1] + 
   u[1, 3]*u[2, 2]*u[3, 5]*u[4, 6]*u[5, 4]*u[6, 1] + 
   u[1, 2]*u[2, 3]*u[3, 5]*u[4, 6]*u[5, 4]*u[6, 1] + 
   u[1, 6]*u[2, 4]*u[3, 3]*u[4, 2]*u[5, 5]*u[6, 1] + 
   u[1, 4]*u[2, 6]*u[3, 3]*u[4, 2]*u[5, 5]*u[6, 1] + 
   u[1, 6]*u[2, 3]*u[3, 4]*u[4, 2]*u[5, 5]*u[6, 1] + 
   u[1, 3]*u[2, 6]*u[3, 4]*u[4, 2]*u[5, 5]*u[6, 1] + 
   u[1, 4]*u[2, 3]*u[3, 6]*u[4, 2]*u[5, 5]*u[6, 1] + 
   u[1, 3]*u[2, 4]*u[3, 6]*u[4, 2]*u[5, 5]*u[6, 1] + 
   u[1, 6]*u[2, 4]*u[3, 2]*u[4, 3]*u[5, 5]*u[6, 1] + 
   u[1, 4]*u[2, 6]*u[3, 2]*u[4, 3]*u[5, 5]*u[6, 1] + 
   u[1, 6]*u[2, 2]*u[3, 4]*u[4, 3]*u[5, 5]*u[6, 1] + 
   u[1, 2]*u[2, 6]*u[3, 4]*u[4, 3]*u[5, 5]*u[6, 1] + 
   u[1, 4]*u[2, 2]*u[3, 6]*u[4, 3]*u[5, 5]*u[6, 1] + 
   u[1, 2]*u[2, 4]*u[3, 6]*u[4, 3]*u[5, 5]*u[6, 1] + 
   u[1, 6]*u[2, 3]*u[3, 2]*u[4, 4]*u[5, 5]*u[6, 1] + 
   u[1, 3]*u[2, 6]*u[3, 2]*u[4, 4]*u[5, 5]*u[6, 1] + 
   u[1, 6]*u[2, 2]*u[3, 3]*u[4, 4]*u[5, 5]*u[6, 1] + 
   u[1, 2]*u[2, 6]*u[3, 3]*u[4, 4]*u[5, 5]*u[6, 1] + 
   u[1, 3]*u[2, 2]*u[3, 6]*u[4, 4]*u[5, 5]*u[6, 1] + 
   u[1, 2]*u[2, 3]*u[3, 6]*u[4, 4]*u[5, 5]*u[6, 1] + 
   u[1, 4]*u[2, 3]*u[3, 2]*u[4, 6]*u[5, 5]*u[6, 1] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 6]*u[5, 5]*u[6, 1] + 
   u[1, 4]*u[2, 2]*u[3, 3]*u[4, 6]*u[5, 5]*u[6, 1] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 6]*u[5, 5]*u[6, 1] + 
   u[1, 3]*u[2, 2]*u[3, 4]*u[4, 6]*u[5, 5]*u[6, 1] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 6]*u[5, 5]*u[6, 1] + 
   u[1, 5]*u[2, 4]*u[3, 3]*u[4, 2]*u[5, 6]*u[6, 1] + 
   u[1, 4]*u[2, 5]*u[3, 3]*u[4, 2]*u[5, 6]*u[6, 1] + 
   u[1, 5]*u[2, 3]*u[3, 4]*u[4, 2]*u[5, 6]*u[6, 1] + 
   u[1, 3]*u[2, 5]*u[3, 4]*u[4, 2]*u[5, 6]*u[6, 1] + 
   u[1, 4]*u[2, 3]*u[3, 5]*u[4, 2]*u[5, 6]*u[6, 1] + 
   u[1, 3]*u[2, 4]*u[3, 5]*u[4, 2]*u[5, 6]*u[6, 1] + 
   u[1, 5]*u[2, 4]*u[3, 2]*u[4, 3]*u[5, 6]*u[6, 1] + 
   u[1, 4]*u[2, 5]*u[3, 2]*u[4, 3]*u[5, 6]*u[6, 1] + 
   u[1, 5]*u[2, 2]*u[3, 4]*u[4, 3]*u[5, 6]*u[6, 1] + 
   u[1, 2]*u[2, 5]*u[3, 4]*u[4, 3]*u[5, 6]*u[6, 1] + 
   u[1, 4]*u[2, 2]*u[3, 5]*u[4, 3]*u[5, 6]*u[6, 1] + 
   u[1, 2]*u[2, 4]*u[3, 5]*u[4, 3]*u[5, 6]*u[6, 1] + 
   u[1, 5]*u[2, 3]*u[3, 2]*u[4, 4]*u[5, 6]*u[6, 1] + 
   u[1, 3]*u[2, 5]*u[3, 2]*u[4, 4]*u[5, 6]*u[6, 1] + 
   u[1, 5]*u[2, 2]*u[3, 3]*u[4, 4]*u[5, 6]*u[6, 1] + 
   u[1, 2]*u[2, 5]*u[3, 3]*u[4, 4]*u[5, 6]*u[6, 1] + 
   u[1, 3]*u[2, 2]*u[3, 5]*u[4, 4]*u[5, 6]*u[6, 1] + 
   u[1, 2]*u[2, 3]*u[3, 5]*u[4, 4]*u[5, 6]*u[6, 1] + 
   u[1, 4]*u[2, 3]*u[3, 2]*u[4, 5]*u[5, 6]*u[6, 1] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 5]*u[5, 6]*u[6, 1] + 
   u[1, 4]*u[2, 2]*u[3, 3]*u[4, 5]*u[5, 6]*u[6, 1] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 5]*u[5, 6]*u[6, 1] + 
   u[1, 3]*u[2, 2]*u[3, 4]*u[4, 5]*u[5, 6]*u[6, 1] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 5]*u[5, 6]*u[6, 1] + 
   u[1, 6]*u[2, 5]*u[3, 4]*u[4, 3]*u[5, 1]*u[6, 2] + 
   u[1, 5]*u[2, 6]*u[3, 4]*u[4, 3]*u[5, 1]*u[6, 2] + 
   u[1, 6]*u[2, 4]*u[3, 5]*u[4, 3]*u[5, 1]*u[6, 2] + 
   u[1, 4]*u[2, 6]*u[3, 5]*u[4, 3]*u[5, 1]*u[6, 2] + 
   u[1, 5]*u[2, 4]*u[3, 6]*u[4, 3]*u[5, 1]*u[6, 2] + 
   u[1, 4]*u[2, 5]*u[3, 6]*u[4, 3]*u[5, 1]*u[6, 2] + 
   u[1, 6]*u[2, 5]*u[3, 3]*u[4, 4]*u[5, 1]*u[6, 2] + 
   u[1, 5]*u[2, 6]*u[3, 3]*u[4, 4]*u[5, 1]*u[6, 2] + 
   u[1, 6]*u[2, 3]*u[3, 5]*u[4, 4]*u[5, 1]*u[6, 2] + 
   u[1, 3]*u[2, 6]*u[3, 5]*u[4, 4]*u[5, 1]*u[6, 2] + 
   u[1, 5]*u[2, 3]*u[3, 6]*u[4, 4]*u[5, 1]*u[6, 2] + 
   u[1, 3]*u[2, 5]*u[3, 6]*u[4, 4]*u[5, 1]*u[6, 2] + 
   u[1, 6]*u[2, 4]*u[3, 3]*u[4, 5]*u[5, 1]*u[6, 2] + 
   u[1, 4]*u[2, 6]*u[3, 3]*u[4, 5]*u[5, 1]*u[6, 2] + 
   u[1, 6]*u[2, 3]*u[3, 4]*u[4, 5]*u[5, 1]*u[6, 2] + 
   u[1, 3]*u[2, 6]*u[3, 4]*u[4, 5]*u[5, 1]*u[6, 2] + 
   u[1, 4]*u[2, 3]*u[3, 6]*u[4, 5]*u[5, 1]*u[6, 2] + 
   u[1, 3]*u[2, 4]*u[3, 6]*u[4, 5]*u[5, 1]*u[6, 2] + 
   u[1, 5]*u[2, 4]*u[3, 3]*u[4, 6]*u[5, 1]*u[6, 2] + 
   u[1, 4]*u[2, 5]*u[3, 3]*u[4, 6]*u[5, 1]*u[6, 2] + 
   u[1, 5]*u[2, 3]*u[3, 4]*u[4, 6]*u[5, 1]*u[6, 2] + 
   u[1, 3]*u[2, 5]*u[3, 4]*u[4, 6]*u[5, 1]*u[6, 2] + 
   u[1, 4]*u[2, 3]*u[3, 5]*u[4, 6]*u[5, 1]*u[6, 2] + 
   u[1, 3]*u[2, 4]*u[3, 5]*u[4, 6]*u[5, 1]*u[6, 2] + 
   u[1, 6]*u[2, 5]*u[3, 4]*u[4, 1]*u[5, 3]*u[6, 2] + 
   u[1, 5]*u[2, 6]*u[3, 4]*u[4, 1]*u[5, 3]*u[6, 2] + 
   u[1, 6]*u[2, 4]*u[3, 5]*u[4, 1]*u[5, 3]*u[6, 2] + 
   u[1, 4]*u[2, 6]*u[3, 5]*u[4, 1]*u[5, 3]*u[6, 2] + 
   u[1, 5]*u[2, 4]*u[3, 6]*u[4, 1]*u[5, 3]*u[6, 2] + 
   u[1, 4]*u[2, 5]*u[3, 6]*u[4, 1]*u[5, 3]*u[6, 2] + 
   u[1, 6]*u[2, 5]*u[3, 1]*u[4, 4]*u[5, 3]*u[6, 2] + 
   u[1, 5]*u[2, 6]*u[3, 1]*u[4, 4]*u[5, 3]*u[6, 2] + 
   u[1, 6]*u[2, 1]*u[3, 5]*u[4, 4]*u[5, 3]*u[6, 2] + 
   u[1, 1]*u[2, 6]*u[3, 5]*u[4, 4]*u[5, 3]*u[6, 2] + 
   u[1, 5]*u[2, 1]*u[3, 6]*u[4, 4]*u[5, 3]*u[6, 2] + 
   u[1, 1]*u[2, 5]*u[3, 6]*u[4, 4]*u[5, 3]*u[6, 2] + 
   u[1, 6]*u[2, 4]*u[3, 1]*u[4, 5]*u[5, 3]*u[6, 2] + 
   u[1, 4]*u[2, 6]*u[3, 1]*u[4, 5]*u[5, 3]*u[6, 2] + 
   u[1, 6]*u[2, 1]*u[3, 4]*u[4, 5]*u[5, 3]*u[6, 2] + 
   u[1, 1]*u[2, 6]*u[3, 4]*u[4, 5]*u[5, 3]*u[6, 2] + 
   u[1, 4]*u[2, 1]*u[3, 6]*u[4, 5]*u[5, 3]*u[6, 2] + 
   u[1, 1]*u[2, 4]*u[3, 6]*u[4, 5]*u[5, 3]*u[6, 2] + 
   u[1, 5]*u[2, 4]*u[3, 1]*u[4, 6]*u[5, 3]*u[6, 2] + 
   u[1, 4]*u[2, 5]*u[3, 1]*u[4, 6]*u[5, 3]*u[6, 2] + 
   u[1, 5]*u[2, 1]*u[3, 4]*u[4, 6]*u[5, 3]*u[6, 2] + 
   u[1, 1]*u[2, 5]*u[3, 4]*u[4, 6]*u[5, 3]*u[6, 2] + 
   u[1, 4]*u[2, 1]*u[3, 5]*u[4, 6]*u[5, 3]*u[6, 2] + 
   u[1, 1]*u[2, 4]*u[3, 5]*u[4, 6]*u[5, 3]*u[6, 2] + 
   u[1, 6]*u[2, 5]*u[3, 3]*u[4, 1]*u[5, 4]*u[6, 2] + 
   u[1, 5]*u[2, 6]*u[3, 3]*u[4, 1]*u[5, 4]*u[6, 2] + 
   u[1, 6]*u[2, 3]*u[3, 5]*u[4, 1]*u[5, 4]*u[6, 2] + 
   u[1, 3]*u[2, 6]*u[3, 5]*u[4, 1]*u[5, 4]*u[6, 2] + 
   u[1, 5]*u[2, 3]*u[3, 6]*u[4, 1]*u[5, 4]*u[6, 2] + 
   u[1, 3]*u[2, 5]*u[3, 6]*u[4, 1]*u[5, 4]*u[6, 2] + 
   u[1, 6]*u[2, 5]*u[3, 1]*u[4, 3]*u[5, 4]*u[6, 2] + 
   u[1, 5]*u[2, 6]*u[3, 1]*u[4, 3]*u[5, 4]*u[6, 2] + 
   u[1, 6]*u[2, 1]*u[3, 5]*u[4, 3]*u[5, 4]*u[6, 2] + 
   u[1, 1]*u[2, 6]*u[3, 5]*u[4, 3]*u[5, 4]*u[6, 2] + 
   u[1, 5]*u[2, 1]*u[3, 6]*u[4, 3]*u[5, 4]*u[6, 2] + 
   u[1, 1]*u[2, 5]*u[3, 6]*u[4, 3]*u[5, 4]*u[6, 2] + 
   u[1, 6]*u[2, 3]*u[3, 1]*u[4, 5]*u[5, 4]*u[6, 2] + 
   u[1, 3]*u[2, 6]*u[3, 1]*u[4, 5]*u[5, 4]*u[6, 2] + 
   u[1, 6]*u[2, 1]*u[3, 3]*u[4, 5]*u[5, 4]*u[6, 2] + 
   u[1, 1]*u[2, 6]*u[3, 3]*u[4, 5]*u[5, 4]*u[6, 2] + 
   u[1, 3]*u[2, 1]*u[3, 6]*u[4, 5]*u[5, 4]*u[6, 2] + 
   u[1, 1]*u[2, 3]*u[3, 6]*u[4, 5]*u[5, 4]*u[6, 2] + 
   u[1, 5]*u[2, 3]*u[3, 1]*u[4, 6]*u[5, 4]*u[6, 2] + 
   u[1, 3]*u[2, 5]*u[3, 1]*u[4, 6]*u[5, 4]*u[6, 2] + 
   u[1, 5]*u[2, 1]*u[3, 3]*u[4, 6]*u[5, 4]*u[6, 2] + 
   u[1, 1]*u[2, 5]*u[3, 3]*u[4, 6]*u[5, 4]*u[6, 2] + 
   u[1, 3]*u[2, 1]*u[3, 5]*u[4, 6]*u[5, 4]*u[6, 2] + 
   u[1, 1]*u[2, 3]*u[3, 5]*u[4, 6]*u[5, 4]*u[6, 2] + 
   u[1, 6]*u[2, 4]*u[3, 3]*u[4, 1]*u[5, 5]*u[6, 2] + 
   u[1, 4]*u[2, 6]*u[3, 3]*u[4, 1]*u[5, 5]*u[6, 2] + 
   u[1, 6]*u[2, 3]*u[3, 4]*u[4, 1]*u[5, 5]*u[6, 2] + 
   u[1, 3]*u[2, 6]*u[3, 4]*u[4, 1]*u[5, 5]*u[6, 2] + 
   u[1, 4]*u[2, 3]*u[3, 6]*u[4, 1]*u[5, 5]*u[6, 2] + 
   u[1, 3]*u[2, 4]*u[3, 6]*u[4, 1]*u[5, 5]*u[6, 2] + 
   u[1, 6]*u[2, 4]*u[3, 1]*u[4, 3]*u[5, 5]*u[6, 2] + 
   u[1, 4]*u[2, 6]*u[3, 1]*u[4, 3]*u[5, 5]*u[6, 2] + 
   u[1, 6]*u[2, 1]*u[3, 4]*u[4, 3]*u[5, 5]*u[6, 2] + 
   u[1, 1]*u[2, 6]*u[3, 4]*u[4, 3]*u[5, 5]*u[6, 2] + 
   u[1, 4]*u[2, 1]*u[3, 6]*u[4, 3]*u[5, 5]*u[6, 2] + 
   u[1, 1]*u[2, 4]*u[3, 6]*u[4, 3]*u[5, 5]*u[6, 2] + 
   u[1, 6]*u[2, 3]*u[3, 1]*u[4, 4]*u[5, 5]*u[6, 2] + 
   u[1, 3]*u[2, 6]*u[3, 1]*u[4, 4]*u[5, 5]*u[6, 2] + 
   u[1, 6]*u[2, 1]*u[3, 3]*u[4, 4]*u[5, 5]*u[6, 2] + 
   u[1, 1]*u[2, 6]*u[3, 3]*u[4, 4]*u[5, 5]*u[6, 2] + 
   u[1, 3]*u[2, 1]*u[3, 6]*u[4, 4]*u[5, 5]*u[6, 2] + 
   u[1, 1]*u[2, 3]*u[3, 6]*u[4, 4]*u[5, 5]*u[6, 2] + 
   u[1, 4]*u[2, 3]*u[3, 1]*u[4, 6]*u[5, 5]*u[6, 2] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 6]*u[5, 5]*u[6, 2] + 
   u[1, 4]*u[2, 1]*u[3, 3]*u[4, 6]*u[5, 5]*u[6, 2] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 6]*u[5, 5]*u[6, 2] + 
   u[1, 3]*u[2, 1]*u[3, 4]*u[4, 6]*u[5, 5]*u[6, 2] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 6]*u[5, 5]*u[6, 2] + 
   u[1, 5]*u[2, 4]*u[3, 3]*u[4, 1]*u[5, 6]*u[6, 2] + 
   u[1, 4]*u[2, 5]*u[3, 3]*u[4, 1]*u[5, 6]*u[6, 2] + 
   u[1, 5]*u[2, 3]*u[3, 4]*u[4, 1]*u[5, 6]*u[6, 2] + 
   u[1, 3]*u[2, 5]*u[3, 4]*u[4, 1]*u[5, 6]*u[6, 2] + 
   u[1, 4]*u[2, 3]*u[3, 5]*u[4, 1]*u[5, 6]*u[6, 2] + 
   u[1, 3]*u[2, 4]*u[3, 5]*u[4, 1]*u[5, 6]*u[6, 2] + 
   u[1, 5]*u[2, 4]*u[3, 1]*u[4, 3]*u[5, 6]*u[6, 2] + 
   u[1, 4]*u[2, 5]*u[3, 1]*u[4, 3]*u[5, 6]*u[6, 2] + 
   u[1, 5]*u[2, 1]*u[3, 4]*u[4, 3]*u[5, 6]*u[6, 2] + 
   u[1, 1]*u[2, 5]*u[3, 4]*u[4, 3]*u[5, 6]*u[6, 2] + 
   u[1, 4]*u[2, 1]*u[3, 5]*u[4, 3]*u[5, 6]*u[6, 2] + 
   u[1, 1]*u[2, 4]*u[3, 5]*u[4, 3]*u[5, 6]*u[6, 2] + 
   u[1, 5]*u[2, 3]*u[3, 1]*u[4, 4]*u[5, 6]*u[6, 2] + 
   u[1, 3]*u[2, 5]*u[3, 1]*u[4, 4]*u[5, 6]*u[6, 2] + 
   u[1, 5]*u[2, 1]*u[3, 3]*u[4, 4]*u[5, 6]*u[6, 2] + 
   u[1, 1]*u[2, 5]*u[3, 3]*u[4, 4]*u[5, 6]*u[6, 2] + 
   u[1, 3]*u[2, 1]*u[3, 5]*u[4, 4]*u[5, 6]*u[6, 2] + 
   u[1, 1]*u[2, 3]*u[3, 5]*u[4, 4]*u[5, 6]*u[6, 2] + 
   u[1, 4]*u[2, 3]*u[3, 1]*u[4, 5]*u[5, 6]*u[6, 2] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 5]*u[5, 6]*u[6, 2] + 
   u[1, 4]*u[2, 1]*u[3, 3]*u[4, 5]*u[5, 6]*u[6, 2] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 5]*u[5, 6]*u[6, 2] + 
   u[1, 3]*u[2, 1]*u[3, 4]*u[4, 5]*u[5, 6]*u[6, 2] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 5]*u[5, 6]*u[6, 2] + 
   u[1, 6]*u[2, 5]*u[3, 4]*u[4, 2]*u[5, 1]*u[6, 3] + 
   u[1, 5]*u[2, 6]*u[3, 4]*u[4, 2]*u[5, 1]*u[6, 3] + 
   u[1, 6]*u[2, 4]*u[3, 5]*u[4, 2]*u[5, 1]*u[6, 3] + 
   u[1, 4]*u[2, 6]*u[3, 5]*u[4, 2]*u[5, 1]*u[6, 3] + 
   u[1, 5]*u[2, 4]*u[3, 6]*u[4, 2]*u[5, 1]*u[6, 3] + 
   u[1, 4]*u[2, 5]*u[3, 6]*u[4, 2]*u[5, 1]*u[6, 3] + 
   u[1, 6]*u[2, 5]*u[3, 2]*u[4, 4]*u[5, 1]*u[6, 3] + 
   u[1, 5]*u[2, 6]*u[3, 2]*u[4, 4]*u[5, 1]*u[6, 3] + 
   u[1, 6]*u[2, 2]*u[3, 5]*u[4, 4]*u[5, 1]*u[6, 3] + 
   u[1, 2]*u[2, 6]*u[3, 5]*u[4, 4]*u[5, 1]*u[6, 3] + 
   u[1, 5]*u[2, 2]*u[3, 6]*u[4, 4]*u[5, 1]*u[6, 3] + 
   u[1, 2]*u[2, 5]*u[3, 6]*u[4, 4]*u[5, 1]*u[6, 3] + 
   u[1, 6]*u[2, 4]*u[3, 2]*u[4, 5]*u[5, 1]*u[6, 3] + 
   u[1, 4]*u[2, 6]*u[3, 2]*u[4, 5]*u[5, 1]*u[6, 3] + 
   u[1, 6]*u[2, 2]*u[3, 4]*u[4, 5]*u[5, 1]*u[6, 3] + 
   u[1, 2]*u[2, 6]*u[3, 4]*u[4, 5]*u[5, 1]*u[6, 3] + 
   u[1, 4]*u[2, 2]*u[3, 6]*u[4, 5]*u[5, 1]*u[6, 3] + 
   u[1, 2]*u[2, 4]*u[3, 6]*u[4, 5]*u[5, 1]*u[6, 3] + 
   u[1, 5]*u[2, 4]*u[3, 2]*u[4, 6]*u[5, 1]*u[6, 3] + 
   u[1, 4]*u[2, 5]*u[3, 2]*u[4, 6]*u[5, 1]*u[6, 3] + 
   u[1, 5]*u[2, 2]*u[3, 4]*u[4, 6]*u[5, 1]*u[6, 3] + 
   u[1, 2]*u[2, 5]*u[3, 4]*u[4, 6]*u[5, 1]*u[6, 3] + 
   u[1, 4]*u[2, 2]*u[3, 5]*u[4, 6]*u[5, 1]*u[6, 3] + 
   u[1, 2]*u[2, 4]*u[3, 5]*u[4, 6]*u[5, 1]*u[6, 3] + 
   u[1, 6]*u[2, 5]*u[3, 4]*u[4, 1]*u[5, 2]*u[6, 3] + 
   u[1, 5]*u[2, 6]*u[3, 4]*u[4, 1]*u[5, 2]*u[6, 3] + 
   u[1, 6]*u[2, 4]*u[3, 5]*u[4, 1]*u[5, 2]*u[6, 3] + 
   u[1, 4]*u[2, 6]*u[3, 5]*u[4, 1]*u[5, 2]*u[6, 3] + 
   u[1, 5]*u[2, 4]*u[3, 6]*u[4, 1]*u[5, 2]*u[6, 3] + 
   u[1, 4]*u[2, 5]*u[3, 6]*u[4, 1]*u[5, 2]*u[6, 3] + 
   u[1, 6]*u[2, 5]*u[3, 1]*u[4, 4]*u[5, 2]*u[6, 3] + 
   u[1, 5]*u[2, 6]*u[3, 1]*u[4, 4]*u[5, 2]*u[6, 3] + 
   u[1, 6]*u[2, 1]*u[3, 5]*u[4, 4]*u[5, 2]*u[6, 3] + 
   u[1, 1]*u[2, 6]*u[3, 5]*u[4, 4]*u[5, 2]*u[6, 3] + 
   u[1, 5]*u[2, 1]*u[3, 6]*u[4, 4]*u[5, 2]*u[6, 3] + 
   u[1, 1]*u[2, 5]*u[3, 6]*u[4, 4]*u[5, 2]*u[6, 3] + 
   u[1, 6]*u[2, 4]*u[3, 1]*u[4, 5]*u[5, 2]*u[6, 3] + 
   u[1, 4]*u[2, 6]*u[3, 1]*u[4, 5]*u[5, 2]*u[6, 3] + 
   u[1, 6]*u[2, 1]*u[3, 4]*u[4, 5]*u[5, 2]*u[6, 3] + 
   u[1, 1]*u[2, 6]*u[3, 4]*u[4, 5]*u[5, 2]*u[6, 3] + 
   u[1, 4]*u[2, 1]*u[3, 6]*u[4, 5]*u[5, 2]*u[6, 3] + 
   u[1, 1]*u[2, 4]*u[3, 6]*u[4, 5]*u[5, 2]*u[6, 3] + 
   u[1, 5]*u[2, 4]*u[3, 1]*u[4, 6]*u[5, 2]*u[6, 3] + 
   u[1, 4]*u[2, 5]*u[3, 1]*u[4, 6]*u[5, 2]*u[6, 3] + 
   u[1, 5]*u[2, 1]*u[3, 4]*u[4, 6]*u[5, 2]*u[6, 3] + 
   u[1, 1]*u[2, 5]*u[3, 4]*u[4, 6]*u[5, 2]*u[6, 3] + 
   u[1, 4]*u[2, 1]*u[3, 5]*u[4, 6]*u[5, 2]*u[6, 3] + 
   u[1, 1]*u[2, 4]*u[3, 5]*u[4, 6]*u[5, 2]*u[6, 3] + 
   u[1, 6]*u[2, 5]*u[3, 2]*u[4, 1]*u[5, 4]*u[6, 3] + 
   u[1, 5]*u[2, 6]*u[3, 2]*u[4, 1]*u[5, 4]*u[6, 3] + 
   u[1, 6]*u[2, 2]*u[3, 5]*u[4, 1]*u[5, 4]*u[6, 3] + 
   u[1, 2]*u[2, 6]*u[3, 5]*u[4, 1]*u[5, 4]*u[6, 3] + 
   u[1, 5]*u[2, 2]*u[3, 6]*u[4, 1]*u[5, 4]*u[6, 3] + 
   u[1, 2]*u[2, 5]*u[3, 6]*u[4, 1]*u[5, 4]*u[6, 3] + 
   u[1, 6]*u[2, 5]*u[3, 1]*u[4, 2]*u[5, 4]*u[6, 3] + 
   u[1, 5]*u[2, 6]*u[3, 1]*u[4, 2]*u[5, 4]*u[6, 3] + 
   u[1, 6]*u[2, 1]*u[3, 5]*u[4, 2]*u[5, 4]*u[6, 3] + 
   u[1, 1]*u[2, 6]*u[3, 5]*u[4, 2]*u[5, 4]*u[6, 3] + 
   u[1, 5]*u[2, 1]*u[3, 6]*u[4, 2]*u[5, 4]*u[6, 3] + 
   u[1, 1]*u[2, 5]*u[3, 6]*u[4, 2]*u[5, 4]*u[6, 3] + 
   u[1, 6]*u[2, 2]*u[3, 1]*u[4, 5]*u[5, 4]*u[6, 3] + 
   u[1, 2]*u[2, 6]*u[3, 1]*u[4, 5]*u[5, 4]*u[6, 3] + 
   u[1, 6]*u[2, 1]*u[3, 2]*u[4, 5]*u[5, 4]*u[6, 3] + 
   u[1, 1]*u[2, 6]*u[3, 2]*u[4, 5]*u[5, 4]*u[6, 3] + 
   u[1, 2]*u[2, 1]*u[3, 6]*u[4, 5]*u[5, 4]*u[6, 3] + 
   u[1, 1]*u[2, 2]*u[3, 6]*u[4, 5]*u[5, 4]*u[6, 3] + 
   u[1, 5]*u[2, 2]*u[3, 1]*u[4, 6]*u[5, 4]*u[6, 3] + 
   u[1, 2]*u[2, 5]*u[3, 1]*u[4, 6]*u[5, 4]*u[6, 3] + 
   u[1, 5]*u[2, 1]*u[3, 2]*u[4, 6]*u[5, 4]*u[6, 3] + 
   u[1, 1]*u[2, 5]*u[3, 2]*u[4, 6]*u[5, 4]*u[6, 3] + 
   u[1, 2]*u[2, 1]*u[3, 5]*u[4, 6]*u[5, 4]*u[6, 3] + 
   u[1, 1]*u[2, 2]*u[3, 5]*u[4, 6]*u[5, 4]*u[6, 3] + 
   u[1, 6]*u[2, 4]*u[3, 2]*u[4, 1]*u[5, 5]*u[6, 3] + 
   u[1, 4]*u[2, 6]*u[3, 2]*u[4, 1]*u[5, 5]*u[6, 3] + 
   u[1, 6]*u[2, 2]*u[3, 4]*u[4, 1]*u[5, 5]*u[6, 3] + 
   u[1, 2]*u[2, 6]*u[3, 4]*u[4, 1]*u[5, 5]*u[6, 3] + 
   u[1, 4]*u[2, 2]*u[3, 6]*u[4, 1]*u[5, 5]*u[6, 3] + 
   u[1, 2]*u[2, 4]*u[3, 6]*u[4, 1]*u[5, 5]*u[6, 3] + 
   u[1, 6]*u[2, 4]*u[3, 1]*u[4, 2]*u[5, 5]*u[6, 3] + 
   u[1, 4]*u[2, 6]*u[3, 1]*u[4, 2]*u[5, 5]*u[6, 3] + 
   u[1, 6]*u[2, 1]*u[3, 4]*u[4, 2]*u[5, 5]*u[6, 3] + 
   u[1, 1]*u[2, 6]*u[3, 4]*u[4, 2]*u[5, 5]*u[6, 3] + 
   u[1, 4]*u[2, 1]*u[3, 6]*u[4, 2]*u[5, 5]*u[6, 3] + 
   u[1, 1]*u[2, 4]*u[3, 6]*u[4, 2]*u[5, 5]*u[6, 3] + 
   u[1, 6]*u[2, 2]*u[3, 1]*u[4, 4]*u[5, 5]*u[6, 3] + 
   u[1, 2]*u[2, 6]*u[3, 1]*u[4, 4]*u[5, 5]*u[6, 3] + 
   u[1, 6]*u[2, 1]*u[3, 2]*u[4, 4]*u[5, 5]*u[6, 3] + 
   u[1, 1]*u[2, 6]*u[3, 2]*u[4, 4]*u[5, 5]*u[6, 3] + 
   u[1, 2]*u[2, 1]*u[3, 6]*u[4, 4]*u[5, 5]*u[6, 3] + 
   u[1, 1]*u[2, 2]*u[3, 6]*u[4, 4]*u[5, 5]*u[6, 3] + 
   u[1, 4]*u[2, 2]*u[3, 1]*u[4, 6]*u[5, 5]*u[6, 3] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 6]*u[5, 5]*u[6, 3] + 
   u[1, 4]*u[2, 1]*u[3, 2]*u[4, 6]*u[5, 5]*u[6, 3] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 6]*u[5, 5]*u[6, 3] + 
   u[1, 2]*u[2, 1]*u[3, 4]*u[4, 6]*u[5, 5]*u[6, 3] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 6]*u[5, 5]*u[6, 3] + 
   u[1, 5]*u[2, 4]*u[3, 2]*u[4, 1]*u[5, 6]*u[6, 3] + 
   u[1, 4]*u[2, 5]*u[3, 2]*u[4, 1]*u[5, 6]*u[6, 3] + 
   u[1, 5]*u[2, 2]*u[3, 4]*u[4, 1]*u[5, 6]*u[6, 3] + 
   u[1, 2]*u[2, 5]*u[3, 4]*u[4, 1]*u[5, 6]*u[6, 3] + 
   u[1, 4]*u[2, 2]*u[3, 5]*u[4, 1]*u[5, 6]*u[6, 3] + 
   u[1, 2]*u[2, 4]*u[3, 5]*u[4, 1]*u[5, 6]*u[6, 3] + 
   u[1, 5]*u[2, 4]*u[3, 1]*u[4, 2]*u[5, 6]*u[6, 3] + 
   u[1, 4]*u[2, 5]*u[3, 1]*u[4, 2]*u[5, 6]*u[6, 3] + 
   u[1, 5]*u[2, 1]*u[3, 4]*u[4, 2]*u[5, 6]*u[6, 3] + 
   u[1, 1]*u[2, 5]*u[3, 4]*u[4, 2]*u[5, 6]*u[6, 3] + 
   u[1, 4]*u[2, 1]*u[3, 5]*u[4, 2]*u[5, 6]*u[6, 3] + 
   u[1, 1]*u[2, 4]*u[3, 5]*u[4, 2]*u[5, 6]*u[6, 3] + 
   u[1, 5]*u[2, 2]*u[3, 1]*u[4, 4]*u[5, 6]*u[6, 3] + 
   u[1, 2]*u[2, 5]*u[3, 1]*u[4, 4]*u[5, 6]*u[6, 3] + 
   u[1, 5]*u[2, 1]*u[3, 2]*u[4, 4]*u[5, 6]*u[6, 3] + 
   u[1, 1]*u[2, 5]*u[3, 2]*u[4, 4]*u[5, 6]*u[6, 3] + 
   u[1, 2]*u[2, 1]*u[3, 5]*u[4, 4]*u[5, 6]*u[6, 3] + 
   u[1, 1]*u[2, 2]*u[3, 5]*u[4, 4]*u[5, 6]*u[6, 3] + 
   u[1, 4]*u[2, 2]*u[3, 1]*u[4, 5]*u[5, 6]*u[6, 3] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 5]*u[5, 6]*u[6, 3] + 
   u[1, 4]*u[2, 1]*u[3, 2]*u[4, 5]*u[5, 6]*u[6, 3] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 5]*u[5, 6]*u[6, 3] + 
   u[1, 2]*u[2, 1]*u[3, 4]*u[4, 5]*u[5, 6]*u[6, 3] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 5]*u[5, 6]*u[6, 3] + 
   u[1, 6]*u[2, 5]*u[3, 3]*u[4, 2]*u[5, 1]*u[6, 4] + 
   u[1, 5]*u[2, 6]*u[3, 3]*u[4, 2]*u[5, 1]*u[6, 4] + 
   u[1, 6]*u[2, 3]*u[3, 5]*u[4, 2]*u[5, 1]*u[6, 4] + 
   u[1, 3]*u[2, 6]*u[3, 5]*u[4, 2]*u[5, 1]*u[6, 4] + 
   u[1, 5]*u[2, 3]*u[3, 6]*u[4, 2]*u[5, 1]*u[6, 4] + 
   u[1, 3]*u[2, 5]*u[3, 6]*u[4, 2]*u[5, 1]*u[6, 4] + 
   u[1, 6]*u[2, 5]*u[3, 2]*u[4, 3]*u[5, 1]*u[6, 4] + 
   u[1, 5]*u[2, 6]*u[3, 2]*u[4, 3]*u[5, 1]*u[6, 4] + 
   u[1, 6]*u[2, 2]*u[3, 5]*u[4, 3]*u[5, 1]*u[6, 4] + 
   u[1, 2]*u[2, 6]*u[3, 5]*u[4, 3]*u[5, 1]*u[6, 4] + 
   u[1, 5]*u[2, 2]*u[3, 6]*u[4, 3]*u[5, 1]*u[6, 4] + 
   u[1, 2]*u[2, 5]*u[3, 6]*u[4, 3]*u[5, 1]*u[6, 4] + 
   u[1, 6]*u[2, 3]*u[3, 2]*u[4, 5]*u[5, 1]*u[6, 4] + 
   u[1, 3]*u[2, 6]*u[3, 2]*u[4, 5]*u[5, 1]*u[6, 4] + 
   u[1, 6]*u[2, 2]*u[3, 3]*u[4, 5]*u[5, 1]*u[6, 4] + 
   u[1, 2]*u[2, 6]*u[3, 3]*u[4, 5]*u[5, 1]*u[6, 4] + 
   u[1, 3]*u[2, 2]*u[3, 6]*u[4, 5]*u[5, 1]*u[6, 4] + 
   u[1, 2]*u[2, 3]*u[3, 6]*u[4, 5]*u[5, 1]*u[6, 4] + 
   u[1, 5]*u[2, 3]*u[3, 2]*u[4, 6]*u[5, 1]*u[6, 4] + 
   u[1, 3]*u[2, 5]*u[3, 2]*u[4, 6]*u[5, 1]*u[6, 4] + 
   u[1, 5]*u[2, 2]*u[3, 3]*u[4, 6]*u[5, 1]*u[6, 4] + 
   u[1, 2]*u[2, 5]*u[3, 3]*u[4, 6]*u[5, 1]*u[6, 4] + 
   u[1, 3]*u[2, 2]*u[3, 5]*u[4, 6]*u[5, 1]*u[6, 4] + 
   u[1, 2]*u[2, 3]*u[3, 5]*u[4, 6]*u[5, 1]*u[6, 4] + 
   u[1, 6]*u[2, 5]*u[3, 3]*u[4, 1]*u[5, 2]*u[6, 4] + 
   u[1, 5]*u[2, 6]*u[3, 3]*u[4, 1]*u[5, 2]*u[6, 4] + 
   u[1, 6]*u[2, 3]*u[3, 5]*u[4, 1]*u[5, 2]*u[6, 4] + 
   u[1, 3]*u[2, 6]*u[3, 5]*u[4, 1]*u[5, 2]*u[6, 4] + 
   u[1, 5]*u[2, 3]*u[3, 6]*u[4, 1]*u[5, 2]*u[6, 4] + 
   u[1, 3]*u[2, 5]*u[3, 6]*u[4, 1]*u[5, 2]*u[6, 4] + 
   u[1, 6]*u[2, 5]*u[3, 1]*u[4, 3]*u[5, 2]*u[6, 4] + 
   u[1, 5]*u[2, 6]*u[3, 1]*u[4, 3]*u[5, 2]*u[6, 4] + 
   u[1, 6]*u[2, 1]*u[3, 5]*u[4, 3]*u[5, 2]*u[6, 4] + 
   u[1, 1]*u[2, 6]*u[3, 5]*u[4, 3]*u[5, 2]*u[6, 4] + 
   u[1, 5]*u[2, 1]*u[3, 6]*u[4, 3]*u[5, 2]*u[6, 4] + 
   u[1, 1]*u[2, 5]*u[3, 6]*u[4, 3]*u[5, 2]*u[6, 4] + 
   u[1, 6]*u[2, 3]*u[3, 1]*u[4, 5]*u[5, 2]*u[6, 4] + 
   u[1, 3]*u[2, 6]*u[3, 1]*u[4, 5]*u[5, 2]*u[6, 4] + 
   u[1, 6]*u[2, 1]*u[3, 3]*u[4, 5]*u[5, 2]*u[6, 4] + 
   u[1, 1]*u[2, 6]*u[3, 3]*u[4, 5]*u[5, 2]*u[6, 4] + 
   u[1, 3]*u[2, 1]*u[3, 6]*u[4, 5]*u[5, 2]*u[6, 4] + 
   u[1, 1]*u[2, 3]*u[3, 6]*u[4, 5]*u[5, 2]*u[6, 4] + 
   u[1, 5]*u[2, 3]*u[3, 1]*u[4, 6]*u[5, 2]*u[6, 4] + 
   u[1, 3]*u[2, 5]*u[3, 1]*u[4, 6]*u[5, 2]*u[6, 4] + 
   u[1, 5]*u[2, 1]*u[3, 3]*u[4, 6]*u[5, 2]*u[6, 4] + 
   u[1, 1]*u[2, 5]*u[3, 3]*u[4, 6]*u[5, 2]*u[6, 4] + 
   u[1, 3]*u[2, 1]*u[3, 5]*u[4, 6]*u[5, 2]*u[6, 4] + 
   u[1, 1]*u[2, 3]*u[3, 5]*u[4, 6]*u[5, 2]*u[6, 4] + 
   u[1, 6]*u[2, 5]*u[3, 2]*u[4, 1]*u[5, 3]*u[6, 4] + 
   u[1, 5]*u[2, 6]*u[3, 2]*u[4, 1]*u[5, 3]*u[6, 4] + 
   u[1, 6]*u[2, 2]*u[3, 5]*u[4, 1]*u[5, 3]*u[6, 4] + 
   u[1, 2]*u[2, 6]*u[3, 5]*u[4, 1]*u[5, 3]*u[6, 4] + 
   u[1, 5]*u[2, 2]*u[3, 6]*u[4, 1]*u[5, 3]*u[6, 4] + 
   u[1, 2]*u[2, 5]*u[3, 6]*u[4, 1]*u[5, 3]*u[6, 4] + 
   u[1, 6]*u[2, 5]*u[3, 1]*u[4, 2]*u[5, 3]*u[6, 4] + 
   u[1, 5]*u[2, 6]*u[3, 1]*u[4, 2]*u[5, 3]*u[6, 4] + 
   u[1, 6]*u[2, 1]*u[3, 5]*u[4, 2]*u[5, 3]*u[6, 4] + 
   u[1, 1]*u[2, 6]*u[3, 5]*u[4, 2]*u[5, 3]*u[6, 4] + 
   u[1, 5]*u[2, 1]*u[3, 6]*u[4, 2]*u[5, 3]*u[6, 4] + 
   u[1, 1]*u[2, 5]*u[3, 6]*u[4, 2]*u[5, 3]*u[6, 4] + 
   u[1, 6]*u[2, 2]*u[3, 1]*u[4, 5]*u[5, 3]*u[6, 4] + 
   u[1, 2]*u[2, 6]*u[3, 1]*u[4, 5]*u[5, 3]*u[6, 4] + 
   u[1, 6]*u[2, 1]*u[3, 2]*u[4, 5]*u[5, 3]*u[6, 4] + 
   u[1, 1]*u[2, 6]*u[3, 2]*u[4, 5]*u[5, 3]*u[6, 4] + 
   u[1, 2]*u[2, 1]*u[3, 6]*u[4, 5]*u[5, 3]*u[6, 4] + 
   u[1, 1]*u[2, 2]*u[3, 6]*u[4, 5]*u[5, 3]*u[6, 4] + 
   u[1, 5]*u[2, 2]*u[3, 1]*u[4, 6]*u[5, 3]*u[6, 4] + 
   u[1, 2]*u[2, 5]*u[3, 1]*u[4, 6]*u[5, 3]*u[6, 4] + 
   u[1, 5]*u[2, 1]*u[3, 2]*u[4, 6]*u[5, 3]*u[6, 4] + 
   u[1, 1]*u[2, 5]*u[3, 2]*u[4, 6]*u[5, 3]*u[6, 4] + 
   u[1, 2]*u[2, 1]*u[3, 5]*u[4, 6]*u[5, 3]*u[6, 4] + 
   u[1, 1]*u[2, 2]*u[3, 5]*u[4, 6]*u[5, 3]*u[6, 4] + 
   u[1, 6]*u[2, 3]*u[3, 2]*u[4, 1]*u[5, 5]*u[6, 4] + 
   u[1, 3]*u[2, 6]*u[3, 2]*u[4, 1]*u[5, 5]*u[6, 4] + 
   u[1, 6]*u[2, 2]*u[3, 3]*u[4, 1]*u[5, 5]*u[6, 4] + 
   u[1, 2]*u[2, 6]*u[3, 3]*u[4, 1]*u[5, 5]*u[6, 4] + 
   u[1, 3]*u[2, 2]*u[3, 6]*u[4, 1]*u[5, 5]*u[6, 4] + 
   u[1, 2]*u[2, 3]*u[3, 6]*u[4, 1]*u[5, 5]*u[6, 4] + 
   u[1, 6]*u[2, 3]*u[3, 1]*u[4, 2]*u[5, 5]*u[6, 4] + 
   u[1, 3]*u[2, 6]*u[3, 1]*u[4, 2]*u[5, 5]*u[6, 4] + 
   u[1, 6]*u[2, 1]*u[3, 3]*u[4, 2]*u[5, 5]*u[6, 4] + 
   u[1, 1]*u[2, 6]*u[3, 3]*u[4, 2]*u[5, 5]*u[6, 4] + 
   u[1, 3]*u[2, 1]*u[3, 6]*u[4, 2]*u[5, 5]*u[6, 4] + 
   u[1, 1]*u[2, 3]*u[3, 6]*u[4, 2]*u[5, 5]*u[6, 4] + 
   u[1, 6]*u[2, 2]*u[3, 1]*u[4, 3]*u[5, 5]*u[6, 4] + 
   u[1, 2]*u[2, 6]*u[3, 1]*u[4, 3]*u[5, 5]*u[6, 4] + 
   u[1, 6]*u[2, 1]*u[3, 2]*u[4, 3]*u[5, 5]*u[6, 4] + 
   u[1, 1]*u[2, 6]*u[3, 2]*u[4, 3]*u[5, 5]*u[6, 4] + 
   u[1, 2]*u[2, 1]*u[3, 6]*u[4, 3]*u[5, 5]*u[6, 4] + 
   u[1, 1]*u[2, 2]*u[3, 6]*u[4, 3]*u[5, 5]*u[6, 4] + 
   u[1, 3]*u[2, 2]*u[3, 1]*u[4, 6]*u[5, 5]*u[6, 4] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 6]*u[5, 5]*u[6, 4] + 
   u[1, 3]*u[2, 1]*u[3, 2]*u[4, 6]*u[5, 5]*u[6, 4] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 6]*u[5, 5]*u[6, 4] + 
   u[1, 2]*u[2, 1]*u[3, 3]*u[4, 6]*u[5, 5]*u[6, 4] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 6]*u[5, 5]*u[6, 4] + 
   u[1, 5]*u[2, 3]*u[3, 2]*u[4, 1]*u[5, 6]*u[6, 4] + 
   u[1, 3]*u[2, 5]*u[3, 2]*u[4, 1]*u[5, 6]*u[6, 4] + 
   u[1, 5]*u[2, 2]*u[3, 3]*u[4, 1]*u[5, 6]*u[6, 4] + 
   u[1, 2]*u[2, 5]*u[3, 3]*u[4, 1]*u[5, 6]*u[6, 4] + 
   u[1, 3]*u[2, 2]*u[3, 5]*u[4, 1]*u[5, 6]*u[6, 4] + 
   u[1, 2]*u[2, 3]*u[3, 5]*u[4, 1]*u[5, 6]*u[6, 4] + 
   u[1, 5]*u[2, 3]*u[3, 1]*u[4, 2]*u[5, 6]*u[6, 4] + 
   u[1, 3]*u[2, 5]*u[3, 1]*u[4, 2]*u[5, 6]*u[6, 4] + 
   u[1, 5]*u[2, 1]*u[3, 3]*u[4, 2]*u[5, 6]*u[6, 4] + 
   u[1, 1]*u[2, 5]*u[3, 3]*u[4, 2]*u[5, 6]*u[6, 4] + 
   u[1, 3]*u[2, 1]*u[3, 5]*u[4, 2]*u[5, 6]*u[6, 4] + 
   u[1, 1]*u[2, 3]*u[3, 5]*u[4, 2]*u[5, 6]*u[6, 4] + 
   u[1, 5]*u[2, 2]*u[3, 1]*u[4, 3]*u[5, 6]*u[6, 4] + 
   u[1, 2]*u[2, 5]*u[3, 1]*u[4, 3]*u[5, 6]*u[6, 4] + 
   u[1, 5]*u[2, 1]*u[3, 2]*u[4, 3]*u[5, 6]*u[6, 4] + 
   u[1, 1]*u[2, 5]*u[3, 2]*u[4, 3]*u[5, 6]*u[6, 4] + 
   u[1, 2]*u[2, 1]*u[3, 5]*u[4, 3]*u[5, 6]*u[6, 4] + 
   u[1, 1]*u[2, 2]*u[3, 5]*u[4, 3]*u[5, 6]*u[6, 4] + 
   u[1, 3]*u[2, 2]*u[3, 1]*u[4, 5]*u[5, 6]*u[6, 4] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 5]*u[5, 6]*u[6, 4] + 
   u[1, 3]*u[2, 1]*u[3, 2]*u[4, 5]*u[5, 6]*u[6, 4] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 5]*u[5, 6]*u[6, 4] + 
   u[1, 2]*u[2, 1]*u[3, 3]*u[4, 5]*u[5, 6]*u[6, 4] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 5]*u[5, 6]*u[6, 4] + 
   u[1, 6]*u[2, 4]*u[3, 3]*u[4, 2]*u[5, 1]*u[6, 5] + 
   u[1, 4]*u[2, 6]*u[3, 3]*u[4, 2]*u[5, 1]*u[6, 5] + 
   u[1, 6]*u[2, 3]*u[3, 4]*u[4, 2]*u[5, 1]*u[6, 5] + 
   u[1, 3]*u[2, 6]*u[3, 4]*u[4, 2]*u[5, 1]*u[6, 5] + 
   u[1, 4]*u[2, 3]*u[3, 6]*u[4, 2]*u[5, 1]*u[6, 5] + 
   u[1, 3]*u[2, 4]*u[3, 6]*u[4, 2]*u[5, 1]*u[6, 5] + 
   u[1, 6]*u[2, 4]*u[3, 2]*u[4, 3]*u[5, 1]*u[6, 5] + 
   u[1, 4]*u[2, 6]*u[3, 2]*u[4, 3]*u[5, 1]*u[6, 5] + 
   u[1, 6]*u[2, 2]*u[3, 4]*u[4, 3]*u[5, 1]*u[6, 5] + 
   u[1, 2]*u[2, 6]*u[3, 4]*u[4, 3]*u[5, 1]*u[6, 5] + 
   u[1, 4]*u[2, 2]*u[3, 6]*u[4, 3]*u[5, 1]*u[6, 5] + 
   u[1, 2]*u[2, 4]*u[3, 6]*u[4, 3]*u[5, 1]*u[6, 5] + 
   u[1, 6]*u[2, 3]*u[3, 2]*u[4, 4]*u[5, 1]*u[6, 5] + 
   u[1, 3]*u[2, 6]*u[3, 2]*u[4, 4]*u[5, 1]*u[6, 5] + 
   u[1, 6]*u[2, 2]*u[3, 3]*u[4, 4]*u[5, 1]*u[6, 5] + 
   u[1, 2]*u[2, 6]*u[3, 3]*u[4, 4]*u[5, 1]*u[6, 5] + 
   u[1, 3]*u[2, 2]*u[3, 6]*u[4, 4]*u[5, 1]*u[6, 5] + 
   u[1, 2]*u[2, 3]*u[3, 6]*u[4, 4]*u[5, 1]*u[6, 5] + 
   u[1, 4]*u[2, 3]*u[3, 2]*u[4, 6]*u[5, 1]*u[6, 5] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 6]*u[5, 1]*u[6, 5] + 
   u[1, 4]*u[2, 2]*u[3, 3]*u[4, 6]*u[5, 1]*u[6, 5] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 6]*u[5, 1]*u[6, 5] + 
   u[1, 3]*u[2, 2]*u[3, 4]*u[4, 6]*u[5, 1]*u[6, 5] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 6]*u[5, 1]*u[6, 5] + 
   u[1, 6]*u[2, 4]*u[3, 3]*u[4, 1]*u[5, 2]*u[6, 5] + 
   u[1, 4]*u[2, 6]*u[3, 3]*u[4, 1]*u[5, 2]*u[6, 5] + 
   u[1, 6]*u[2, 3]*u[3, 4]*u[4, 1]*u[5, 2]*u[6, 5] + 
   u[1, 3]*u[2, 6]*u[3, 4]*u[4, 1]*u[5, 2]*u[6, 5] + 
   u[1, 4]*u[2, 3]*u[3, 6]*u[4, 1]*u[5, 2]*u[6, 5] + 
   u[1, 3]*u[2, 4]*u[3, 6]*u[4, 1]*u[5, 2]*u[6, 5] + 
   u[1, 6]*u[2, 4]*u[3, 1]*u[4, 3]*u[5, 2]*u[6, 5] + 
   u[1, 4]*u[2, 6]*u[3, 1]*u[4, 3]*u[5, 2]*u[6, 5] + 
   u[1, 6]*u[2, 1]*u[3, 4]*u[4, 3]*u[5, 2]*u[6, 5] + 
   u[1, 1]*u[2, 6]*u[3, 4]*u[4, 3]*u[5, 2]*u[6, 5] + 
   u[1, 4]*u[2, 1]*u[3, 6]*u[4, 3]*u[5, 2]*u[6, 5] + 
   u[1, 1]*u[2, 4]*u[3, 6]*u[4, 3]*u[5, 2]*u[6, 5] + 
   u[1, 6]*u[2, 3]*u[3, 1]*u[4, 4]*u[5, 2]*u[6, 5] + 
   u[1, 3]*u[2, 6]*u[3, 1]*u[4, 4]*u[5, 2]*u[6, 5] + 
   u[1, 6]*u[2, 1]*u[3, 3]*u[4, 4]*u[5, 2]*u[6, 5] + 
   u[1, 1]*u[2, 6]*u[3, 3]*u[4, 4]*u[5, 2]*u[6, 5] + 
   u[1, 3]*u[2, 1]*u[3, 6]*u[4, 4]*u[5, 2]*u[6, 5] + 
   u[1, 1]*u[2, 3]*u[3, 6]*u[4, 4]*u[5, 2]*u[6, 5] + 
   u[1, 4]*u[2, 3]*u[3, 1]*u[4, 6]*u[5, 2]*u[6, 5] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 6]*u[5, 2]*u[6, 5] + 
   u[1, 4]*u[2, 1]*u[3, 3]*u[4, 6]*u[5, 2]*u[6, 5] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 6]*u[5, 2]*u[6, 5] + 
   u[1, 3]*u[2, 1]*u[3, 4]*u[4, 6]*u[5, 2]*u[6, 5] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 6]*u[5, 2]*u[6, 5] + 
   u[1, 6]*u[2, 4]*u[3, 2]*u[4, 1]*u[5, 3]*u[6, 5] + 
   u[1, 4]*u[2, 6]*u[3, 2]*u[4, 1]*u[5, 3]*u[6, 5] + 
   u[1, 6]*u[2, 2]*u[3, 4]*u[4, 1]*u[5, 3]*u[6, 5] + 
   u[1, 2]*u[2, 6]*u[3, 4]*u[4, 1]*u[5, 3]*u[6, 5] + 
   u[1, 4]*u[2, 2]*u[3, 6]*u[4, 1]*u[5, 3]*u[6, 5] + 
   u[1, 2]*u[2, 4]*u[3, 6]*u[4, 1]*u[5, 3]*u[6, 5] + 
   u[1, 6]*u[2, 4]*u[3, 1]*u[4, 2]*u[5, 3]*u[6, 5] + 
   u[1, 4]*u[2, 6]*u[3, 1]*u[4, 2]*u[5, 3]*u[6, 5] + 
   u[1, 6]*u[2, 1]*u[3, 4]*u[4, 2]*u[5, 3]*u[6, 5] + 
   u[1, 1]*u[2, 6]*u[3, 4]*u[4, 2]*u[5, 3]*u[6, 5] + 
   u[1, 4]*u[2, 1]*u[3, 6]*u[4, 2]*u[5, 3]*u[6, 5] + 
   u[1, 1]*u[2, 4]*u[3, 6]*u[4, 2]*u[5, 3]*u[6, 5] + 
   u[1, 6]*u[2, 2]*u[3, 1]*u[4, 4]*u[5, 3]*u[6, 5] + 
   u[1, 2]*u[2, 6]*u[3, 1]*u[4, 4]*u[5, 3]*u[6, 5] + 
   u[1, 6]*u[2, 1]*u[3, 2]*u[4, 4]*u[5, 3]*u[6, 5] + 
   u[1, 1]*u[2, 6]*u[3, 2]*u[4, 4]*u[5, 3]*u[6, 5] + 
   u[1, 2]*u[2, 1]*u[3, 6]*u[4, 4]*u[5, 3]*u[6, 5] + 
   u[1, 1]*u[2, 2]*u[3, 6]*u[4, 4]*u[5, 3]*u[6, 5] + 
   u[1, 4]*u[2, 2]*u[3, 1]*u[4, 6]*u[5, 3]*u[6, 5] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 6]*u[5, 3]*u[6, 5] + 
   u[1, 4]*u[2, 1]*u[3, 2]*u[4, 6]*u[5, 3]*u[6, 5] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 6]*u[5, 3]*u[6, 5] + 
   u[1, 2]*u[2, 1]*u[3, 4]*u[4, 6]*u[5, 3]*u[6, 5] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 6]*u[5, 3]*u[6, 5] + 
   u[1, 6]*u[2, 3]*u[3, 2]*u[4, 1]*u[5, 4]*u[6, 5] + 
   u[1, 3]*u[2, 6]*u[3, 2]*u[4, 1]*u[5, 4]*u[6, 5] + 
   u[1, 6]*u[2, 2]*u[3, 3]*u[4, 1]*u[5, 4]*u[6, 5] + 
   u[1, 2]*u[2, 6]*u[3, 3]*u[4, 1]*u[5, 4]*u[6, 5] + 
   u[1, 3]*u[2, 2]*u[3, 6]*u[4, 1]*u[5, 4]*u[6, 5] + 
   u[1, 2]*u[2, 3]*u[3, 6]*u[4, 1]*u[5, 4]*u[6, 5] + 
   u[1, 6]*u[2, 3]*u[3, 1]*u[4, 2]*u[5, 4]*u[6, 5] + 
   u[1, 3]*u[2, 6]*u[3, 1]*u[4, 2]*u[5, 4]*u[6, 5] + 
   u[1, 6]*u[2, 1]*u[3, 3]*u[4, 2]*u[5, 4]*u[6, 5] + 
   u[1, 1]*u[2, 6]*u[3, 3]*u[4, 2]*u[5, 4]*u[6, 5] + 
   u[1, 3]*u[2, 1]*u[3, 6]*u[4, 2]*u[5, 4]*u[6, 5] + 
   u[1, 1]*u[2, 3]*u[3, 6]*u[4, 2]*u[5, 4]*u[6, 5] + 
   u[1, 6]*u[2, 2]*u[3, 1]*u[4, 3]*u[5, 4]*u[6, 5] + 
   u[1, 2]*u[2, 6]*u[3, 1]*u[4, 3]*u[5, 4]*u[6, 5] + 
   u[1, 6]*u[2, 1]*u[3, 2]*u[4, 3]*u[5, 4]*u[6, 5] + 
   u[1, 1]*u[2, 6]*u[3, 2]*u[4, 3]*u[5, 4]*u[6, 5] + 
   u[1, 2]*u[2, 1]*u[3, 6]*u[4, 3]*u[5, 4]*u[6, 5] + 
   u[1, 1]*u[2, 2]*u[3, 6]*u[4, 3]*u[5, 4]*u[6, 5] + 
   u[1, 3]*u[2, 2]*u[3, 1]*u[4, 6]*u[5, 4]*u[6, 5] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 6]*u[5, 4]*u[6, 5] + 
   u[1, 3]*u[2, 1]*u[3, 2]*u[4, 6]*u[5, 4]*u[6, 5] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 6]*u[5, 4]*u[6, 5] + 
   u[1, 2]*u[2, 1]*u[3, 3]*u[4, 6]*u[5, 4]*u[6, 5] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 6]*u[5, 4]*u[6, 5] + 
   u[1, 4]*u[2, 3]*u[3, 2]*u[4, 1]*u[5, 6]*u[6, 5] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 1]*u[5, 6]*u[6, 5] + 
   u[1, 4]*u[2, 2]*u[3, 3]*u[4, 1]*u[5, 6]*u[6, 5] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 1]*u[5, 6]*u[6, 5] + 
   u[1, 3]*u[2, 2]*u[3, 4]*u[4, 1]*u[5, 6]*u[6, 5] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 1]*u[5, 6]*u[6, 5] + 
   u[1, 4]*u[2, 3]*u[3, 1]*u[4, 2]*u[5, 6]*u[6, 5] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 2]*u[5, 6]*u[6, 5] + 
   u[1, 4]*u[2, 1]*u[3, 3]*u[4, 2]*u[5, 6]*u[6, 5] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 2]*u[5, 6]*u[6, 5] + 
   u[1, 3]*u[2, 1]*u[3, 4]*u[4, 2]*u[5, 6]*u[6, 5] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 2]*u[5, 6]*u[6, 5] + 
   u[1, 4]*u[2, 2]*u[3, 1]*u[4, 3]*u[5, 6]*u[6, 5] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 3]*u[5, 6]*u[6, 5] + 
   u[1, 4]*u[2, 1]*u[3, 2]*u[4, 3]*u[5, 6]*u[6, 5] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 3]*u[5, 6]*u[6, 5] + 
   u[1, 2]*u[2, 1]*u[3, 4]*u[4, 3]*u[5, 6]*u[6, 5] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 3]*u[5, 6]*u[6, 5] + 
   u[1, 3]*u[2, 2]*u[3, 1]*u[4, 4]*u[5, 6]*u[6, 5] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 4]*u[5, 6]*u[6, 5] + 
   u[1, 3]*u[2, 1]*u[3, 2]*u[4, 4]*u[5, 6]*u[6, 5] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 4]*u[5, 6]*u[6, 5] + 
   u[1, 2]*u[2, 1]*u[3, 3]*u[4, 4]*u[5, 6]*u[6, 5] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 4]*u[5, 6]*u[6, 5] + 
   u[1, 5]*u[2, 4]*u[3, 3]*u[4, 2]*u[5, 1]*u[6, 6] + 
   u[1, 4]*u[2, 5]*u[3, 3]*u[4, 2]*u[5, 1]*u[6, 6] + 
   u[1, 5]*u[2, 3]*u[3, 4]*u[4, 2]*u[5, 1]*u[6, 6] + 
   u[1, 3]*u[2, 5]*u[3, 4]*u[4, 2]*u[5, 1]*u[6, 6] + 
   u[1, 4]*u[2, 3]*u[3, 5]*u[4, 2]*u[5, 1]*u[6, 6] + 
   u[1, 3]*u[2, 4]*u[3, 5]*u[4, 2]*u[5, 1]*u[6, 6] + 
   u[1, 5]*u[2, 4]*u[3, 2]*u[4, 3]*u[5, 1]*u[6, 6] + 
   u[1, 4]*u[2, 5]*u[3, 2]*u[4, 3]*u[5, 1]*u[6, 6] + 
   u[1, 5]*u[2, 2]*u[3, 4]*u[4, 3]*u[5, 1]*u[6, 6] + 
   u[1, 2]*u[2, 5]*u[3, 4]*u[4, 3]*u[5, 1]*u[6, 6] + 
   u[1, 4]*u[2, 2]*u[3, 5]*u[4, 3]*u[5, 1]*u[6, 6] + 
   u[1, 2]*u[2, 4]*u[3, 5]*u[4, 3]*u[5, 1]*u[6, 6] + 
   u[1, 5]*u[2, 3]*u[3, 2]*u[4, 4]*u[5, 1]*u[6, 6] + 
   u[1, 3]*u[2, 5]*u[3, 2]*u[4, 4]*u[5, 1]*u[6, 6] + 
   u[1, 5]*u[2, 2]*u[3, 3]*u[4, 4]*u[5, 1]*u[6, 6] + 
   u[1, 2]*u[2, 5]*u[3, 3]*u[4, 4]*u[5, 1]*u[6, 6] + 
   u[1, 3]*u[2, 2]*u[3, 5]*u[4, 4]*u[5, 1]*u[6, 6] + 
   u[1, 2]*u[2, 3]*u[3, 5]*u[4, 4]*u[5, 1]*u[6, 6] + 
   u[1, 4]*u[2, 3]*u[3, 2]*u[4, 5]*u[5, 1]*u[6, 6] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 5]*u[5, 1]*u[6, 6] + 
   u[1, 4]*u[2, 2]*u[3, 3]*u[4, 5]*u[5, 1]*u[6, 6] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 5]*u[5, 1]*u[6, 6] + 
   u[1, 3]*u[2, 2]*u[3, 4]*u[4, 5]*u[5, 1]*u[6, 6] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 5]*u[5, 1]*u[6, 6] + 
   u[1, 5]*u[2, 4]*u[3, 3]*u[4, 1]*u[5, 2]*u[6, 6] + 
   u[1, 4]*u[2, 5]*u[3, 3]*u[4, 1]*u[5, 2]*u[6, 6] + 
   u[1, 5]*u[2, 3]*u[3, 4]*u[4, 1]*u[5, 2]*u[6, 6] + 
   u[1, 3]*u[2, 5]*u[3, 4]*u[4, 1]*u[5, 2]*u[6, 6] + 
   u[1, 4]*u[2, 3]*u[3, 5]*u[4, 1]*u[5, 2]*u[6, 6] + 
   u[1, 3]*u[2, 4]*u[3, 5]*u[4, 1]*u[5, 2]*u[6, 6] + 
   u[1, 5]*u[2, 4]*u[3, 1]*u[4, 3]*u[5, 2]*u[6, 6] + 
   u[1, 4]*u[2, 5]*u[3, 1]*u[4, 3]*u[5, 2]*u[6, 6] + 
   u[1, 5]*u[2, 1]*u[3, 4]*u[4, 3]*u[5, 2]*u[6, 6] + 
   u[1, 1]*u[2, 5]*u[3, 4]*u[4, 3]*u[5, 2]*u[6, 6] + 
   u[1, 4]*u[2, 1]*u[3, 5]*u[4, 3]*u[5, 2]*u[6, 6] + 
   u[1, 1]*u[2, 4]*u[3, 5]*u[4, 3]*u[5, 2]*u[6, 6] + 
   u[1, 5]*u[2, 3]*u[3, 1]*u[4, 4]*u[5, 2]*u[6, 6] + 
   u[1, 3]*u[2, 5]*u[3, 1]*u[4, 4]*u[5, 2]*u[6, 6] + 
   u[1, 5]*u[2, 1]*u[3, 3]*u[4, 4]*u[5, 2]*u[6, 6] + 
   u[1, 1]*u[2, 5]*u[3, 3]*u[4, 4]*u[5, 2]*u[6, 6] + 
   u[1, 3]*u[2, 1]*u[3, 5]*u[4, 4]*u[5, 2]*u[6, 6] + 
   u[1, 1]*u[2, 3]*u[3, 5]*u[4, 4]*u[5, 2]*u[6, 6] + 
   u[1, 4]*u[2, 3]*u[3, 1]*u[4, 5]*u[5, 2]*u[6, 6] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 5]*u[5, 2]*u[6, 6] + 
   u[1, 4]*u[2, 1]*u[3, 3]*u[4, 5]*u[5, 2]*u[6, 6] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 5]*u[5, 2]*u[6, 6] + 
   u[1, 3]*u[2, 1]*u[3, 4]*u[4, 5]*u[5, 2]*u[6, 6] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 5]*u[5, 2]*u[6, 6] + 
   u[1, 5]*u[2, 4]*u[3, 2]*u[4, 1]*u[5, 3]*u[6, 6] + 
   u[1, 4]*u[2, 5]*u[3, 2]*u[4, 1]*u[5, 3]*u[6, 6] + 
   u[1, 5]*u[2, 2]*u[3, 4]*u[4, 1]*u[5, 3]*u[6, 6] + 
   u[1, 2]*u[2, 5]*u[3, 4]*u[4, 1]*u[5, 3]*u[6, 6] + 
   u[1, 4]*u[2, 2]*u[3, 5]*u[4, 1]*u[5, 3]*u[6, 6] + 
   u[1, 2]*u[2, 4]*u[3, 5]*u[4, 1]*u[5, 3]*u[6, 6] + 
   u[1, 5]*u[2, 4]*u[3, 1]*u[4, 2]*u[5, 3]*u[6, 6] + 
   u[1, 4]*u[2, 5]*u[3, 1]*u[4, 2]*u[5, 3]*u[6, 6] + 
   u[1, 5]*u[2, 1]*u[3, 4]*u[4, 2]*u[5, 3]*u[6, 6] + 
   u[1, 1]*u[2, 5]*u[3, 4]*u[4, 2]*u[5, 3]*u[6, 6] + 
   u[1, 4]*u[2, 1]*u[3, 5]*u[4, 2]*u[5, 3]*u[6, 6] + 
   u[1, 1]*u[2, 4]*u[3, 5]*u[4, 2]*u[5, 3]*u[6, 6] + 
   u[1, 5]*u[2, 2]*u[3, 1]*u[4, 4]*u[5, 3]*u[6, 6] + 
   u[1, 2]*u[2, 5]*u[3, 1]*u[4, 4]*u[5, 3]*u[6, 6] + 
   u[1, 5]*u[2, 1]*u[3, 2]*u[4, 4]*u[5, 3]*u[6, 6] + 
   u[1, 1]*u[2, 5]*u[3, 2]*u[4, 4]*u[5, 3]*u[6, 6] + 
   u[1, 2]*u[2, 1]*u[3, 5]*u[4, 4]*u[5, 3]*u[6, 6] + 
   u[1, 1]*u[2, 2]*u[3, 5]*u[4, 4]*u[5, 3]*u[6, 6] + 
   u[1, 4]*u[2, 2]*u[3, 1]*u[4, 5]*u[5, 3]*u[6, 6] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 5]*u[5, 3]*u[6, 6] + 
   u[1, 4]*u[2, 1]*u[3, 2]*u[4, 5]*u[5, 3]*u[6, 6] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 5]*u[5, 3]*u[6, 6] + 
   u[1, 2]*u[2, 1]*u[3, 4]*u[4, 5]*u[5, 3]*u[6, 6] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 5]*u[5, 3]*u[6, 6] + 
   u[1, 5]*u[2, 3]*u[3, 2]*u[4, 1]*u[5, 4]*u[6, 6] + 
   u[1, 3]*u[2, 5]*u[3, 2]*u[4, 1]*u[5, 4]*u[6, 6] + 
   u[1, 5]*u[2, 2]*u[3, 3]*u[4, 1]*u[5, 4]*u[6, 6] + 
   u[1, 2]*u[2, 5]*u[3, 3]*u[4, 1]*u[5, 4]*u[6, 6] + 
   u[1, 3]*u[2, 2]*u[3, 5]*u[4, 1]*u[5, 4]*u[6, 6] + 
   u[1, 2]*u[2, 3]*u[3, 5]*u[4, 1]*u[5, 4]*u[6, 6] + 
   u[1, 5]*u[2, 3]*u[3, 1]*u[4, 2]*u[5, 4]*u[6, 6] + 
   u[1, 3]*u[2, 5]*u[3, 1]*u[4, 2]*u[5, 4]*u[6, 6] + 
   u[1, 5]*u[2, 1]*u[3, 3]*u[4, 2]*u[5, 4]*u[6, 6] + 
   u[1, 1]*u[2, 5]*u[3, 3]*u[4, 2]*u[5, 4]*u[6, 6] + 
   u[1, 3]*u[2, 1]*u[3, 5]*u[4, 2]*u[5, 4]*u[6, 6] + 
   u[1, 1]*u[2, 3]*u[3, 5]*u[4, 2]*u[5, 4]*u[6, 6] + 
   u[1, 5]*u[2, 2]*u[3, 1]*u[4, 3]*u[5, 4]*u[6, 6] + 
   u[1, 2]*u[2, 5]*u[3, 1]*u[4, 3]*u[5, 4]*u[6, 6] + 
   u[1, 5]*u[2, 1]*u[3, 2]*u[4, 3]*u[5, 4]*u[6, 6] + 
   u[1, 1]*u[2, 5]*u[3, 2]*u[4, 3]*u[5, 4]*u[6, 6] + 
   u[1, 2]*u[2, 1]*u[3, 5]*u[4, 3]*u[5, 4]*u[6, 6] + 
   u[1, 1]*u[2, 2]*u[3, 5]*u[4, 3]*u[5, 4]*u[6, 6] + 
   u[1, 3]*u[2, 2]*u[3, 1]*u[4, 5]*u[5, 4]*u[6, 6] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 5]*u[5, 4]*u[6, 6] + 
   u[1, 3]*u[2, 1]*u[3, 2]*u[4, 5]*u[5, 4]*u[6, 6] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 5]*u[5, 4]*u[6, 6] + 
   u[1, 2]*u[2, 1]*u[3, 3]*u[4, 5]*u[5, 4]*u[6, 6] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 5]*u[5, 4]*u[6, 6] + 
   u[1, 4]*u[2, 3]*u[3, 2]*u[4, 1]*u[5, 5]*u[6, 6] + 
   u[1, 3]*u[2, 4]*u[3, 2]*u[4, 1]*u[5, 5]*u[6, 6] + 
   u[1, 4]*u[2, 2]*u[3, 3]*u[4, 1]*u[5, 5]*u[6, 6] + 
   u[1, 2]*u[2, 4]*u[3, 3]*u[4, 1]*u[5, 5]*u[6, 6] + 
   u[1, 3]*u[2, 2]*u[3, 4]*u[4, 1]*u[5, 5]*u[6, 6] + 
   u[1, 2]*u[2, 3]*u[3, 4]*u[4, 1]*u[5, 5]*u[6, 6] + 
   u[1, 4]*u[2, 3]*u[3, 1]*u[4, 2]*u[5, 5]*u[6, 6] + 
   u[1, 3]*u[2, 4]*u[3, 1]*u[4, 2]*u[5, 5]*u[6, 6] + 
   u[1, 4]*u[2, 1]*u[3, 3]*u[4, 2]*u[5, 5]*u[6, 6] + 
   u[1, 1]*u[2, 4]*u[3, 3]*u[4, 2]*u[5, 5]*u[6, 6] + 
   u[1, 3]*u[2, 1]*u[3, 4]*u[4, 2]*u[5, 5]*u[6, 6] + 
   u[1, 1]*u[2, 3]*u[3, 4]*u[4, 2]*u[5, 5]*u[6, 6] + 
   u[1, 4]*u[2, 2]*u[3, 1]*u[4, 3]*u[5, 5]*u[6, 6] + 
   u[1, 2]*u[2, 4]*u[3, 1]*u[4, 3]*u[5, 5]*u[6, 6] + 
   u[1, 4]*u[2, 1]*u[3, 2]*u[4, 3]*u[5, 5]*u[6, 6] + 
   u[1, 1]*u[2, 4]*u[3, 2]*u[4, 3]*u[5, 5]*u[6, 6] + 
   u[1, 2]*u[2, 1]*u[3, 4]*u[4, 3]*u[5, 5]*u[6, 6] + 
   u[1, 1]*u[2, 2]*u[3, 4]*u[4, 3]*u[5, 5]*u[6, 6] + 
   u[1, 3]*u[2, 2]*u[3, 1]*u[4, 4]*u[5, 5]*u[6, 6] + 
   u[1, 2]*u[2, 3]*u[3, 1]*u[4, 4]*u[5, 5]*u[6, 6] + 
   u[1, 3]*u[2, 1]*u[3, 2]*u[4, 4]*u[5, 5]*u[6, 6] + 
   u[1, 1]*u[2, 3]*u[3, 2]*u[4, 4]*u[5, 5]*u[6, 6] + 
   u[1, 2]*u[2, 1]*u[3, 3]*u[4, 4]*u[5, 5]*u[6, 6] + 
   u[1, 1]*u[2, 2]*u[3, 3]*u[4, 4]*u[5, 5]*u[6, 6]}\
\>", "\<\
{9.4 Second, u[1, 6] u[2, 5] u[3, 4] u[4, 3] u[5, 2] u[6, 1] + 
 
   u[1, 5] u[2, 6] u[3, 4] u[4, 3] u[5, 2] u[6, 1] + 
 
   u[1, 6] u[2, 4] u[3, 5] u[4, 3] u[5, 2] u[6, 1] + 
 
   u[1, 4] u[2, 6] u[3, 5] u[4, 3] u[5, 2] u[6, 1] + 
 
   u[1, 5] u[2, 4] u[3, 6] u[4, 3] u[5, 2] u[6, 1] + 
 
   u[1, 4] u[2, 5] u[3, 6] u[4, 3] u[5, 2] u[6, 1] + 
 
   u[1, 6] u[2, 5] u[3, 3] u[4, 4] u[5, 2] u[6, 1] + 
 
   u[1, 5] u[2, 6] u[3, 3] u[4, 4] u[5, 2] u[6, 1] + 
 
   u[1, 6] u[2, 3] u[3, 5] u[4, 4] u[5, 2] u[6, 1] + 
 
   u[1, 3] u[2, 6] u[3, 5] u[4, 4] u[5, 2] u[6, 1] + 
 
   u[1, 5] u[2, 3] u[3, 6] u[4, 4] u[5, 2] u[6, 1] + 
 
   u[1, 3] u[2, 5] u[3, 6] u[4, 4] u[5, 2] u[6, 1] + 
 
   u[1, 6] u[2, 4] u[3, 3] u[4, 5] u[5, 2] u[6, 1] + 
 
   u[1, 4] u[2, 6] u[3, 3] u[4, 5] u[5, 2] u[6, 1] + 
 
   u[1, 6] u[2, 3] u[3, 4] u[4, 5] u[5, 2] u[6, 1] + 
 
   u[1, 3] u[2, 6] u[3, 4] u[4, 5] u[5, 2] u[6, 1] + 
 
   u[1, 4] u[2, 3] u[3, 6] u[4, 5] u[5, 2] u[6, 1] + 
 
   u[1, 3] u[2, 4] u[3, 6] u[4, 5] u[5, 2] u[6, 1] + 
 
   u[1, 5] u[2, 4] u[3, 3] u[4, 6] u[5, 2] u[6, 1] + 
 
   u[1, 4] u[2, 5] u[3, 3] u[4, 6] u[5, 2] u[6, 1] + 
 
   u[1, 5] u[2, 3] u[3, 4] u[4, 6] u[5, 2] u[6, 1] + 
 
   u[1, 3] u[2, 5] u[3, 4] u[4, 6] u[5, 2] u[6, 1] + 
 
   u[1, 4] u[2, 3] u[3, 5] u[4, 6] u[5, 2] u[6, 1] + 
 
   u[1, 3] u[2, 4] u[3, 5] u[4, 6] u[5, 2] u[6, 1] + 
 
   u[1, 6] u[2, 5] u[3, 4] u[4, 2] u[5, 3] u[6, 1] + 
 
   u[1, 5] u[2, 6] u[3, 4] u[4, 2] u[5, 3] u[6, 1] + 
 
   u[1, 6] u[2, 4] u[3, 5] u[4, 2] u[5, 3] u[6, 1] + 
 
   u[1, 4] u[2, 6] u[3, 5] u[4, 2] u[5, 3] u[6, 1] + 
 
   u[1, 5] u[2, 4] u[3, 6] u[4, 2] u[5, 3] u[6, 1] + 
 
   u[1, 4] u[2, 5] u[3, 6] u[4, 2] u[5, 3] u[6, 1] + 
 
   u[1, 6] u[2, 5] u[3, 2] u[4, 4] u[5, 3] u[6, 1] + 
 
   u[1, 5] u[2, 6] u[3, 2] u[4, 4] u[5, 3] u[6, 1] + 
 
   u[1, 6] u[2, 2] u[3, 5] u[4, 4] u[5, 3] u[6, 1] + 
 
   u[1, 2] u[2, 6] u[3, 5] u[4, 4] u[5, 3] u[6, 1] + 
 
   u[1, 5] u[2, 2] u[3, 6] u[4, 4] u[5, 3] u[6, 1] + 
 
   u[1, 2] u[2, 5] u[3, 6] u[4, 4] u[5, 3] u[6, 1] + 
 
   u[1, 6] u[2, 4] u[3, 2] u[4, 5] u[5, 3] u[6, 1] + 
 
   u[1, 4] u[2, 6] u[3, 2] u[4, 5] u[5, 3] u[6, 1] + 
 
   u[1, 6] u[2, 2] u[3, 4] u[4, 5] u[5, 3] u[6, 1] + 
 
   u[1, 2] u[2, 6] u[3, 4] u[4, 5] u[5, 3] u[6, 1] + 
 
   u[1, 4] u[2, 2] u[3, 6] u[4, 5] u[5, 3] u[6, 1] + 
 
   u[1, 2] u[2, 4] u[3, 6] u[4, 5] u[5, 3] u[6, 1] + 
 
   u[1, 5] u[2, 4] u[3, 2] u[4, 6] u[5, 3] u[6, 1] + 
 
   u[1, 4] u[2, 5] u[3, 2] u[4, 6] u[5, 3] u[6, 1] + 
 
   u[1, 5] u[2, 2] u[3, 4] u[4, 6] u[5, 3] u[6, 1] + 
 
   u[1, 2] u[2, 5] u[3, 4] u[4, 6] u[5, 3] u[6, 1] + 
 
   u[1, 4] u[2, 2] u[3, 5] u[4, 6] u[5, 3] u[6, 1] + 
 
   u[1, 2] u[2, 4] u[3, 5] u[4, 6] u[5, 3] u[6, 1] + 
 
   u[1, 6] u[2, 5] u[3, 3] u[4, 2] u[5, 4] u[6, 1] + 
 
   u[1, 5] u[2, 6] u[3, 3] u[4, 2] u[5, 4] u[6, 1] + 
 
   u[1, 6] u[2, 3] u[3, 5] u[4, 2] u[5, 4] u[6, 1] + 
 
   u[1, 3] u[2, 6] u[3, 5] u[4, 2] u[5, 4] u[6, 1] + 
 
   u[1, 5] u[2, 3] u[3, 6] u[4, 2] u[5, 4] u[6, 1] + 
 
   u[1, 3] u[2, 5] u[3, 6] u[4, 2] u[5, 4] u[6, 1] + 
 
   u[1, 6] u[2, 5] u[3, 2] u[4, 3] u[5, 4] u[6, 1] + 
 
   u[1, 5] u[2, 6] u[3, 2] u[4, 3] u[5, 4] u[6, 1] + 
 
   u[1, 6] u[2, 2] u[3, 5] u[4, 3] u[5, 4] u[6, 1] + 
 
   u[1, 2] u[2, 6] u[3, 5] u[4, 3] u[5, 4] u[6, 1] + 
 
   u[1, 5] u[2, 2] u[3, 6] u[4, 3] u[5, 4] u[6, 1] + 
 
   u[1, 2] u[2, 5] u[3, 6] u[4, 3] u[5, 4] u[6, 1] + 
 
   u[1, 6] u[2, 3] u[3, 2] u[4, 5] u[5, 4] u[6, 1] + 
 
   u[1, 3] u[2, 6] u[3, 2] u[4, 5] u[5, 4] u[6, 1] + 
 
   u[1, 6] u[2, 2] u[3, 3] u[4, 5] u[5, 4] u[6, 1] + 
 
   u[1, 2] u[2, 6] u[3, 3] u[4, 5] u[5, 4] u[6, 1] + 
 
   u[1, 3] u[2, 2] u[3, 6] u[4, 5] u[5, 4] u[6, 1] + 
 
   u[1, 2] u[2, 3] u[3, 6] u[4, 5] u[5, 4] u[6, 1] + 
 
   u[1, 5] u[2, 3] u[3, 2] u[4, 6] u[5, 4] u[6, 1] + 
 
   u[1, 3] u[2, 5] u[3, 2] u[4, 6] u[5, 4] u[6, 1] + 
 
   u[1, 5] u[2, 2] u[3, 3] u[4, 6] u[5, 4] u[6, 1] + 
 
   u[1, 2] u[2, 5] u[3, 3] u[4, 6] u[5, 4] u[6, 1] + 
 
   u[1, 3] u[2, 2] u[3, 5] u[4, 6] u[5, 4] u[6, 1] + 
 
   u[1, 2] u[2, 3] u[3, 5] u[4, 6] u[5, 4] u[6, 1] + 
 
   u[1, 6] u[2, 4] u[3, 3] u[4, 2] u[5, 5] u[6, 1] + 
 
   u[1, 4] u[2, 6] u[3, 3] u[4, 2] u[5, 5] u[6, 1] + 
 
   u[1, 6] u[2, 3] u[3, 4] u[4, 2] u[5, 5] u[6, 1] + 
 
   u[1, 3] u[2, 6] u[3, 4] u[4, 2] u[5, 5] u[6, 1] + 
 
   u[1, 4] u[2, 3] u[3, 6] u[4, 2] u[5, 5] u[6, 1] + 
 
   u[1, 3] u[2, 4] u[3, 6] u[4, 2] u[5, 5] u[6, 1] + 
 
   u[1, 6] u[2, 4] u[3, 2] u[4, 3] u[5, 5] u[6, 1] + 
 
   u[1, 4] u[2, 6] u[3, 2] u[4, 3] u[5, 5] u[6, 1] + 
 
   u[1, 6] u[2, 2] u[3, 4] u[4, 3] u[5, 5] u[6, 1] + 
 
   u[1, 2] u[2, 6] u[3, 4] u[4, 3] u[5, 5] u[6, 1] + 
 
   u[1, 4] u[2, 2] u[3, 6] u[4, 3] u[5, 5] u[6, 1] + 
 
   u[1, 2] u[2, 4] u[3, 6] u[4, 3] u[5, 5] u[6, 1] + 
 
   u[1, 6] u[2, 3] u[3, 2] u[4, 4] u[5, 5] u[6, 1] + 
 
   u[1, 3] u[2, 6] u[3, 2] u[4, 4] u[5, 5] u[6, 1] + 
 
   u[1, 6] u[2, 2] u[3, 3] u[4, 4] u[5, 5] u[6, 1] + 
 
   u[1, 2] u[2, 6] u[3, 3] u[4, 4] u[5, 5] u[6, 1] + 
 
   u[1, 3] u[2, 2] u[3, 6] u[4, 4] u[5, 5] u[6, 1] + 
 
   u[1, 2] u[2, 3] u[3, 6] u[4, 4] u[5, 5] u[6, 1] + 
 
   u[1, 4] u[2, 3] u[3, 2] u[4, 6] u[5, 5] u[6, 1] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 6] u[5, 5] u[6, 1] + 
 
   u[1, 4] u[2, 2] u[3, 3] u[4, 6] u[5, 5] u[6, 1] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 6] u[5, 5] u[6, 1] + 
 
   u[1, 3] u[2, 2] u[3, 4] u[4, 6] u[5, 5] u[6, 1] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 6] u[5, 5] u[6, 1] + 
 
   u[1, 5] u[2, 4] u[3, 3] u[4, 2] u[5, 6] u[6, 1] + 
 
   u[1, 4] u[2, 5] u[3, 3] u[4, 2] u[5, 6] u[6, 1] + 
 
   u[1, 5] u[2, 3] u[3, 4] u[4, 2] u[5, 6] u[6, 1] + 
 
   u[1, 3] u[2, 5] u[3, 4] u[4, 2] u[5, 6] u[6, 1] + 
 
   u[1, 4] u[2, 3] u[3, 5] u[4, 2] u[5, 6] u[6, 1] + 
 
   u[1, 3] u[2, 4] u[3, 5] u[4, 2] u[5, 6] u[6, 1] + 
 
   u[1, 5] u[2, 4] u[3, 2] u[4, 3] u[5, 6] u[6, 1] + 
 
   u[1, 4] u[2, 5] u[3, 2] u[4, 3] u[5, 6] u[6, 1] + 
 
   u[1, 5] u[2, 2] u[3, 4] u[4, 3] u[5, 6] u[6, 1] + 
 
   u[1, 2] u[2, 5] u[3, 4] u[4, 3] u[5, 6] u[6, 1] + 
 
   u[1, 4] u[2, 2] u[3, 5] u[4, 3] u[5, 6] u[6, 1] + 
 
   u[1, 2] u[2, 4] u[3, 5] u[4, 3] u[5, 6] u[6, 1] + 
 
   u[1, 5] u[2, 3] u[3, 2] u[4, 4] u[5, 6] u[6, 1] + 
 
   u[1, 3] u[2, 5] u[3, 2] u[4, 4] u[5, 6] u[6, 1] + 
 
   u[1, 5] u[2, 2] u[3, 3] u[4, 4] u[5, 6] u[6, 1] + 
 
   u[1, 2] u[2, 5] u[3, 3] u[4, 4] u[5, 6] u[6, 1] + 
 
   u[1, 3] u[2, 2] u[3, 5] u[4, 4] u[5, 6] u[6, 1] + 
 
   u[1, 2] u[2, 3] u[3, 5] u[4, 4] u[5, 6] u[6, 1] + 
 
   u[1, 4] u[2, 3] u[3, 2] u[4, 5] u[5, 6] u[6, 1] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 5] u[5, 6] u[6, 1] + 
 
   u[1, 4] u[2, 2] u[3, 3] u[4, 5] u[5, 6] u[6, 1] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 5] u[5, 6] u[6, 1] + 
 
   u[1, 3] u[2, 2] u[3, 4] u[4, 5] u[5, 6] u[6, 1] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 5] u[5, 6] u[6, 1] + 
 
   u[1, 6] u[2, 5] u[3, 4] u[4, 3] u[5, 1] u[6, 2] + 
 
   u[1, 5] u[2, 6] u[3, 4] u[4, 3] u[5, 1] u[6, 2] + 
 
   u[1, 6] u[2, 4] u[3, 5] u[4, 3] u[5, 1] u[6, 2] + 
 
   u[1, 4] u[2, 6] u[3, 5] u[4, 3] u[5, 1] u[6, 2] + 
 
   u[1, 5] u[2, 4] u[3, 6] u[4, 3] u[5, 1] u[6, 2] + 
 
   u[1, 4] u[2, 5] u[3, 6] u[4, 3] u[5, 1] u[6, 2] + 
 
   u[1, 6] u[2, 5] u[3, 3] u[4, 4] u[5, 1] u[6, 2] + 
 
   u[1, 5] u[2, 6] u[3, 3] u[4, 4] u[5, 1] u[6, 2] + 
 
   u[1, 6] u[2, 3] u[3, 5] u[4, 4] u[5, 1] u[6, 2] + 
 
   u[1, 3] u[2, 6] u[3, 5] u[4, 4] u[5, 1] u[6, 2] + 
 
   u[1, 5] u[2, 3] u[3, 6] u[4, 4] u[5, 1] u[6, 2] + 
 
   u[1, 3] u[2, 5] u[3, 6] u[4, 4] u[5, 1] u[6, 2] + 
 
   u[1, 6] u[2, 4] u[3, 3] u[4, 5] u[5, 1] u[6, 2] + 
 
   u[1, 4] u[2, 6] u[3, 3] u[4, 5] u[5, 1] u[6, 2] + 
 
   u[1, 6] u[2, 3] u[3, 4] u[4, 5] u[5, 1] u[6, 2] + 
 
   u[1, 3] u[2, 6] u[3, 4] u[4, 5] u[5, 1] u[6, 2] + 
 
   u[1, 4] u[2, 3] u[3, 6] u[4, 5] u[5, 1] u[6, 2] + 
 
   u[1, 3] u[2, 4] u[3, 6] u[4, 5] u[5, 1] u[6, 2] + 
 
   u[1, 5] u[2, 4] u[3, 3] u[4, 6] u[5, 1] u[6, 2] + 
 
   u[1, 4] u[2, 5] u[3, 3] u[4, 6] u[5, 1] u[6, 2] + 
 
   u[1, 5] u[2, 3] u[3, 4] u[4, 6] u[5, 1] u[6, 2] + 
 
   u[1, 3] u[2, 5] u[3, 4] u[4, 6] u[5, 1] u[6, 2] + 
 
   u[1, 4] u[2, 3] u[3, 5] u[4, 6] u[5, 1] u[6, 2] + 
 
   u[1, 3] u[2, 4] u[3, 5] u[4, 6] u[5, 1] u[6, 2] + 
 
   u[1, 6] u[2, 5] u[3, 4] u[4, 1] u[5, 3] u[6, 2] + 
 
   u[1, 5] u[2, 6] u[3, 4] u[4, 1] u[5, 3] u[6, 2] + 
 
   u[1, 6] u[2, 4] u[3, 5] u[4, 1] u[5, 3] u[6, 2] + 
 
   u[1, 4] u[2, 6] u[3, 5] u[4, 1] u[5, 3] u[6, 2] + 
 
   u[1, 5] u[2, 4] u[3, 6] u[4, 1] u[5, 3] u[6, 2] + 
 
   u[1, 4] u[2, 5] u[3, 6] u[4, 1] u[5, 3] u[6, 2] + 
 
   u[1, 6] u[2, 5] u[3, 1] u[4, 4] u[5, 3] u[6, 2] + 
 
   u[1, 5] u[2, 6] u[3, 1] u[4, 4] u[5, 3] u[6, 2] + 
 
   u[1, 6] u[2, 1] u[3, 5] u[4, 4] u[5, 3] u[6, 2] + 
 
   u[1, 1] u[2, 6] u[3, 5] u[4, 4] u[5, 3] u[6, 2] + 
 
   u[1, 5] u[2, 1] u[3, 6] u[4, 4] u[5, 3] u[6, 2] + 
 
   u[1, 1] u[2, 5] u[3, 6] u[4, 4] u[5, 3] u[6, 2] + 
 
   u[1, 6] u[2, 4] u[3, 1] u[4, 5] u[5, 3] u[6, 2] + 
 
   u[1, 4] u[2, 6] u[3, 1] u[4, 5] u[5, 3] u[6, 2] + 
 
   u[1, 6] u[2, 1] u[3, 4] u[4, 5] u[5, 3] u[6, 2] + 
 
   u[1, 1] u[2, 6] u[3, 4] u[4, 5] u[5, 3] u[6, 2] + 
 
   u[1, 4] u[2, 1] u[3, 6] u[4, 5] u[5, 3] u[6, 2] + 
 
   u[1, 1] u[2, 4] u[3, 6] u[4, 5] u[5, 3] u[6, 2] + 
 
   u[1, 5] u[2, 4] u[3, 1] u[4, 6] u[5, 3] u[6, 2] + 
 
   u[1, 4] u[2, 5] u[3, 1] u[4, 6] u[5, 3] u[6, 2] + 
 
   u[1, 5] u[2, 1] u[3, 4] u[4, 6] u[5, 3] u[6, 2] + 
 
   u[1, 1] u[2, 5] u[3, 4] u[4, 6] u[5, 3] u[6, 2] + 
 
   u[1, 4] u[2, 1] u[3, 5] u[4, 6] u[5, 3] u[6, 2] + 
 
   u[1, 1] u[2, 4] u[3, 5] u[4, 6] u[5, 3] u[6, 2] + 
 
   u[1, 6] u[2, 5] u[3, 3] u[4, 1] u[5, 4] u[6, 2] + 
 
   u[1, 5] u[2, 6] u[3, 3] u[4, 1] u[5, 4] u[6, 2] + 
 
   u[1, 6] u[2, 3] u[3, 5] u[4, 1] u[5, 4] u[6, 2] + 
 
   u[1, 3] u[2, 6] u[3, 5] u[4, 1] u[5, 4] u[6, 2] + 
 
   u[1, 5] u[2, 3] u[3, 6] u[4, 1] u[5, 4] u[6, 2] + 
 
   u[1, 3] u[2, 5] u[3, 6] u[4, 1] u[5, 4] u[6, 2] + 
 
   u[1, 6] u[2, 5] u[3, 1] u[4, 3] u[5, 4] u[6, 2] + 
 
   u[1, 5] u[2, 6] u[3, 1] u[4, 3] u[5, 4] u[6, 2] + 
 
   u[1, 6] u[2, 1] u[3, 5] u[4, 3] u[5, 4] u[6, 2] + 
 
   u[1, 1] u[2, 6] u[3, 5] u[4, 3] u[5, 4] u[6, 2] + 
 
   u[1, 5] u[2, 1] u[3, 6] u[4, 3] u[5, 4] u[6, 2] + 
 
   u[1, 1] u[2, 5] u[3, 6] u[4, 3] u[5, 4] u[6, 2] + 
 
   u[1, 6] u[2, 3] u[3, 1] u[4, 5] u[5, 4] u[6, 2] + 
 
   u[1, 3] u[2, 6] u[3, 1] u[4, 5] u[5, 4] u[6, 2] + 
 
   u[1, 6] u[2, 1] u[3, 3] u[4, 5] u[5, 4] u[6, 2] + 
 
   u[1, 1] u[2, 6] u[3, 3] u[4, 5] u[5, 4] u[6, 2] + 
 
   u[1, 3] u[2, 1] u[3, 6] u[4, 5] u[5, 4] u[6, 2] + 
 
   u[1, 1] u[2, 3] u[3, 6] u[4, 5] u[5, 4] u[6, 2] + 
 
   u[1, 5] u[2, 3] u[3, 1] u[4, 6] u[5, 4] u[6, 2] + 
 
   u[1, 3] u[2, 5] u[3, 1] u[4, 6] u[5, 4] u[6, 2] + 
 
   u[1, 5] u[2, 1] u[3, 3] u[4, 6] u[5, 4] u[6, 2] + 
 
   u[1, 1] u[2, 5] u[3, 3] u[4, 6] u[5, 4] u[6, 2] + 
 
   u[1, 3] u[2, 1] u[3, 5] u[4, 6] u[5, 4] u[6, 2] + 
 
   u[1, 1] u[2, 3] u[3, 5] u[4, 6] u[5, 4] u[6, 2] + 
 
   u[1, 6] u[2, 4] u[3, 3] u[4, 1] u[5, 5] u[6, 2] + 
 
   u[1, 4] u[2, 6] u[3, 3] u[4, 1] u[5, 5] u[6, 2] + 
 
   u[1, 6] u[2, 3] u[3, 4] u[4, 1] u[5, 5] u[6, 2] + 
 
   u[1, 3] u[2, 6] u[3, 4] u[4, 1] u[5, 5] u[6, 2] + 
 
   u[1, 4] u[2, 3] u[3, 6] u[4, 1] u[5, 5] u[6, 2] + 
 
   u[1, 3] u[2, 4] u[3, 6] u[4, 1] u[5, 5] u[6, 2] + 
 
   u[1, 6] u[2, 4] u[3, 1] u[4, 3] u[5, 5] u[6, 2] + 
 
   u[1, 4] u[2, 6] u[3, 1] u[4, 3] u[5, 5] u[6, 2] + 
 
   u[1, 6] u[2, 1] u[3, 4] u[4, 3] u[5, 5] u[6, 2] + 
 
   u[1, 1] u[2, 6] u[3, 4] u[4, 3] u[5, 5] u[6, 2] + 
 
   u[1, 4] u[2, 1] u[3, 6] u[4, 3] u[5, 5] u[6, 2] + 
 
   u[1, 1] u[2, 4] u[3, 6] u[4, 3] u[5, 5] u[6, 2] + 
 
   u[1, 6] u[2, 3] u[3, 1] u[4, 4] u[5, 5] u[6, 2] + 
 
   u[1, 3] u[2, 6] u[3, 1] u[4, 4] u[5, 5] u[6, 2] + 
 
   u[1, 6] u[2, 1] u[3, 3] u[4, 4] u[5, 5] u[6, 2] + 
 
   u[1, 1] u[2, 6] u[3, 3] u[4, 4] u[5, 5] u[6, 2] + 
 
   u[1, 3] u[2, 1] u[3, 6] u[4, 4] u[5, 5] u[6, 2] + 
 
   u[1, 1] u[2, 3] u[3, 6] u[4, 4] u[5, 5] u[6, 2] + 
 
   u[1, 4] u[2, 3] u[3, 1] u[4, 6] u[5, 5] u[6, 2] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 6] u[5, 5] u[6, 2] + 
 
   u[1, 4] u[2, 1] u[3, 3] u[4, 6] u[5, 5] u[6, 2] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 6] u[5, 5] u[6, 2] + 
 
   u[1, 3] u[2, 1] u[3, 4] u[4, 6] u[5, 5] u[6, 2] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 6] u[5, 5] u[6, 2] + 
 
   u[1, 5] u[2, 4] u[3, 3] u[4, 1] u[5, 6] u[6, 2] + 
 
   u[1, 4] u[2, 5] u[3, 3] u[4, 1] u[5, 6] u[6, 2] + 
 
   u[1, 5] u[2, 3] u[3, 4] u[4, 1] u[5, 6] u[6, 2] + 
 
   u[1, 3] u[2, 5] u[3, 4] u[4, 1] u[5, 6] u[6, 2] + 
 
   u[1, 4] u[2, 3] u[3, 5] u[4, 1] u[5, 6] u[6, 2] + 
 
   u[1, 3] u[2, 4] u[3, 5] u[4, 1] u[5, 6] u[6, 2] + 
 
   u[1, 5] u[2, 4] u[3, 1] u[4, 3] u[5, 6] u[6, 2] + 
 
   u[1, 4] u[2, 5] u[3, 1] u[4, 3] u[5, 6] u[6, 2] + 
 
   u[1, 5] u[2, 1] u[3, 4] u[4, 3] u[5, 6] u[6, 2] + 
 
   u[1, 1] u[2, 5] u[3, 4] u[4, 3] u[5, 6] u[6, 2] + 
 
   u[1, 4] u[2, 1] u[3, 5] u[4, 3] u[5, 6] u[6, 2] + 
 
   u[1, 1] u[2, 4] u[3, 5] u[4, 3] u[5, 6] u[6, 2] + 
 
   u[1, 5] u[2, 3] u[3, 1] u[4, 4] u[5, 6] u[6, 2] + 
 
   u[1, 3] u[2, 5] u[3, 1] u[4, 4] u[5, 6] u[6, 2] + 
 
   u[1, 5] u[2, 1] u[3, 3] u[4, 4] u[5, 6] u[6, 2] + 
 
   u[1, 1] u[2, 5] u[3, 3] u[4, 4] u[5, 6] u[6, 2] + 
 
   u[1, 3] u[2, 1] u[3, 5] u[4, 4] u[5, 6] u[6, 2] + 
 
   u[1, 1] u[2, 3] u[3, 5] u[4, 4] u[5, 6] u[6, 2] + 
 
   u[1, 4] u[2, 3] u[3, 1] u[4, 5] u[5, 6] u[6, 2] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 5] u[5, 6] u[6, 2] + 
 
   u[1, 4] u[2, 1] u[3, 3] u[4, 5] u[5, 6] u[6, 2] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 5] u[5, 6] u[6, 2] + 
 
   u[1, 3] u[2, 1] u[3, 4] u[4, 5] u[5, 6] u[6, 2] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 5] u[5, 6] u[6, 2] + 
 
   u[1, 6] u[2, 5] u[3, 4] u[4, 2] u[5, 1] u[6, 3] + 
 
   u[1, 5] u[2, 6] u[3, 4] u[4, 2] u[5, 1] u[6, 3] + 
 
   u[1, 6] u[2, 4] u[3, 5] u[4, 2] u[5, 1] u[6, 3] + 
 
   u[1, 4] u[2, 6] u[3, 5] u[4, 2] u[5, 1] u[6, 3] + 
 
   u[1, 5] u[2, 4] u[3, 6] u[4, 2] u[5, 1] u[6, 3] + 
 
   u[1, 4] u[2, 5] u[3, 6] u[4, 2] u[5, 1] u[6, 3] + 
 
   u[1, 6] u[2, 5] u[3, 2] u[4, 4] u[5, 1] u[6, 3] + 
 
   u[1, 5] u[2, 6] u[3, 2] u[4, 4] u[5, 1] u[6, 3] + 
 
   u[1, 6] u[2, 2] u[3, 5] u[4, 4] u[5, 1] u[6, 3] + 
 
   u[1, 2] u[2, 6] u[3, 5] u[4, 4] u[5, 1] u[6, 3] + 
 
   u[1, 5] u[2, 2] u[3, 6] u[4, 4] u[5, 1] u[6, 3] + 
 
   u[1, 2] u[2, 5] u[3, 6] u[4, 4] u[5, 1] u[6, 3] + 
 
   u[1, 6] u[2, 4] u[3, 2] u[4, 5] u[5, 1] u[6, 3] + 
 
   u[1, 4] u[2, 6] u[3, 2] u[4, 5] u[5, 1] u[6, 3] + 
 
   u[1, 6] u[2, 2] u[3, 4] u[4, 5] u[5, 1] u[6, 3] + 
 
   u[1, 2] u[2, 6] u[3, 4] u[4, 5] u[5, 1] u[6, 3] + 
 
   u[1, 4] u[2, 2] u[3, 6] u[4, 5] u[5, 1] u[6, 3] + 
 
   u[1, 2] u[2, 4] u[3, 6] u[4, 5] u[5, 1] u[6, 3] + 
 
   u[1, 5] u[2, 4] u[3, 2] u[4, 6] u[5, 1] u[6, 3] + 
 
   u[1, 4] u[2, 5] u[3, 2] u[4, 6] u[5, 1] u[6, 3] + 
 
   u[1, 5] u[2, 2] u[3, 4] u[4, 6] u[5, 1] u[6, 3] + 
 
   u[1, 2] u[2, 5] u[3, 4] u[4, 6] u[5, 1] u[6, 3] + 
 
   u[1, 4] u[2, 2] u[3, 5] u[4, 6] u[5, 1] u[6, 3] + 
 
   u[1, 2] u[2, 4] u[3, 5] u[4, 6] u[5, 1] u[6, 3] + 
 
   u[1, 6] u[2, 5] u[3, 4] u[4, 1] u[5, 2] u[6, 3] + 
 
   u[1, 5] u[2, 6] u[3, 4] u[4, 1] u[5, 2] u[6, 3] + 
 
   u[1, 6] u[2, 4] u[3, 5] u[4, 1] u[5, 2] u[6, 3] + 
 
   u[1, 4] u[2, 6] u[3, 5] u[4, 1] u[5, 2] u[6, 3] + 
 
   u[1, 5] u[2, 4] u[3, 6] u[4, 1] u[5, 2] u[6, 3] + 
 
   u[1, 4] u[2, 5] u[3, 6] u[4, 1] u[5, 2] u[6, 3] + 
 
   u[1, 6] u[2, 5] u[3, 1] u[4, 4] u[5, 2] u[6, 3] + 
 
   u[1, 5] u[2, 6] u[3, 1] u[4, 4] u[5, 2] u[6, 3] + 
 
   u[1, 6] u[2, 1] u[3, 5] u[4, 4] u[5, 2] u[6, 3] + 
 
   u[1, 1] u[2, 6] u[3, 5] u[4, 4] u[5, 2] u[6, 3] + 
 
   u[1, 5] u[2, 1] u[3, 6] u[4, 4] u[5, 2] u[6, 3] + 
 
   u[1, 1] u[2, 5] u[3, 6] u[4, 4] u[5, 2] u[6, 3] + 
 
   u[1, 6] u[2, 4] u[3, 1] u[4, 5] u[5, 2] u[6, 3] + 
 
   u[1, 4] u[2, 6] u[3, 1] u[4, 5] u[5, 2] u[6, 3] + 
 
   u[1, 6] u[2, 1] u[3, 4] u[4, 5] u[5, 2] u[6, 3] + 
 
   u[1, 1] u[2, 6] u[3, 4] u[4, 5] u[5, 2] u[6, 3] + 
 
   u[1, 4] u[2, 1] u[3, 6] u[4, 5] u[5, 2] u[6, 3] + 
 
   u[1, 1] u[2, 4] u[3, 6] u[4, 5] u[5, 2] u[6, 3] + 
 
   u[1, 5] u[2, 4] u[3, 1] u[4, 6] u[5, 2] u[6, 3] + 
 
   u[1, 4] u[2, 5] u[3, 1] u[4, 6] u[5, 2] u[6, 3] + 
 
   u[1, 5] u[2, 1] u[3, 4] u[4, 6] u[5, 2] u[6, 3] + 
 
   u[1, 1] u[2, 5] u[3, 4] u[4, 6] u[5, 2] u[6, 3] + 
 
   u[1, 4] u[2, 1] u[3, 5] u[4, 6] u[5, 2] u[6, 3] + 
 
   u[1, 1] u[2, 4] u[3, 5] u[4, 6] u[5, 2] u[6, 3] + 
 
   u[1, 6] u[2, 5] u[3, 2] u[4, 1] u[5, 4] u[6, 3] + 
 
   u[1, 5] u[2, 6] u[3, 2] u[4, 1] u[5, 4] u[6, 3] + 
 
   u[1, 6] u[2, 2] u[3, 5] u[4, 1] u[5, 4] u[6, 3] + 
 
   u[1, 2] u[2, 6] u[3, 5] u[4, 1] u[5, 4] u[6, 3] + 
 
   u[1, 5] u[2, 2] u[3, 6] u[4, 1] u[5, 4] u[6, 3] + 
 
   u[1, 2] u[2, 5] u[3, 6] u[4, 1] u[5, 4] u[6, 3] + 
 
   u[1, 6] u[2, 5] u[3, 1] u[4, 2] u[5, 4] u[6, 3] + 
 
   u[1, 5] u[2, 6] u[3, 1] u[4, 2] u[5, 4] u[6, 3] + 
 
   u[1, 6] u[2, 1] u[3, 5] u[4, 2] u[5, 4] u[6, 3] + 
 
   u[1, 1] u[2, 6] u[3, 5] u[4, 2] u[5, 4] u[6, 3] + 
 
   u[1, 5] u[2, 1] u[3, 6] u[4, 2] u[5, 4] u[6, 3] + 
 
   u[1, 1] u[2, 5] u[3, 6] u[4, 2] u[5, 4] u[6, 3] + 
 
   u[1, 6] u[2, 2] u[3, 1] u[4, 5] u[5, 4] u[6, 3] + 
 
   u[1, 2] u[2, 6] u[3, 1] u[4, 5] u[5, 4] u[6, 3] + 
 
   u[1, 6] u[2, 1] u[3, 2] u[4, 5] u[5, 4] u[6, 3] + 
 
   u[1, 1] u[2, 6] u[3, 2] u[4, 5] u[5, 4] u[6, 3] + 
 
   u[1, 2] u[2, 1] u[3, 6] u[4, 5] u[5, 4] u[6, 3] + 
 
   u[1, 1] u[2, 2] u[3, 6] u[4, 5] u[5, 4] u[6, 3] + 
 
   u[1, 5] u[2, 2] u[3, 1] u[4, 6] u[5, 4] u[6, 3] + 
 
   u[1, 2] u[2, 5] u[3, 1] u[4, 6] u[5, 4] u[6, 3] + 
 
   u[1, 5] u[2, 1] u[3, 2] u[4, 6] u[5, 4] u[6, 3] + 
 
   u[1, 1] u[2, 5] u[3, 2] u[4, 6] u[5, 4] u[6, 3] + 
 
   u[1, 2] u[2, 1] u[3, 5] u[4, 6] u[5, 4] u[6, 3] + 
 
   u[1, 1] u[2, 2] u[3, 5] u[4, 6] u[5, 4] u[6, 3] + 
 
   u[1, 6] u[2, 4] u[3, 2] u[4, 1] u[5, 5] u[6, 3] + 
 
   u[1, 4] u[2, 6] u[3, 2] u[4, 1] u[5, 5] u[6, 3] + 
 
   u[1, 6] u[2, 2] u[3, 4] u[4, 1] u[5, 5] u[6, 3] + 
 
   u[1, 2] u[2, 6] u[3, 4] u[4, 1] u[5, 5] u[6, 3] + 
 
   u[1, 4] u[2, 2] u[3, 6] u[4, 1] u[5, 5] u[6, 3] + 
 
   u[1, 2] u[2, 4] u[3, 6] u[4, 1] u[5, 5] u[6, 3] + 
 
   u[1, 6] u[2, 4] u[3, 1] u[4, 2] u[5, 5] u[6, 3] + 
 
   u[1, 4] u[2, 6] u[3, 1] u[4, 2] u[5, 5] u[6, 3] + 
 
   u[1, 6] u[2, 1] u[3, 4] u[4, 2] u[5, 5] u[6, 3] + 
 
   u[1, 1] u[2, 6] u[3, 4] u[4, 2] u[5, 5] u[6, 3] + 
 
   u[1, 4] u[2, 1] u[3, 6] u[4, 2] u[5, 5] u[6, 3] + 
 
   u[1, 1] u[2, 4] u[3, 6] u[4, 2] u[5, 5] u[6, 3] + 
 
   u[1, 6] u[2, 2] u[3, 1] u[4, 4] u[5, 5] u[6, 3] + 
 
   u[1, 2] u[2, 6] u[3, 1] u[4, 4] u[5, 5] u[6, 3] + 
 
   u[1, 6] u[2, 1] u[3, 2] u[4, 4] u[5, 5] u[6, 3] + 
 
   u[1, 1] u[2, 6] u[3, 2] u[4, 4] u[5, 5] u[6, 3] + 
 
   u[1, 2] u[2, 1] u[3, 6] u[4, 4] u[5, 5] u[6, 3] + 
 
   u[1, 1] u[2, 2] u[3, 6] u[4, 4] u[5, 5] u[6, 3] + 
 
   u[1, 4] u[2, 2] u[3, 1] u[4, 6] u[5, 5] u[6, 3] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 6] u[5, 5] u[6, 3] + 
 
   u[1, 4] u[2, 1] u[3, 2] u[4, 6] u[5, 5] u[6, 3] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 6] u[5, 5] u[6, 3] + 
 
   u[1, 2] u[2, 1] u[3, 4] u[4, 6] u[5, 5] u[6, 3] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 6] u[5, 5] u[6, 3] + 
 
   u[1, 5] u[2, 4] u[3, 2] u[4, 1] u[5, 6] u[6, 3] + 
 
   u[1, 4] u[2, 5] u[3, 2] u[4, 1] u[5, 6] u[6, 3] + 
 
   u[1, 5] u[2, 2] u[3, 4] u[4, 1] u[5, 6] u[6, 3] + 
 
   u[1, 2] u[2, 5] u[3, 4] u[4, 1] u[5, 6] u[6, 3] + 
 
   u[1, 4] u[2, 2] u[3, 5] u[4, 1] u[5, 6] u[6, 3] + 
 
   u[1, 2] u[2, 4] u[3, 5] u[4, 1] u[5, 6] u[6, 3] + 
 
   u[1, 5] u[2, 4] u[3, 1] u[4, 2] u[5, 6] u[6, 3] + 
 
   u[1, 4] u[2, 5] u[3, 1] u[4, 2] u[5, 6] u[6, 3] + 
 
   u[1, 5] u[2, 1] u[3, 4] u[4, 2] u[5, 6] u[6, 3] + 
 
   u[1, 1] u[2, 5] u[3, 4] u[4, 2] u[5, 6] u[6, 3] + 
 
   u[1, 4] u[2, 1] u[3, 5] u[4, 2] u[5, 6] u[6, 3] + 
 
   u[1, 1] u[2, 4] u[3, 5] u[4, 2] u[5, 6] u[6, 3] + 
 
   u[1, 5] u[2, 2] u[3, 1] u[4, 4] u[5, 6] u[6, 3] + 
 
   u[1, 2] u[2, 5] u[3, 1] u[4, 4] u[5, 6] u[6, 3] + 
 
   u[1, 5] u[2, 1] u[3, 2] u[4, 4] u[5, 6] u[6, 3] + 
 
   u[1, 1] u[2, 5] u[3, 2] u[4, 4] u[5, 6] u[6, 3] + 
 
   u[1, 2] u[2, 1] u[3, 5] u[4, 4] u[5, 6] u[6, 3] + 
 
   u[1, 1] u[2, 2] u[3, 5] u[4, 4] u[5, 6] u[6, 3] + 
 
   u[1, 4] u[2, 2] u[3, 1] u[4, 5] u[5, 6] u[6, 3] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 5] u[5, 6] u[6, 3] + 
 
   u[1, 4] u[2, 1] u[3, 2] u[4, 5] u[5, 6] u[6, 3] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 5] u[5, 6] u[6, 3] + 
 
   u[1, 2] u[2, 1] u[3, 4] u[4, 5] u[5, 6] u[6, 3] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 5] u[5, 6] u[6, 3] + 
 
   u[1, 6] u[2, 5] u[3, 3] u[4, 2] u[5, 1] u[6, 4] + 
 
   u[1, 5] u[2, 6] u[3, 3] u[4, 2] u[5, 1] u[6, 4] + 
 
   u[1, 6] u[2, 3] u[3, 5] u[4, 2] u[5, 1] u[6, 4] + 
 
   u[1, 3] u[2, 6] u[3, 5] u[4, 2] u[5, 1] u[6, 4] + 
 
   u[1, 5] u[2, 3] u[3, 6] u[4, 2] u[5, 1] u[6, 4] + 
 
   u[1, 3] u[2, 5] u[3, 6] u[4, 2] u[5, 1] u[6, 4] + 
 
   u[1, 6] u[2, 5] u[3, 2] u[4, 3] u[5, 1] u[6, 4] + 
 
   u[1, 5] u[2, 6] u[3, 2] u[4, 3] u[5, 1] u[6, 4] + 
 
   u[1, 6] u[2, 2] u[3, 5] u[4, 3] u[5, 1] u[6, 4] + 
 
   u[1, 2] u[2, 6] u[3, 5] u[4, 3] u[5, 1] u[6, 4] + 
 
   u[1, 5] u[2, 2] u[3, 6] u[4, 3] u[5, 1] u[6, 4] + 
 
   u[1, 2] u[2, 5] u[3, 6] u[4, 3] u[5, 1] u[6, 4] + 
 
   u[1, 6] u[2, 3] u[3, 2] u[4, 5] u[5, 1] u[6, 4] + 
 
   u[1, 3] u[2, 6] u[3, 2] u[4, 5] u[5, 1] u[6, 4] + 
 
   u[1, 6] u[2, 2] u[3, 3] u[4, 5] u[5, 1] u[6, 4] + 
 
   u[1, 2] u[2, 6] u[3, 3] u[4, 5] u[5, 1] u[6, 4] + 
 
   u[1, 3] u[2, 2] u[3, 6] u[4, 5] u[5, 1] u[6, 4] + 
 
   u[1, 2] u[2, 3] u[3, 6] u[4, 5] u[5, 1] u[6, 4] + 
 
   u[1, 5] u[2, 3] u[3, 2] u[4, 6] u[5, 1] u[6, 4] + 
 
   u[1, 3] u[2, 5] u[3, 2] u[4, 6] u[5, 1] u[6, 4] + 
 
   u[1, 5] u[2, 2] u[3, 3] u[4, 6] u[5, 1] u[6, 4] + 
 
   u[1, 2] u[2, 5] u[3, 3] u[4, 6] u[5, 1] u[6, 4] + 
 
   u[1, 3] u[2, 2] u[3, 5] u[4, 6] u[5, 1] u[6, 4] + 
 
   u[1, 2] u[2, 3] u[3, 5] u[4, 6] u[5, 1] u[6, 4] + 
 
   u[1, 6] u[2, 5] u[3, 3] u[4, 1] u[5, 2] u[6, 4] + 
 
   u[1, 5] u[2, 6] u[3, 3] u[4, 1] u[5, 2] u[6, 4] + 
 
   u[1, 6] u[2, 3] u[3, 5] u[4, 1] u[5, 2] u[6, 4] + 
 
   u[1, 3] u[2, 6] u[3, 5] u[4, 1] u[5, 2] u[6, 4] + 
 
   u[1, 5] u[2, 3] u[3, 6] u[4, 1] u[5, 2] u[6, 4] + 
 
   u[1, 3] u[2, 5] u[3, 6] u[4, 1] u[5, 2] u[6, 4] + 
 
   u[1, 6] u[2, 5] u[3, 1] u[4, 3] u[5, 2] u[6, 4] + 
 
   u[1, 5] u[2, 6] u[3, 1] u[4, 3] u[5, 2] u[6, 4] + 
 
   u[1, 6] u[2, 1] u[3, 5] u[4, 3] u[5, 2] u[6, 4] + 
 
   u[1, 1] u[2, 6] u[3, 5] u[4, 3] u[5, 2] u[6, 4] + 
 
   u[1, 5] u[2, 1] u[3, 6] u[4, 3] u[5, 2] u[6, 4] + 
 
   u[1, 1] u[2, 5] u[3, 6] u[4, 3] u[5, 2] u[6, 4] + 
 
   u[1, 6] u[2, 3] u[3, 1] u[4, 5] u[5, 2] u[6, 4] + 
 
   u[1, 3] u[2, 6] u[3, 1] u[4, 5] u[5, 2] u[6, 4] + 
 
   u[1, 6] u[2, 1] u[3, 3] u[4, 5] u[5, 2] u[6, 4] + 
 
   u[1, 1] u[2, 6] u[3, 3] u[4, 5] u[5, 2] u[6, 4] + 
 
   u[1, 3] u[2, 1] u[3, 6] u[4, 5] u[5, 2] u[6, 4] + 
 
   u[1, 1] u[2, 3] u[3, 6] u[4, 5] u[5, 2] u[6, 4] + 
 
   u[1, 5] u[2, 3] u[3, 1] u[4, 6] u[5, 2] u[6, 4] + 
 
   u[1, 3] u[2, 5] u[3, 1] u[4, 6] u[5, 2] u[6, 4] + 
 
   u[1, 5] u[2, 1] u[3, 3] u[4, 6] u[5, 2] u[6, 4] + 
 
   u[1, 1] u[2, 5] u[3, 3] u[4, 6] u[5, 2] u[6, 4] + 
 
   u[1, 3] u[2, 1] u[3, 5] u[4, 6] u[5, 2] u[6, 4] + 
 
   u[1, 1] u[2, 3] u[3, 5] u[4, 6] u[5, 2] u[6, 4] + 
 
   u[1, 6] u[2, 5] u[3, 2] u[4, 1] u[5, 3] u[6, 4] + 
 
   u[1, 5] u[2, 6] u[3, 2] u[4, 1] u[5, 3] u[6, 4] + 
 
   u[1, 6] u[2, 2] u[3, 5] u[4, 1] u[5, 3] u[6, 4] + 
 
   u[1, 2] u[2, 6] u[3, 5] u[4, 1] u[5, 3] u[6, 4] + 
 
   u[1, 5] u[2, 2] u[3, 6] u[4, 1] u[5, 3] u[6, 4] + 
 
   u[1, 2] u[2, 5] u[3, 6] u[4, 1] u[5, 3] u[6, 4] + 
 
   u[1, 6] u[2, 5] u[3, 1] u[4, 2] u[5, 3] u[6, 4] + 
 
   u[1, 5] u[2, 6] u[3, 1] u[4, 2] u[5, 3] u[6, 4] + 
 
   u[1, 6] u[2, 1] u[3, 5] u[4, 2] u[5, 3] u[6, 4] + 
 
   u[1, 1] u[2, 6] u[3, 5] u[4, 2] u[5, 3] u[6, 4] + 
 
   u[1, 5] u[2, 1] u[3, 6] u[4, 2] u[5, 3] u[6, 4] + 
 
   u[1, 1] u[2, 5] u[3, 6] u[4, 2] u[5, 3] u[6, 4] + 
 
   u[1, 6] u[2, 2] u[3, 1] u[4, 5] u[5, 3] u[6, 4] + 
 
   u[1, 2] u[2, 6] u[3, 1] u[4, 5] u[5, 3] u[6, 4] + 
 
   u[1, 6] u[2, 1] u[3, 2] u[4, 5] u[5, 3] u[6, 4] + 
 
   u[1, 1] u[2, 6] u[3, 2] u[4, 5] u[5, 3] u[6, 4] + 
 
   u[1, 2] u[2, 1] u[3, 6] u[4, 5] u[5, 3] u[6, 4] + 
 
   u[1, 1] u[2, 2] u[3, 6] u[4, 5] u[5, 3] u[6, 4] + 
 
   u[1, 5] u[2, 2] u[3, 1] u[4, 6] u[5, 3] u[6, 4] + 
 
   u[1, 2] u[2, 5] u[3, 1] u[4, 6] u[5, 3] u[6, 4] + 
 
   u[1, 5] u[2, 1] u[3, 2] u[4, 6] u[5, 3] u[6, 4] + 
 
   u[1, 1] u[2, 5] u[3, 2] u[4, 6] u[5, 3] u[6, 4] + 
 
   u[1, 2] u[2, 1] u[3, 5] u[4, 6] u[5, 3] u[6, 4] + 
 
   u[1, 1] u[2, 2] u[3, 5] u[4, 6] u[5, 3] u[6, 4] + 
 
   u[1, 6] u[2, 3] u[3, 2] u[4, 1] u[5, 5] u[6, 4] + 
 
   u[1, 3] u[2, 6] u[3, 2] u[4, 1] u[5, 5] u[6, 4] + 
 
   u[1, 6] u[2, 2] u[3, 3] u[4, 1] u[5, 5] u[6, 4] + 
 
   u[1, 2] u[2, 6] u[3, 3] u[4, 1] u[5, 5] u[6, 4] + 
 
   u[1, 3] u[2, 2] u[3, 6] u[4, 1] u[5, 5] u[6, 4] + 
 
   u[1, 2] u[2, 3] u[3, 6] u[4, 1] u[5, 5] u[6, 4] + 
 
   u[1, 6] u[2, 3] u[3, 1] u[4, 2] u[5, 5] u[6, 4] + 
 
   u[1, 3] u[2, 6] u[3, 1] u[4, 2] u[5, 5] u[6, 4] + 
 
   u[1, 6] u[2, 1] u[3, 3] u[4, 2] u[5, 5] u[6, 4] + 
 
   u[1, 1] u[2, 6] u[3, 3] u[4, 2] u[5, 5] u[6, 4] + 
 
   u[1, 3] u[2, 1] u[3, 6] u[4, 2] u[5, 5] u[6, 4] + 
 
   u[1, 1] u[2, 3] u[3, 6] u[4, 2] u[5, 5] u[6, 4] + 
 
   u[1, 6] u[2, 2] u[3, 1] u[4, 3] u[5, 5] u[6, 4] + 
 
   u[1, 2] u[2, 6] u[3, 1] u[4, 3] u[5, 5] u[6, 4] + 
 
   u[1, 6] u[2, 1] u[3, 2] u[4, 3] u[5, 5] u[6, 4] + 
 
   u[1, 1] u[2, 6] u[3, 2] u[4, 3] u[5, 5] u[6, 4] + 
 
   u[1, 2] u[2, 1] u[3, 6] u[4, 3] u[5, 5] u[6, 4] + 
 
   u[1, 1] u[2, 2] u[3, 6] u[4, 3] u[5, 5] u[6, 4] + 
 
   u[1, 3] u[2, 2] u[3, 1] u[4, 6] u[5, 5] u[6, 4] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 6] u[5, 5] u[6, 4] + 
 
   u[1, 3] u[2, 1] u[3, 2] u[4, 6] u[5, 5] u[6, 4] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 6] u[5, 5] u[6, 4] + 
 
   u[1, 2] u[2, 1] u[3, 3] u[4, 6] u[5, 5] u[6, 4] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 6] u[5, 5] u[6, 4] + 
 
   u[1, 5] u[2, 3] u[3, 2] u[4, 1] u[5, 6] u[6, 4] + 
 
   u[1, 3] u[2, 5] u[3, 2] u[4, 1] u[5, 6] u[6, 4] + 
 
   u[1, 5] u[2, 2] u[3, 3] u[4, 1] u[5, 6] u[6, 4] + 
 
   u[1, 2] u[2, 5] u[3, 3] u[4, 1] u[5, 6] u[6, 4] + 
 
   u[1, 3] u[2, 2] u[3, 5] u[4, 1] u[5, 6] u[6, 4] + 
 
   u[1, 2] u[2, 3] u[3, 5] u[4, 1] u[5, 6] u[6, 4] + 
 
   u[1, 5] u[2, 3] u[3, 1] u[4, 2] u[5, 6] u[6, 4] + 
 
   u[1, 3] u[2, 5] u[3, 1] u[4, 2] u[5, 6] u[6, 4] + 
 
   u[1, 5] u[2, 1] u[3, 3] u[4, 2] u[5, 6] u[6, 4] + 
 
   u[1, 1] u[2, 5] u[3, 3] u[4, 2] u[5, 6] u[6, 4] + 
 
   u[1, 3] u[2, 1] u[3, 5] u[4, 2] u[5, 6] u[6, 4] + 
 
   u[1, 1] u[2, 3] u[3, 5] u[4, 2] u[5, 6] u[6, 4] + 
 
   u[1, 5] u[2, 2] u[3, 1] u[4, 3] u[5, 6] u[6, 4] + 
 
   u[1, 2] u[2, 5] u[3, 1] u[4, 3] u[5, 6] u[6, 4] + 
 
   u[1, 5] u[2, 1] u[3, 2] u[4, 3] u[5, 6] u[6, 4] + 
 
   u[1, 1] u[2, 5] u[3, 2] u[4, 3] u[5, 6] u[6, 4] + 
 
   u[1, 2] u[2, 1] u[3, 5] u[4, 3] u[5, 6] u[6, 4] + 
 
   u[1, 1] u[2, 2] u[3, 5] u[4, 3] u[5, 6] u[6, 4] + 
 
   u[1, 3] u[2, 2] u[3, 1] u[4, 5] u[5, 6] u[6, 4] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 5] u[5, 6] u[6, 4] + 
 
   u[1, 3] u[2, 1] u[3, 2] u[4, 5] u[5, 6] u[6, 4] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 5] u[5, 6] u[6, 4] + 
 
   u[1, 2] u[2, 1] u[3, 3] u[4, 5] u[5, 6] u[6, 4] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 5] u[5, 6] u[6, 4] + 
 
   u[1, 6] u[2, 4] u[3, 3] u[4, 2] u[5, 1] u[6, 5] + 
 
   u[1, 4] u[2, 6] u[3, 3] u[4, 2] u[5, 1] u[6, 5] + 
 
   u[1, 6] u[2, 3] u[3, 4] u[4, 2] u[5, 1] u[6, 5] + 
 
   u[1, 3] u[2, 6] u[3, 4] u[4, 2] u[5, 1] u[6, 5] + 
 
   u[1, 4] u[2, 3] u[3, 6] u[4, 2] u[5, 1] u[6, 5] + 
 
   u[1, 3] u[2, 4] u[3, 6] u[4, 2] u[5, 1] u[6, 5] + 
 
   u[1, 6] u[2, 4] u[3, 2] u[4, 3] u[5, 1] u[6, 5] + 
 
   u[1, 4] u[2, 6] u[3, 2] u[4, 3] u[5, 1] u[6, 5] + 
 
   u[1, 6] u[2, 2] u[3, 4] u[4, 3] u[5, 1] u[6, 5] + 
 
   u[1, 2] u[2, 6] u[3, 4] u[4, 3] u[5, 1] u[6, 5] + 
 
   u[1, 4] u[2, 2] u[3, 6] u[4, 3] u[5, 1] u[6, 5] + 
 
   u[1, 2] u[2, 4] u[3, 6] u[4, 3] u[5, 1] u[6, 5] + 
 
   u[1, 6] u[2, 3] u[3, 2] u[4, 4] u[5, 1] u[6, 5] + 
 
   u[1, 3] u[2, 6] u[3, 2] u[4, 4] u[5, 1] u[6, 5] + 
 
   u[1, 6] u[2, 2] u[3, 3] u[4, 4] u[5, 1] u[6, 5] + 
 
   u[1, 2] u[2, 6] u[3, 3] u[4, 4] u[5, 1] u[6, 5] + 
 
   u[1, 3] u[2, 2] u[3, 6] u[4, 4] u[5, 1] u[6, 5] + 
 
   u[1, 2] u[2, 3] u[3, 6] u[4, 4] u[5, 1] u[6, 5] + 
 
   u[1, 4] u[2, 3] u[3, 2] u[4, 6] u[5, 1] u[6, 5] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 6] u[5, 1] u[6, 5] + 
 
   u[1, 4] u[2, 2] u[3, 3] u[4, 6] u[5, 1] u[6, 5] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 6] u[5, 1] u[6, 5] + 
 
   u[1, 3] u[2, 2] u[3, 4] u[4, 6] u[5, 1] u[6, 5] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 6] u[5, 1] u[6, 5] + 
 
   u[1, 6] u[2, 4] u[3, 3] u[4, 1] u[5, 2] u[6, 5] + 
 
   u[1, 4] u[2, 6] u[3, 3] u[4, 1] u[5, 2] u[6, 5] + 
 
   u[1, 6] u[2, 3] u[3, 4] u[4, 1] u[5, 2] u[6, 5] + 
 
   u[1, 3] u[2, 6] u[3, 4] u[4, 1] u[5, 2] u[6, 5] + 
 
   u[1, 4] u[2, 3] u[3, 6] u[4, 1] u[5, 2] u[6, 5] + 
 
   u[1, 3] u[2, 4] u[3, 6] u[4, 1] u[5, 2] u[6, 5] + 
 
   u[1, 6] u[2, 4] u[3, 1] u[4, 3] u[5, 2] u[6, 5] + 
 
   u[1, 4] u[2, 6] u[3, 1] u[4, 3] u[5, 2] u[6, 5] + 
 
   u[1, 6] u[2, 1] u[3, 4] u[4, 3] u[5, 2] u[6, 5] + 
 
   u[1, 1] u[2, 6] u[3, 4] u[4, 3] u[5, 2] u[6, 5] + 
 
   u[1, 4] u[2, 1] u[3, 6] u[4, 3] u[5, 2] u[6, 5] + 
 
   u[1, 1] u[2, 4] u[3, 6] u[4, 3] u[5, 2] u[6, 5] + 
 
   u[1, 6] u[2, 3] u[3, 1] u[4, 4] u[5, 2] u[6, 5] + 
 
   u[1, 3] u[2, 6] u[3, 1] u[4, 4] u[5, 2] u[6, 5] + 
 
   u[1, 6] u[2, 1] u[3, 3] u[4, 4] u[5, 2] u[6, 5] + 
 
   u[1, 1] u[2, 6] u[3, 3] u[4, 4] u[5, 2] u[6, 5] + 
 
   u[1, 3] u[2, 1] u[3, 6] u[4, 4] u[5, 2] u[6, 5] + 
 
   u[1, 1] u[2, 3] u[3, 6] u[4, 4] u[5, 2] u[6, 5] + 
 
   u[1, 4] u[2, 3] u[3, 1] u[4, 6] u[5, 2] u[6, 5] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 6] u[5, 2] u[6, 5] + 
 
   u[1, 4] u[2, 1] u[3, 3] u[4, 6] u[5, 2] u[6, 5] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 6] u[5, 2] u[6, 5] + 
 
   u[1, 3] u[2, 1] u[3, 4] u[4, 6] u[5, 2] u[6, 5] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 6] u[5, 2] u[6, 5] + 
 
   u[1, 6] u[2, 4] u[3, 2] u[4, 1] u[5, 3] u[6, 5] + 
 
   u[1, 4] u[2, 6] u[3, 2] u[4, 1] u[5, 3] u[6, 5] + 
 
   u[1, 6] u[2, 2] u[3, 4] u[4, 1] u[5, 3] u[6, 5] + 
 
   u[1, 2] u[2, 6] u[3, 4] u[4, 1] u[5, 3] u[6, 5] + 
 
   u[1, 4] u[2, 2] u[3, 6] u[4, 1] u[5, 3] u[6, 5] + 
 
   u[1, 2] u[2, 4] u[3, 6] u[4, 1] u[5, 3] u[6, 5] + 
 
   u[1, 6] u[2, 4] u[3, 1] u[4, 2] u[5, 3] u[6, 5] + 
 
   u[1, 4] u[2, 6] u[3, 1] u[4, 2] u[5, 3] u[6, 5] + 
 
   u[1, 6] u[2, 1] u[3, 4] u[4, 2] u[5, 3] u[6, 5] + 
 
   u[1, 1] u[2, 6] u[3, 4] u[4, 2] u[5, 3] u[6, 5] + 
 
   u[1, 4] u[2, 1] u[3, 6] u[4, 2] u[5, 3] u[6, 5] + 
 
   u[1, 1] u[2, 4] u[3, 6] u[4, 2] u[5, 3] u[6, 5] + 
 
   u[1, 6] u[2, 2] u[3, 1] u[4, 4] u[5, 3] u[6, 5] + 
 
   u[1, 2] u[2, 6] u[3, 1] u[4, 4] u[5, 3] u[6, 5] + 
 
   u[1, 6] u[2, 1] u[3, 2] u[4, 4] u[5, 3] u[6, 5] + 
 
   u[1, 1] u[2, 6] u[3, 2] u[4, 4] u[5, 3] u[6, 5] + 
 
   u[1, 2] u[2, 1] u[3, 6] u[4, 4] u[5, 3] u[6, 5] + 
 
   u[1, 1] u[2, 2] u[3, 6] u[4, 4] u[5, 3] u[6, 5] + 
 
   u[1, 4] u[2, 2] u[3, 1] u[4, 6] u[5, 3] u[6, 5] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 6] u[5, 3] u[6, 5] + 
 
   u[1, 4] u[2, 1] u[3, 2] u[4, 6] u[5, 3] u[6, 5] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 6] u[5, 3] u[6, 5] + 
 
   u[1, 2] u[2, 1] u[3, 4] u[4, 6] u[5, 3] u[6, 5] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 6] u[5, 3] u[6, 5] + 
 
   u[1, 6] u[2, 3] u[3, 2] u[4, 1] u[5, 4] u[6, 5] + 
 
   u[1, 3] u[2, 6] u[3, 2] u[4, 1] u[5, 4] u[6, 5] + 
 
   u[1, 6] u[2, 2] u[3, 3] u[4, 1] u[5, 4] u[6, 5] + 
 
   u[1, 2] u[2, 6] u[3, 3] u[4, 1] u[5, 4] u[6, 5] + 
 
   u[1, 3] u[2, 2] u[3, 6] u[4, 1] u[5, 4] u[6, 5] + 
 
   u[1, 2] u[2, 3] u[3, 6] u[4, 1] u[5, 4] u[6, 5] + 
 
   u[1, 6] u[2, 3] u[3, 1] u[4, 2] u[5, 4] u[6, 5] + 
 
   u[1, 3] u[2, 6] u[3, 1] u[4, 2] u[5, 4] u[6, 5] + 
 
   u[1, 6] u[2, 1] u[3, 3] u[4, 2] u[5, 4] u[6, 5] + 
 
   u[1, 1] u[2, 6] u[3, 3] u[4, 2] u[5, 4] u[6, 5] + 
 
   u[1, 3] u[2, 1] u[3, 6] u[4, 2] u[5, 4] u[6, 5] + 
 
   u[1, 1] u[2, 3] u[3, 6] u[4, 2] u[5, 4] u[6, 5] + 
 
   u[1, 6] u[2, 2] u[3, 1] u[4, 3] u[5, 4] u[6, 5] + 
 
   u[1, 2] u[2, 6] u[3, 1] u[4, 3] u[5, 4] u[6, 5] + 
 
   u[1, 6] u[2, 1] u[3, 2] u[4, 3] u[5, 4] u[6, 5] + 
 
   u[1, 1] u[2, 6] u[3, 2] u[4, 3] u[5, 4] u[6, 5] + 
 
   u[1, 2] u[2, 1] u[3, 6] u[4, 3] u[5, 4] u[6, 5] + 
 
   u[1, 1] u[2, 2] u[3, 6] u[4, 3] u[5, 4] u[6, 5] + 
 
   u[1, 3] u[2, 2] u[3, 1] u[4, 6] u[5, 4] u[6, 5] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 6] u[5, 4] u[6, 5] + 
 
   u[1, 3] u[2, 1] u[3, 2] u[4, 6] u[5, 4] u[6, 5] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 6] u[5, 4] u[6, 5] + 
 
   u[1, 2] u[2, 1] u[3, 3] u[4, 6] u[5, 4] u[6, 5] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 6] u[5, 4] u[6, 5] + 
 
   u[1, 4] u[2, 3] u[3, 2] u[4, 1] u[5, 6] u[6, 5] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 1] u[5, 6] u[6, 5] + 
 
   u[1, 4] u[2, 2] u[3, 3] u[4, 1] u[5, 6] u[6, 5] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 1] u[5, 6] u[6, 5] + 
 
   u[1, 3] u[2, 2] u[3, 4] u[4, 1] u[5, 6] u[6, 5] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 1] u[5, 6] u[6, 5] + 
 
   u[1, 4] u[2, 3] u[3, 1] u[4, 2] u[5, 6] u[6, 5] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 2] u[5, 6] u[6, 5] + 
 
   u[1, 4] u[2, 1] u[3, 3] u[4, 2] u[5, 6] u[6, 5] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 2] u[5, 6] u[6, 5] + 
 
   u[1, 3] u[2, 1] u[3, 4] u[4, 2] u[5, 6] u[6, 5] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 2] u[5, 6] u[6, 5] + 
 
   u[1, 4] u[2, 2] u[3, 1] u[4, 3] u[5, 6] u[6, 5] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 3] u[5, 6] u[6, 5] + 
 
   u[1, 4] u[2, 1] u[3, 2] u[4, 3] u[5, 6] u[6, 5] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 3] u[5, 6] u[6, 5] + 
 
   u[1, 2] u[2, 1] u[3, 4] u[4, 3] u[5, 6] u[6, 5] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 3] u[5, 6] u[6, 5] + 
 
   u[1, 3] u[2, 2] u[3, 1] u[4, 4] u[5, 6] u[6, 5] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 4] u[5, 6] u[6, 5] + 
 
   u[1, 3] u[2, 1] u[3, 2] u[4, 4] u[5, 6] u[6, 5] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 4] u[5, 6] u[6, 5] + 
 
   u[1, 2] u[2, 1] u[3, 3] u[4, 4] u[5, 6] u[6, 5] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 4] u[5, 6] u[6, 5] + 
 
   u[1, 5] u[2, 4] u[3, 3] u[4, 2] u[5, 1] u[6, 6] + 
 
   u[1, 4] u[2, 5] u[3, 3] u[4, 2] u[5, 1] u[6, 6] + 
 
   u[1, 5] u[2, 3] u[3, 4] u[4, 2] u[5, 1] u[6, 6] + 
 
   u[1, 3] u[2, 5] u[3, 4] u[4, 2] u[5, 1] u[6, 6] + 
 
   u[1, 4] u[2, 3] u[3, 5] u[4, 2] u[5, 1] u[6, 6] + 
 
   u[1, 3] u[2, 4] u[3, 5] u[4, 2] u[5, 1] u[6, 6] + 
 
   u[1, 5] u[2, 4] u[3, 2] u[4, 3] u[5, 1] u[6, 6] + 
 
   u[1, 4] u[2, 5] u[3, 2] u[4, 3] u[5, 1] u[6, 6] + 
 
   u[1, 5] u[2, 2] u[3, 4] u[4, 3] u[5, 1] u[6, 6] + 
 
   u[1, 2] u[2, 5] u[3, 4] u[4, 3] u[5, 1] u[6, 6] + 
 
   u[1, 4] u[2, 2] u[3, 5] u[4, 3] u[5, 1] u[6, 6] + 
 
   u[1, 2] u[2, 4] u[3, 5] u[4, 3] u[5, 1] u[6, 6] + 
 
   u[1, 5] u[2, 3] u[3, 2] u[4, 4] u[5, 1] u[6, 6] + 
 
   u[1, 3] u[2, 5] u[3, 2] u[4, 4] u[5, 1] u[6, 6] + 
 
   u[1, 5] u[2, 2] u[3, 3] u[4, 4] u[5, 1] u[6, 6] + 
 
   u[1, 2] u[2, 5] u[3, 3] u[4, 4] u[5, 1] u[6, 6] + 
 
   u[1, 3] u[2, 2] u[3, 5] u[4, 4] u[5, 1] u[6, 6] + 
 
   u[1, 2] u[2, 3] u[3, 5] u[4, 4] u[5, 1] u[6, 6] + 
 
   u[1, 4] u[2, 3] u[3, 2] u[4, 5] u[5, 1] u[6, 6] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 5] u[5, 1] u[6, 6] + 
 
   u[1, 4] u[2, 2] u[3, 3] u[4, 5] u[5, 1] u[6, 6] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 5] u[5, 1] u[6, 6] + 
 
   u[1, 3] u[2, 2] u[3, 4] u[4, 5] u[5, 1] u[6, 6] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 5] u[5, 1] u[6, 6] + 
 
   u[1, 5] u[2, 4] u[3, 3] u[4, 1] u[5, 2] u[6, 6] + 
 
   u[1, 4] u[2, 5] u[3, 3] u[4, 1] u[5, 2] u[6, 6] + 
 
   u[1, 5] u[2, 3] u[3, 4] u[4, 1] u[5, 2] u[6, 6] + 
 
   u[1, 3] u[2, 5] u[3, 4] u[4, 1] u[5, 2] u[6, 6] + 
 
   u[1, 4] u[2, 3] u[3, 5] u[4, 1] u[5, 2] u[6, 6] + 
 
   u[1, 3] u[2, 4] u[3, 5] u[4, 1] u[5, 2] u[6, 6] + 
 
   u[1, 5] u[2, 4] u[3, 1] u[4, 3] u[5, 2] u[6, 6] + 
 
   u[1, 4] u[2, 5] u[3, 1] u[4, 3] u[5, 2] u[6, 6] + 
 
   u[1, 5] u[2, 1] u[3, 4] u[4, 3] u[5, 2] u[6, 6] + 
 
   u[1, 1] u[2, 5] u[3, 4] u[4, 3] u[5, 2] u[6, 6] + 
 
   u[1, 4] u[2, 1] u[3, 5] u[4, 3] u[5, 2] u[6, 6] + 
 
   u[1, 1] u[2, 4] u[3, 5] u[4, 3] u[5, 2] u[6, 6] + 
 
   u[1, 5] u[2, 3] u[3, 1] u[4, 4] u[5, 2] u[6, 6] + 
 
   u[1, 3] u[2, 5] u[3, 1] u[4, 4] u[5, 2] u[6, 6] + 
 
   u[1, 5] u[2, 1] u[3, 3] u[4, 4] u[5, 2] u[6, 6] + 
 
   u[1, 1] u[2, 5] u[3, 3] u[4, 4] u[5, 2] u[6, 6] + 
 
   u[1, 3] u[2, 1] u[3, 5] u[4, 4] u[5, 2] u[6, 6] + 
 
   u[1, 1] u[2, 3] u[3, 5] u[4, 4] u[5, 2] u[6, 6] + 
 
   u[1, 4] u[2, 3] u[3, 1] u[4, 5] u[5, 2] u[6, 6] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 5] u[5, 2] u[6, 6] + 
 
   u[1, 4] u[2, 1] u[3, 3] u[4, 5] u[5, 2] u[6, 6] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 5] u[5, 2] u[6, 6] + 
 
   u[1, 3] u[2, 1] u[3, 4] u[4, 5] u[5, 2] u[6, 6] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 5] u[5, 2] u[6, 6] + 
 
   u[1, 5] u[2, 4] u[3, 2] u[4, 1] u[5, 3] u[6, 6] + 
 
   u[1, 4] u[2, 5] u[3, 2] u[4, 1] u[5, 3] u[6, 6] + 
 
   u[1, 5] u[2, 2] u[3, 4] u[4, 1] u[5, 3] u[6, 6] + 
 
   u[1, 2] u[2, 5] u[3, 4] u[4, 1] u[5, 3] u[6, 6] + 
 
   u[1, 4] u[2, 2] u[3, 5] u[4, 1] u[5, 3] u[6, 6] + 
 
   u[1, 2] u[2, 4] u[3, 5] u[4, 1] u[5, 3] u[6, 6] + 
 
   u[1, 5] u[2, 4] u[3, 1] u[4, 2] u[5, 3] u[6, 6] + 
 
   u[1, 4] u[2, 5] u[3, 1] u[4, 2] u[5, 3] u[6, 6] + 
 
   u[1, 5] u[2, 1] u[3, 4] u[4, 2] u[5, 3] u[6, 6] + 
 
   u[1, 1] u[2, 5] u[3, 4] u[4, 2] u[5, 3] u[6, 6] + 
 
   u[1, 4] u[2, 1] u[3, 5] u[4, 2] u[5, 3] u[6, 6] + 
 
   u[1, 1] u[2, 4] u[3, 5] u[4, 2] u[5, 3] u[6, 6] + 
 
   u[1, 5] u[2, 2] u[3, 1] u[4, 4] u[5, 3] u[6, 6] + 
 
   u[1, 2] u[2, 5] u[3, 1] u[4, 4] u[5, 3] u[6, 6] + 
 
   u[1, 5] u[2, 1] u[3, 2] u[4, 4] u[5, 3] u[6, 6] + 
 
   u[1, 1] u[2, 5] u[3, 2] u[4, 4] u[5, 3] u[6, 6] + 
 
   u[1, 2] u[2, 1] u[3, 5] u[4, 4] u[5, 3] u[6, 6] + 
 
   u[1, 1] u[2, 2] u[3, 5] u[4, 4] u[5, 3] u[6, 6] + 
 
   u[1, 4] u[2, 2] u[3, 1] u[4, 5] u[5, 3] u[6, 6] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 5] u[5, 3] u[6, 6] + 
 
   u[1, 4] u[2, 1] u[3, 2] u[4, 5] u[5, 3] u[6, 6] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 5] u[5, 3] u[6, 6] + 
 
   u[1, 2] u[2, 1] u[3, 4] u[4, 5] u[5, 3] u[6, 6] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 5] u[5, 3] u[6, 6] + 
 
   u[1, 5] u[2, 3] u[3, 2] u[4, 1] u[5, 4] u[6, 6] + 
 
   u[1, 3] u[2, 5] u[3, 2] u[4, 1] u[5, 4] u[6, 6] + 
 
   u[1, 5] u[2, 2] u[3, 3] u[4, 1] u[5, 4] u[6, 6] + 
 
   u[1, 2] u[2, 5] u[3, 3] u[4, 1] u[5, 4] u[6, 6] + 
 
   u[1, 3] u[2, 2] u[3, 5] u[4, 1] u[5, 4] u[6, 6] + 
 
   u[1, 2] u[2, 3] u[3, 5] u[4, 1] u[5, 4] u[6, 6] + 
 
   u[1, 5] u[2, 3] u[3, 1] u[4, 2] u[5, 4] u[6, 6] + 
 
   u[1, 3] u[2, 5] u[3, 1] u[4, 2] u[5, 4] u[6, 6] + 
 
   u[1, 5] u[2, 1] u[3, 3] u[4, 2] u[5, 4] u[6, 6] + 
 
   u[1, 1] u[2, 5] u[3, 3] u[4, 2] u[5, 4] u[6, 6] + 
 
   u[1, 3] u[2, 1] u[3, 5] u[4, 2] u[5, 4] u[6, 6] + 
 
   u[1, 1] u[2, 3] u[3, 5] u[4, 2] u[5, 4] u[6, 6] + 
 
   u[1, 5] u[2, 2] u[3, 1] u[4, 3] u[5, 4] u[6, 6] + 
 
   u[1, 2] u[2, 5] u[3, 1] u[4, 3] u[5, 4] u[6, 6] + 
 
   u[1, 5] u[2, 1] u[3, 2] u[4, 3] u[5, 4] u[6, 6] + 
 
   u[1, 1] u[2, 5] u[3, 2] u[4, 3] u[5, 4] u[6, 6] + 
 
   u[1, 2] u[2, 1] u[3, 5] u[4, 3] u[5, 4] u[6, 6] + 
 
   u[1, 1] u[2, 2] u[3, 5] u[4, 3] u[5, 4] u[6, 6] + 
 
   u[1, 3] u[2, 2] u[3, 1] u[4, 5] u[5, 4] u[6, 6] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 5] u[5, 4] u[6, 6] + 
 
   u[1, 3] u[2, 1] u[3, 2] u[4, 5] u[5, 4] u[6, 6] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 5] u[5, 4] u[6, 6] + 
 
   u[1, 2] u[2, 1] u[3, 3] u[4, 5] u[5, 4] u[6, 6] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 5] u[5, 4] u[6, 6] + 
 
   u[1, 4] u[2, 3] u[3, 2] u[4, 1] u[5, 5] u[6, 6] + 
 
   u[1, 3] u[2, 4] u[3, 2] u[4, 1] u[5, 5] u[6, 6] + 
 
   u[1, 4] u[2, 2] u[3, 3] u[4, 1] u[5, 5] u[6, 6] + 
 
   u[1, 2] u[2, 4] u[3, 3] u[4, 1] u[5, 5] u[6, 6] + 
 
   u[1, 3] u[2, 2] u[3, 4] u[4, 1] u[5, 5] u[6, 6] + 
 
   u[1, 2] u[2, 3] u[3, 4] u[4, 1] u[5, 5] u[6, 6] + 
 
   u[1, 4] u[2, 3] u[3, 1] u[4, 2] u[5, 5] u[6, 6] + 
 
   u[1, 3] u[2, 4] u[3, 1] u[4, 2] u[5, 5] u[6, 6] + 
 
   u[1, 4] u[2, 1] u[3, 3] u[4, 2] u[5, 5] u[6, 6] + 
 
   u[1, 1] u[2, 4] u[3, 3] u[4, 2] u[5, 5] u[6, 6] + 
 
   u[1, 3] u[2, 1] u[3, 4] u[4, 2] u[5, 5] u[6, 6] + 
 
   u[1, 1] u[2, 3] u[3, 4] u[4, 2] u[5, 5] u[6, 6] + 
 
   u[1, 4] u[2, 2] u[3, 1] u[4, 3] u[5, 5] u[6, 6] + 
 
   u[1, 2] u[2, 4] u[3, 1] u[4, 3] u[5, 5] u[6, 6] + 
 
   u[1, 4] u[2, 1] u[3, 2] u[4, 3] u[5, 5] u[6, 6] + 
 
   u[1, 1] u[2, 4] u[3, 2] u[4, 3] u[5, 5] u[6, 6] + 
 
   u[1, 2] u[2, 1] u[3, 4] u[4, 3] u[5, 5] u[6, 6] + 
 
   u[1, 1] u[2, 2] u[3, 4] u[4, 3] u[5, 5] u[6, 6] + 
 
   u[1, 3] u[2, 2] u[3, 1] u[4, 4] u[5, 5] u[6, 6] + 
 
   u[1, 2] u[2, 3] u[3, 1] u[4, 4] u[5, 5] u[6, 6] + 
 
   u[1, 3] u[2, 1] u[3, 2] u[4, 4] u[5, 5] u[6, 6] + 
 
   u[1, 1] u[2, 3] u[3, 2] u[4, 4] u[5, 5] u[6, 6] + 
 
   u[1, 2] u[2, 1] u[3, 3] u[4, 4] u[5, 5] u[6, 6] + 
 
   u[1, 1] u[2, 2] u[3, 3] u[4, 4] u[5, 5] u[6, 6]}\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "The calculation of Permanent1 for a (7\[Times]7)-array leads to problems \
concerning memory. Handle the next two steps carfully.\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " changed into the swapp mode with very many accesses to the hard disk. \
After a time of 10 minutes we stopped the calculation."
}], "Text"],

Cell[CellGroupData[{

Cell["A = Array[u,{7,7}]", "Input"],

Cell[OutputFormData["\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5], u[1, 6], u[1, 7]}, 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5], u[2, 6], u[2, 7]}, 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5], u[3, 6], u[3, 7]}, 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5], u[4, 6], u[4, 7]}, 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5], u[5, 6], u[5, 7]}, 
  {u[6, 1], u[6, 2], u[6, 3], u[6, 4], u[6, 5], u[6, 6], u[6, 7]}, 
  {u[7, 1], u[7, 2], u[7, 3], u[7, 4], u[7, 5], u[7, 6], u[7, 7]}}\
\>", "\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5], u[1, 6], u[1, 7]}, 
 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5], u[2, 6], u[2, 7]}, 
 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5], u[3, 6], u[3, 7]}, 
 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5], u[4, 6], u[4, 7]}, 
 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5], u[5, 6], u[5, 7]}, 
 
  {u[6, 1], u[6, 2], u[6, 3], u[6, 4], u[6, 5], u[6, 6], u[6, 7]}, 
 
  {u[7, 1], u[7, 2], u[7, 3], u[7, 4], u[7, 5], u[7, 6], u[7, 7]}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Permanent1[A];]", "Input"],

Cell[OutputFormData["\<\
$Aborted\
\>", "\<\
$Aborted\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MemoryInUse[]", "Input"],

Cell[OutputFormData["\<\
941112\
\>", "\<\
941112\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaxMemoryUsed[]", "Input"],

Cell[OutputFormData["\<\
61190544\
\>", "\<\
61190544\
\>"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The procedure Permanent", "Subsection"],

Cell["\<\
The following procedure Permanent is the best procedure for calculating \
permanents given in the book of Vardi [1]. However, further improvements of \
this procedure are necessary since this procedure leads to memory problems, \
too.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The definition of GrayInsert and Permanent", "Subsubsection"],

Cell["\<\
GrayInsert[k_] :=
Module[{q = k , j = 1},
      While[EvenQ[q],
           q = q/2;
           j = j + 1
           ];
      {j, (-1)^((q-1)/2)}
      ]\
\>", "Input"],

Cell["\<\
Permanent[a_List] :=
With[{n = Length[a]},
    (* do *)
    Module[{rowsum = Table[0,{n}], sum = 0, i},
          Do[
            With[{gi = GrayInsert[i]},
                (* do *)
                rowsum = rowsum + gi[[2]] a[[ gi[[1]] ]];
                sum = sum + (-1)^i (Times @@ rowsum);
                ],
            {i, 1, 2^n - 1}
            ]; (* End Do *)
          (-1)^n sum
          ] (* End Module *)
    ] (* End With *)\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Test of the procedure Permanent", "Subsubsection"],

Cell["\<\
Before you carry out the following examples, you have to evaluate the \
definitions of the subsections \"The definition of GrayInsert and \
Permanent\".\
\>", "Text"],

Cell[CellGroupData[{

Cell["A = Array[u,{6,6}]", "Input"],

Cell[OutputFormData["\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5], u[1, 6]}, 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5], u[2, 6]}, 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5], u[3, 6]}, 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5], u[4, 6]}, 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5], u[5, 6]}, 
  {u[6, 1], u[6, 2], u[6, 3], u[6, 4], u[6, 5], u[6, 6]}}\
\>", "\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5], u[1, 6]}, 
 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5], u[2, 6]}, 
 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5], u[3, 6]}, 
 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5], u[4, 6]}, 
 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5], u[5, 6]}, 
 
  {u[6, 1], u[6, 2], u[6, 3], u[6, 4], u[6, 5], u[6, 6]}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["perm = Permanent[A]", "Input"],

Cell[OutputFormData["\<\
-(u[1, 1]*u[1, 2]*u[1, 3]*u[1, 4]*u[1, 5]*u[1, 6]) - 
  u[2, 1]*u[2, 2]*u[2, 3]*u[2, 4]*u[2, 5]*u[2, 6] + 
  (u[1, 1] + u[2, 1])*(u[1, 2] + u[2, 2])*(u[1, 3] + u[2, 3])*
   (u[1, 4] + u[2, 4])*(u[1, 5] + u[2, 5])*(u[1, 6] + u[2, 6]) - 
  u[3, 1]*u[3, 2]*u[3, 3]*u[3, 4]*u[3, 5]*u[3, 6] + 
  (u[1, 1] + u[3, 1])*(u[1, 2] + u[3, 2])*(u[1, 3] + u[3, 3])*
   (u[1, 4] + u[3, 4])*(u[1, 5] + u[3, 5])*(u[1, 6] + u[3, 6]) + 
  (u[2, 1] + u[3, 1])*(u[2, 2] + u[3, 2])*(u[2, 3] + u[3, 3])*
   (u[2, 4] + u[3, 4])*(u[2, 5] + u[3, 5])*(u[2, 6] + u[3, 6]) - 
  (u[1, 1] + u[2, 1] + u[3, 1])*(u[1, 2] + u[2, 2] + u[3, 2])*
   (u[1, 3] + u[2, 3] + u[3, 3])*(u[1, 4] + u[2, 4] + u[3, 4])*
   (u[1, 5] + u[2, 5] + u[3, 5])*(u[1, 6] + u[2, 6] + u[3, 6]) - 
  u[4, 1]*u[4, 2]*u[4, 3]*u[4, 4]*u[4, 5]*u[4, 6] + 
  (u[1, 1] + u[4, 1])*(u[1, 2] + u[4, 2])*(u[1, 3] + u[4, 3])*
   (u[1, 4] + u[4, 4])*(u[1, 5] + u[4, 5])*(u[1, 6] + u[4, 6]) + 
  (u[2, 1] + u[4, 1])*(u[2, 2] + u[4, 2])*(u[2, 3] + u[4, 3])*
   (u[2, 4] + u[4, 4])*(u[2, 5] + u[4, 5])*(u[2, 6] + u[4, 6]) - 
  (u[1, 1] + u[2, 1] + u[4, 1])*(u[1, 2] + u[2, 2] + u[4, 2])*
   (u[1, 3] + u[2, 3] + u[4, 3])*(u[1, 4] + u[2, 4] + u[4, 4])*
   (u[1, 5] + u[2, 5] + u[4, 5])*(u[1, 6] + u[2, 6] + u[4, 6]) + 
  (u[3, 1] + u[4, 1])*(u[3, 2] + u[4, 2])*(u[3, 3] + u[4, 3])*
   (u[3, 4] + u[4, 4])*(u[3, 5] + u[4, 5])*(u[3, 6] + u[4, 6]) - 
  (u[1, 1] + u[3, 1] + u[4, 1])*(u[1, 2] + u[3, 2] + u[4, 2])*
   (u[1, 3] + u[3, 3] + u[4, 3])*(u[1, 4] + u[3, 4] + u[4, 4])*
   (u[1, 5] + u[3, 5] + u[4, 5])*(u[1, 6] + u[3, 6] + u[4, 6]) - 
  (u[2, 1] + u[3, 1] + u[4, 1])*(u[2, 2] + u[3, 2] + u[4, 2])*
   (u[2, 3] + u[3, 3] + u[4, 3])*(u[2, 4] + u[3, 4] + u[4, 4])*
   (u[2, 5] + u[3, 5] + u[4, 5])*(u[2, 6] + u[3, 6] + u[4, 6]) + 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[4, 1])*
   (u[1, 2] + u[2, 2] + u[3, 2] + u[4, 2])*
   (u[1, 3] + u[2, 3] + u[3, 3] + u[4, 3])*
   (u[1, 4] + u[2, 4] + u[3, 4] + u[4, 4])*
   (u[1, 5] + u[2, 5] + u[3, 5] + u[4, 5])*
   (u[1, 6] + u[2, 6] + u[3, 6] + u[4, 6]) - 
  u[5, 1]*u[5, 2]*u[5, 3]*u[5, 4]*u[5, 5]*u[5, 6] + 
  (u[1, 1] + u[5, 1])*(u[1, 2] + u[5, 2])*(u[1, 3] + u[5, 3])*
   (u[1, 4] + u[5, 4])*(u[1, 5] + u[5, 5])*(u[1, 6] + u[5, 6]) + 
  (u[2, 1] + u[5, 1])*(u[2, 2] + u[5, 2])*(u[2, 3] + u[5, 3])*
   (u[2, 4] + u[5, 4])*(u[2, 5] + u[5, 5])*(u[2, 6] + u[5, 6]) - 
  (u[1, 1] + u[2, 1] + u[5, 1])*(u[1, 2] + u[2, 2] + u[5, 2])*
   (u[1, 3] + u[2, 3] + u[5, 3])*(u[1, 4] + u[2, 4] + u[5, 4])*
   (u[1, 5] + u[2, 5] + u[5, 5])*(u[1, 6] + u[2, 6] + u[5, 6]) + 
  (u[3, 1] + u[5, 1])*(u[3, 2] + u[5, 2])*(u[3, 3] + u[5, 3])*
   (u[3, 4] + u[5, 4])*(u[3, 5] + u[5, 5])*(u[3, 6] + u[5, 6]) - 
  (u[1, 1] + u[3, 1] + u[5, 1])*(u[1, 2] + u[3, 2] + u[5, 2])*
   (u[1, 3] + u[3, 3] + u[5, 3])*(u[1, 4] + u[3, 4] + u[5, 4])*
   (u[1, 5] + u[3, 5] + u[5, 5])*(u[1, 6] + u[3, 6] + u[5, 6]) - 
  (u[2, 1] + u[3, 1] + u[5, 1])*(u[2, 2] + u[3, 2] + u[5, 2])*
   (u[2, 3] + u[3, 3] + u[5, 3])*(u[2, 4] + u[3, 4] + u[5, 4])*
   (u[2, 5] + u[3, 5] + u[5, 5])*(u[2, 6] + u[3, 6] + u[5, 6]) + 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[5, 1])*
   (u[1, 2] + u[2, 2] + u[3, 2] + u[5, 2])*
   (u[1, 3] + u[2, 3] + u[3, 3] + u[5, 3])*
   (u[1, 4] + u[2, 4] + u[3, 4] + u[5, 4])*
   (u[1, 5] + u[2, 5] + u[3, 5] + u[5, 5])*
   (u[1, 6] + u[2, 6] + u[3, 6] + u[5, 6]) + 
  (u[4, 1] + u[5, 1])*(u[4, 2] + u[5, 2])*(u[4, 3] + u[5, 3])*
   (u[4, 4] + u[5, 4])*(u[4, 5] + u[5, 5])*(u[4, 6] + u[5, 6]) - 
  (u[1, 1] + u[4, 1] + u[5, 1])*(u[1, 2] + u[4, 2] + u[5, 2])*
   (u[1, 3] + u[4, 3] + u[5, 3])*(u[1, 4] + u[4, 4] + u[5, 4])*
   (u[1, 5] + u[4, 5] + u[5, 5])*(u[1, 6] + u[4, 6] + u[5, 6]) - 
  (u[2, 1] + u[4, 1] + u[5, 1])*(u[2, 2] + u[4, 2] + u[5, 2])*
   (u[2, 3] + u[4, 3] + u[5, 3])*(u[2, 4] + u[4, 4] + u[5, 4])*
   (u[2, 5] + u[4, 5] + u[5, 5])*(u[2, 6] + u[4, 6] + u[5, 6]) + 
  (u[1, 1] + u[2, 1] + u[4, 1] + u[5, 1])*
   (u[1, 2] + u[2, 2] + u[4, 2] + u[5, 2])*
   (u[1, 3] + u[2, 3] + u[4, 3] + u[5, 3])*
   (u[1, 4] + u[2, 4] + u[4, 4] + u[5, 4])*
   (u[1, 5] + u[2, 5] + u[4, 5] + u[5, 5])*
   (u[1, 6] + u[2, 6] + u[4, 6] + u[5, 6]) - 
  (u[3, 1] + u[4, 1] + u[5, 1])*(u[3, 2] + u[4, 2] + u[5, 2])*
   (u[3, 3] + u[4, 3] + u[5, 3])*(u[3, 4] + u[4, 4] + u[5, 4])*
   (u[3, 5] + u[4, 5] + u[5, 5])*(u[3, 6] + u[4, 6] + u[5, 6]) + 
  (u[1, 1] + u[3, 1] + u[4, 1] + u[5, 1])*
   (u[1, 2] + u[3, 2] + u[4, 2] + u[5, 2])*
   (u[1, 3] + u[3, 3] + u[4, 3] + u[5, 3])*
   (u[1, 4] + u[3, 4] + u[4, 4] + u[5, 4])*
   (u[1, 5] + u[3, 5] + u[4, 5] + u[5, 5])*
   (u[1, 6] + u[3, 6] + u[4, 6] + u[5, 6]) + 
  (u[2, 1] + u[3, 1] + u[4, 1] + u[5, 1])*
   (u[2, 2] + u[3, 2] + u[4, 2] + u[5, 2])*
   (u[2, 3] + u[3, 3] + u[4, 3] + u[5, 3])*
   (u[2, 4] + u[3, 4] + u[4, 4] + u[5, 4])*
   (u[2, 5] + u[3, 5] + u[4, 5] + u[5, 5])*
   (u[2, 6] + u[3, 6] + u[4, 6] + u[5, 6]) - 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[4, 1] + u[5, 1])*
   (u[1, 2] + u[2, 2] + u[3, 2] + u[4, 2] + u[5, 2])*
   (u[1, 3] + u[2, 3] + u[3, 3] + u[4, 3] + u[5, 3])*
   (u[1, 4] + u[2, 4] + u[3, 4] + u[4, 4] + u[5, 4])*
   (u[1, 5] + u[2, 5] + u[3, 5] + u[4, 5] + u[5, 5])*
   (u[1, 6] + u[2, 6] + u[3, 6] + u[4, 6] + u[5, 6]) - 
  u[6, 1]*u[6, 2]*u[6, 3]*u[6, 4]*u[6, 5]*u[6, 6] + 
  (u[1, 1] + u[6, 1])*(u[1, 2] + u[6, 2])*(u[1, 3] + u[6, 3])*
   (u[1, 4] + u[6, 4])*(u[1, 5] + u[6, 5])*(u[1, 6] + u[6, 6]) + 
  (u[2, 1] + u[6, 1])*(u[2, 2] + u[6, 2])*(u[2, 3] + u[6, 3])*
   (u[2, 4] + u[6, 4])*(u[2, 5] + u[6, 5])*(u[2, 6] + u[6, 6]) - 
  (u[1, 1] + u[2, 1] + u[6, 1])*(u[1, 2] + u[2, 2] + u[6, 2])*
   (u[1, 3] + u[2, 3] + u[6, 3])*(u[1, 4] + u[2, 4] + u[6, 4])*
   (u[1, 5] + u[2, 5] + u[6, 5])*(u[1, 6] + u[2, 6] + u[6, 6]) + 
  (u[3, 1] + u[6, 1])*(u[3, 2] + u[6, 2])*(u[3, 3] + u[6, 3])*
   (u[3, 4] + u[6, 4])*(u[3, 5] + u[6, 5])*(u[3, 6] + u[6, 6]) - 
  (u[1, 1] + u[3, 1] + u[6, 1])*(u[1, 2] + u[3, 2] + u[6, 2])*
   (u[1, 3] + u[3, 3] + u[6, 3])*(u[1, 4] + u[3, 4] + u[6, 4])*
   (u[1, 5] + u[3, 5] + u[6, 5])*(u[1, 6] + u[3, 6] + u[6, 6]) - 
  (u[2, 1] + u[3, 1] + u[6, 1])*(u[2, 2] + u[3, 2] + u[6, 2])*
   (u[2, 3] + u[3, 3] + u[6, 3])*(u[2, 4] + u[3, 4] + u[6, 4])*
   (u[2, 5] + u[3, 5] + u[6, 5])*(u[2, 6] + u[3, 6] + u[6, 6]) + 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[6, 1])*
   (u[1, 2] + u[2, 2] + u[3, 2] + u[6, 2])*
   (u[1, 3] + u[2, 3] + u[3, 3] + u[6, 3])*
   (u[1, 4] + u[2, 4] + u[3, 4] + u[6, 4])*
   (u[1, 5] + u[2, 5] + u[3, 5] + u[6, 5])*
   (u[1, 6] + u[2, 6] + u[3, 6] + u[6, 6]) + 
  (u[4, 1] + u[6, 1])*(u[4, 2] + u[6, 2])*(u[4, 3] + u[6, 3])*
   (u[4, 4] + u[6, 4])*(u[4, 5] + u[6, 5])*(u[4, 6] + u[6, 6]) - 
  (u[1, 1] + u[4, 1] + u[6, 1])*(u[1, 2] + u[4, 2] + u[6, 2])*
   (u[1, 3] + u[4, 3] + u[6, 3])*(u[1, 4] + u[4, 4] + u[6, 4])*
   (u[1, 5] + u[4, 5] + u[6, 5])*(u[1, 6] + u[4, 6] + u[6, 6]) - 
  (u[2, 1] + u[4, 1] + u[6, 1])*(u[2, 2] + u[4, 2] + u[6, 2])*
   (u[2, 3] + u[4, 3] + u[6, 3])*(u[2, 4] + u[4, 4] + u[6, 4])*
   (u[2, 5] + u[4, 5] + u[6, 5])*(u[2, 6] + u[4, 6] + u[6, 6]) + 
  (u[1, 1] + u[2, 1] + u[4, 1] + u[6, 1])*
   (u[1, 2] + u[2, 2] + u[4, 2] + u[6, 2])*
   (u[1, 3] + u[2, 3] + u[4, 3] + u[6, 3])*
   (u[1, 4] + u[2, 4] + u[4, 4] + u[6, 4])*
   (u[1, 5] + u[2, 5] + u[4, 5] + u[6, 5])*
   (u[1, 6] + u[2, 6] + u[4, 6] + u[6, 6]) - 
  (u[3, 1] + u[4, 1] + u[6, 1])*(u[3, 2] + u[4, 2] + u[6, 2])*
   (u[3, 3] + u[4, 3] + u[6, 3])*(u[3, 4] + u[4, 4] + u[6, 4])*
   (u[3, 5] + u[4, 5] + u[6, 5])*(u[3, 6] + u[4, 6] + u[6, 6]) + 
  (u[1, 1] + u[3, 1] + u[4, 1] + u[6, 1])*
   (u[1, 2] + u[3, 2] + u[4, 2] + u[6, 2])*
   (u[1, 3] + u[3, 3] + u[4, 3] + u[6, 3])*
   (u[1, 4] + u[3, 4] + u[4, 4] + u[6, 4])*
   (u[1, 5] + u[3, 5] + u[4, 5] + u[6, 5])*
   (u[1, 6] + u[3, 6] + u[4, 6] + u[6, 6]) + 
  (u[2, 1] + u[3, 1] + u[4, 1] + u[6, 1])*
   (u[2, 2] + u[3, 2] + u[4, 2] + u[6, 2])*
   (u[2, 3] + u[3, 3] + u[4, 3] + u[6, 3])*
   (u[2, 4] + u[3, 4] + u[4, 4] + u[6, 4])*
   (u[2, 5] + u[3, 5] + u[4, 5] + u[6, 5])*
   (u[2, 6] + u[3, 6] + u[4, 6] + u[6, 6]) - 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[4, 1] + u[6, 1])*
   (u[1, 2] + u[2, 2] + u[3, 2] + u[4, 2] + u[6, 2])*
   (u[1, 3] + u[2, 3] + u[3, 3] + u[4, 3] + u[6, 3])*
   (u[1, 4] + u[2, 4] + u[3, 4] + u[4, 4] + u[6, 4])*
   (u[1, 5] + u[2, 5] + u[3, 5] + u[4, 5] + u[6, 5])*
   (u[1, 6] + u[2, 6] + u[3, 6] + u[4, 6] + u[6, 6]) + 
  (u[5, 1] + u[6, 1])*(u[5, 2] + u[6, 2])*(u[5, 3] + u[6, 3])*
   (u[5, 4] + u[6, 4])*(u[5, 5] + u[6, 5])*(u[5, 6] + u[6, 6]) - 
  (u[1, 1] + u[5, 1] + u[6, 1])*(u[1, 2] + u[5, 2] + u[6, 2])*
   (u[1, 3] + u[5, 3] + u[6, 3])*(u[1, 4] + u[5, 4] + u[6, 4])*
   (u[1, 5] + u[5, 5] + u[6, 5])*(u[1, 6] + u[5, 6] + u[6, 6]) - 
  (u[2, 1] + u[5, 1] + u[6, 1])*(u[2, 2] + u[5, 2] + u[6, 2])*
   (u[2, 3] + u[5, 3] + u[6, 3])*(u[2, 4] + u[5, 4] + u[6, 4])*
   (u[2, 5] + u[5, 5] + u[6, 5])*(u[2, 6] + u[5, 6] + u[6, 6]) + 
  (u[1, 1] + u[2, 1] + u[5, 1] + u[6, 1])*
   (u[1, 2] + u[2, 2] + u[5, 2] + u[6, 2])*
   (u[1, 3] + u[2, 3] + u[5, 3] + u[6, 3])*
   (u[1, 4] + u[2, 4] + u[5, 4] + u[6, 4])*
   (u[1, 5] + u[2, 5] + u[5, 5] + u[6, 5])*
   (u[1, 6] + u[2, 6] + u[5, 6] + u[6, 6]) - 
  (u[3, 1] + u[5, 1] + u[6, 1])*(u[3, 2] + u[5, 2] + u[6, 2])*
   (u[3, 3] + u[5, 3] + u[6, 3])*(u[3, 4] + u[5, 4] + u[6, 4])*
   (u[3, 5] + u[5, 5] + u[6, 5])*(u[3, 6] + u[5, 6] + u[6, 6]) + 
  (u[1, 1] + u[3, 1] + u[5, 1] + u[6, 1])*
   (u[1, 2] + u[3, 2] + u[5, 2] + u[6, 2])*
   (u[1, 3] + u[3, 3] + u[5, 3] + u[6, 3])*
   (u[1, 4] + u[3, 4] + u[5, 4] + u[6, 4])*
   (u[1, 5] + u[3, 5] + u[5, 5] + u[6, 5])*
   (u[1, 6] + u[3, 6] + u[5, 6] + u[6, 6]) + 
  (u[2, 1] + u[3, 1] + u[5, 1] + u[6, 1])*
   (u[2, 2] + u[3, 2] + u[5, 2] + u[6, 2])*
   (u[2, 3] + u[3, 3] + u[5, 3] + u[6, 3])*
   (u[2, 4] + u[3, 4] + u[5, 4] + u[6, 4])*
   (u[2, 5] + u[3, 5] + u[5, 5] + u[6, 5])*
   (u[2, 6] + u[3, 6] + u[5, 6] + u[6, 6]) - 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[5, 1] + u[6, 1])*
   (u[1, 2] + u[2, 2] + u[3, 2] + u[5, 2] + u[6, 2])*
   (u[1, 3] + u[2, 3] + u[3, 3] + u[5, 3] + u[6, 3])*
   (u[1, 4] + u[2, 4] + u[3, 4] + u[5, 4] + u[6, 4])*
   (u[1, 5] + u[2, 5] + u[3, 5] + u[5, 5] + u[6, 5])*
   (u[1, 6] + u[2, 6] + u[3, 6] + u[5, 6] + u[6, 6]) - 
  (u[4, 1] + u[5, 1] + u[6, 1])*(u[4, 2] + u[5, 2] + u[6, 2])*
   (u[4, 3] + u[5, 3] + u[6, 3])*(u[4, 4] + u[5, 4] + u[6, 4])*
   (u[4, 5] + u[5, 5] + u[6, 5])*(u[4, 6] + u[5, 6] + u[6, 6]) + 
  (u[1, 1] + u[4, 1] + u[5, 1] + u[6, 1])*
   (u[1, 2] + u[4, 2] + u[5, 2] + u[6, 2])*
   (u[1, 3] + u[4, 3] + u[5, 3] + u[6, 3])*
   (u[1, 4] + u[4, 4] + u[5, 4] + u[6, 4])*
   (u[1, 5] + u[4, 5] + u[5, 5] + u[6, 5])*
   (u[1, 6] + u[4, 6] + u[5, 6] + u[6, 6]) + 
  (u[2, 1] + u[4, 1] + u[5, 1] + u[6, 1])*
   (u[2, 2] + u[4, 2] + u[5, 2] + u[6, 2])*
   (u[2, 3] + u[4, 3] + u[5, 3] + u[6, 3])*
   (u[2, 4] + u[4, 4] + u[5, 4] + u[6, 4])*
   (u[2, 5] + u[4, 5] + u[5, 5] + u[6, 5])*
   (u[2, 6] + u[4, 6] + u[5, 6] + u[6, 6]) - 
  (u[1, 1] + u[2, 1] + u[4, 1] + u[5, 1] + u[6, 1])*
   (u[1, 2] + u[2, 2] + u[4, 2] + u[5, 2] + u[6, 2])*
   (u[1, 3] + u[2, 3] + u[4, 3] + u[5, 3] + u[6, 3])*
   (u[1, 4] + u[2, 4] + u[4, 4] + u[5, 4] + u[6, 4])*
   (u[1, 5] + u[2, 5] + u[4, 5] + u[5, 5] + u[6, 5])*
   (u[1, 6] + u[2, 6] + u[4, 6] + u[5, 6] + u[6, 6]) + 
  (u[3, 1] + u[4, 1] + u[5, 1] + u[6, 1])*
   (u[3, 2] + u[4, 2] + u[5, 2] + u[6, 2])*
   (u[3, 3] + u[4, 3] + u[5, 3] + u[6, 3])*
   (u[3, 4] + u[4, 4] + u[5, 4] + u[6, 4])*
   (u[3, 5] + u[4, 5] + u[5, 5] + u[6, 5])*
   (u[3, 6] + u[4, 6] + u[5, 6] + u[6, 6]) - 
  (u[1, 1] + u[3, 1] + u[4, 1] + u[5, 1] + u[6, 1])*
   (u[1, 2] + u[3, 2] + u[4, 2] + u[5, 2] + u[6, 2])*
   (u[1, 3] + u[3, 3] + u[4, 3] + u[5, 3] + u[6, 3])*
   (u[1, 4] + u[3, 4] + u[4, 4] + u[5, 4] + u[6, 4])*
   (u[1, 5] + u[3, 5] + u[4, 5] + u[5, 5] + u[6, 5])*
   (u[1, 6] + u[3, 6] + u[4, 6] + u[5, 6] + u[6, 6]) - 
  (u[2, 1] + u[3, 1] + u[4, 1] + u[5, 1] + u[6, 1])*
   (u[2, 2] + u[3, 2] + u[4, 2] + u[5, 2] + u[6, 2])*
   (u[2, 3] + u[3, 3] + u[4, 3] + u[5, 3] + u[6, 3])*
   (u[2, 4] + u[3, 4] + u[4, 4] + u[5, 4] + u[6, 4])*
   (u[2, 5] + u[3, 5] + u[4, 5] + u[5, 5] + u[6, 5])*
   (u[2, 6] + u[3, 6] + u[4, 6] + u[5, 6] + u[6, 6]) + 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[4, 1] + u[5, 1] + u[6, 1])*
   (u[1, 2] + u[2, 2] + u[3, 2] + u[4, 2] + u[5, 2] + u[6, 2])*
   (u[1, 3] + u[2, 3] + u[3, 3] + u[4, 3] + u[5, 3] + u[6, 3])*
   (u[1, 4] + u[2, 4] + u[3, 4] + u[4, 4] + u[5, 4] + u[6, 4])*
   (u[1, 5] + u[2, 5] + u[3, 5] + u[4, 5] + u[5, 5] + u[6, 5])*
   (u[1, 6] + u[2, 6] + u[3, 6] + u[4, 6] + u[5, 6] + u[6, 6])\
\>", "\<\
-(u[1, 1] u[1, 2] u[1, 3] u[1, 4] u[1, 5] u[1, 6]) - 
 
  u[2, 1] u[2, 2] u[2, 3] u[2, 4] u[2, 5] u[2, 6] + 
 
  (u[1, 1] + u[2, 1]) (u[1, 2] + u[2, 2]) (u[1, 3] + u[2, 3]) 
 
   (u[1, 4] + u[2, 4]) (u[1, 5] + u[2, 5]) (u[1, 6] + u[2, 6]) - 
 
  u[3, 1] u[3, 2] u[3, 3] u[3, 4] u[3, 5] u[3, 6] + 
 
  (u[1, 1] + u[3, 1]) (u[1, 2] + u[3, 2]) (u[1, 3] + u[3, 3]) 
 
   (u[1, 4] + u[3, 4]) (u[1, 5] + u[3, 5]) (u[1, 6] + u[3, 6]) + 
 
  (u[2, 1] + u[3, 1]) (u[2, 2] + u[3, 2]) (u[2, 3] + u[3, 3]) 
 
   (u[2, 4] + u[3, 4]) (u[2, 5] + u[3, 5]) (u[2, 6] + u[3, 6]) - 
 
  (u[1, 1] + u[2, 1] + u[3, 1]) (u[1, 2] + u[2, 2] + u[3, 2]) 
 
   (u[1, 3] + u[2, 3] + u[3, 3]) (u[1, 4] + u[2, 4] + u[3, 4]) 
 
   (u[1, 5] + u[2, 5] + u[3, 5]) (u[1, 6] + u[2, 6] + u[3, 6]) - 
 
  u[4, 1] u[4, 2] u[4, 3] u[4, 4] u[4, 5] u[4, 6] + 
 
  (u[1, 1] + u[4, 1]) (u[1, 2] + u[4, 2]) (u[1, 3] + u[4, 3]) 
 
   (u[1, 4] + u[4, 4]) (u[1, 5] + u[4, 5]) (u[1, 6] + u[4, 6]) + 
 
  (u[2, 1] + u[4, 1]) (u[2, 2] + u[4, 2]) (u[2, 3] + u[4, 3]) 
 
   (u[2, 4] + u[4, 4]) (u[2, 5] + u[4, 5]) (u[2, 6] + u[4, 6]) - 
 
  (u[1, 1] + u[2, 1] + u[4, 1]) (u[1, 2] + u[2, 2] + u[4, 2]) 
 
   (u[1, 3] + u[2, 3] + u[4, 3]) (u[1, 4] + u[2, 4] + u[4, 4]) 
 
   (u[1, 5] + u[2, 5] + u[4, 5]) (u[1, 6] + u[2, 6] + u[4, 6]) + 
 
  (u[3, 1] + u[4, 1]) (u[3, 2] + u[4, 2]) (u[3, 3] + u[4, 3]) 
 
   (u[3, 4] + u[4, 4]) (u[3, 5] + u[4, 5]) (u[3, 6] + u[4, 6]) - 
 
  (u[1, 1] + u[3, 1] + u[4, 1]) (u[1, 2] + u[3, 2] + u[4, 2]) 
 
   (u[1, 3] + u[3, 3] + u[4, 3]) (u[1, 4] + u[3, 4] + u[4, 4]) 
 
   (u[1, 5] + u[3, 5] + u[4, 5]) (u[1, 6] + u[3, 6] + u[4, 6]) - 
 
  (u[2, 1] + u[3, 1] + u[4, 1]) (u[2, 2] + u[3, 2] + u[4, 2]) 
 
   (u[2, 3] + u[3, 3] + u[4, 3]) (u[2, 4] + u[3, 4] + u[4, 4]) 
 
   (u[2, 5] + u[3, 5] + u[4, 5]) (u[2, 6] + u[3, 6] + u[4, 6]) + 
 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[4, 1]) 
 
   (u[1, 2] + u[2, 2] + u[3, 2] + u[4, 2]) 
 
   (u[1, 3] + u[2, 3] + u[3, 3] + u[4, 3]) 
 
   (u[1, 4] + u[2, 4] + u[3, 4] + u[4, 4]) 
 
   (u[1, 5] + u[2, 5] + u[3, 5] + u[4, 5]) 
 
   (u[1, 6] + u[2, 6] + u[3, 6] + u[4, 6]) - 
 
  u[5, 1] u[5, 2] u[5, 3] u[5, 4] u[5, 5] u[5, 6] + 
 
  (u[1, 1] + u[5, 1]) (u[1, 2] + u[5, 2]) (u[1, 3] + u[5, 3]) 
 
   (u[1, 4] + u[5, 4]) (u[1, 5] + u[5, 5]) (u[1, 6] + u[5, 6]) + 
 
  (u[2, 1] + u[5, 1]) (u[2, 2] + u[5, 2]) (u[2, 3] + u[5, 3]) 
 
   (u[2, 4] + u[5, 4]) (u[2, 5] + u[5, 5]) (u[2, 6] + u[5, 6]) - 
 
  (u[1, 1] + u[2, 1] + u[5, 1]) (u[1, 2] + u[2, 2] + u[5, 2]) 
 
   (u[1, 3] + u[2, 3] + u[5, 3]) (u[1, 4] + u[2, 4] + u[5, 4]) 
 
   (u[1, 5] + u[2, 5] + u[5, 5]) (u[1, 6] + u[2, 6] + u[5, 6]) + 
 
  (u[3, 1] + u[5, 1]) (u[3, 2] + u[5, 2]) (u[3, 3] + u[5, 3]) 
 
   (u[3, 4] + u[5, 4]) (u[3, 5] + u[5, 5]) (u[3, 6] + u[5, 6]) - 
 
  (u[1, 1] + u[3, 1] + u[5, 1]) (u[1, 2] + u[3, 2] + u[5, 2]) 
 
   (u[1, 3] + u[3, 3] + u[5, 3]) (u[1, 4] + u[3, 4] + u[5, 4]) 
 
   (u[1, 5] + u[3, 5] + u[5, 5]) (u[1, 6] + u[3, 6] + u[5, 6]) - 
 
  (u[2, 1] + u[3, 1] + u[5, 1]) (u[2, 2] + u[3, 2] + u[5, 2]) 
 
   (u[2, 3] + u[3, 3] + u[5, 3]) (u[2, 4] + u[3, 4] + u[5, 4]) 
 
   (u[2, 5] + u[3, 5] + u[5, 5]) (u[2, 6] + u[3, 6] + u[5, 6]) + 
 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[5, 1]) 
 
   (u[1, 2] + u[2, 2] + u[3, 2] + u[5, 2]) 
 
   (u[1, 3] + u[2, 3] + u[3, 3] + u[5, 3]) 
 
   (u[1, 4] + u[2, 4] + u[3, 4] + u[5, 4]) 
 
   (u[1, 5] + u[2, 5] + u[3, 5] + u[5, 5]) 
 
   (u[1, 6] + u[2, 6] + u[3, 6] + u[5, 6]) + 
 
  (u[4, 1] + u[5, 1]) (u[4, 2] + u[5, 2]) (u[4, 3] + u[5, 3]) 
 
   (u[4, 4] + u[5, 4]) (u[4, 5] + u[5, 5]) (u[4, 6] + u[5, 6]) - 
 
  (u[1, 1] + u[4, 1] + u[5, 1]) (u[1, 2] + u[4, 2] + u[5, 2]) 
 
   (u[1, 3] + u[4, 3] + u[5, 3]) (u[1, 4] + u[4, 4] + u[5, 4]) 
 
   (u[1, 5] + u[4, 5] + u[5, 5]) (u[1, 6] + u[4, 6] + u[5, 6]) - 
 
  (u[2, 1] + u[4, 1] + u[5, 1]) (u[2, 2] + u[4, 2] + u[5, 2]) 
 
   (u[2, 3] + u[4, 3] + u[5, 3]) (u[2, 4] + u[4, 4] + u[5, 4]) 
 
   (u[2, 5] + u[4, 5] + u[5, 5]) (u[2, 6] + u[4, 6] + u[5, 6]) + 
 
  (u[1, 1] + u[2, 1] + u[4, 1] + u[5, 1]) 
 
   (u[1, 2] + u[2, 2] + u[4, 2] + u[5, 2]) 
 
   (u[1, 3] + u[2, 3] + u[4, 3] + u[5, 3]) 
 
   (u[1, 4] + u[2, 4] + u[4, 4] + u[5, 4]) 
 
   (u[1, 5] + u[2, 5] + u[4, 5] + u[5, 5]) 
 
   (u[1, 6] + u[2, 6] + u[4, 6] + u[5, 6]) - 
 
  (u[3, 1] + u[4, 1] + u[5, 1]) (u[3, 2] + u[4, 2] + u[5, 2]) 
 
   (u[3, 3] + u[4, 3] + u[5, 3]) (u[3, 4] + u[4, 4] + u[5, 4]) 
 
   (u[3, 5] + u[4, 5] + u[5, 5]) (u[3, 6] + u[4, 6] + u[5, 6]) + 
 
  (u[1, 1] + u[3, 1] + u[4, 1] + u[5, 1]) 
 
   (u[1, 2] + u[3, 2] + u[4, 2] + u[5, 2]) 
 
   (u[1, 3] + u[3, 3] + u[4, 3] + u[5, 3]) 
 
   (u[1, 4] + u[3, 4] + u[4, 4] + u[5, 4]) 
 
   (u[1, 5] + u[3, 5] + u[4, 5] + u[5, 5]) 
 
   (u[1, 6] + u[3, 6] + u[4, 6] + u[5, 6]) + 
 
  (u[2, 1] + u[3, 1] + u[4, 1] + u[5, 1]) 
 
   (u[2, 2] + u[3, 2] + u[4, 2] + u[5, 2]) 
 
   (u[2, 3] + u[3, 3] + u[4, 3] + u[5, 3]) 
 
   (u[2, 4] + u[3, 4] + u[4, 4] + u[5, 4]) 
 
   (u[2, 5] + u[3, 5] + u[4, 5] + u[5, 5]) 
 
   (u[2, 6] + u[3, 6] + u[4, 6] + u[5, 6]) - 
 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[4, 1] + u[5, 1]) 
 
   (u[1, 2] + u[2, 2] + u[3, 2] + u[4, 2] + u[5, 2]) 
 
   (u[1, 3] + u[2, 3] + u[3, 3] + u[4, 3] + u[5, 3]) 
 
   (u[1, 4] + u[2, 4] + u[3, 4] + u[4, 4] + u[5, 4]) 
 
   (u[1, 5] + u[2, 5] + u[3, 5] + u[4, 5] + u[5, 5]) 
 
   (u[1, 6] + u[2, 6] + u[3, 6] + u[4, 6] + u[5, 6]) - 
 
  u[6, 1] u[6, 2] u[6, 3] u[6, 4] u[6, 5] u[6, 6] + 
 
  (u[1, 1] + u[6, 1]) (u[1, 2] + u[6, 2]) (u[1, 3] + u[6, 3]) 
 
   (u[1, 4] + u[6, 4]) (u[1, 5] + u[6, 5]) (u[1, 6] + u[6, 6]) + 
 
  (u[2, 1] + u[6, 1]) (u[2, 2] + u[6, 2]) (u[2, 3] + u[6, 3]) 
 
   (u[2, 4] + u[6, 4]) (u[2, 5] + u[6, 5]) (u[2, 6] + u[6, 6]) - 
 
  (u[1, 1] + u[2, 1] + u[6, 1]) (u[1, 2] + u[2, 2] + u[6, 2]) 
 
   (u[1, 3] + u[2, 3] + u[6, 3]) (u[1, 4] + u[2, 4] + u[6, 4]) 
 
   (u[1, 5] + u[2, 5] + u[6, 5]) (u[1, 6] + u[2, 6] + u[6, 6]) + 
 
  (u[3, 1] + u[6, 1]) (u[3, 2] + u[6, 2]) (u[3, 3] + u[6, 3]) 
 
   (u[3, 4] + u[6, 4]) (u[3, 5] + u[6, 5]) (u[3, 6] + u[6, 6]) - 
 
  (u[1, 1] + u[3, 1] + u[6, 1]) (u[1, 2] + u[3, 2] + u[6, 2]) 
 
   (u[1, 3] + u[3, 3] + u[6, 3]) (u[1, 4] + u[3, 4] + u[6, 4]) 
 
   (u[1, 5] + u[3, 5] + u[6, 5]) (u[1, 6] + u[3, 6] + u[6, 6]) - 
 
  (u[2, 1] + u[3, 1] + u[6, 1]) (u[2, 2] + u[3, 2] + u[6, 2]) 
 
   (u[2, 3] + u[3, 3] + u[6, 3]) (u[2, 4] + u[3, 4] + u[6, 4]) 
 
   (u[2, 5] + u[3, 5] + u[6, 5]) (u[2, 6] + u[3, 6] + u[6, 6]) + 
 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[6, 1]) 
 
   (u[1, 2] + u[2, 2] + u[3, 2] + u[6, 2]) 
 
   (u[1, 3] + u[2, 3] + u[3, 3] + u[6, 3]) 
 
   (u[1, 4] + u[2, 4] + u[3, 4] + u[6, 4]) 
 
   (u[1, 5] + u[2, 5] + u[3, 5] + u[6, 5]) 
 
   (u[1, 6] + u[2, 6] + u[3, 6] + u[6, 6]) + 
 
  (u[4, 1] + u[6, 1]) (u[4, 2] + u[6, 2]) (u[4, 3] + u[6, 3]) 
 
   (u[4, 4] + u[6, 4]) (u[4, 5] + u[6, 5]) (u[4, 6] + u[6, 6]) - 
 
  (u[1, 1] + u[4, 1] + u[6, 1]) (u[1, 2] + u[4, 2] + u[6, 2]) 
 
   (u[1, 3] + u[4, 3] + u[6, 3]) (u[1, 4] + u[4, 4] + u[6, 4]) 
 
   (u[1, 5] + u[4, 5] + u[6, 5]) (u[1, 6] + u[4, 6] + u[6, 6]) - 
 
  (u[2, 1] + u[4, 1] + u[6, 1]) (u[2, 2] + u[4, 2] + u[6, 2]) 
 
   (u[2, 3] + u[4, 3] + u[6, 3]) (u[2, 4] + u[4, 4] + u[6, 4]) 
 
   (u[2, 5] + u[4, 5] + u[6, 5]) (u[2, 6] + u[4, 6] + u[6, 6]) + 
 
  (u[1, 1] + u[2, 1] + u[4, 1] + u[6, 1]) 
 
   (u[1, 2] + u[2, 2] + u[4, 2] + u[6, 2]) 
 
   (u[1, 3] + u[2, 3] + u[4, 3] + u[6, 3]) 
 
   (u[1, 4] + u[2, 4] + u[4, 4] + u[6, 4]) 
 
   (u[1, 5] + u[2, 5] + u[4, 5] + u[6, 5]) 
 
   (u[1, 6] + u[2, 6] + u[4, 6] + u[6, 6]) - 
 
  (u[3, 1] + u[4, 1] + u[6, 1]) (u[3, 2] + u[4, 2] + u[6, 2]) 
 
   (u[3, 3] + u[4, 3] + u[6, 3]) (u[3, 4] + u[4, 4] + u[6, 4]) 
 
   (u[3, 5] + u[4, 5] + u[6, 5]) (u[3, 6] + u[4, 6] + u[6, 6]) + 
 
  (u[1, 1] + u[3, 1] + u[4, 1] + u[6, 1]) 
 
   (u[1, 2] + u[3, 2] + u[4, 2] + u[6, 2]) 
 
   (u[1, 3] + u[3, 3] + u[4, 3] + u[6, 3]) 
 
   (u[1, 4] + u[3, 4] + u[4, 4] + u[6, 4]) 
 
   (u[1, 5] + u[3, 5] + u[4, 5] + u[6, 5]) 
 
   (u[1, 6] + u[3, 6] + u[4, 6] + u[6, 6]) + 
 
  (u[2, 1] + u[3, 1] + u[4, 1] + u[6, 1]) 
 
   (u[2, 2] + u[3, 2] + u[4, 2] + u[6, 2]) 
 
   (u[2, 3] + u[3, 3] + u[4, 3] + u[6, 3]) 
 
   (u[2, 4] + u[3, 4] + u[4, 4] + u[6, 4]) 
 
   (u[2, 5] + u[3, 5] + u[4, 5] + u[6, 5]) 
 
   (u[2, 6] + u[3, 6] + u[4, 6] + u[6, 6]) - 
 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[4, 1] + u[6, 1]) 
 
   (u[1, 2] + u[2, 2] + u[3, 2] + u[4, 2] + u[6, 2]) 
 
   (u[1, 3] + u[2, 3] + u[3, 3] + u[4, 3] + u[6, 3]) 
 
   (u[1, 4] + u[2, 4] + u[3, 4] + u[4, 4] + u[6, 4]) 
 
   (u[1, 5] + u[2, 5] + u[3, 5] + u[4, 5] + u[6, 5]) 
 
   (u[1, 6] + u[2, 6] + u[3, 6] + u[4, 6] + u[6, 6]) + 
 
  (u[5, 1] + u[6, 1]) (u[5, 2] + u[6, 2]) (u[5, 3] + u[6, 3]) 
 
   (u[5, 4] + u[6, 4]) (u[5, 5] + u[6, 5]) (u[5, 6] + u[6, 6]) - 
 
  (u[1, 1] + u[5, 1] + u[6, 1]) (u[1, 2] + u[5, 2] + u[6, 2]) 
 
   (u[1, 3] + u[5, 3] + u[6, 3]) (u[1, 4] + u[5, 4] + u[6, 4]) 
 
   (u[1, 5] + u[5, 5] + u[6, 5]) (u[1, 6] + u[5, 6] + u[6, 6]) - 
 
  (u[2, 1] + u[5, 1] + u[6, 1]) (u[2, 2] + u[5, 2] + u[6, 2]) 
 
   (u[2, 3] + u[5, 3] + u[6, 3]) (u[2, 4] + u[5, 4] + u[6, 4]) 
 
   (u[2, 5] + u[5, 5] + u[6, 5]) (u[2, 6] + u[5, 6] + u[6, 6]) + 
 
  (u[1, 1] + u[2, 1] + u[5, 1] + u[6, 1]) 
 
   (u[1, 2] + u[2, 2] + u[5, 2] + u[6, 2]) 
 
   (u[1, 3] + u[2, 3] + u[5, 3] + u[6, 3]) 
 
   (u[1, 4] + u[2, 4] + u[5, 4] + u[6, 4]) 
 
   (u[1, 5] + u[2, 5] + u[5, 5] + u[6, 5]) 
 
   (u[1, 6] + u[2, 6] + u[5, 6] + u[6, 6]) - 
 
  (u[3, 1] + u[5, 1] + u[6, 1]) (u[3, 2] + u[5, 2] + u[6, 2]) 
 
   (u[3, 3] + u[5, 3] + u[6, 3]) (u[3, 4] + u[5, 4] + u[6, 4]) 
 
   (u[3, 5] + u[5, 5] + u[6, 5]) (u[3, 6] + u[5, 6] + u[6, 6]) + 
 
  (u[1, 1] + u[3, 1] + u[5, 1] + u[6, 1]) 
 
   (u[1, 2] + u[3, 2] + u[5, 2] + u[6, 2]) 
 
   (u[1, 3] + u[3, 3] + u[5, 3] + u[6, 3]) 
 
   (u[1, 4] + u[3, 4] + u[5, 4] + u[6, 4]) 
 
   (u[1, 5] + u[3, 5] + u[5, 5] + u[6, 5]) 
 
   (u[1, 6] + u[3, 6] + u[5, 6] + u[6, 6]) + 
 
  (u[2, 1] + u[3, 1] + u[5, 1] + u[6, 1]) 
 
   (u[2, 2] + u[3, 2] + u[5, 2] + u[6, 2]) 
 
   (u[2, 3] + u[3, 3] + u[5, 3] + u[6, 3]) 
 
   (u[2, 4] + u[3, 4] + u[5, 4] + u[6, 4]) 
 
   (u[2, 5] + u[3, 5] + u[5, 5] + u[6, 5]) 
 
   (u[2, 6] + u[3, 6] + u[5, 6] + u[6, 6]) - 
 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[5, 1] + u[6, 1]) 
 
   (u[1, 2] + u[2, 2] + u[3, 2] + u[5, 2] + u[6, 2]) 
 
   (u[1, 3] + u[2, 3] + u[3, 3] + u[5, 3] + u[6, 3]) 
 
   (u[1, 4] + u[2, 4] + u[3, 4] + u[5, 4] + u[6, 4]) 
 
   (u[1, 5] + u[2, 5] + u[3, 5] + u[5, 5] + u[6, 5]) 
 
   (u[1, 6] + u[2, 6] + u[3, 6] + u[5, 6] + u[6, 6]) - 
 
  (u[4, 1] + u[5, 1] + u[6, 1]) (u[4, 2] + u[5, 2] + u[6, 2]) 
 
   (u[4, 3] + u[5, 3] + u[6, 3]) (u[4, 4] + u[5, 4] + u[6, 4]) 
 
   (u[4, 5] + u[5, 5] + u[6, 5]) (u[4, 6] + u[5, 6] + u[6, 6]) + 
 
  (u[1, 1] + u[4, 1] + u[5, 1] + u[6, 1]) 
 
   (u[1, 2] + u[4, 2] + u[5, 2] + u[6, 2]) 
 
   (u[1, 3] + u[4, 3] + u[5, 3] + u[6, 3]) 
 
   (u[1, 4] + u[4, 4] + u[5, 4] + u[6, 4]) 
 
   (u[1, 5] + u[4, 5] + u[5, 5] + u[6, 5]) 
 
   (u[1, 6] + u[4, 6] + u[5, 6] + u[6, 6]) + 
 
  (u[2, 1] + u[4, 1] + u[5, 1] + u[6, 1]) 
 
   (u[2, 2] + u[4, 2] + u[5, 2] + u[6, 2]) 
 
   (u[2, 3] + u[4, 3] + u[5, 3] + u[6, 3]) 
 
   (u[2, 4] + u[4, 4] + u[5, 4] + u[6, 4]) 
 
   (u[2, 5] + u[4, 5] + u[5, 5] + u[6, 5]) 
 
   (u[2, 6] + u[4, 6] + u[5, 6] + u[6, 6]) - 
 
  (u[1, 1] + u[2, 1] + u[4, 1] + u[5, 1] + u[6, 1]) 
 
   (u[1, 2] + u[2, 2] + u[4, 2] + u[5, 2] + u[6, 2]) 
 
   (u[1, 3] + u[2, 3] + u[4, 3] + u[5, 3] + u[6, 3]) 
 
   (u[1, 4] + u[2, 4] + u[4, 4] + u[5, 4] + u[6, 4]) 
 
   (u[1, 5] + u[2, 5] + u[4, 5] + u[5, 5] + u[6, 5]) 
 
   (u[1, 6] + u[2, 6] + u[4, 6] + u[5, 6] + u[6, 6]) + 
 
  (u[3, 1] + u[4, 1] + u[5, 1] + u[6, 1]) 
 
   (u[3, 2] + u[4, 2] + u[5, 2] + u[6, 2]) 
 
   (u[3, 3] + u[4, 3] + u[5, 3] + u[6, 3]) 
 
   (u[3, 4] + u[4, 4] + u[5, 4] + u[6, 4]) 
 
   (u[3, 5] + u[4, 5] + u[5, 5] + u[6, 5]) 
 
   (u[3, 6] + u[4, 6] + u[5, 6] + u[6, 6]) - 
 
  (u[1, 1] + u[3, 1] + u[4, 1] + u[5, 1] + u[6, 1]) 
 
   (u[1, 2] + u[3, 2] + u[4, 2] + u[5, 2] + u[6, 2]) 
 
   (u[1, 3] + u[3, 3] + u[4, 3] + u[5, 3] + u[6, 3]) 
 
   (u[1, 4] + u[3, 4] + u[4, 4] + u[5, 4] + u[6, 4]) 
 
   (u[1, 5] + u[3, 5] + u[4, 5] + u[5, 5] + u[6, 5]) 
 
   (u[1, 6] + u[3, 6] + u[4, 6] + u[5, 6] + u[6, 6]) - 
 
  (u[2, 1] + u[3, 1] + u[4, 1] + u[5, 1] + u[6, 1]) 
 
   (u[2, 2] + u[3, 2] + u[4, 2] + u[5, 2] + u[6, 2]) 
 
   (u[2, 3] + u[3, 3] + u[4, 3] + u[5, 3] + u[6, 3]) 
 
   (u[2, 4] + u[3, 4] + u[4, 4] + u[5, 4] + u[6, 4]) 
 
   (u[2, 5] + u[3, 5] + u[4, 5] + u[5, 5] + u[6, 5]) 
 
   (u[2, 6] + u[3, 6] + u[4, 6] + u[5, 6] + u[6, 6]) + 
 
  (u[1, 1] + u[2, 1] + u[3, 1] + u[4, 1] + u[5, 1] + u[6, 1]) 
 
   (u[1, 2] + u[2, 2] + u[3, 2] + u[4, 2] + u[5, 2] + u[6, 2]) 
 
   (u[1, 3] + u[2, 3] + u[3, 3] + u[4, 3] + u[5, 3] + u[6, 3]) 
 
   (u[1, 4] + u[2, 4] + u[3, 4] + u[4, 4] + u[5, 4] + u[6, 4]) 
 
   (u[1, 5] + u[2, 5] + u[3, 5] + u[4, 5] + u[5, 5] + u[6, 5]) 
 
   (u[1, 6] + u[2, 6] + u[3, 6] + u[4, 6] + u[5, 6] + u[6, 6])\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[perm]", "Input"],

Cell[OutputFormData["\<\
63\
\>", "\<\
63\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[perm1 = perm //Expand;]", "Input"],

Cell[OutputFormData["\<\
{40.09000000000003*Second, Null}\
\>", "\<\
{40.09 Second, Null}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[perm1]", "Input"],

Cell[OutputFormData["\<\
720\
\>", "\<\
720\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["perm1 /. u[___] -> 1", "Input"],

Cell[OutputFormData["\<\
720\
\>", "\<\
720\
\>"], "Output"]
}, Open  ]],

Cell["perm1", "Input"],

Cell["\<\
We obtain memory problems if we try to carry out an analogous calculation for \
A = Array[u,{7,7}]. The reason is that Permanent generates more than n! terms \
in a symbolic calculation of a permanent of an (n\[Times]n)-matrix. The \
procedure Permanent is not very suitable to calculate permanents of large \
matrices in a symbolic way. However, it works very good for numerical \
calculations.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A = Range[16*16]", "Input"],

Cell[OutputFormData["\<\
{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
  39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
  57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
  75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
  93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 
  109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
  123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
  137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 
  151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
  165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
  179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 
  193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 
  207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 
  221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 
  235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 
  249, 250, 251, 252, 253, 254, 255, 256}\
\>", "\<\
{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
 
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
 
  39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
 
  57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
 
  75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
 
  93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 
 
  109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
 
  123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
 
  137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 
 
  151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
 
  165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
 
  179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 
 
  193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 
 
  207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 
 
  221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 
 
  235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 
 
  249, 250, 251, 252, 253, 254, 255, 256}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Partition[A,16]", "Input"],

Cell[OutputFormData["\<\
{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}, 
  {17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32}, 
  {33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48}, 
  {49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64}, 
  {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80}, 
  {81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96}, 
  {97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 
   111, 112}, {113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 
   124, 125, 126, 127, 128}, {129, 130, 131, 132, 133, 134, 135, 136, 
   137, 138, 139, 140, 141, 142, 143, 144}, 
  {145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
   159, 160}, {161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 
   172, 173, 174, 175, 176}, {177, 178, 179, 180, 181, 182, 183, 184, 
   185, 186, 187, 188, 189, 190, 191, 192}, 
  {193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 
   207, 208}, {209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 
   220, 221, 222, 223, 224}, {225, 226, 227, 228, 229, 230, 231, 232, 
   233, 234, 235, 236, 237, 238, 239, 240}, 
  {241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
   255, 256}}\
\>", "\<\
{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}, 
 
  {17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32}, 
 
  {33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48}, 
 
  {49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64}, 
 
  {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80}, 
 
  {81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96}, 
 
  {97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
 
   112}, {113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
 
   126, 127, 128}, {129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
 
   140, 141, 142, 143, 144}, {145, 146, 147, 148, 149, 150, 151, 152, 153, 
 
   154, 155, 156, 157, 158, 159, 160}, 
 
  {161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
 
   175, 176}, {177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 
 
   189, 190, 191, 192}, {193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 
 
   203, 204, 205, 206, 207, 208}, 
 
  {209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 
 
   223, 224}, {225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
 
   237, 238, 239, 240}, {241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
 
   251, 252, 253, 254, 255, 256}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MatrixQ[A]", "Input"],

Cell[OutputFormData["\<\
True\
\>", "\<\
True\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{58.44000000000005*Second, 1247685757487613731555240243531523777626112000}\
\>", "\<\
{58.44 Second, 1247685757487613731555240243531523777626112000}\
\>"], "Output"]
}, Open  ]],

Cell["\<\
We can observe the same calculation times if we determine permanents of real \
matrices.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A = Table[Random[],{i,16},{j,16}]", "Input"],

Cell[OutputFormData["\<\
{{0.3160966248172317, 0.9662850410831, 0.3542199492251101, \
0.8384312920669211, 
   0.529069353524176, 0.5939591544206534, 0.2030134608226545, \
0.1502333938504154, 
   0.6322154063238286, 0.7949605880523434, 0.2765013963656211, \
0.2246502881763727, 
   0.8642028077676073, 0.3060579253189956, 0.5662372254916538, \
0.8699280973994016}, 
  {0.4369187225003527, 0.7415126298500748, 0.2610200861000959, \
0.1746781593287489, 
   0.9427932098771814, 0.9181375072322651, 0.1667885761492212, \
0.1725817647085461, 
   0.6266965850599496, 0.9518524661491653, 0.8125686269241111, \
0.3341504726416249, 
   0.09762723153577358, 0.3578933117285119, 0.6095551661014565, \
0.1839170787912094}\\
, {0.4654118252119448, 0.5629327236761684, 0.3330537697358354, \
0.9592667906148367, 
   0.6012090174443375, 0.2568747983571728, 0.7668165442441815, 
   0.08933869321543513, 0.1642902949439847, 0.515362168507098, \
0.5057964581440856, 
   0.914660533886686, 0.2214970850668033, 0.5972246612748327, \
0.3390078819948644, 
   0.74207876917814}, {0.5948005000068537, 0.6453721951256675, \
0.5264392550707533, 
   0.407928296536515, 0.49717326847108, 0.2874788833971555, \
0.9168840889692969, 
   0.2240112177453056, 0.03176144325913521, 0.7245461597209871, 
   0.5838303192334613, 0.2647444271304689, 0.4305524258147976, \
0.4676713613638143, 
   0.8170137749892798, 0.1754057339150338}, 
  {0.2662621308708128, 0.9523091928567163, 0.3112173168451941, \
0.2607452000283476, 
   0.04476504580400958, 0.3550845315818835, 0.9722094348503297, 
   0.5186664308502075, 0.4499645457971559, 0.7097123364562161, \
0.4457701797795763, 
   0.1107381343136925, 0.9527912773260759, 0.4222334530590605, \
0.5288860908102794, 
   0.8867269165683868}, {0.9210298340669405, 0.6976872933380732, 
   0.945055771576818, 0.6219824894379178, 0.4904774082521429, \
0.230015931974259, 
   0.1280419965875383, 0.4465767555228842, 0.22421527738133, \
0.2777067391175427, 
   0.8168246797423442, 0.1858315554945365, 0.1794502315773204, \
0.9226222075356592, 
   0.8446152448920145, 0.6671651246443288}, 
  {0.7294856857801645, 0.212909871079443, 0.398845065112438, \
0.5564269903306363, 
   0.7766944084540886, 0.7906764180203825, 0.8699589743021585, \
0.6697000737622494, 
   0.8556645743871481, 0.09298912468230922, 0.9249032027253404, 
   0.04771758432433158, 0.3651871661350051, 0.8629731927080502, 
   0.7968612061378021, 0.6011408288014474}, 
  {0.1409718887536751, 0.5852664535905073, 0.980036526395458, \
0.4153092733069109, 
   0.9615216571763546, 0.6626442460548482, 0.1354212815034435, \
0.748144148662582, 
   0.2320359713961901, 0.4497343749754052, 0.7365762163910054, \
0.1917171583319456, 
   0.4553415629421015, 0.6590579569550226, 0.8666172420888468, \
0.522017084569696}, 
  {0.5996769885549534, 0.5660688322727134, 0.9417140393635065, \
0.4742995002453644, 
   0.2344898224199482, 0.7030956395646632, 0.1448528332257043, \
0.8731586714439171, 
   0.09351793366627314, 0.1178291859741558, 0.1648163068302463, \
0.457849398137006, 
   0.1319962764899184, 0.4551849399193075, 0.02939502532680283, \
0.7097052494744239}\\
, {0.8999603050937283, 0.005450564943902261, 0.2928188089357973, 
   0.5179880911424784, 0.4446187421516269, 0.3463926079888795, \
0.4262015668469504, 
   0.9959710065727824, 0.8449417535966734, 0.780323775716166, \
0.4844875274834439, 
   0.5216715063274179, 0.6104519311767252, 0.07722813615150281, 
   0.3396346942577395, 0.648512834883501}, 
  {0.516933997510452, 0.9593989501773469, 0.1748183874274932, \
0.1906634367464948, 
   0.3849377210205336, 0.5042140102580394, 0.1454233621006903, \
0.4809581872720707, 
   0.4849774159268052, 0.4987634453141371, 0.852604553164893, \
0.9629700961295922, 
   0.0403586737751784, 0.1523708373252576, 0.4264029863179425, \
0.9669990895568098}, 
  {0.1954169201785049, 0.3720470616090914, 0.9419154588344985, \
0.4453275832293918, 
   0.5849649890017797, 0.2948189254575886, 0.602280764576759, \
0.7968147483458909, 
   0.06803099149132759, 0.3354199752802417, 0.4274623771492658, \
0.606151311599396, 
   0.6830932704707938, 0.8312059650222021, 0.2820390150485754, \
0.1251931243273253}, 
  {0.1981158545439886, 0.332442519708065, 0.4294344618836825, \
0.162223028197733, 
   0.1577571807688102, 0.1800716823828074, 0.003031475565739919, 
   0.1952239386409232, 0.9623402605903052, 0.8080246207737159, 
   0.06111601673124131, 0.7498963554115314, 0.3773752715885256, 
   0.5132056953161272, 0.4588352521544822, 0.9530816070656404}, 
  {0.309344280097198, 0.1777857200358854, 0.03137287500521645, \
0.3469302954662444, 
   0.626251009626404, 0.3465797550136832, 0.749333859956641, \
0.2217371711389191, 
   0.4281351550824154, 0.01413723530561816, 0.3198993980729585, 
   0.05951414294118603, 0.2703779743136051, 0.8340655529228106, 
   0.3168679225072185, 0.8642902043002626}, 
  {0.3080377137232997, 0.02604093214909481, 0.2557519057759773, 
   0.1143938488887313, 0.9306624421347741, 0.5128352368329675, \
0.796916653621495, 
   0.1613122418230908, 0.621318162037576, 0.3350495167970821, \
0.7655437786162785, 
   0.8143819463568464, 0.9950671524111719, 0.9884697617833989, 
   0.01620991865963754, 0.5926447752179272}, 
  {0.5669319973287565, 0.9743325264777807, 0.696310520586679, \
0.5331306322767412, 
   0.2965540230151514, 0.1402669735549699, 0.3794425980794604, \
0.6688404279764784, 
   0.9885163092918515, 0.1142260414058751, 0.1236906923034831, \
0.5544465790877471, 
   0.05785386715707749, 0.6013908045729076, 0.3267740386819882, \
0.3931343372646562}}\
\>", "\<\
{{0.316097, 0.966285, 0.35422, 0.838431, 0.529069, 0.593959, 0.203013, \
0.150233, 
 
   0.632215, 0.794961, 0.276501, 0.22465, 0.864203, 0.306058, 0.566237, \
0.869928}, 
 
  {0.436919, 0.741513, 0.26102, 0.174678, 0.942793, 0.918138, 0.166789, \
0.172582, 
 
   0.626697, 0.951852, 0.812569, 0.33415, 0.0976272, 0.357893, 0.609555, \
0.183917}, 
 
  {0.465412, 0.562933, 0.333054, 0.959267, 0.601209, 0.256875, 0.766817, \
0.0893387, 
 
   0.16429, 0.515362, 0.505796, 0.914661, 0.221497, 0.597225, 0.339008, \
0.742079}, 
 
  {0.594801, 0.645372, 0.526439, 0.407928, 0.497173, 0.287479, 0.916884, \
0.224011, 
 
   0.0317614, 0.724546, 0.58383, 0.264744, 0.430552, 0.467671, 0.817014, \
0.175406}, 
 
  {0.266262, 0.952309, 0.311217, 0.260745, 0.044765, 0.355085, 0.972209, \
0.518666, 
 
   0.449965, 0.709712, 0.44577, 0.110738, 0.952791, 0.422233, 0.528886, \
0.886727}, 
 
  {0.92103, 0.697687, 0.945056, 0.621982, 0.490477, 0.230016, 0.128042, \
0.446577, 
 
   0.224215, 0.277707, 0.816825, 0.185832, 0.17945, 0.922622, 0.844615, \
0.667165}, 
 
  {0.729486, 0.21291, 0.398845, 0.556427, 0.776694, 0.790676, 0.869959, \
0.6697, 
 
   0.855665, 0.0929891, 0.924903, 0.0477176, 0.365187, 0.862973, 0.796861, \
0.601141}
 
   , {0.140972, 0.585266, 0.980037, 0.415309, 0.961522, 0.662644, 0.135421, 
 
   0.748144, 0.232036, 0.449734, 0.736576, 0.191717, 0.455342, 0.659058, \
0.866617, 
 
   0.522017}, {0.599677, 0.566069, 0.941714, 0.4743, 0.23449, 0.703096, \
0.144853, 
 
   0.873159, 0.0935179, 0.117829, 0.164816, 0.457849, 0.131996, 0.455185, \
0.029395, 
 
   0.709705}, {0.89996, 0.00545056, 0.292819, 0.517988, 0.444619, 0.346393, 
 
   0.426202, 0.995971, 0.844942, 0.780324, 0.484488, 0.521672, 0.610452, \
0.0772281, 
 
   0.339635, 0.648513}, {0.516934, 0.959399, 0.174818, 0.190663, 0.384938, 
 
   0.504214, 0.145423, 0.480958, 0.484977, 0.498763, 0.852605, 0.96297, \
0.0403587, 
 
   0.152371, 0.426403, 0.966999}, 
 
  {0.195417, 0.372047, 0.941915, 0.445328, 0.584965, 0.294819, 0.602281, \
0.796815, 
 
   0.068031, 0.33542, 0.427462, 0.606151, 0.683093, 0.831206, 0.282039, \
0.125193}, 
 
  {0.198116, 0.332443, 0.429434, 0.162223, 0.157757, 0.180072, 0.00303148, 
 
   0.195224, 0.96234, 0.808025, 0.061116, 0.749896, 0.377375, 0.513206, \
0.458835, 
 
   0.953082}, {0.309344, 0.177786, 0.0313729, 0.34693, 0.626251, 0.34658, \
0.749334, 
 
   0.221737, 0.428135, 0.0141372, 0.319899, 0.0595141, 0.270378, 0.834066, 
 
   0.316868, 0.86429}, {0.308038, 0.0260409, 0.255752, 0.114394, 0.930662, 
 
   0.512835, 0.796917, 0.161312, 0.621318, 0.33505, 0.765544, 0.814382, \
0.995067, 
 
   0.98847, 0.0162099, 0.592645}, 
 
  {0.566932, 0.974333, 0.696311, 0.533131, 0.296554, 0.140267, 0.379443, \
0.66884, 
 
   0.988516, 0.114226, 0.123691, 0.554447, 0.0578539, 0.601391, 0.326774, \
0.393134}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{56.84000000000001*Second, 2.236182150651039*^8}\
\>", "\<\
                         8
{56.84 Second, 2.23618 10 }\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Table[Random[],{i,17},{j,17}]", "Input"],

Cell[OutputFormData["\<\
{{0.4365357051195013, 0.2663412877758254, 0.5612302600657096, \
0.5787523909078099, 
   0.4414685527083294, 0.2778715259924266, 0.5450203414060721, \
0.9861076156898825, 
   0.8745365553795728, 0.3035389995146458, 0.8487098208193931, \
0.4529769834131413, 
   0.5779825323644214, 0.1632720259596758, 0.4692672227399326, \
0.7841365554366628, 
   0.5894662230725698}, {0.04904598455380069, 0.3455765304364494, 
   0.2296899763489157, 0.5316123559154922, 0.447655179980893, \
0.01880249175446123, 
   0.8365556390842593, 0.09507665079599087, 0.1813138922050676, 
   0.4575722316887515, 0.2578032481764494, 0.6536080980876613, \
0.903442366212641, 
   0.9125518902826794, 0.2716956324865668, 0.7790715427080884, \
0.5999033666979952}, 
  {0.06384206946328633, 0.8187186490734255, 0.2010890103436671, 
   0.4366313407383193, 0.5945748467233537, 0.03458209363676263, 
   0.6116227872710973, 0.3875853561845186, 0.2489983162869042, \
0.8048921172878468, 
   0.080010431355605, 0.9399301762036255, 0.230195824532443, \
0.9683364782035875, 
   0.9849337805596141, 0.7586162839985578, 0.7726235928436913}, 
  {0.710533230027138, 0.3313256824719527, 0.8551739177859168, \
0.8600717025610119, 
   0.4388375975405712, 0.5522541397638641, 0.2552705510879215, \
0.7962296330977257, 
   0.6201189484671457, 0.351165129420197, 0.8186392103496022, \
0.201654786374372, 
   0.5855368548303832, 0.7395423421490997, 0.4310538541650835, \
0.9526564700874677, 
   0.7806447375425361}, {0.6595319107934947, 0.4911236779614579, 
   0.7224606455550247, 0.8123082593389487, 0.6745981302338805, \
0.7325073939629, 
   0.9498370527113332, 0.1017750293118105, 0.3432724477619278, \
0.8773334761769833, 
   0.08976535015032119, 0.6629374317712391, 0.7910183079980637, 
   0.6220629250890617, 0.2935357170525954, 0.0428184833040934, \
0.4398531785778666}, 
  {0.8034237147394595, 0.09188093067822347, 0.4572816284737102, 
   0.7003108364287669, 0.3723698605743759, 0.1392244605907557, \
0.676636890931174, 
   0.04077892563527224, 0.881246182612918, 0.4167638150357309, \
0.8643286315922253, 
   0.3661807954013916, 0.1487387886500179, 0.4669267623243977, \
0.7625536022804149, 
   0.0229083476394638, 0.2714053124730346}, 
  {0.3771614121740766, 0.09961617050917565, 0.2318900396414, \
0.6493423873839729, 
   0.08362569512148111, 0.05679768720508225, 0.7920368610635334, 
   0.8459186726445134, 0.9917447644432575, 0.599516058731372, \
0.09172602463476644, 
   0.4735488120701373, 0.8525203038525019, 0.9228791678001979, 
   0.05094709899949422, 0.5923026294572193, 0.4357564888167708}, 
  {0.05855053620797257, 0.6847663035981025, 0.4435638408072014, 
   0.9688297264923731, 0.2959969339275577, 0.6618579559586387, \
0.1721585283341667, 
   0.5916683143182964, 0.196380763418382, 0.4299679163172386, \
0.5228161409501938, 
   0.5080426191968153, 0.1395830762132997, 0.6379310552537052, \
0.6768974683056804, 
   0.5162978547535576, 0.5400670174819277}, 
  {0.5462050306189388, 0.2033486562355429, 0.6637775509010558, \
0.6171878496817297, 
   0.4952579316194445, 0.6110460267783236, 0.2280210620842849, \
0.5586373134737572, 
   0.8104916280213419, 0.1674821859711222, 0.2591913355919118, \
0.2626403795461995, 
   0.1486336720627032, 0.9953236576369555, 0.6675230212736154, 
   0.06625961612781747, 0.7186657557454646}, 
  {0.4725075166867616, 0.1594804020767999, 0.9266765399145176, 
   0.08073470049175936, 0.7956100483810813, 0.6431825473232422, 
   0.3866095224325899, 0.5345296698728205, 0.5922613921455383, \
0.9794049964221864, 
   0.7694216727508601, 0.03927173825337598, 0.9812153653672146, 
   0.7513839343379014, 0.2107843592771029, 0.2287801102320339, \
0.8137331793960925}, 
  {0.4921925987459895, 0.9481439797309034, 0.08014643816933066, 
   0.8184095217591368, 0.8246695774723741, 0.8818843636030859, \
0.361480682423866, 
   0.3459020050723751, 0.6651891753955742, 0.9552078236885682, \
0.2807459819321067, 
   0.5502919566912938, 0.02200662807233193, 0.5685983012559782, 
   0.7462163120592862, 0.9580305645457553, 0.04260163165014557}, 
  {0.7991766285051181, 0.7069445738059101, 0.9768151991785407, \
0.2912176973122441, 
   0.5883922692280152, 0.4781644635738762, 0.1630820197824483, \
0.7990250985662546, 
   0.6402482894971117, 0.3980180254045455, 0.3446724980233113, \
0.9743555210938804, 
   0.7583639258940256, 0.03653734298067947, 0.9987704929509362, 
   0.3091663456983063, 0.8031561022054575}, 
  {0.7557913610485727, 0.4484785362596425, 0.2871597176259744, \
0.234557800949479, 
   0.009575048989286624, 0.490447971713887, 0.2445580859758288, 
   0.4353811724443609, 0.3026304751833764, 0.5136327725353463, \
0.9533403886635847, 
   0.8469889032163456, 0.8244660116095003, 0.3505507527528979, \
0.15431529009733, 
   0.2067406137192339, 0.4264479862049546}, 
  {0.005878254729586577, 0.1799597690034495, 0.4483766878252081, 
   0.3899106432242751, 0.007107761778650303, 0.8707934233051432, 
   0.6452205856197508, 0.6341192821757024, 0.5586292255190078, \
0.5836337056791687, 
   0.4106627846702717, 0.6245442331864158, 0.06818125380512077, 
   0.3390756197033399, 0.9752816122259108, 0.3219137580030393, \
0.5545484812697743}, 
  {0.3857352310397552, 0.1282927090095651, 0.497447746393539, \
0.2039977285168764, 
   0.2314199409424251, 0.9215520952903311, 0.07099976018858442, 
   0.1981194737872898, 0.05146017193897563, 0.4731754074651229, 
   0.6810891169643092, 0.1910117120086395, 0.1806667486338324, \
0.8279548218453721, 
   0.04696983478860672, 0.6323824864896318, 0.5970330429546637}, 
  {0.4172920371751004, 0.4224256016021908, 0.5642012326845109, \
0.2579574232513238, 
   0.4420104249491896, 0.1005118435991514, 0.009652751414736531, 
   0.8722221922115686, 0.3137177159396245, 0.6030640972056123, \
0.8056550228978601, 
   0.6408022512691434, 0.3921656206492933, 0.5320643370170278, \
0.6075355491105701, 
   0.5893420793301677, 0.9189902131841703}, 
  {0.8509752200527188, 0.4165238371019305, 0.4086753306963354, \
0.09103539133879818, 
   0.804005385264112, 0.7841413506122988, 0.8116422877416717, \
0.6737433541636976, 
   0.3815797836619211, 0.2199401179277878, 0.5536848644903478, \
0.231732929214508, 
   0.2810679400627696, 0.2102873665130513, 0.6814626722787791, \
0.9180152132748835, 
   0.6780038428571573}}\
\>", "\<\
{{0.436536, 0.266341, 0.56123, 0.578752, 0.441469, 0.277872, 0.54502, \
0.986108, 
 
   0.874537, 0.303539, 0.84871, 0.452977, 0.577983, 0.163272, 0.469267, \
0.784137, 
 
   0.589466}, {0.049046, 0.345577, 0.22969, 0.531612, 0.447655, 0.0188025, 
 
   0.836556, 0.0950767, 0.181314, 0.457572, 0.257803, 0.653608, 0.903442, \
0.912552, 
 
   0.271696, 0.779072, 0.599903}, 
 
  {0.0638421, 0.818719, 0.201089, 0.436631, 0.594575, 0.0345821, 0.611623, 
 
   0.387585, 0.248998, 0.804892, 0.0800104, 0.93993, 0.230196, 0.968336, \
0.984934, 
 
   0.758616, 0.772624}, {0.710533, 0.331326, 0.855174, 0.860072, 0.438838, 
 
   0.552254, 0.255271, 0.79623, 0.620119, 0.351165, 0.818639, 0.201655, \
0.585537, 
 
   0.739542, 0.431054, 0.952656, 0.780645}, 
 
  {0.659532, 0.491124, 0.722461, 0.812308, 0.674598, 0.732507, 0.949837, \
0.101775, 
 
   0.343272, 0.877333, 0.0897654, 0.662937, 0.791018, 0.622063, 0.293536, 
 
   0.0428185, 0.439853}, {0.803424, 0.0918809, 0.457282, 0.700311, 0.37237, 
 
   0.139224, 0.676637, 0.0407789, 0.881246, 0.416764, 0.864329, 0.366181, \
0.148739, 
 
   0.466927, 0.762554, 0.0229083, 0.271405}, 
 
  {0.377161, 0.0996162, 0.23189, 0.649342, 0.0836257, 0.0567977, 0.792037, 
 
   0.845919, 0.991745, 0.599516, 0.091726, 0.473549, 0.85252, 0.922879, \
0.0509471, 
 
   0.592303, 0.435756}, {0.0585505, 0.684766, 0.443564, 0.96883, 0.295997, 
 
   0.661858, 0.172159, 0.591668, 0.196381, 0.429968, 0.522816, 0.508043, \
0.139583, 
 
   0.637931, 0.676897, 0.516298, 0.540067}, 
 
  {0.546205, 0.203349, 0.663778, 0.617188, 0.495258, 0.611046, 0.228021, \
0.558637, 
 
   0.810492, 0.167482, 0.259191, 0.26264, 0.148634, 0.995324, 0.667523, \
0.0662596, 
 
   0.718666}, {0.472508, 0.15948, 0.926677, 0.0807347, 0.79561, 0.643183, \
0.38661, 
 
   0.53453, 0.592261, 0.979405, 0.769422, 0.0392717, 0.981215, 0.751384, \
0.210784, 
 
   0.22878, 0.813733}, {0.492193, 0.948144, 0.0801464, 0.81841, 0.82467, \
0.881884, 
 
   0.361481, 0.345902, 0.665189, 0.955208, 0.280746, 0.550292, 0.0220066, \
0.568598, 
 
   0.746216, 0.958031, 0.0426016}, 
 
  {0.799177, 0.706945, 0.976815, 0.291218, 0.588392, 0.478164, 0.163082, \
0.799025, 
 
   0.640248, 0.398018, 0.344672, 0.974356, 0.758364, 0.0365373, 0.99877, \
0.309166, 
 
   0.803156}, {0.755791, 0.448479, 0.28716, 0.234558, 0.00957505, 0.490448, 
 
   0.244558, 0.435381, 0.30263, 0.513633, 0.95334, 0.846989, 0.824466, \
0.350551, 
 
   0.154315, 0.206741, 0.426448}, 
 
  {0.00587825, 0.17996, 0.448377, 0.389911, 0.00710776, 0.870793, 0.645221, 
 
   0.634119, 0.558629, 0.583634, 0.410663, 0.624544, 0.0681813, 0.339076, \
0.975282, 
 
   0.321914, 0.554548}, {0.385735, 0.128293, 0.497448, 0.203998, 0.23142, \
0.921552, 
 
   0.0709998, 0.198119, 0.0514602, 0.473175, 0.681089, 0.191012, 0.180667, 
 
   0.827955, 0.0469698, 0.632382, 0.597033}, 
 
  {0.417292, 0.422426, 0.564201, 0.257957, 0.44201, 0.100512, 0.00965275, \
0.872222, 
 
   0.313718, 0.603064, 0.805655, 0.640802, 0.392166, 0.532064, 0.607536, \
0.589342, 
 
   0.91899}, {0.850975, 0.416524, 0.408675, 0.0910354, 0.804005, 0.784141, 
 
   0.811642, 0.673743, 0.38158, 0.21994, 0.553685, 0.231733, 0.281068, \
0.210287, 
 
   0.681463, 0.918015, 0.678004}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{115.12*Second, 2.658849076787044*^9}\
\>", "\<\
                          9
{115.12 Second, 2.65885 10 }\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Table[Random[],{i,18},{j,18}]", "Input"],

Cell[OutputFormData["\<\
{{0.4046323436151912, 0.04066042100963578, 0.5258495926255902, \
0.1459395058401293, 
   0.797096794504621, 0.4513183416794679, 0.6068593794414197, \
0.2949642857874105, 
   0.3805729574026904, 0.04264301098313257, 0.5158239881026216, 
   0.4909589005232985, 0.5964316067903916, 0.2310007232414609, \
0.8420806339389239, 
   0.1093791168613774, 0.3764914888626037, 0.677315858751113}, 
  {0.6103477047244157, 0.8283111767986078, 0.1662041223495524, \
0.9958531864723337, 
   0.6923324914495323, 0.1503073339414504, 0.7615717787343612, \
0.9551927654626981, 
   0.1664828988239421, 0.004367828101321122, 0.96447498422974, \
0.50387442378323, 
   0.5596235193825224, 0.7094035423139105, 0.5839020268270497, \
0.4612314128000974, 
   0.04379953127990081, 0.2184446417906119}, 
  {0.9874704200366581, 0.2302306895586366, 0.2017188973409769, \
0.1090655249292345, 
   0.6109789311740543, 0.5529148308075235, 0.5913711926165611, \
0.2807543481306268, 
   0.4447748088245018, 0.5570616443351896, 0.8990387011670287, \
0.1304470141891763, 
   0.6832030300901406, 0.6018688788724916, 0.7325558023430866, \
0.1260791860878552, 
   0.7187280458604004, 0.09799445508926158}, 
  {0.1729322829605641, 0.4166756437739447, 0.1348260190333507, \
0.636763042289164, 
   0.1291327516806633, 0.1982310019833326, 0.1473555989966927, \
0.4065323527305274, 
   0.9274138543396864, 0.08916547705409815, 0.5363766678226385, 
   0.8536175219230038, 0.3360426617231253, 0.8084111289234712, \
0.0916018589981366, 
   0.2965558775878141, 0.4370039605560966, 0.677964114734295}, 
  {0.4083988289079959, 0.6946869987153224, 0.7044481582130099, \
0.5518849286464396, 
   0.6896707830475953, 0.5966925436260609, 0.5315158752524459, \
0.135209284872495, 
   0.5548447640142446, 0.9599295013368969, 0.4023831235717825, \
0.9369782828891622, 
   0.4074891650175519, 0.5533971486063694, 0.4749692692320961, \
0.8478128058350641, 
   0.8711124971949134, 0.6997796266833654}, 
  {0.1389266075089707, 0.03940167691159283, 0.7795106381967769, 
   0.4032237490955512, 0.7019226469528741, 0.3614375621772978, \
0.3711118092887809, 
   0.7085367503802287, 0.9974744887398641, 0.8095526335308582, \
0.6814410262411855, 
   0.1118442067541678, 0.4659586134874182, 0.674343348658363, \
0.1265962622269408, 
   0.1519147054172709, 0.06357548991563573, 0.7373650657692008}, 
  {0.7191070972093889, 0.5985175568109015, 0.5886062206835395, \
0.8895522599341367, 
   0.8479946000144753, 0.898737930127536, 0.4496796131745687, \
0.8501505830225438, 
   0.06848396181769844, 0.4955141810319847, 0.7477569662216946, 
   0.4887130208452459, 0.6973721525289175, 0.7869774306517559, \
0.7502824774818305, 
   0.6791603873143879, 0.01593112628773199, 0.6751332238975881}, 
  {0.2843238639944122, 0.004817038656024696, 0.8893348640607911, 
   0.5232185184803171, 0.2207483740787765, 0.2674519728868238, \
0.1702277668514022, 
   0.9247009616694155, 0.6321421533952369, 0.3778997129526871, \
0.3222331668369269, 
   0.02596303154187951, 0.182462540220668, 0.5277491299301432, \
0.2537492050192284, 
   0.5304488505098947, 0.4347055739989734, 0.03903610908489734}, 
  {0.556377052490311, 0.7434714198581388, 0.6844230965171428, \
0.3598757217705095, 
   0.540445926202579, 0.06833819596055069, 0.4000992325227306, \
0.3550586831144848, 
   0.6511110621417878, 0.5451196774802335, 0.179350858443954, \
0.08760671022766096, 
   0.4808832952903855, 0.620418715810818, 0.5472087050487171, \
0.7097069972749737, 
   0.1586501284534586, 0.5944556842689384}, 
  {0.364746164828049, 0.1819578673448304, 0.9049009234342301, \
0.06400683375904371, 
   0.9300405908290755, 0.1429217582599331, 0.3485238709439191, \
0.3205354139009048, 
   0.2456174943119327, 0.7830460364894236, 0.8080779447413402, \
0.2521972179403542, 
   0.8455182617892022, 0.4279873533749388, 0.1569668825995523, \
0.7070775404601206, 
   0.666167403345248, 0.3403806431472777}, 
  {0.6760835873091668, 0.08665882464930263, 0.1189586982965309, 
   0.6306736458723039, 0.5174334588557082, 0.4922031403803641, \
0.7542125334684818, 
   0.4487157785274735, 0.612532535421478, 0.4281963066213203, \
0.8241719426394061, 
   0.3057940202675404, 0.2640086644775588, 0.1076608927204155, \
0.5785544483274734, 
   0.5227479837781167, 0.4559307197362186, 0.8554636747800612}, 
  {0.7330361865382712, 0.09476063040317807, 0.2989638371366663, 
   0.1483861343199406, 0.0668687831930232, 0.7543799872559002, \
0.6228802498274995, 
   0.06172730967063801, 0.9479100848964922, 0.1237063413835962, 
   0.1054467909717913, 0.5695241692902738, 0.1936975514280104, \
0.6749905628561227, 
   0.4929142555503132, 0.1413278626689534, 0.3695256087886042, \
0.3691965425885822}, 
  {0.2289055910727543, 0.03366696994853791, 0.7909711604611308, 
   0.8464485588104652, 0.7729748713365356, 0.1782032951684766, 
   0.05793497392285949, 0.7516879284072873, 0.4740110341998693, 
   0.02981716084853594, 0.9910661907298361, 0.997307941151387, \
0.8511307843723697, 
   0.9680898511778979, 0.04315610583334399, 0.8736015997677906, 
   0.7456839934005784, 0.398565681887624}, 
  {0.8494585544053336, 0.198611036911668, 0.2527697378502652, \
0.2572378192186706, 
   0.4799329456167293, 0.8294144943230858, 0.02386414677751083, 
   0.2235708492701327, 0.6889617851555986, 0.9829659355126205, \
0.2508892754409751, 
   0.04536755410165608, 0.631026811232739, 0.2312780071053331, \
0.7768782412411058, 
   0.01555039325312012, 0.6399606205029027, 0.2339700659539461}, 
  {0.925747456868736, 0.0474605420752222, 0.5968045146695587, \
0.3603684661861554, 
   0.1800634634681576, 0.648894860187598, 0.7473459602642251, \
0.1617574292744873, 
   0.9272937256178924, 0.3916570409689274, 0.2674130146474959, \
0.3323429349514015, 
   0.9034295788403815, 0.1680861916987948, 0.5784512294918973, \
0.349376999438781, 
   0.6525403033994063, 0.1227186375971387}, 
  {0.9474244182591583, 0.1180989923334479, 0.8756620621583003, \
0.1071682443440186, 
   0.3074637977562554, 0.8841289263795017, 0.9499146052895643, 
   0.05970770226879641, 0.7106592830866967, 0.5237604601933463, 
   0.7698511418214067, 0.4108128420811983, 0.9633133228224714, \
0.362003030918859, 
   0.8425574162035143, 0.01915580111227073, 0.6959003081749756, 
   0.02966009596745749}, {0.9391278373631328, 0.8510696094134758, 
   0.1174490786830783, 0.6802830965286763, 0.2865875339637265, \
0.7283509718163371, 
   0.17002466042392, 0.5621841041952285, 0.4109254718054261, \
0.6211827274723185, 
   0.8625608626676644, 0.6780551778157266, 0.4610108665158616, \
0.5614750252035221, 
   0.1519015795809678, 0.1542947176223803, 0.6911597246944548, \
0.1506621831223238}, 
  {0.1885882567584963, 0.7922916867035213, 0.8486023084909403, \
0.131506382010053, 
   0.4926879485835207, 0.7626315907360638, 0.9094744711278075, \
0.2804367725965771, 
   0.3752388699004423, 0.08234849420738743, 0.6228869371640808, \
0.55208580078024, 
   0.2052142094765223, 0.5201643900121589, 0.2119614653586547, \
0.9309030733079215, 
   0.3426533468088577, 0.8421092121964321}}\
\>", "\<\
{{0.404632, 0.0406604, 0.52585, 0.14594, 0.797097, 0.451318, 0.606859, \
0.294964, 
 
   0.380573, 0.042643, 0.515824, 0.490959, 0.596432, 0.231001, 0.842081, \
0.109379, 
 
   0.376491, 0.677316}, {0.610348, 0.828311, 0.166204, 0.995853, 0.692332, 
 
   0.150307, 0.761572, 0.955193, 0.166483, 0.00436783, 0.964475, 0.503874, 
 
   0.559624, 0.709404, 0.583902, 0.461231, 0.0437995, 0.218445}, 
 
  {0.98747, 0.230231, 0.201719, 0.109066, 0.610979, 0.552915, 0.591371, \
0.280754, 
 
   0.444775, 0.557062, 0.899039, 0.130447, 0.683203, 0.601869, 0.732556, \
0.126079, 
 
   0.718728, 0.0979945}, {0.172932, 0.416676, 0.134826, 0.636763, 0.129133, 
 
   0.198231, 0.147356, 0.406532, 0.927414, 0.0891655, 0.536377, 0.853618, \
0.336043, 
 
   0.808411, 0.0916019, 0.296556, 0.437004, 0.677964}, 
 
  {0.408399, 0.694687, 0.704448, 0.551885, 0.689671, 0.596693, 0.531516, \
0.135209, 
 
   0.554845, 0.95993, 0.402383, 0.936978, 0.407489, 0.553397, 0.474969, \
0.847813, 
 
   0.871112, 0.69978}, {0.138927, 0.0394017, 0.779511, 0.403224, 0.701923, 
 
   0.361438, 0.371112, 0.708537, 0.997474, 0.809553, 0.681441, 0.111844, \
0.465959, 
 
   0.674343, 0.126596, 0.151915, 0.0635755, 0.737365}, 
 
  {0.719107, 0.598518, 0.588606, 0.889552, 0.847995, 0.898738, 0.44968, \
0.850151, 
 
   0.068484, 0.495514, 0.747757, 0.488713, 0.697372, 0.786977, 0.750282, \
0.67916, 
 
   0.0159311, 0.675133}, {0.284324, 0.00481704, 0.889335, 0.523219, 0.220748, \

 
   0.267452, 0.170228, 0.924701, 0.632142, 0.3779, 0.322233, 0.025963, \
0.182463, 
 
   0.527749, 0.253749, 0.530449, 0.434706, 0.0390361}, 
 
  {0.556377, 0.743471, 0.684423, 0.359876, 0.540446, 0.0683382, 0.400099, \
0.355059, 
 
   0.651111, 0.54512, 0.179351, 0.0876067, 0.480883, 0.620419, 0.547209, \
0.709707, 
 
   0.15865, 0.594456}, {0.364746, 0.181958, 0.904901, 0.0640068, 0.930041, 
 
   0.142922, 0.348524, 0.320535, 0.245617, 0.783046, 0.808078, 0.252197, \
0.845518, 
 
   0.427987, 0.156967, 0.707078, 0.666167, 0.340381}, 
 
  {0.676084, 0.0866588, 0.118959, 0.630674, 0.517433, 0.492203, 0.754213, \
0.448716, 
 
   0.612533, 0.428196, 0.824172, 0.305794, 0.264009, 0.107661, 0.578554, \
0.522748, 
 
   0.455931, 0.855464}, {0.733036, 0.0947606, 0.298964, 0.148386, 0.0668688, 
 
   0.75438, 0.62288, 0.0617273, 0.94791, 0.123706, 0.105447, 0.569524, \
0.193698, 
 
   0.674991, 0.492914, 0.141328, 0.369526, 0.369197}, 
 
  {0.228906, 0.033667, 0.790971, 0.846449, 0.772975, 0.178203, 0.057935, \
0.751688, 
 
   0.474011, 0.0298172, 0.991066, 0.997308, 0.851131, 0.96809, 0.0431561, \
0.873602, 
 
   0.745684, 0.398566}, {0.849459, 0.198611, 0.25277, 0.257238, 0.479933, \
0.829414, 
 
   0.0238641, 0.223571, 0.688962, 0.982966, 0.250889, 0.0453676, 0.631027, 
 
   0.231278, 0.776878, 0.0155504, 0.639961, 0.23397}, 
 
  {0.925747, 0.0474605, 0.596805, 0.360368, 0.180063, 0.648895, 0.747346, \
0.161757, 
 
   0.927294, 0.391657, 0.267413, 0.332343, 0.90343, 0.168086, 0.578451, \
0.349377, 
 
   0.65254, 0.122719}, {0.947424, 0.118099, 0.875662, 0.107168, 0.307464, \
0.884129, 
 
   0.949915, 0.0597077, 0.710659, 0.52376, 0.769851, 0.410813, 0.963313, \
0.362003, 
 
   0.842557, 0.0191558, 0.6959, 0.0296601}, 
 
  {0.939128, 0.85107, 0.117449, 0.680283, 0.286588, 0.728351, 0.170025, \
0.562184, 
 
   0.410925, 0.621183, 0.862561, 0.678055, 0.461011, 0.561475, 0.151902, \
0.154295, 
 
   0.69116, 0.150662}, {0.188588, 0.792292, 0.848602, 0.131506, 0.492688, \
0.762632, 
 
   0.909474, 0.280437, 0.375239, 0.0823485, 0.622887, 0.552086, 0.205214, \
0.520164, 
 
   0.211961, 0.930903, 0.342653, 0.842109}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Permanent[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{234.26*Second, 1.005037182213772*^10}\
\>", "\<\
                          10
{234.26 Second, 1.00504 10  }\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "We see that the calculation time is determined by a function f(n) \[Tilde] \
const. ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  ". This corresponds to the fact, that Ryser's formula calculates a \
permanent of an (n\[Times]n)-matrix in ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " steps.\n\nThe last 3 calculations needed the following memory:"
}], "Text"],

Cell[CellGroupData[{

Cell["MemoryInUse[]", "Input"],

Cell[OutputFormData["\<\
888000\
\>", "\<\
888000\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaxMemoryUsed[]", "Input"],

Cell[OutputFormData["\<\
943168\
\>", "\<\
943168\
\>"], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The procedure QueensPermanent", "Subsection"],

Cell["\<\
In this section we present a modification of Permanent which no longer leads \
to menory problems in the case of the special permanents that have to be \
calculated in our queens problem.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The definition of GrayInsert and QueensPermanent", "Subsubsection"],

Cell["\<\
GrayInsert[k_] :=
Module[{q = k , j = 1},
      While[EvenQ[q],
           q = q/2;
           j = j + 1
           ];
      {j, (-1)^((q-1)/2)}
      ]\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
QueensPermanent[a_List] :=
With[{n = Length[a]},
    (* do *)
    Module[{rowsum = Table[0,{n}], sum = 0, i, j, prod},
          Do[
            With[{gi = GrayInsert[i]},
                (* do *)
                rowsum = rowsum + gi[[2]] a[[ gi[[1]] ]];
                prod = rowsum[[1]];
                Do[prod = prod*rowsum[[j]] //Expand,
                  {j,2,n}
                  ];
                sum = sum + (-1)^i prod;
                ],
            {i, 1, 2^n - 1}
            ]; (* End Do *)
          (-1)^n sum
          ] (* End Module *)
    ] (* End With *)\
\>", "Input"],

Cell["\<\
General::spell1: 
   Possible spelling error: new symbol name \"sum\" is similar to existing \
symbol 
    \"Sum\".\
\>", "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Test of the procedure QueensPermanent", "Subsubsection"],

Cell[CellGroupData[{

Cell["A = Array[u,{6,6}]", "Input"],

Cell[OutputFormData["\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5], u[1, 6]}, 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5], u[2, 6]}, 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5], u[3, 6]}, 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5], u[4, 6]}, 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5], u[5, 6]}, 
  {u[6, 1], u[6, 2], u[6, 3], u[6, 4], u[6, 5], u[6, 6]}}\
\>", "\<\
{{u[1, 1], u[1, 2], u[1, 3], u[1, 4], u[1, 5], u[1, 6]}, 
 
  {u[2, 1], u[2, 2], u[2, 3], u[2, 4], u[2, 5], u[2, 6]}, 
 
  {u[3, 1], u[3, 2], u[3, 3], u[3, 4], u[3, 5], u[3, 6]}, 
 
  {u[4, 1], u[4, 2], u[4, 3], u[4, 4], u[4, 5], u[4, 6]}, 
 
  {u[5, 1], u[5, 2], u[5, 3], u[5, 4], u[5, 5], u[5, 6]}, 
 
  {u[6, 1], u[6, 2], u[6, 3], u[6, 4], u[6, 5], u[6, 6]}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[perm = QueensPermanent[A];]", "Input"],

Cell[OutputFormData["\<\
{63.04999999999999*Second, Null}\
\>", "\<\
{63.05 Second, Null}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[perm]", "Input"],

Cell[OutputFormData["\<\
720\
\>", "\<\
720\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["perm /. u[___] -> 1", "Input"],

Cell[OutputFormData["\<\
720\
\>", "\<\
720\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "We obtain again memory problems if we try to carry out an analogous \
calculation for A = Array[u,{7,7}].\nNote that one of the results for prod \
has ",
  Cell[BoxData[
      \(TraditionalForm\`7\^7\)]],
  " = 823543 summands. The permanent itself has 7! = 5040 summands.\n\nThe \
procedure works very good for numerical calculations."
}], "Text"],

Cell[CellGroupData[{

Cell["A = Range[16*16]", "Input"],

Cell[OutputFormData["\<\
{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 
  22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 
  40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
  58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 
  76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 
  94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
  110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 
  125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
  140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
  155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 
  170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 
  185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 
  200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 
  215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 
  230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 
  245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256}\
\>", "\<\
{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 
 
  22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 
 
  40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
 
  58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 
 
  76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 
 
  94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
 
  110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 
 
  125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
 
  140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
 
  155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 
 
  170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 
 
  185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 
 
  200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 
 
  215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 
 
  230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 
 
  245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Partition[A,16]", "Input"],

Cell[OutputFormData["\<\
{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}, 
  {17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32}, 
  {33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48}, 
  {49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64}, 
  {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80}, 
  {81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96}, 
  {97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
   112}, {113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
   126, 127, 128}, {129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
   140, 141, 142, 143, 144}, {145, 146, 147, 148, 149, 150, 151, 152, 153, 
   154, 155, 156, 157, 158, 159, 160}, 
  {161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
   175, 176}, {177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 
   189, 190, 191, 192}, {193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 
   203, 204, 205, 206, 207, 208}, 
  {209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 
   223, 224}, {225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
   237, 238, 239, 240}, {241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
   251, 252, 253, 254, 255, 256}}\
\>", "\<\
{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}, 
 
  {17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32}, 
 
  {33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48}, 
 
  {49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64}, 
 
  {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80}, 
 
  {81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96}, 
 
  {97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
 
   112}, {113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
 
   126, 127, 128}, {129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
 
   140, 141, 142, 143, 144}, {145, 146, 147, 148, 149, 150, 151, 152, 153, 
 
   154, 155, 156, 157, 158, 159, 160}, 
 
  {161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
 
   175, 176}, {177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 
 
   189, 190, 191, 192}, {193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 
 
   203, 204, 205, 206, 207, 208}, 
 
  {209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 
 
   223, 224}, {225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
 
   237, 238, 239, 240}, {241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
 
   251, 252, 253, 254, 255, 256}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MatrixQ[A]", "Input"],

Cell[OutputFormData["\<\
True\
\>", "\<\
True\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QueensPermanent[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{114.85*Second, 1247685757487613731555240243531523777626112000}\
\>", "\<\
{114.85 Second, 1247685757487613731555240243531523777626112000}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Table[Random[], {i,16},{j,16}]", "Input"],

Cell[OutputFormData["\<\
{{0.7951592345833528, 0.9170525959066566, 0.1803134075446319, \
0.2978577996206801, 
   0.2234776214298954, 0.2784134556173209, 0.2306730729213815, \
0.3547386445989936, 
   0.4034018646508334, 0.3047709344351699, 0.4724373722114064, \
0.0375601649238093, 
   0.8476316128022425, 0.5772182720482742, 0.5437583037911367, \
0.9721073525044005}, 
  {0.1440841748985289, 0.6786508553081408, 0.1130101306729854, \
0.9104921255499816, 
   0.3281484975881053, 0.7042054771762002, 0.5280978668270642, \
0.7072085714313589, 
   0.5329892630047524, 0.7871528812695435, 0.3477844592824323, \
0.4093507718106788, 
   0.3095116415748569, 0.5087394256522226, 0.1171113863610507, \
0.05461212721168519}, 
  {0.9061097769240234, 0.2039684912170526, 0.6446740141496443, \
0.01705196228787588, 
   0.05847816412178092, 0.6267502191687785, 0.1009157103585075, \
0.04494460978347544, 
   0.914393989223252, 0.9480993638606376, 0.9879055796855221, \
0.1344524842334938, 
   0.5862454916351466, 0.2438938866844373, 0.4598077128584577, \
0.4272439128021348}, 
  {0.05325622863039424, 0.4567410054148938, 0.1120232535760255, \
0.01789314099145607, 
   0.7437445870555372, 0.9480015797626711, 0.9949118672149747, \
0.9632810137797708, 
   0.8376348101315137, 0.7440330885456186, 0.3502378530653304, \
0.9462290514918949, 
   0.7791566460097328, 0.11728286937684, 0.2493221427068228, \
0.9012844417084195}, 
  {0.8647626567864808, 0.1691835055162024, 0.2614165630213008, \
0.7668319574749257, 
   0.2785171651513342, 0.9252896188317651, 0.8016088501628431, \
0.3395880446727908, 
   0.2252609365209399, 0.4685486134168712, 0.6895855965868175, \
0.3216949036813347, 
   0.4815163494654026, 0.5205470336542, 0.6946737293718427, \
0.3584138899015639}, 
  {0.6438815393338889, 0.7765139451085815, 0.3444358763065124, \
0.4121848384096688, 
   0.8647248933241559, 0.6592310757317413, 0.09511373359968949, \
0.5109003967012492, 
   0.9999622365376751, 0.4900475702155389, 0.8336971705783886, \
0.7440684392263236, 
   0.7214450713863409, 0.5647579513837738, 0.03208832041554554, \
0.4044803945535327}, 
  {0.496184134865401, 0.09620933796690257, 0.3425027238287279, \
0.08278549087219797, 
   0.01466778539999835, 0.5756623043127025, 0.6478289944568851, \
0.7243716009706339, 
   0.3707862460661095, 0.7991483592041211, 0.3033931181503727, \
0.3121867625609651, 
   0.5060613527419533, 0.1399172834723796, 0.2082793845506833, \
0.8012863658597158}, 
  {0.5060991162042782, 0.6498697132568407, 0.3745822139722946, \
0.05721792663339217, 
   0.7846540448179371, 0.08511176187306691, 0.3424938935567491, \
0.6527375320798594, 
   0.2884699099525362, 0.9889024239061644, 0.9999911697280211, \
0.5699520412076614, 
   0.2738021245525378, 0.4132401195934617, 0.3521621752711359, \
0.8455804402370274}, 
  {0.9030158784864283, 0.6140917603893408, 0.04876905712076323, \
0.5333936776760622, 
   0.396954525744475, 0.474174476916961, 0.8404896725700799, \
0.7321073118163463, 
   0.8908554095401967, 0.8243047636601202, 0.4659074585977853, \
0.6748893851829542, 
   0.1062013647222594, 0.7391930017870533, 0.1234135650410361, \
0.02215185310309481}, 
  {0.8177314547697232, 0.7502905778808889, 0.123422395313015, \
0.4521998118954333, 
   0.5439293302171853, 0.3370504582874271, 0.7712602200418791, \
0.6066193716584059, 
   0.640913451730757, 0.7229586978980863, 0.7224911629211158, \
0.07322569398234374, 
   0.243958925986282, 0.2487842209811254, 0.8820014903510358, \
0.3411183821659973}, 
  {0.3531035164460853, 0.424479457321005, 0.4160940317532506, \
0.666228996983043, 
   0.2469021517238258, 0.6852864555339518, 0.2926804667122144, \
0.6440771438799482, 
   0.4291706969541025, 0.9349958776530627, 0.1692580713991993, \
0.1918773319845149, 
   0.8852413667369171, 0.5979454193656356, 0.3979978513573203, \
0.5852579603261089}, 
  {0.2443279150061602, 0.8749867214675491, 0.6755066884362044, \
0.5120322663437652, 
   0.0003689890198782265, 0.6262025004864238, 0.7935051980851685, 
   0.1709138841777678, 0.6472654725737929, 0.2017230431654186, \
0.377411166331918, 
   0.5046848871947248, 0.400363320849967, 0.5164365876314668, \
0.08473069961970358, 
   0.8606077433147765}, {0.9711926238958644, 0.5814407099784039, \
0.9154726282205041, 
   0.6687304113302615, 0.08595125715894724, 0.9834952906127684, \
0.5174747768631839, 
   0.08347245100415257, 0.841623342152787, 0.1085085691452192, \
0.8419680884269794, 
   0.5714401846603873, 0.8412543531329086, 0.4823060686587954, \
0.04846289034181092, 
   0.4005263004826194}, {0.1939888805591158, 0.2805830254933768, \
0.671051724009893, 
   0.8958414132878948, 0.7936255597091487, 0.7641464378619099, \
0.5863210243901892, 
   0.03523366997311827, 0.8224329358132841, 0.1827057278835059, \
0.670848396169685, 
   0.3665032586428567, 0.7364816786543371, 0.1992104372707375, \
0.1533736193065011, 
   0.2830308076387041}, {0.8948583365015501, 0.09070186812551837, 
   0.3114055308795216, 0.7115906229783167, 0.05360398336864133, \
0.6083957994667229, 
   0.2629426405377107, 0.3110643224956972, 0.8596151028095254, \
0.3278127739733461, 
   0.5918909165278178, 0.4152229092078025, 0.06598954310037673, \
0.5636663361114361, 
   0.005569892137628436, 0.3799892392346842}, 
  {0.2435566072870924, 0.3809606082279302, 0.3347214959679432, \
0.0134859805918275, 
   0.5070749286327553, 0.1817501709571926, 0.1813478766614421, \
0.7304551729531233, 
   0.6122165921312053, 0.09104830283167428, 0.8699423457819206, \
0.01886454997480657, 
   0.5586126087625639, 0.4826525033649513, 0.6069997052442097, \
0.7078002274791092}}\
\>", "\<\
{{0.795159, 0.917053, 0.180313, 0.297858, 0.223478, 0.278413, 0.230673, \
0.354739, 
 
   0.403402, 0.304771, 0.472437, 0.0375602, 0.847632, 0.577218, 0.543758, \
0.972107}, 
 
  {0.144084, 0.678651, 0.11301, 0.910492, 0.328148, 0.704205, 0.528098, \
0.707209, 
 
   0.532989, 0.787153, 0.347784, 0.409351, 0.309512, 0.508739, 0.117111, \
0.0546121}, 
 
  {0.90611, 0.203968, 0.644674, 0.017052, 0.0584782, 0.62675, 0.100916, \
0.0449446, 
 
   0.914394, 0.948099, 0.987906, 0.134452, 0.586245, 0.243894, 0.459808, \
0.427244}, 
 
  {0.0532562, 0.456741, 0.112023, 0.0178931, 0.743745, 0.948002, 0.994912, \
0.963281, 
 
   0.837635, 0.744033, 0.350238, 0.946229, 0.779157, 0.117283, 0.249322, \
0.901284}, 
 
  {0.864763, 0.169184, 0.261417, 0.766832, 0.278517, 0.92529, 0.801609, \
0.339588, 
 
   0.225261, 0.468549, 0.689586, 0.321695, 0.481516, 0.520547, 0.694674, \
0.358414}, 
 
  {0.643882, 0.776514, 0.344436, 0.412185, 0.864725, 0.659231, 0.0951137, \
0.5109, 
 
   0.999962, 0.490048, 0.833697, 0.744068, 0.721445, 0.564758, 0.0320883, \
0.40448}, 
 
  {0.496184, 0.0962093, 0.342503, 0.0827855, 0.0146678, 0.575662, 0.647829, \
0.724372, 
 
   0.370786, 0.799148, 0.303393, 0.312187, 0.506061, 0.139917, 0.208279, \
0.801286}, 
 
  {0.506099, 0.64987, 0.374582, 0.0572179, 0.784654, 0.0851118, 0.342494, \
0.652738, 
 
   0.28847, 0.988902, 0.999991, 0.569952, 0.273802, 0.41324, 0.352162, \
0.84558}, 
 
  {0.903016, 0.614092, 0.0487691, 0.533394, 0.396955, 0.474174, 0.84049, \
0.732107, 
 
   0.890855, 0.824305, 0.465907, 0.674889, 0.106201, 0.739193, 0.123414, \
0.0221519}, 
 
  {0.817731, 0.750291, 0.123422, 0.4522, 0.543929, 0.33705, 0.77126, \
0.606619, 
 
   0.640913, 0.722959, 0.722491, 0.0732257, 0.243959, 0.248784, 0.882001, \
0.341118}, 
 
  {0.353104, 0.424479, 0.416094, 0.666229, 0.246902, 0.685286, 0.29268, \
0.644077, 
 
   0.429171, 0.934996, 0.169258, 0.191877, 0.885241, 0.597945, 0.397998, \
0.585258}, 
 
  {0.244328, 0.874987, 0.675507, 0.512032, 0.000368989, 0.626203, 0.793505, \
0.170914, 
 
   0.647265, 0.201723, 0.377411, 0.504685, 0.400363, 0.516437, 0.0847307, \
0.860608}, 
 
  {0.971193, 0.581441, 0.915473, 0.66873, 0.0859513, 0.983495, 0.517475, \
0.0834725, 
 
   0.841623, 0.108509, 0.841968, 0.57144, 0.841254, 0.482306, 0.0484629, \
0.400526}, 
 
  {0.193989, 0.280583, 0.671052, 0.895841, 0.793626, 0.764146, 0.586321, \
0.0352337, 
 
   0.822433, 0.182706, 0.670848, 0.366503, 0.736482, 0.19921, 0.153374, \
0.283031}, 
 
  {0.894858, 0.0907019, 0.311406, 0.711591, 0.053604, 0.608396, 0.262943, \
0.311064, 
 
   0.859615, 0.327813, 0.591891, 0.415223, 0.0659895, 0.563666, 0.00556989, \
0.379989}\\
 
   , {0.243557, 0.380961, 0.334721, 0.013486, 0.507075, 0.18175, 0.181348, \
0.730455, 
 
   0.612217, 0.0910483, 0.869942, 0.0188645, 0.558613, 0.482653, 0.607, \
0.7078}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QueensPermanent[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{111.39*Second, 1.626163106611057*^8}\
\>", "\<\
                          8
{111.39 Second, 1.62616 10 }\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Table[Random[], {i,17},{j,17}]", "Input"],

Cell[OutputFormData["\<\
{{0.6989975059530384, 0.1548397293916051, 0.015108788716392, \
0.2925773182713067, 
   0.6330079628526616, 0.591173393280169, 0.009538896578763573, \
0.9125880790366224, 
   0.3894513555655692, 0.2102127850522387, 0.6748174006108202, \
0.8991020984447949, 
   0.8823764269328139, 0.02846261409504617, 0.493469523949378, \
0.1686469254916716, 
   0.2701598348016086}, {0.9374143112633719, 0.6235271781674574, \
0.1497823755168651, 
   0.7115472260390446, 0.4547618078984204, 0.01652747292324775, \
0.4419821480377557, 
   0.01254972008600622, 0.2999220785068153, 0.001418684206855744, \
0.149404829766449, 
   0.3795417572333445, 0.7087486852266462, 0.9918797876280921, \
0.2368167507298264, 
   0.9900904016677751, 0.4985359001744074}, 
  {0.3170623870172719, 0.3377146522850314, 0.1077139747349612, \
0.4700732860793612, 
   0.8235928630678937, 0.1690677267933597, 0.8375541399333526, \
0.5326589748159894, 
   0.2000656849004363, 0.01928535127649469, 0.1260069138943079, \
0.07789716691756886, 
   0.1835382119771885, 0.5773032032387388, 0.1134571938083017, \
0.7779750884107535, 
   0.1821195277703328}, {0.4278983734722898, 0.7339154365749572, 
   0.06922640318410726, 0.1902397401422406, 0.1910816227424633, \
0.743825034907182, 
   0.5706905030096997, 0.8731773531249686, 0.8533669704574318, \
0.6361110601722207, 
   0.1006172169303385, 0.04958449005707485, 0.6842992436640721, \
0.7985569202388681, 
   0.567958242114349, 0.8495188051566385, 0.6650138923875773}, 
  {0.6725500063445601, 0.4900610751967802, 0.6659805931794499, \
0.08771068914883851, 
   0.5590928125362584, 0.7120859867860266, 0.4838610654091172, \
0.6598123156765486, 
   0.8251773759613012, 0.6428595836019193, 0.2936213252668765, \
0.4687306929340852, 
   0.08135234105411916, 0.07216908059221961, 0.4204439721419078, \
0.6153637224766534, 
   0.4452412808818984}, {0.971551863661881, 0.3708594820848329, \
0.9310644788125813, 
   0.6466843606430302, 0.4035936215475319, 0.5213406769281945, \
0.2660505864250038, 
   0.9741343542984701, 0.9135325463507516, 0.8553600837487444, \
0.1783398972761653, 
   0.4150415417622117, 0.201446559564725, 0.3714990183396272, \
0.5185275815996166, 
   0.5898641658009104, 0.5585869759628056}, 
  {0.07787769307275067, 0.04979688866553141, 0.5085118247467913, \
0.486417895370586, 
   0.6574337209308428, 0.434433166188878, 0.06327054386489288, \
0.5148660317087049, 
   0.2865742388460097, 0.5033686873762968, 0.4165861832218626, \
0.1112724101611729, 
   0.7652335619178153, 0.2373181009512928, 0.4424518289233924, \
0.1977398638104211, 
   0.9098734781690708}, {0.05897820367512758, 0.02741028716118083, 
   0.9962933042456961, 0.5383744598294436, 0.5404506220755108, \
0.4375461213602704, 
   0.4377063282828904, 0.4604967667566929, 0.4906537334099795, \
0.929034296613479, 
   0.9512884329123044, 0.8030630458258499, 0.05622056722110142, \
0.8657637527485862, 
   0.4364224012035995, 0.5164888069798402, 0.5528518798448046}, 
  {0.4491775695267235, 0.3251499910424265, 0.7512552450620249, \
0.3155337788935117, 
   0.006725740603331042, 0.1274101272320053, 0.8413817668929542, \
0.2565555752183841, 
   0.9793154534421502, 0.1311168229863092, 0.3030073070635105, \
0.7161049531428732, 
   0.5417693320818798, 0.6934104947034187, 0.8425105403068176, \
0.2254512197328938, 
   0.6127350354684008}, {0.7421220617911142, 0.03944749448096751, 
   0.1692306525117923, 0.7469712827198145, 0.3056996605875147, \
0.5229586875011271, 
   0.6163787726669877, 0.297793713193091, 0.980549669545088, \
0.7717034424391021, 
   0.300844993773476, 0.29106797258976, 0.8531395423130827, \
0.930321675546148, 
   0.04428941855509184, 0.3117525191476098, 0.7220227193267733}, 
  {0.6273143684826375, 0.3281844654122185, 0.7699831870657299, \
0.02861222462335471, 
   0.7848038281758199, 0.1027332456793247, 0.1572481515973291, \
0.2864901628322404, 
   0.7453563336948524, 0.9335025931675323, 0.4102768688775145, \
0.9807905022447258, 
   0.2223976461937251, 0.3171238205005446, 0.1124831556844234, 
   0.0002408326996375686, 0.4506942037546229}, 
  {0.01627882672706868, 0.8214151830946633, 0.1471012903865548, \
0.5203725282084748, 
   0.9719894081719768, 0.5096626639470535, 0.4250785710597813, \
0.8930581597258374, 
   0.6438049427597583, 0.7396794768813236, 0.3964663464364266, \
0.1082543315500174, 
   0.5410716970804334, 0.5824313252839944, 0.1099761836041861, \
0.362897997855165, 
   0.6075691039129011}, {0.1721544564064798, 0.1291856813594604, \
0.1405003516614398, 
   0.2904452834123563, 0.05967130072205639, 0.1289448486598229, \
0.6898061479068168, 
   0.2741664566852877, 0.2382561176273929, 0.981843558273268, \
0.1694336196983418, 
   0.3021770485133108, 0.7285934536803393, 0.5567649872134867, \
0.2763754599725045, 
   0.6583721057535526, 0.9889139767990155}, 
  {0.1602986407770601, 0.168121128422487, 0.1173004086731191, \
0.4064826515150211, 
   0.05032245717287389, 0.8052231305673219, 0.5097313047602181, \
0.2343281951085412, 
   0.9211367758134134, 0.6647227789058821, 0.2192860213478616, \
0.1746568943864848, 
   0.7921919271535903, 0.9749166309990652, 0.9451195646625739, \
0.9364007767590919, 
   0.8103483688803223}, {0.8054830113007234, 0.642942516149263, \
0.2078073230787526, 
   0.2535833816668356, 0.5291075513282189, 0.9845704103957103, \
0.218893346279737, 
   0.09328474088977554, 0.3609864229057318, 0.8672700017225913, \
0.8124106947647158, 
   0.04296228371690164, 0.5557632923384099, 0.3575386969623733, \
0.5780824996561745, 
   0.1218255079034882, 0.8910405134325277}, 
  {0.1382526756145116, 0.4034256052696896, 0.3296335807498977, \
0.9161238824334624, 
   0.1931331109519376, 0.4670248285105977, 0.5192852118695753, \
0.1106408711327389, 
   0.5501905948026745, 0.2592175054318451, 0.2657018302027398, \
0.5815333198045199, 
   0.565620184406964, 0.04032415915210808, 0.1724170893129642, \
0.220546896898788, 
   0.6983501826843726}, {0.2279134643873922, 0.1294548055960625, \
0.6647836045603781, 
   0.3408114857219993, 0.6498309647312177, 0.007629297692574345, \
0.7737430911278504, 
   0.2025588101074876, 0.2464053594615279, 0.6779957169426765, \
0.857619208694388, 
   0.009425699155550002, 0.7793805309509301, 0.1587105050731011, \
0.7469783375616491, 
   0.4592351043528753, 0.5201630255190851}}\
\>", "\<\
{{0.698998, 0.15484, 0.0151088, 0.292577, 0.633008, 0.591173, 0.0095389, \
0.912588, 
 
   0.389451, 0.210213, 0.674817, 0.899102, 0.882376, 0.0284626, 0.49347, \
0.168647, 
 
   0.27016}, {0.937414, 0.623527, 0.149782, 0.711547, 0.454762, 0.0165275, \
0.441982, 
 
   0.0125497, 0.299922, 0.00141868, 0.149405, 0.379542, 0.708749, 0.99188, \
0.236817, 
 
   0.99009, 0.498536}, {0.317062, 0.337715, 0.107714, 0.470073, 0.823593, \
0.169068, 
 
   0.837554, 0.532659, 0.200066, 0.0192854, 0.126007, 0.0778972, 0.183538, \
0.577303, 
 
   0.113457, 0.777975, 0.18212}, {0.427898, 0.733915, 0.0692264, 0.19024, \
0.191082, 
 
   0.743825, 0.570691, 0.873177, 0.853367, 0.636111, 0.100617, 0.0495845, \
0.684299, 
 
   0.798557, 0.567958, 0.849519, 0.665014}, 
 
  {0.67255, 0.490061, 0.665981, 0.0877107, 0.559093, 0.712086, 0.483861, \
0.659812, 
 
   0.825177, 0.64286, 0.293621, 0.468731, 0.0813523, 0.0721691, 0.420444, \
0.615364, 
 
   0.445241}, {0.971552, 0.370859, 0.931064, 0.646684, 0.403594, 0.521341, \
0.266051, 
 
   0.974134, 0.913533, 0.85536, 0.17834, 0.415042, 0.201447, 0.371499, \
0.518528, 
 
   0.589864, 0.558587}, {0.0778777, 0.0497969, 0.508512, 0.486418, 0.657434, 
 
   0.434433, 0.0632705, 0.514866, 0.286574, 0.503369, 0.416586, 0.111272, \
0.765234, 
 
   0.237318, 0.442452, 0.19774, 0.909873}, 
 
  {0.0589782, 0.0274103, 0.996293, 0.538374, 0.540451, 0.437546, 0.437706, \
0.460497, 
 
   0.490654, 0.929034, 0.951288, 0.803063, 0.0562206, 0.865764, 0.436422, \
0.516489, 
 
   0.552852}, {0.449178, 0.32515, 0.751255, 0.315534, 0.00672574, 0.12741, \
0.841382, 
 
   0.256556, 0.979315, 0.131117, 0.303007, 0.716105, 0.541769, 0.69341, \
0.842511, 
 
   0.225451, 0.612735}, {0.742122, 0.0394475, 0.169231, 0.746971, 0.3057, \
0.522959, 
 
   0.616379, 0.297794, 0.98055, 0.771703, 0.300845, 0.291068, 0.85314, \
0.930322, 
 
   0.0442894, 0.311753, 0.722023}, 
 
  {0.627314, 0.328184, 0.769983, 0.0286122, 0.784804, 0.102733, 0.157248, \
0.28649, 
 
   0.745356, 0.933503, 0.410277, 0.980791, 0.222398, 0.317124, 0.112483, \
0.000240833, 
 
   0.450694}, {0.0162788, 0.821415, 0.147101, 0.520373, 0.971989, 0.509663, \
0.425079, 
 
   0.893058, 0.643805, 0.739679, 0.396466, 0.108254, 0.541072, 0.582431, \
0.109976, 
 
   0.362898, 0.607569}, {0.172154, 0.129186, 0.1405, 0.290445, 0.0596713, \
0.128945, 
 
   0.689806, 0.274166, 0.238256, 0.981844, 0.169434, 0.302177, 0.728593, \
0.556765, 
 
   0.276375, 0.658372, 0.988914}, {0.160299, 0.168121, 0.1173, 0.406483, \
0.0503225, 
 
   0.805223, 0.509731, 0.234328, 0.921137, 0.664723, 0.219286, 0.174657, \
0.792192, 
 
   0.974917, 0.94512, 0.936401, 0.810348}, 
 
  {0.805483, 0.642943, 0.207807, 0.253583, 0.529108, 0.98457, 0.218893, \
0.0932847, 
 
   0.360986, 0.86727, 0.812411, 0.0429623, 0.555763, 0.357539, 0.578082, \
0.121826, 
 
   0.891041}, {0.138253, 0.403426, 0.329634, 0.916124, 0.193133, 0.467025, \
0.519285, 
 
   0.110641, 0.550191, 0.259218, 0.265702, 0.581533, 0.56562, 0.0403242, \
0.172417, 
 
   0.220547, 0.69835}, {0.227913, 0.129455, 0.664784, 0.340811, 0.649831, \
0.0076293, 
 
   0.773743, 0.202559, 0.246405, 0.677996, 0.857619, 0.0094257, 0.779381, \
0.158711, 
 
   0.746978, 0.459235, 0.520163}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QueensPermanent[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{229.7*Second, 6.175922632598446*^8}\
\>", "\<\
                         8
{229.7 Second, 6.17592 10 }\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = Table[Random[], {i,18},{j,18}]", "Input"],

Cell[OutputFormData["\<\
{{0.8930086748703613, 0.1654450177571291, 0.8936149199459112, \
0.479838866366977, 
   0.720591585557397, 0.9448981208583409, 0.1952647372615386, \
0.2519254019795847, 
   0.5911367799613344, 0.2801145162979628, 0.8544532515395392, \
0.602094437248367, 
   0.5835074822687602, 0.5063714251701124, 0.6518944414320515, \
0.3556890777868391, 
   0.9055117653260836, 0.6487522164757244}, 
  {0.6424687422765015, 0.5763085468359089, 0.7468012602529824, \
0.9017738789140754, 
   0.1832336379236261, 0.0561455213168238, 0.8537925853826211, \
0.7363288611569461, 
   0.2896187179777148, 0.5763066549498468, 0.1332009998252239, \
0.791430740298605, 
   0.09435398071617619, 0.3243812529702619, 0.5420642198638894, \
0.5113162240006422, 
   0.2399007291766369, 0.7222868157218949}, 
  {0.9585567375951292, 0.00494479883052974, 0.5880062877445854, \
0.3665977379350557, 
   0.05304497226904554, 0.3561925823548053, 0.9455375454680837, \
0.7902891910991467, 
   0.306243712016063, 0.45441870344073, 0.7623039075444576, \
0.734143669782323, 
   0.4524511266334419, 0.7180898422837839, 0.4726851895667428, \
0.1578370148324762, 
   0.319250126808218, 0.9266591019851787}, 
  {0.3783312088505666, 0.8334557618622142, 0.7771859069443286, \
0.4153428779845365, 
   0.1384304796739297, 0.1111689461403193, 0.8186291693491993, \
0.4103980791540068, 
   0.5504241919293443, 0.7445712082052637, 0.7655841970801539, \
0.05420549679920149, 
   0.6048866464612605, 0.9542820171061169, 0.4593404850640908, \
0.5997867933584714, 
   0.8425827389168029, 0.2201383473237939}, 
  {0.006889358430648863, 0.8816969510746876, 0.36989754935006, \
0.06230133249131768, 
   0.6876392316224309, 0.9550378490895088, 0.9915663404994933, \
0.2288455706291034, 
   0.9104533246781022, 0.5396949711049722, 0.8531358608255635, \
0.117676624488784, 
   0.0918241553289028, 0.1292968919509654, 0.3027116688962192, \
0.3731054162835203, 
   0.3262399582487489, 0.07509139515176394}, 
  {0.6978250224349587, 0.4188233991774035, 0.8668994731846581, \
0.4753046017932924, 
   0.8552422835181559, 0.1986850518536096, 0.8600101147540092, \
0.5936076507186048, 
   0.4853447341680959, 0.1363837193622918, 0.1723708831315783, \
0.638569801629096, 
   0.4937783936686025, 0.9075381487331885, 0.2619175584534761, \
0.09887483052412376, 
   0.6406425328430389, 0.7898615242444043}, 
  {0.1700934031245733, 0.9695779385731583, 0.3379308639468196, \
0.4167561079608839, 
   0.8438534448758245, 0.8944865434213944, 0.6401058415118608, \
0.9979327087834805, 
   0.9769539716911664, 0.4191819416281019, 0.784863557993705, \
0.7992476569298708, 
   0.1169438569371571, 0.8255742909094971, 0.299518823825609, \
0.6628639375675789, 
   0.9445729738055788, 0.187004489280401}, 
  {0.8057404301570064, 0.7553257888343906, 0.6826554153521025, \
0.08812965875627726, 
   0.1650978973139675, 0.965464264589986, 0.5125620122275292, \
0.1185517201831189, 
   0.827167033367148, 0.5487081566291021, 0.6687085673517048, \
0.2240651767617245, 
   0.187061191855287, 0.5507754478456217, 0.6917545956605385, \
0.8048832351336226, 
   0.4021976338615821, 0.7515277909157507}, 
  {0.5748107387233813, 0.9793089442241257, 0.102678810035973, \
0.08866385334817177, 
   0.6302377649178025, 0.7923044549437245, 0.2969383798789665, \
0.3333380645137812, 
   0.9475823495656999, 0.7041747961874472, 0.1318404825649989, \
0.367873799923795, 
   0.4350203373381706, 0.5856230760043282, 0.304673449197851, \
0.8191656432946928, 
   0.7663117699864657, 0.3615578992426037}, 
  {0.1176122573425639, 0.2683901954490711, 0.07455717432592726, \
0.556674664108981, 
   0.7154146234809818, 0.5168624045333203, 0.4997464356025458, \
0.5773657198848555, 
   0.6127358134450088, 0.4281985511851486, 0.8695086706847432, \
0.7850612649411309, 
   0.3157974335660422, 0.09486048667136742, 0.9219263211190432, \
0.08088646875368375, 
   0.1839569510010432, 0.7269866867475723}, 
  {0.4869059837808726, 0.4952633927493554, 0.8792835018031921, \
0.9078210434528795, 
   0.7205942137944068, 0.1337054935067517, 0.7616712444606283, \
0.6394308480038083, 
   0.6460370394684796, 0.5770308293977706, 0.04625662097964639, \
0.1225684434704879, 
   0.1462906038659337, 0.999665109512915, 0.4335208075346375, \
0.6943698922853394, 
   0.2767819331811904, 0.2146038445717841}, 
  {0.1177233739685954, 0.5995094056139719, 0.3548556120621471, \
0.1337173758181004, 
   0.9337664229675521, 0.8725227188663994, 0.8679496282812745, \
0.6384539830687449, 
   0.05448292116435998, 0.9647016754135201, 0.1473554144868676, \
0.5047484895619932, 
   0.2928116767037317, 0.3252708274097116, 0.501318375018388, \
0.9277176601642224, 
   0.2465550557240853, 0.2027023839392236}, 
  {0.3550277711524543, 0.9280525506513074, 0.8130342481894476, \
0.5083324916538842, 
   0.07824583797126392, 0.7134487060795232, 0.6953108742208523, \
0.9088230860399123, 
   0.7233902259091166, 0.5797313302614228, 0.7615444512533001, \
0.03630036717351277, 
   0.8554405976278422, 0.9412773471926778, 0.7070615300889401, \
0.07159869175999272, 
   0.7080851831409745, 0.4365288576306846}, 
  {0.4142498533852084, 0.746327864350281, 0.2067668081225864, \
0.508811197466462, 
   0.167694797661123, 0.5436254804110573, 0.851739036970132, \
0.5807586468151546, 
   0.3546605494716752, 0.03529298875717307, 0.7734931989988681, \
0.8673099407356314, 
   0.6593496752508229, 0.1264699027172607, 0.05010297308975139, \
0.2875786104742085, 
   0.8978052239975228, 0.09016953554374794}, 
  {0.1946623754619091, 0.3463012632815307, 0.1907436939085826, \
0.01857084378375521, 
   0.4865771923209345, 0.9097724056508461, 0.7764938405233742, \
0.2722429794334741, 
   0.2798103841983481, 0.4009612081843839, 0.6087990428622511, \
0.7286174990224168, 
   0.428071347228216, 0.8202025613692292, 0.2541384933905758, \
0.6933245102652437, 
   0.6545781482293478, 0.9528926206335979}, 
  {0.5947888181397527, 0.5668546075479829, 0.6044751751395964, \
0.6653140101593892, 
   0.6969835941422299, 0.476685072004235, 0.4098127996776873, \
0.3190127468778585, 
   0.5062399002336474, 0.4581142282204798, 0.9232356073567528, \
0.4092403412270124, 
   0.7297460597102731, 0.1858712487870056, 0.6434252231584046, \
0.008279133042628481, 
   0.1209470168480219, 0.4572537497645888}, 
  {0.2153538759301885, 0.1880765716733991, 0.866808523457446, \
0.7639292394993452, 
   0.5607757277008405, 0.2351839510398012, 0.2720197053176932, \
0.1970746319513622, 
   0.9563005525612441, 0.5698699408804119, 0.5750361111754632, \
0.7203895599471271, 
   0.5464877528835567, 0.2508571940025534, 0.06879621094181582, \
0.2622753317266473, 
   0.6232521455268039, 0.8416168527755409}, 
  {0.3390501512315426, 0.07640408293964171, 0.9798269223683993, \
0.8333377197329124, 
   0.2181031343835206, 0.6191503331750528, 0.7644730464382107, \
0.6452611480595132, 
   0.3512946109260745, 0.8552210936757075, 0.2036973187373702, \
0.4100771970197119, 
   0.07927490560838132, 0.6581464617243454, 0.247396766176126, \
0.8402072561393, 
   0.504238794432918, 0.9377569017772183}}\
\>", "\<\
{{0.893009, 0.165445, 0.893615, 0.479839, 0.720592, 0.944898, 0.195265, \
0.251925, 
 
   0.591137, 0.280115, 0.854453, 0.602094, 0.583507, 0.506371, 0.651894, \
0.355689, 
 
   0.905512, 0.648752}, {0.642469, 0.576309, 0.746801, 0.901774, 0.183234, \
0.0561455, 
 
   0.853793, 0.736329, 0.289619, 0.576307, 0.133201, 0.791431, 0.094354, \
0.324381, 
 
   0.542064, 0.511316, 0.239901, 0.722287}, 
 
  {0.958557, 0.0049448, 0.588006, 0.366598, 0.053045, 0.356193, 0.945538, \
0.790289, 
 
   0.306244, 0.454419, 0.762304, 0.734144, 0.452451, 0.71809, 0.472685, \
0.157837, 
 
   0.31925, 0.926659}, {0.378331, 0.833456, 0.777186, 0.415343, 0.13843, \
0.111169, 
 
   0.818629, 0.410398, 0.550424, 0.744571, 0.765584, 0.0542055, 0.604887, \
0.954282, 
 
   0.45934, 0.599787, 0.842583, 0.220138}, 
 
  {0.00688936, 0.881697, 0.369898, 0.0623013, 0.687639, 0.955038, 0.991566, \
0.228846, 
 
   0.910453, 0.539695, 0.853136, 0.117677, 0.0918242, 0.129297, 0.302712, \
0.373105, 
 
   0.32624, 0.0750914}, {0.697825, 0.418823, 0.866899, 0.475305, 0.855242, \
0.198685, 
 
   0.86001, 0.593608, 0.485345, 0.136384, 0.172371, 0.63857, 0.493778, \
0.907538, 
 
   0.261918, 0.0988748, 0.640643, 0.789862}, 
 
  {0.170093, 0.969578, 0.337931, 0.416756, 0.843853, 0.894487, 0.640106, \
0.997933, 
 
   0.976954, 0.419182, 0.784864, 0.799248, 0.116944, 0.825574, 0.299519, \
0.662864, 
 
   0.944573, 0.187004}, {0.80574, 0.755326, 0.682655, 0.0881297, 0.165098, \
0.965464, 
 
   0.512562, 0.118552, 0.827167, 0.548708, 0.668709, 0.224065, 0.187061, \
0.550775, 
 
   0.691755, 0.804883, 0.402198, 0.751528}, 
 
  {0.574811, 0.979309, 0.102679, 0.0886639, 0.630238, 0.792304, 0.296938, \
0.333338, 
 
   0.947582, 0.704175, 0.13184, 0.367874, 0.43502, 0.585623, 0.304673, \
0.819166, 
 
   0.766312, 0.361558}, {0.117612, 0.26839, 0.0745572, 0.556675, 0.715415, \
0.516862, 
 
   0.499746, 0.577366, 0.612736, 0.428199, 0.869509, 0.785061, 0.315797, \
0.0948605, 
 
   0.921926, 0.0808865, 0.183957, 0.726987}, 
 
  {0.486906, 0.495263, 0.879284, 0.907821, 0.720594, 0.133705, 0.761671, \
0.639431, 
 
   0.646037, 0.577031, 0.0462566, 0.122568, 0.146291, 0.999665, 0.433521, \
0.69437, 
 
   0.276782, 0.214604}, {0.117723, 0.599509, 0.354856, 0.133717, 0.933766, \
0.872523, 
 
   0.86795, 0.638454, 0.0544829, 0.964702, 0.147355, 0.504748, 0.292812, \
0.325271, 
 
   0.501318, 0.927718, 0.246555, 0.202702}, 
 
  {0.355028, 0.928053, 0.813034, 0.508332, 0.0782458, 0.713449, 0.695311, \
0.908823, 
 
   0.72339, 0.579731, 0.761544, 0.0363004, 0.855441, 0.941277, 0.707062, \
0.0715987, 
 
   0.708085, 0.436529}, {0.41425, 0.746328, 0.206767, 0.508811, 0.167695, \
0.543625, 
 
   0.851739, 0.580759, 0.354661, 0.035293, 0.773493, 0.86731, 0.65935, \
0.12647, 
 
   0.050103, 0.287579, 0.897805, 0.0901695}, 
 
  {0.194662, 0.346301, 0.190744, 0.0185708, 0.486577, 0.909772, 0.776494, \
0.272243, 
 
   0.27981, 0.400961, 0.608799, 0.728617, 0.428071, 0.820203, 0.254138, \
0.693325, 
 
   0.654578, 0.952893}, {0.594789, 0.566855, 0.604475, 0.665314, 0.696984, \
0.476685, 
 
   0.409813, 0.319013, 0.50624, 0.458114, 0.923236, 0.40924, 0.729746, \
0.185871, 
 
   0.643425, 0.00827913, 0.120947, 0.457254}, 
 
  {0.215354, 0.188077, 0.866809, 0.763929, 0.560776, 0.235184, 0.27202, \
0.197075, 
 
   0.956301, 0.56987, 0.575036, 0.72039, 0.546488, 0.250857, 0.0687962, \
0.262275, 
 
   0.623252, 0.841617}, {0.33905, 0.0764041, 0.979827, 0.833338, 0.218103, \
0.61915, 
 
   0.764473, 0.645261, 0.351295, 0.855221, 0.203697, 0.410077, 0.0792749, \
0.658146, 
 
   0.247397, 0.840207, 0.504239, 0.937757}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QueensPermanent[A] //Timing", "Input"],

Cell[OutputFormData["\<\
{482.47*Second, 4.194144385325866*^10}\
\>", "\<\
                          10
{482.47 Second, 4.19414 10  }\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "We see that the calculation time is determined by a function f(n) \[Tilde] \
const. ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  ", too (see subsection \"",
  "Test of the procedure Permanent\"",
  ". This corresponds to the fact, that Ryser's formula calculates a \
permanent of an (n\[Times]n)-matrix in ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " steps.\n\nThe last 3 calculations needed the following memory:"
}], "Text"],

Cell[CellGroupData[{

Cell["MemoryInUse[]", "Input"],

Cell[OutputFormData["\<\
889256\
\>", "\<\
889256\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaxMemoryUsed[]", "Input"],

Cell[OutputFormData["\<\
944008\
\>", "\<\
944008\
\>"], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The program Queens0", "Section"],

Cell["\<\
The program Queens0 determines the number of queens solutions for an (n\
\[Times]n)-board. It is the version of Vardi [1] which uses the procedure \
Permanent. However, Permanent has high costs in memory.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The definition of Queens0", "Subsection"],

Cell["\<\
Before you evaluate the cells of this subsection, you have to evaluate the \
cells of the subsection \"The definition of Permanent\".\
\>", "Text"],

Cell["x/: x[_]^_ := 0", "Input"],

Cell["y/: y[_]^_ := 0", "Input"],

Cell["\<\
Queens0[n_] := Expand[
                     Permanent[
                              Array[x[#1 + #2]*y[#1 - #2] & ,
                                   {n,n}
                                   ]
                              ]
                     ] /. x[_] -> 1 /. y[_] ->1\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Calculation of numbers of queens solutions by means of Queens\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["Timing[Queens0[2]]", "Input"],

Cell[OutputFormData["\<\
{0.1099999999999994*Second, 0}\
\>", "\<\
{0.11 Second, 0}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens0[3]]", "Input"],

Cell[OutputFormData["\<\
{0.*Second, 0}\
\>", "\<\
{0. Second, 0}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens0[4]]", "Input"],

Cell[OutputFormData["\<\
{0.1099999999999994*Second, 2}\
\>", "\<\
{0.11 Second, 2}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens0[5]]", "Input"],

Cell[OutputFormData["\<\
{1.810000000000002*Second, 10}\
\>", "\<\
{1.81 Second, 10}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens0[6]]", "Input"],

Cell[OutputFormData["\<\
{41.13999999999998*Second, 4}\
\>", "\<\
{41.14 Second, 4}\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "The evaluation of  Timing[Queens0[7]] could not be carried out. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " changed into the swapp mode with very many accesses to the hard disk. \
After a time of 30 minutes we stopped the calculation."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The program Queens", "Section"],

Cell["\<\
The program Queens determines the number of queens solutions for an \
(n\[Times]n)-board. The version Queens0 of Vardi [1] uses the procedure \
Permanent which has high costs in memory. We use the procedure \
QueensPermanent which allows a cancelation of all terms that are not square \
free after every multiplication. Thus the procedure QueensPermanent leads to \
essentially smaller costs in memory.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The definition of Queens", "Subsection"],

Cell["\<\
Before you evaluate the cells of this subsection, you have to evaluate the \
cells of the subsection \"The definition of QueensPermanent\".\
\>", "Text"],

Cell["x/: x[_]^_ := 0", "Input"],

Cell["y/: y[_]^_ := 0", "Input"],

Cell["\<\
Queens[n_] := QueensPermanent[
                             Array[x[#1 + #2]*y[#1 - #2] & ,
                                  {n,n}
                                  ]
                             ] /. x[_] -> 1 /. y[_] ->1\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Calculation of numbers of queens solutions by means of Queens\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["Timing[Queens[2]]", "Input"],

Cell[OutputFormData["\<\
{0.1100000000000136*Second, 0}\
\>", "\<\
{0.11 Second, 0}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens[3]]", "Input"],

Cell[OutputFormData["\<\
{0.*Second, 0}\
\>", "\<\
{0. Second, 0}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens[4]]", "Input"],

Cell[OutputFormData["\<\
{0.1100000000000136*Second, 2}\
\>", "\<\
{0.11 Second, 2}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens[5]]", "Input"],

Cell[OutputFormData["\<\
{0.5499999999999829*Second, 10}\
\>", "\<\
{0.55 Second, 10}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens[6]]", "Input"],

Cell[OutputFormData["\<\
{5.219999999999998*Second, 4}\
\>", "\<\
{5.22 Second, 4}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens[7]]", "Input"],

Cell[OutputFormData["\<\
{58.44*Second, 40}\
\>", "\<\
{58.44 Second, 40}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timing[Queens[8]]", "Input"],

Cell[OutputFormData["\<\
{771.5399999999999*Second, 92}\
\>", "\<\
{771.54 Second, 92}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MemoryInUse[]", "Input"],

Cell[OutputFormData["\<\
889504\
\>", "\<\
889504\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaxMemoryUsed[]", "Input"],

Cell[OutputFormData["\<\
18289080\
\>", "\<\
18289080\
\>"], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{712, 595},
WindowMargins->{{0, Automatic}, {Automatic, 5}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 105, "Title"],
Cell[1771, 53, 133, 5, 65, "Subtitle"],
Cell[1907, 60, 65, 3, 93, "Subtitle"],
Cell[1975, 65, 92, 2, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2092, 71, 30, 0, 53, "Section"],
Cell[2125, 73, 68, 1, 33, "Text"],
Cell[2196, 76, 108, 3, 33, "Text"],
Cell[2307, 81, 48, 1, 33, "Text"],
Cell[2358, 84, 102, 3, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2497, 92, 29, 0, 33, "Section"],
Cell[2529, 94, 192, 5, 33, "Text"],
Cell[2724, 101, 99, 2, 33, "Text"],
Cell[2826, 105, 156, 3, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3019, 113, 45, 0, 33, "Section"],
Cell[3067, 115, 321, 6, 71, "Text"],
Cell[3391, 123, 179, 7, 120, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3607, 135, 29, 0, 33, "Section"],
Cell[3639, 137, 106, 3, 33, "Text"],
Cell[3748, 142, 676, 32, 570, "Input"],
Cell[4427, 176, 89, 2, 30, "Input"],
Cell[4519, 180, 67, 0, 30, "Input"],
Cell[4589, 182, 89, 2, 30, "Input"],
Cell[4681, 186, 646, 20, 354, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5364, 211, 47, 0, 33, "Section"],
Cell[5414, 213, 179, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[5618, 221, 70, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[5713, 225, 34, 0, 30, "Input"],
Cell[5750, 227, 58, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5845, 236, 34, 0, 30, "Input"],
Cell[5882, 238, 58, 4, 27, "Output"]
}, Open  ]],
Cell[5955, 245, 54, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6046, 250, 56, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[6127, 254, 48, 0, 30, "Input"],
Cell[6178, 256, 136, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6351, 265, 29, 0, 30, "Input"],
Cell[6383, 267, 72, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6492, 276, 48, 0, 30, "Input"],
Cell[6543, 278, 2314, 46, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8894, 329, 41, 0, 30, "Input"],
Cell[8938, 331, 31687, 675, 146, 4418, 334, "GraphicsData", 
"PostScript", "Graphics"],
Cell[40628, 1008, 2362, 47, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[43039, 1061, 46, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[43110, 1065, 48, 0, 30, "Input"],
Cell[43161, 1067, 463, 12, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43661, 1084, 29, 0, 30, "Input"],
Cell[43693, 1086, 91, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43821, 1095, 32, 0, 30, "Input"],
Cell[43856, 1097, 58, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43951, 1106, 48, 0, 30, "Input"],
Cell[44002, 1108, 15590, 298, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59629, 1411, 40, 0, 30, "Input"],
Cell[59672, 1413, 137, 3, 42, "Message"],
Cell[59812, 1418, 14336, 279, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74185, 1702, 42, 0, 30, "Input"],
Cell[74230, 1704, 134563, 3211, 411, 25800, 1863, "GraphicsData", 
"PostScript", "Graphics"],
Cell[208798, 4918, 14537, 283, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223372, 5206, 32, 0, 30, "Input"],
Cell[223407, 5208, 31169, 566, 202, 2965, 213, "GraphicsData", 
"PostScript", "Graphics"],
Cell[254579, 5776, 1568, 33, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[256196, 5815, 46, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[256267, 5819, 48, 0, 30, "Input"],
Cell[256318, 5821, 268, 7, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256623, 5833, 29, 0, 30, "Input"],
Cell[256655, 5835, 90, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256782, 5844, 32, 0, 30, "Input"],
Cell[256817, 5846, 56, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256910, 5855, 48, 0, 30, "Input"],
Cell[256961, 5857, 8288, 168, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[265286, 6030, 40, 0, 30, "Input"],
Cell[265329, 6032, 8453, 167, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[273819, 6204, 42, 0, 30, "Input"],
Cell[273864, 6206, 62564, 1693, 296, 15288, 1104, "GraphicsData", 
"PostScript", "Graphics"],
Cell[336431, 7901, 8603, 172, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[345083, 8079, 46, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[345154, 8083, 48, 0, 30, "Input"],
Cell[345205, 8085, 2069, 44, 287, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347311, 8134, 29, 0, 30, "Input"],
Cell[347343, 8136, 89, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347469, 8145, 32, 0, 30, "Input"],
Cell[347504, 8147, 58, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347599, 8156, 48, 0, 30, "Input"],
Cell[347650, 8158, 103278, 1940, 127, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[450965, 10103, 40, 0, 30, "Input"],
Cell[451008, 10105, 105318, 1965, 167, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[556363, 12075, 42, 0, 30, "Input"],
Cell[556408, 12077, 458263, 17175, 844, 175791, 13676, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1014674, 29254, 106846, 2003, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1121569, 31263, 46, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[1121640, 31267, 48, 0, 30, "Input"],
Cell[1121691, 31269, 5304, 155, 627, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1127032, 31429, 29, 0, 30, "Input"],
Cell[1127064, 31431, 90, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1127191, 31440, 32, 0, 30, "Input"],
Cell[1127226, 31442, 58, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1127321, 31451, 48, 0, 30, "Input"],
Cell[1127372, 31453, 289847, 5103, 287, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1417256, 36561, 40, 0, 30, "Input"],
Cell[1417299, 36563, 288351, 4986, 307, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1705687, 41554, 42, 0, 30, "Input"],
Cell[1705732, 41556, 817454, 41922, 607, 524390, 38286, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2523189, 83480, 292138, 5043, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2815364, 88528, 59, 0, 30, "Input"],
Cell[2815426, 88530, 39027, 1222, 146, 12238, 886, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2854456, 89754, 6458, 113, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2860963, 89873, 46, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[2861034, 89877, 58, 0, 30, "Input"],
Cell[2861095, 89879, 80, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2861212, 89888, 27, 0, 30, "Input"],
Cell[2861242, 89890, 60, 4, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2861351, 89900, 49, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[2861425, 89904, 41, 0, 30, "Input"],
Cell[2861469, 89906, 271, 6, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2861777, 89917, 30, 0, 30, "Input"],
Cell[2861810, 89919, 68, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2861915, 89928, 32, 0, 30, "Input"],
Cell[2861950, 89930, 70, 4, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2862081, 89941, 44, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[2862150, 89945, 46, 0, 47, "Subsection"],
Cell[2862199, 89947, 96, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[2862320, 89953, 33, 0, 30, "Input"],
Cell[2862356, 89955, 233, 12, 210, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2862638, 89973, 47, 0, 31, "Subsection"],
Cell[2862688, 89975, 158, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[2862871, 89982, 35, 0, 30, "Input"],
Cell[2862909, 89984, 134, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2863080, 89993, 39, 0, 30, "Input"],
Cell[2863122, 89995, 146, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2863305, 90004, 35, 0, 30, "Input"],
Cell[2863343, 90006, 236, 7, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2863616, 90018, 39, 0, 30, "Input"],
Cell[2863658, 90020, 406, 10, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2864101, 90035, 35, 0, 30, "Input"],
Cell[2864139, 90037, 370, 9, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2864546, 90051, 39, 0, 30, "Input"],
Cell[2864588, 90053, 1845, 40, 267, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2866470, 90098, 35, 0, 30, "Input"],
Cell[2866508, 90100, 556, 16, 107, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2867101, 90121, 39, 0, 30, "Input"],
Cell[2867143, 90123, 11361, 361, 2407, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2878541, 90489, 35, 0, 30, "Input"],
Cell[2878579, 90491, 766, 19, 127, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2879382, 90515, 39, 0, 30, "Input"],
Cell[2879424, 90517, 79280, 2161, 14407, "Output"]
}, Open  ]],
Cell[2958719, 92681, 348, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[2959092, 92692, 35, 0, 30, "Input"],
Cell[2959130, 92694, 1012, 22, 147, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2960179, 92721, 39, 0, 30, "Input"],
Cell[2960221, 92723, 70, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2960328, 92732, 30, 0, 30, "Input"],
Cell[2960361, 92734, 66, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2960464, 92743, 32, 0, 30, "Input"],
Cell[2960499, 92745, 70, 4, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2960618, 92755, 45, 0, 31, "Subsection"],
Cell[2960666, 92757, 258, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[2960949, 92766, 67, 0, 43, "Subsubsection"],
Cell[2961019, 92768, 177, 9, 156, "Input"],
Cell[2961199, 92779, 464, 16, 282, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2961700, 92800, 56, 0, 29, "Subsubsection"],
Cell[2961759, 92802, 176, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[2961960, 92810, 35, 0, 30, "Input"],
Cell[2961998, 92812, 766, 19, 127, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2962801, 92836, 36, 0, 30, "Input"],
Cell[2962840, 92838, 25348, 685, 4567, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2988225, 93528, 29, 0, 30, "Input"],
Cell[2988257, 93530, 58, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2988352, 93539, 47, 0, 30, "Input"],
Cell[2988402, 93541, 106, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2988545, 93550, 30, 0, 30, "Input"],
Cell[2988578, 93552, 60, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2988675, 93561, 37, 0, 30, "Input"],
Cell[2988715, 93563, 60, 4, 27, "Output"]
}, Open  ]],
Cell[2988790, 93570, 22, 0, 30, "Input"],
Cell[2988815, 93572, 419, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[2989259, 93583, 33, 0, 30, "Input"],
Cell[2989295, 93585, 2526, 52, 347, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2991858, 93642, 36, 0, 30, "Input"],
Cell[2991897, 93644, 2629, 59, 387, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2994563, 93708, 27, 0, 30, "Input"],
Cell[2994593, 93710, 62, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2994692, 93719, 38, 0, 30, "Input"],
Cell[2994733, 93721, 190, 4, 27, "Output"]
}, Open  ]],
Cell[2994938, 93728, 112, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[2995075, 93735, 50, 0, 30, "Input"],
Cell[2995128, 93737, 8383, 215, 687, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3003548, 93957, 38, 0, 30, "Input"],
Cell[3003589, 93959, 156, 5, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3003782, 93969, 50, 0, 30, "Input"],
Cell[3003835, 93971, 9503, 239, 847, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3013375, 94215, 38, 0, 30, "Input"],
Cell[3013416, 94217, 147, 5, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3013600, 94227, 50, 0, 30, "Input"],
Cell[3013653, 94229, 10628, 270, 907, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3024318, 94504, 38, 0, 30, "Input"],
Cell[3024359, 94506, 150, 5, 37, "Output"]
}, Open  ]],
Cell[3024524, 94514, 400, 10, 90, "Text"],

Cell[CellGroupData[{
Cell[3024949, 94528, 30, 0, 30, "Input"],
Cell[3024982, 94530, 66, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3025085, 94539, 32, 0, 30, "Input"],
Cell[3025120, 94541, 66, 4, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3025247, 94552, 51, 0, 31, "Subsection"],
Cell[3025301, 94554, 211, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[3025537, 94562, 73, 0, 43, "Subsubsection"],
Cell[3025613, 94564, 177, 9, 156, "Input"],

Cell[CellGroupData[{
Cell[3025815, 94577, 602, 20, 354, "Input"],
Cell[3026420, 94599, 142, 5, 59, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3026611, 94610, 62, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[3026698, 94614, 35, 0, 30, "Input"],
Cell[3026736, 94616, 766, 19, 127, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3027539, 94640, 51, 0, 30, "Input"],
Cell[3027593, 94642, 106, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3027736, 94651, 29, 0, 30, "Input"],
Cell[3027768, 94653, 60, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3027865, 94662, 36, 0, 30, "Input"],
Cell[3027904, 94664, 60, 4, 27, "Output"]
}, Open  ]],
Cell[3027979, 94671, 367, 8, 90, "Text"],

Cell[CellGroupData[{
Cell[3028371, 94683, 33, 0, 30, "Input"],
Cell[3028407, 94685, 2518, 49, 327, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3030962, 94739, 36, 0, 30, "Input"],
Cell[3031001, 94741, 2626, 58, 387, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3033664, 94804, 27, 0, 30, "Input"],
Cell[3033694, 94806, 62, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3033793, 94815, 44, 0, 30, "Input"],
Cell[3033840, 94817, 180, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3034057, 94826, 51, 0, 30, "Input"],
Cell[3034111, 94828, 8420, 224, 647, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3042568, 95057, 44, 0, 30, "Input"],
Cell[3042615, 95059, 147, 5, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3042799, 95069, 51, 0, 30, "Input"],
Cell[3042853, 95071, 9526, 253, 787, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3052416, 95329, 44, 0, 30, "Input"],
Cell[3052463, 95331, 144, 5, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3052644, 95341, 51, 0, 30, "Input"],
Cell[3052698, 95343, 10648, 289, 907, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3063383, 95637, 44, 0, 30, "Input"],
Cell[3063430, 95639, 150, 5, 37, "Output"]
}, Open  ]],
Cell[3063595, 95647, 469, 12, 90, "Text"],

Cell[CellGroupData[{
Cell[3064089, 95663, 30, 0, 30, "Input"],
Cell[3064122, 95665, 66, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3064225, 95674, 32, 0, 30, "Input"],
Cell[3064260, 95676, 66, 4, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3064399, 95688, 38, 0, 33, "Section"],
Cell[3064440, 95690, 228, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[3064693, 95698, 47, 0, 47, "Subsection"],
Cell[3064743, 95700, 157, 3, 33, "Text"],
Cell[3064903, 95705, 32, 0, 30, "Input"],
Cell[3064938, 95707, 32, 0, 30, "Input"],
Cell[3064973, 95709, 299, 8, 138, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3065309, 95722, 91, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[3065425, 95728, 35, 0, 30, "Input"],
Cell[3065463, 95730, 100, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3065600, 95739, 35, 0, 30, "Input"],
Cell[3065638, 95741, 82, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3065757, 95750, 35, 0, 30, "Input"],
Cell[3065795, 95752, 100, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3065932, 95761, 35, 0, 30, "Input"],
Cell[3065970, 95763, 101, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3066108, 95772, 35, 0, 30, "Input"],
Cell[3066146, 95774, 100, 4, 27, "Output"]
}, Open  ]],
Cell[3066261, 95781, 281, 6, 52, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3066591, 95793, 37, 0, 33, "Section"],
Cell[3066631, 95795, 426, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[3067082, 95806, 46, 0, 47, "Subsection"],
Cell[3067131, 95808, 163, 3, 52, "Text"],
Cell[3067297, 95813, 32, 0, 30, "Input"],
Cell[3067332, 95815, 32, 0, 30, "Input"],
Cell[3067367, 95817, 248, 6, 102, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3067652, 95828, 91, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[3067768, 95834, 34, 0, 30, "Input"],
Cell[3067805, 95836, 100, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3067942, 95845, 34, 0, 30, "Input"],
Cell[3067979, 95847, 82, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3068098, 95856, 34, 0, 30, "Input"],
Cell[3068135, 95858, 100, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3068272, 95867, 34, 0, 30, "Input"],
Cell[3068309, 95869, 102, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3068448, 95878, 34, 0, 30, "Input"],
Cell[3068485, 95880, 99, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3068621, 95889, 34, 0, 30, "Input"],
Cell[3068658, 95891, 90, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3068785, 95900, 34, 0, 30, "Input"],
Cell[3068822, 95902, 103, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3068962, 95911, 30, 0, 30, "Input"],
Cell[3068995, 95913, 66, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3069098, 95922, 32, 0, 30, "Input"],
Cell[3069133, 95924, 70, 4, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

